(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    121340,       4643]*)
(*NotebookOutlinePosition[    122691,       4686]*)
(*  CellTagsIndexPosition[    122647,       4682]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Dumping and Import Tariffs
European Union Rules\
\>", "Title"],

Cell["WIlfried Pauwels, Hylke Vandenbussche, Marcel Weverbergh", "Subtitle"],

Cell[BoxData[
    \(<< Utilities`CleanSlate`\)], "Input"],

Cell[CellGroupData[{

Cell["Definitions & Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CleanSlate[]\), 
    \(Off[General::spell1]\), 
    \(Off[General::spell]\), 
    \(Off[Solve::svars]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[
      \("contexts purged: "\[InvisibleSpace]{"Global`"}
          \[InvisibleSpace]"\n"\),
      SequenceForm[ "contexts purged: ", {"Global`"}, "\n"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("approximate kernel memory recovered: "\[InvisibleSpace]"0 Kb"\),
      SequenceForm[ "approximate kernel memory recovered: ", "0 Kb"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({"CleanSlate`", "Graphics`Animation`", "Global`", "System`"}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notation", "Section"],

Cell["\<\
X: quantity produced by home firm
y: quantity produced by foreign firm
w : quantiy on world market  (treated exogenously )
px : price of x
py : price of y
pw : world price\
\>", "DisplayText"],

Cell[CellGroupData[{

Cell["The Two Period Game", "Section"],

Cell["First Period", "Subsection"],

Cell["\<\
The Home firm and the Foreign firm decide on quantities (in the Cournot game)
Injury Margin (PX-PY) and Dumping Margin (PW-PY)  are observed.
The tariff is determined for the second period.
 It is equal to the smaller of Injury Margin (IM) and Dumping Margin (DM) \
provided both are positif.
Otherwise the tariff is zero.\
\>", "DisplayText"],

Cell["Second Period", "Subsection"],

Cell["\<\
Home firm and foreign firm decide on quantities, taking into account the \
tariff decided in period 1
The objective is to maximize the sum of profits over both periods.\
\>", "DisplayText"],

Cell["Solution criterion", "Subsection"],

Cell["\<\
We look for a (Cournot-) Nash equilibrium where profits for both firms ar\
\>", "DisplayText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumptions", "Section"],

Cell["\<\
The Home Company and the Foreign Company  determine quantities and observe \
prices
(Cournot Competition)
We look for a Two-period Subgame Perfect Nash Equilibrium\
\>", "DisplayText"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameter Values", "Section"],

Cell[BoxData[
    \(Parameters\  = 
      \ {\ a -> 10. , \ \ A -> 10.0, g -> 3.0/5, k -> 3.0/10, w -> 6, \ 
        h -> 10. , b -> 3. /5, l -> 2. /5}; \n
    BLspace\ \ \ \ \ \ \  = Drop[Parameters, \(-2\)]; \n
    BLHspace\ \ \ \ \  = \ Drop[Parameters, \(-3\)]; \nbxl\  = \ 0; \n
    bxh\  = \ 20; \nbyl\  = \ 0; \nbyh\  = \ 10; \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inverse Demand functions", "Section"],

Cell[BoxData[{
    \(f[x_, y_]\ \ \ \  := \ 
      h\ x\  - \ l\ x^2/2\ \  + \ a\ y\  - \ b\ y^2/2\  - \ 
        k\ x\ y\ \ \ \ \ \ \  (*\ Utility\ function\ \ *) \), 
    \(PX[x_, y_]\ \  := \ 
      D[f[x, y], x]
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Inverse\ Demand\ X\ \ *) \), 
    \(PY[x_, y_]\ \  := \ 
      D[f[x, y], y]
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Inverse\ Demand\ y\ \ *) \), 
    \(PW[w_]\ \ \ \ \ \ \ \ \  := \ 
      A\  - \ g\ w
          \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \  (*\ world\ price\ \ \ \ \ \ \ *) \ \ \ \ \ \ \ \ \ \ \ \ \), 
    \(CSH[x_, y_]\  := \ 
      f[x, y]\  - \ PX[x, y]\ x\  - \ 
        PY[x, y] y\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Consumer\ Surplus\ \ \ *) \), 
    \(px[x_, y_]\ \  = \ \ PX[x, y] /. Parameters; \n
    py[x_, y_]\ \  = \ \ PY[x, y] /. Parameters; \)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Injury margin and Dumping margin", "Section"],

Cell[BoxData[{
    \(IM[x_, y_]\ \ \ \ \ \ \ \ \  := \ \ PX[x, y]\  - \ PY[x, y]\), 
    \(IMPos[x_, y_]\ \  := \ 1/2\ IM[x, y]\ \((Sign[IM[x, y]] + 1)\)\), 
    \(DM[x_, y_, w_]\  := \ PW[w] - PY[x, y]\), 
    \(Tariff[x_, y_]\ \ \ \ \ \ \ \  := Max[0, Min[IM[x, y], DM[x, y, w]]]; \n
    deqi\ \ \ \ \ \ \ \ \ \ \ \ \  = \ 
      y1 -> \((y1 /. 
            Simplify[
              \((Solve[IM[x1, y1] == DM[x1, y1, w], y1] /. Parameters)\)[
                \([1]\)]])\); \n
    deqi2\ \ \ \ \ \ \ \ \ \  = \ 
      x1 -> \((x1 /. 
            Simplify[
              \((Solve[IM[x1, y1] == DM[x1, y1, w], x1] /. Parameters)\)[
                \([1]\)]])\); \)}], "Input"],

Cell[BoxData[
    \(NulIM\ \ \ \ \ \ \ \ \ \  = \ 
      y /. \(Solve[\ \ PX[x1, y] == PY[x1, y], y]\)[\([1]\)]; \n
    NulDM\ \ \ \ \ \ \ \ \ \  = \ 
      y /. \(Solve[\ \ PY[x1, y] == PW[w], y]\)[\([1]\)]; \n
    InterX\ \ \ \ \ \ \ \  = \ \ 
      x1 /. \(Solve[\ NulIM == NulDM, x1]\)[\([1]\)]; \n
    IntersectID\ \  = \ {InterX, \ NulIM /. x1 -> InterX} /. Parameters; \n
    nuldm\  = \ 
      Line[{IntersectID, {bxl, \(NulDM /. x1 -> bxl\) /. Parameters}}]; \n
    nulim\ \  = 
      Line[{IntersectID, {bxh, \(NulIM /. x1 -> bxh\) /. Parameters}}]; \n
    ideq\ \ \ \ \  = \ 
      Line[{IntersectID, {bxl, 
            \(\(y1 /. deqi\) /. x1 -> bxl\) /. Parameters}}]; \)], "Input"],

Cell[BoxData[
    \(IntersectDY\  = 
      \ {bxl + 0.1, \(NulDM /. x1 -> bxl + 0.1\) /. Parameters}; \n
    IntersectXY\  = \ {bxl +  .1, byh - 0.1}; \n
    IntersectEY\  = 
      \ {\(\(x1 /. deqi2\) /. y1 -> byh - 0.1\) /. Parameters, byh - 0.1}; \n
    IntersectIY\  = 
      \ {bxh - 0.1, \(NulIM /. x1 -> bxh - 0.1\) /. Parameters}; \n
    r1\  = \ Graphics[{\ GrayLevel[0.9], 
          Polygon[{IntersectID, IntersectDY, IntersectXY, IntersectEY}]}]; \n
    r2\  = \ Graphics[{\ GrayLevel[0.6], 
          Polygon[{IntersectID, IntersectEY, {bxh - 0.1, byh - 0.1}, 
              IntersectIY}]}]; 
    CenterDM\  = 
      \ {\((bxl + IntersectID[\([1]\)])\)/3, 
        \((byh + IntersectID[\([2]\)])\)/2}\ ; \n
    CenterIM\  = 
      \ {\((bxh + IntersectID[\([1]\)])\)/3, 
        \((byh + IntersectID[\([2]\)])\)/2}\ ; \n
    t1\  = \ Text["\<IM\>", CenterIM, 
        TextStyle -> {FontSlant -> "\<Italic\>", \ FontSize -> 20}]; \n
    t2\  = \ Text["\<DM\>", CenterDM, 
        TextStyle -> {FontSlant -> "\<Italic\>", \ FontSize -> 20}]; \)], 
  "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the Injury Regime and Dumping Regime Regions", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plot\  = \ 
      Plot[{0}, {x1, bxl, bxh}, PlotRange -> {{bxl, bxh}, {byl, byh}}, \ 
        PlotLabel -> "\<Dumping and Injury Margin Tariff Regions\>", 
        \ \ \ \ \ \ \ \ \n\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        Epilog -> {nuldm, nulim, ideq, t1, t2}, 
        FrameLabel -> {"\<x1\>", "\<y1\>"}, Frame -> True, 
        DisplayFunction -> Identity]; \n
    Show[{plot, r1, r2}, DisplayFunction -> $DisplayFunction]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.05 0 0.0618034 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -21.5 ]
[.5 -0.0125 8 -9 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5 -8 ]
[-0.01875 .30902 -12 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -122.094 0 ]
[.5 .63053 122.094 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.125 0 m
.125 .00625 L
s
[(2.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(7.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(12.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(17.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -25.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x1) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -87.25 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.25 translate
90 rotate
-69 -10.25 translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y1) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -183.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Dumping) show
111.000000 12.750000 moveto
(and) show
135.000000 12.750000 moveto
(Injury) show
177.187500 12.750000 moveto
(Margin) show
219.187500 12.750000 moveto
(Tariff) show
261.187500 12.750000 moveto
(Regions) show
303.187500 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.04057 0 L
.08481 0 L
.12636 0 L
.16632 0 L
.20885 0 L
.2498 0 L
.29331 0 L
.33524 0 L
.37557 0 L
.41848 0 L
.4598 0 L
.49953 0 L
.54183 0 L
.58254 0 L
.62583 0 L
.66752 0 L
.70762 0 L
.7503 0 L
.79139 0 L
.83505 0 L
.87712 0 L
.9176 0 L
.96065 0 L
1 0 L
s
.9 g
.36 .14833 m
.005 .36773 L
.005 .61185 L
.07875 .61185 L
F
.6 g
.36 .14833 m
.07875 .61185 L
.995 .61185 L
.995 .40996 L
F
0 g
.36 .14833 m
0 .37082 L
s
.36 .14833 m
1 .41202 L
s
.36 .14833 m
0 0 rlineto s
.36 .14833 m
.075 .61803 L
s
gsave
.45333 .38318 -75.875 -15.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.9375 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 27.937500 moveto
 457.000000 27.937500 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 27.937500 lineto
closepath
clip newpath
63.000000 21.562500 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
/Courier-Italic findfont 20.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 21.562500 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
/Courier-Italic findfont 20.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(IM) show
88.750000 21.562500 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
/Courier-Italic findfont 20.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Italic
grestore
gsave
.12 .38318 -75.875 -15.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 31.9375 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 27.937500 moveto
 457.000000 27.937500 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 27.937500 lineto
closepath
clip newpath
63.000000 21.562500 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
/Courier-Italic findfont 20.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 21.562500 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
/Courier-Italic findfont 20.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(DM) show
88.750000 21.562500 moveto
%%IncludeResource: font Courier-Italic
%%IncludeFont: Courier-Italic
/Courier-Italic findfont 20.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Italic
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 154.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003j0000VPP10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3ooooooo[_003jk`00n^l00?[_003jk`00Mnl00`3_
k`0607[_001hk`800nl00`3_k`1jk`00N>l200?_00<0knl0N^l007O_00@0knl00^l00`3_k`1jk`00
ONl00`3_k`1jk`00O>l207c_003jk`00n^l0033_0`03k`030>o_00;_00<0knl03nl00`3_k`0?k`03
0>o_00;_00<0knl00^l00`3_k`0;k`D00^l00`3_k`08k`D000C_00000nl00`3_k`02k`030>o_00S_
1@02k`030>o_00W_1@02k`030>o_00;_00<0knl00^l00`3_k`09k`<00nl00`3_k`0Lk`00<>l00`3_
k`07k`030>l000o_00<0k`004>l00`3_k`06k`030>l000k_00L0kno_0>l000__00D0kno_0009k`03
0>l000__00L0kno_0>l000c_00<0knl00^l00`3_k`06k`030>l000[_00<0knl00^l00`3_000Mk`00
<Nl00`3_k`08k`030>o_00o_00<0knl03^l00`3_k`08k`030>o_00c_00L0kno_0>l000__00<0knl0
0^l00`3_k`08k`030>o_00W_00<0knl00nl00`3_k`0:k`030>o_00;_00<0knl02>l00`3_k`09k`07
0>o_k`3_000Mk`00<Nl00`3_k`06k`804>l201;_00<0knl01Nl200o_00L0kno_0>l000__00<0knl0
0^l00`3_k`06k`803>l0103_knl200g_00<0knl00nl00`3_k`05k`803>l01`3_knl0k`007Nl0033_
00<0k`001nl00`3_k`0?k`030>o_00o_00<0k`001nl00`3_k`0>k`070>o_k`3_000;k`070>o_k`3_
0007k`030>o_00__00D0kno_000>k`070>o_k`3_0007k`030>o_00[_00<0k`000^l00`3_000Mk`00
<Nl00`3_k`06k`<03nl300o_0`07k`<03Nl200C_00<0knl02Nl200C_00<0knl01^l300[_0P03k`<0
2nl200?_0`07k`<02nl00`3_k`02k`030>o_01c_003jk`00n^l00?[_003jk`00n^l001o_^`0Pk`00
7nl00`3_k`02k`050>o_k`001>l00`3_k`02k`050>o_k`001>l00`3_k`02k`050>o_k`001>l00`3_
k`02k`050>o_k`001>l01@3_knl000C_00<0knl00^l01@3_knl000C_00<0knl00^l01@3_knl000C_
00<0knl00^l01@3_knl000C_00<0knl00^l01@3_knl000C_00<0knl00^l01@3_knl000C_00D0kno_
0004k`030>o_00;_00D0kno_0004k`030>o_00;_00D0kno_0004k`030>o_00;_00D0kno_0004k`03
0>o_01k_000Ok`030>o_0;O_00<0knl07^l001o_00<0knl0]nl00`3_k`0Nk`007nl00`3_k`2gk`03
0>o_01k_000Ok`030>o_0;O_00<0knl07^l001o_0P2gk`808>l001o_00<0knl0]nl00`3_k`0Nk`00
7nl00`3_k`2gk`030>o_01k_000Ok`030>o_0;O_00<0knl07^l001o_00<0knl0]nl00`3_k`0Nk`00
7nl20;O_0P0Pk`007nl00`3_k`2gk`030>o_01k_000Ok`030>o_0;O_00<0knl07^l001o_00<0knl0
]nl00`3_k`0Nk`007nl00`3_k`2gk`030>o_01k_000Ok`030>o_0;O_00<0knl07^l001o_0P2gk`80
8>l001o_00<0knl0]nl00`3_k`0Nk`007nl00`3_k`2gk`030>o_01k_000Ok`030>o_0;O_00<0knl0
7^l001W_0`03k`030>o_0;O_00<0knl07^l001W_00<0knl00nl00`3_k`2gk`030>o_01k_000Jk`03
0>o_00;_0P2gk`808>l001[_00<0knl00^l00`3_k`2gk`030>o_01k_000Ik`030>l000?_00<0knl0
]nl00`3_k`0Nk`006^l00`3_k`02k`030>o_0;O_00<0knl07^l001o_00<0knl0@>l207G_00<0knl0
7^l001o_00<0knl0?^l200:90P1ck`030>o_01k_000Ok`80?^l00`2d0004R@<0Knl2023_000Ok`03
0>o_03__0P000ol0R@07R@80K^l00`3_k`0Nk`007nl00`3_k`0ik`800_l00k@0R@09R@80K>l00`3_
k`0Nk`007nl00`3_k`0hk`030?oo00:d00<0RHT02hT306W_00<0knl07^l001o_00<0knl0=^l20005
okBdo`004HT206O_00<0knl07^l001o_0P0fk`040?nd]0;o00>d08T04XT306?_0P0Pk`007nl00`3_
k`0ck`800[@2o`:d00<0RHT05HT206;_00<0knl07^l001o_00<0knl0<Nl200:d0ol01;Coo`0IR@<0
Gnl00`3_k`0Nk`007nl00`3_k`0`k`030;Bd00;o0[@2o`03]02901^900?_0000GNl00`3_k`0Nk`00
7nl00`3_k`0^k`8000>dool00[@2o`:d00<0RHT07XT205__00<0knl07^l001o_00<0knl0;Nl0102d
ool2]0;o0[@2o`0308V902290`1Hk`030>o_01k_000Ok`80;>l200;o0[@2o`:d0_l00k@0R@0UR@80
ENl2023_000Ok`030>o_02W_0P02o`:d0_l2]0;o0[@00ol0R@0WR@<0Dnl00`3_k`0Nk`007nl00`3_
k`0Xk`030?oo00:d0_l2]0;o0[@2o`0308V902V900?_0000DNl00`3_k`0Nk`007nl00`3_k`0Vk`80
00?o];@00_l2]0;o0[@2o`03]02902j90`1>k`030>o_01k_000Jk`<00^l00`3_k`0Uk`040?oo]0;o
0[@3o`03]?oo00:d00?o08T0<8T00nl0001<k`030>o_01k_000Kk`050>o_k`009Nl200:d0_l2]0;o
0[@2o`:d0_l00`29R@0cR@80B^l00`3_k`0Nk`006Nl400;_0P0Rk`800[@2o`:d0_l2]0;o0[@2o`:d
00<0RHT0=HT304K_0P0Pk`006Nl00`3_0003k`030>o_023_00<0];@00_l2]0;o0[@2o`:d0_l2]003
o`2903V900?_0000ANl00`3_k`0Nk`006^l200?_00<0knl07^l20003]?oo00:d0_l2]0;o0[@2o`:d
0_l00`29R@0lR@<0@^l00`3_k`0Nk`006nl01@3_knl001o_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d
00<0RHT0?XT00nl00010k`030>o_01k_000Ok`030>o_01__0P02o`:d0_l2]0;o0[@2o`:d0_l2]003
o`2904>90`0mk`030>o_01k_000Ok`030>o_01W_0P02o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0
AHT00nl0000kk`030>o_01k_0008k`030>o_01C_0P0Ik`030?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]02904V90P0hk`808>l000S_0P03k`030>o_00o_00<0knl05^l20003okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d00?o08T0C8T303K_00<0knl07^l000S_00@0k`3_0P0Ak`030>o_01G_00@0okBd
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02904j900?_0000=>l00`3_k`0Nk`002nl00`3_k`0Ak`03
0>o_01?_0P02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V905690`0ak`030>o_01k_0008k`<0
5>l00`3_k`0Ak`800[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V905>900?_0000;nl00`3_
k`0Nk`002>l00`3_k`0Dk`804Nl00`2d]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02905R9
0`0[k`808>l001o_00<0knl03^l20003]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT0
FXT00nl0000Zk`030>o_01k_000;k`030>o_017_00<0knl03Nl0102dool2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00<0RHT0G8T00nl0000Xk`030>o_01k_0006k`030>o_00;_00<0knl04Nl00`3_
k`0;k`800ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol01KCook@006:90`0Uk`030>o_01k_
0006k`H04nl00`3_k`09k`800_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@1SR@03
k`0002?_00<0knl07^l000__00<0knl04Nl00`3_k`08k`030?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00<0RHT0IXT3023_00<0knl07^l000__00<0knl04Nl200O_0P000ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0R@1ZR@03k`0001g_0P0Pk`007nl00`3_k`05k`04
0?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?o08T0K8T01>l0000Kk`030>o_01k_
000Ok`030>o_00?_0P02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@1_R@03
k`0001W_00<0knl07^l001o_00@0kno_0P02]0;o00>d00001P000kCo000400:d0_l50003]?oo00:d
0_l2]00308V901^91`000hT0000300B91@10R@03k`0001O_00<0knl07^l001W_0P04k`040>o_00:d
0_l2]0;o00@0]?oo0[@01_l0];Co00:d0_l2]0;o00@0]?oo0[@2o`:d00?o08T088T00`29R@04R@03
08V900J900<0RHT0@hT301C_00<0knl07^l001W_00<0k`000nl30003]?oo00:d0ol00kCo0002]0?o
00>d0?l00[@0103ook@2o`:d00Co0?nd0_l2]0;o00<0RHT08HT00`29R@04R@0308V900J900<0RHT0
A8T00nl0000Bk`030>o_01k_000Ik`030>l000?_00@0]?oo0[@2o`:d0_l01;@0ool2]0;o00Jd0?oo
0;@2o`:d0_l01;@0ool2]0;o0[@00`29R@0QR@0308V900B900<0RHT01XT00`29R@16R@04k`0000k_
0P0Pk`006Nl200C_00@0okBd0_l2]0;o0[@01?l0];@2o`:d00Ko0;Bd0?l2]006o`2d]?l00[@2o`:d
00?o08T08hT00`29R@04R@0308V900:900D0RHV9001;R@03k`0000g_00<0knl07^l001W_00<0knl0
0nl0102dool2]0;o0[@2o`04]03oo`:d0_l2]0040?l0]0;o00Jd003o]002o`:d0_l00`29R@0SR@03
08V900B900<0RHT00XT200:900<0RHT0BhT01>l0000:k`030>o_01k_000Jk`800nl0103o];@2o`:d
0_l2]0;o00@0]?oo0[@2o`040;Co00:d00@0ok@00_l0102dool2]00308V902B900<0RHT018T01029
R@02R@0408V904n900?_00002>l00`3_k`0Nk`007nl0102dool2]0;o0[@2o`:d00@0okBd0_l2]004
0?nd00;o00@0]?l00[@01P3o];Co02N900<0RHT018T01029R@02R@0408V9056900?_00001^l00`3_
k`0Nk`007nl0103o];@2o`:d0_l2]0;o00@0]?oo0[@2o`040;Co00:d00P0okBd0?l0]0;o00>d08T0
9XT00`29R@04R@0408V900>900<0R@00DhT01>l00002k`808>l001o_00@0]?oo0[@2o`:d0_l2]004
0?nd]0;o0[@0203o];@0o`2d0_l0102do`02]00308V902J900<0RHT01HT00`290003R@0408V905F9
00G_003_000Pk`007nl0103ook@2o`:d0ol01KCook@000?o00>do`000[@2o`040;@0o`:d00Ko0?l0
o`0ZR@0308V900B900<0R@0018T00`29001HR@808>l001o_00@0]?oo0[@2o`:d0_l2]0L000>dool0
1002]0;o0[@402N91`000hT0000200J9101FR@03k`3_01o_000Ok`040?nd]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT0TXT00nl0k`0Ok`007nl0102dool2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`0308V909:900?_0>l07nl001o_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>d08T0U8T2023_000Ok`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]00308V909B900?_0>l07nl001o_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
00<0RHT0U8T00nl0k`0Ok`007nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0
UXT00nl0k`0Ok`007nl0103ook@2o`:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d00?o08T0
UXT00nl0k`0Ok`007nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0UXT00nl0
k`0Ok`007nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02909R90P0Pk`007nl0102d
ool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003o`2909R900?_0>l07nl001o_00@0okBd0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@2HR@03k`3_01o_000Ok`040;Coo`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00<0RHT0V8T00nl0k`0Ok`006^l00`3_k`02k`040?nd]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]003o`2909Z900?_0>l07nl001W_00<0k`000nl0102dool2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00`29R@2JR@03k`3_01o_000Ik`030>l000?_00@0oond0_l2]0?o00>dool00[@3o`03
]?oo00:d0ol00k@0R@2KR@808>l001[_00<0knl00^l0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?o08T0W8T00nl0k`0Ok`006Nl00`3_0003k`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0
R@2LR@03k`3_01o_000Jk`030>o_00;_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V909b9
00?_0>l07nl001o_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@2NR@03k`3_01o_000Ok`04
0;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0WXT2023_000Ok`040?nd]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00<0RHT0WXT00nl0k`0Ok`007nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V909j9
00?_0>l07nl001o_00@0oond0_l2]0?o00>dool00[@3o`05]?oo]000XHT00nl0k`0Ok`007nl0102d
ool2]0;o0[@2o`:d0_l2]0;o0[@00`29R@2PR@03k`3_01o_000Ok`040?nd]0;o0[@2o`:d0_l2]0;o
0[@2o`0308V90:2900?_0>l07nl001o_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`03]0290::90P0Pk`00
7nl0103o];@2o`:d0_l2]0;o0[@2o`:d00?o08T0XXT00nl0k`0Ok`007nl0102dool2]0;o0[@2o`:d
0_l2]0;o00<0RHT0XXT00nl0k`0Ok`007nl0103o];@2o`:d0_l2]0;o0[@2o`03]0290:B900?_0>l0
7nl001o_00@0]?oo0[@2o`:d0_l2]0;o0[@00ol0R@2TR@03k`3_01o_000Ok`040?oo]0;o0[@3o`03
]?oo00:d0_l00`29R@2TR@03k`3_01o_000Ok`040;Coo`:d0_l2]0;o0[@2o`:d00<0RHT0Y8T2023_
000Ok`040?nd]0;o0[@2o`:d0_l2]003o`290:J900?_0>l07nl001o_00@0]?oo0[@2o`:d0_l2]0;o
00<0RHT0YXT00nl0k`0Ok`007nl0103o];@2o`:d0_l2]0;o0[@00`29R@2VR@03k`3_01o_000Ck`D0
0^l00`3_k`02k`040;Coo`:d0_l2]0;o0[@00ol0R@2XR@03k`3_01o_000Ek`070>o_k`3_0003k`04
0?nd]0;o0[@2o`:d0_l00k@0R@2XR@03k`3_01o_000Ek`070>o_k`3_0003kk/08>l001G_00L0kno_
0>l00=k_000Ek`070>o_k`3_003Nk`005>l200C_00<0knl0gNl00?[_000Ck`<03^l2037_0`0<k`80
7nl204g_0P0Rk`005>l00`3_k`0?k`030>o_033_00<0knl02nl00`3_k`0Ok`030>o_04c_00<0knl0
7nl000C_1003k`@000G_0>l0k`0300;_0`000nl00002k`030>o_00<03^l600;_00<0knl00`0:k`<0
00?_00000^l01@3_knl000?_0`001>l00003k`030>o_00c_0P001>l00>l40004k`0000?_0`001Nl0
003_00800^l00`3_k`0;k`<00^l40004k`0000;_0`02k`<00^l300g_0`001>l0knl200?_0`001>l0
0003k`8000?_00000^l0103_000?k`001Nl01P3_k`3_00;_0P001^l0k`3_00;_00@0knl00nl01P3_
k`3_00;_00<0knl03>l300;_00H0knl0k`02k`030>o_00W_00D0kno_0002k`050>o_k`000^l0103_
k`02k`070>o_k`3_000=k`060>o_k`3_0`03k`050>o_k`000^l0103_k`03k`040>o_00k_00@0kno_
0`03k`030>o_00;_00<0knl00^l00`3_k`02k`030>o_00g_00H0knl0k`04k`040>o_00;_00D0kno_
0002k`030>l000;_00D0kno_000>k`001Nl01P3_k`3_00;_0P001^l0k`3_00;_00@0knl00nl01P3_
k`3_00;_00<0knl03^l0103_k`02k`030>l000;_00<0knl02Nl01@3_knl000;_00D0kno_0002k`04
0>o_00;_00L0kno_0>l000g_00D0k`3_0003k`050>o_k`000nl0103_k`02k`050>o_k`000^l00`3_
k`0<k`030>o_00?_00D0kno_0004k`030>o_00;_00<0knl00^l00`3_k`0=k`<00^l300;_00@0knl0
0^l01@3_knl000;_00<0k`000^l0103_k`0?k`001Nl00`3_k`030003k`00008000?_0>l01002k`80
0^l400?_0`0?k`8000?_00000P03k`<02nl00`3_k`0400;_0`001>l00>l20003k`0000@000?_0000
3>l20003k`0000;_0P02k`@00^l30003k`0000;_100?k`030>o_00;_0P02k`@000?_00000nl300;_
0`0>k`050>o_0>l00`03k`<000?_00001>l20003k`0000800nl200k_0005k`040>o_03W_00<0knl0
2Nl00`3_k`0Uk`8000?_00009Nl01@3_0>l0017_00<0knl00^l00`3_k`0=k`040>o_02__0004k`@0
4^l00`3_k`0Tk`802^l300S_00<0knl06nl20003k`00017_00<0knl04Nl500c_00<0knl00nl00`3_
k`02k`030>o_00__100=k`030>o_01c_003jk`00n^l00001\
\>"],
  ImageRangeCache->{{{0, 249}, {153.5, 0}} -> {-3.39883, -2.07425, 0.107621, 
  0.0870673}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["No Protection: Nash-Cournot (quantity game)", "Section"],

Cell[CellGroupData[{

Cell["Profit functions", "Subsection"],

Cell[BoxData[{
    \(HprofC[x_, y_]\ \  := \ PX[x, y]\ x\), 
    \(FprofC[x_, y_]\  := \ PY[x, y]\ y\ \ \ \  - \ t\ y\ \ \ \ \ \ \  (*\ 
      profits\ from\ foreign\ operations\ are\ not\ relevant*) \)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reaction Functions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NPRxC\  := \ Solve[D[HprofC[x, y], x] == 0, y]\), 
    \(NPRyC\  := \ Solve[D[FprofC[x, y] /. t -> 0, y] == 0, y]\), 
    \(nprxc\  = \ \(Simplify[NPRxC /. Parameters]\)[\([1]\)]\), 
    \(npryc\  = \ \(Simplify[NPRyC /. Parameters]\)[\([1]\)]\)}], "Input"],

Cell[BoxData[
    \({y \[Rule] 
        \(33.3333333333333392`\[InvisibleSpace]\) - 2.66666666666666696`\ x}
      \)], "Output"],

Cell[BoxData[
    \({y \[Rule] \(8.33333333333333392`\[InvisibleSpace]\) - 0.25`\ x}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equilibrium quantities", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(NPNashC\  = \ 
      \(Solve[{D[HprofC[x, y], x] == 0, D[FprofC[x, y] /. t -> 0, y] == 0}, {
            x, y}]\)[\([1]\)]; \nNPNashC /. Parameters\), 
    \(\(HprofC[x, y] /. NPNashC\) /. Parameters\), 
    \(\(\(FprofC[x, y] /. NPNashC\) /. Parameters\) /. t -> 0\)}], "Input"],

Cell[BoxData[
    \({x \[Rule] 10.3448275862068972`, y \[Rule] 5.74712643678160883`}\)], 
  "Output"],

Cell[BoxData[
    \(42.8061831153388805`\)], "Output"],

Cell[BoxData[
    \(19.8176773682124469`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphical solution", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NPN\  = \ 
      Plot[\ {\((y /. nprxc)\), \((y /. npryc)\)}, {x, bxl, bxh}, 
        PlotRange -> {{bxl, bxh}, {byl, byh}}, DisplayFunction -> Identity]; 
    \nShow[{NPN, r1, r2, NPN}, DisplayFunction -> $DisplayFunction]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.05 0 0.0618034 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.125 0 m
.125 .00625 L
s
[(2.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(7.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(12.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(17.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
.9 g
.36 .14833 m
.005 .36773 L
.005 .61185 L
.07875 .61185 L
F
.6 g
.36 .14833 m
.07875 .61185 L
.995 .61185 L
.995 .40996 L
F
0 g
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 154.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003j0000VPP10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3ooooooo[_000Wk`<00nl00`3_k`02k`030>o_01?_
00<0knl05>l00`3_k`02k`030>o_00;_00<0knl03nl500;_00<0knl03Nl50004k`0000?_00<0knl0
0^l00`3_k`0=k`D00^l00`3_k`0=k`D00^l00`3_k`02k`030>o_00;_00<0knl03Nl300?_00<0knl0
1^l002O_00<0knl01nl00`3_000Ck`030>l001G_00<0knl01^l00`3_000Bk`070>o_k`3_000@k`05
0>o_k`002Nl00`3_000@k`070>o_k`3_000@k`030>o_00;_00<0knl01^l00`3_000>k`030>o_00;_
00<0k`001nl002S_00<0knl02>l00`3_k`0Ck`030>o_01?_00<0knl02>l00`3_k`0@k`070>o_k`3_
000@k`030>o_00;_00<0knl02>l00`3_k`0>k`030>o_00?_00<0knl03^l00`3_k`02k`030>o_00S_
00<0knl03Nl01`3_knl0k`001nl002S_00<0knl01^l201C_0P0Gk`030>o_00G_0P0Ck`070>o_k`3_
000@k`030>o_00;_00<0knl01^l2017_00@0kno_0P0Ak`030>o_00?_00<0knl01Nl2013_00L0kno_
0>l000O_000Wk`030>l000O_00<0knl04nl00`3_k`0Dk`030>l000O_00<0knl04^l01`3_knl0k`00
4>l01`3_knl0k`001nl00`3_k`0@k`050>o_k`004^l01`3_knl0k`001nl00`3_k`0>k`030>l000;_
00<0k`001nl002S_00<0knl01^l301?_0`0Dk`<01nl3017_0P04k`030>o_00k_0P04k`030>o_00K_
0`0?k`800nl300o_0P03k`<01nl300o_00<0knl00^l00`3_k`06k`00n^l00?[_003jk`00n^l00?[_
000Akml02^l0017_00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00nl00`3_k`02k`030>o_00?_
00<0knl00^l00`3_k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00nl00`3_
k`02k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00?_
00<0knl00^l00`3_k`03k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00;_00<0knl00nl00`3_
k`02k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00;_
00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00^l00`3_k`08k`004Nl00`3_k`27k`030>o_05c_
000Ak`030>o_08O_00<0knl0G>l0017_00<0knl0Qnl00`3_k`1Lk`004Nl00`3_k`27k`030>o_05c_
000Ak`030>o_08K_00<0knl0GNl0017_0P27k`030>o_05g_000Ak`030>o_08K_00<0knl0GNl0017_
00<0knl0QNl00`3_k`1Nk`004Nl00`3_k`25k`030>o_05k_000Ak`030>o_08G_00<0knl0G^l0017_
00<0knl0QNl00`3_k`1Nk`004Nl208G_00<0knl0Gnl0017_00<0knl0Q>l00`3_k`1Ok`004Nl00`3_
k`24k`030>o_05o_000Ak`030>o_08?_00<0knl0H>l0017_00<0knl0Pnl00`3_k`1Pk`004Nl00`3_
k`23k`030>o_063_000Ak`030>o_08;_00<0knl0HNl0017_0P23k`030>o_067_000Ak`030>o_08;_
00<0knl0HNl0017_00<0knl0P^l00`3_k`1Qk`004Nl00`3_k`21k`030>o_06;_000Ak`030>o_087_
00<0knl0H^l000__0`03k`030>o_087_00<0knl0H^l000__00<0knl00nl00`3_k`20k`030>o_06?_
000<k`030>o_00;_0`20k`030>o_06?_000<k`030>o_00;_00<0knl0P>l00`3_k`1Sk`002nl00`3_
0003k`030>o_083_00<0knl0Hnl000c_00<0knl00^l00`3_k`1ok`030>o_06C_000Ak`030>o_07o_
00<0knl0I>l0017_00<0knl0Onl00`3_k`1Tk`004Nl00`3_k`1nk`030>o_06G_000Ak`80CNl3RBo_
00<0knl0INl0017_00<0knl0B^l00ondR@04RBg_00<0knl0INl0017_00<0knl0B>l00ond]009RBW_
00<0knl0I^l0017_00<0knl0Anl2]0;o2hTWk`030>o_06K_000Ak`030>o_04G_0[@2o`03]8V900b9
9Nl00`3_k`1Vk`004Nl00`3_k`13k`:d0_l2]1:98^l00`3_k`1Vk`004Nl00`3_k`12k`05]?oook@0
0_lDRAo_00<0knl0Inl0017_0P11k`03]?oo00:d0_l00kB9R@0FRAc_00<0knl0Inl0017_00<0knl0
?nl2o`:d0_l2]003ohV901R96^l00`3_k`1Wk`004Nl00`3_k`0mk`;o0[@2o`:d0_lNRAK_00<0knl0
J>l0017_00<0knl0>nl2o`:d0_l2]0;o00>dRHT07hTDk`030>o_06S_000Ak`030>o_03[_00?o];@0
0_l2]0;o0[@00on9R@0QRA;_00<0knl0J>l0017_00<0knl0>>l00ond]002o`:d0_l2]0;o9hT>k`03
0>o_05g_0P0:k`004Nl00`3_k`0fk`03okBd00;o0[@2o`:d0_l2]2V93>l00`3_k`1Ik`@03>l0017_
0P0fk`04okCoo`:d0ol00kCoo`02]003ohV902^92Nl00`3_k`1Ek`@04>l0017_00<0knl0<nl2]0;o
0[@2o`:d0_l2]0;o<8T7k`030>o_05;_0`0Dk`004Nl00`3_k`0ak`:d0_l2]0;o0[@2o`:d0_l2]3>9
0nl00`3_k`1?k`@05nl0017_00<0knl0<>l00kCoo`02]0;o0[@2o`:d0_l2]003ohV903B900?_0>l0
CNl301__000Ak`030>o_02k_00>dool00[@2o`:d0_l2]0;o0[@2o`03]8V903F900<0knl0BNl301k_
000<k`<00^l00`3_k`0/k`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]3N900<0RHT00XU5k`<08Nl000g_
00D0kno_000]k`;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0=XT00`29R@04RD3_0`0Tk`002nl400;_
0`0Yk`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0fR@0308V900N9>^l302O_000;k`030>l000?_
00<0knl09nl2o`:d0ol00kCoo`02]0?o00>dool00[@3o`03]8V903J900<0RHT02XTek`<0:^l000c_
0P03k`030>o_02K_00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2ocR900<0RHT03HT_k`<0;Nl000g_
00D0kno_000Vk`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0gR@0308V900n9:^l3033_
000Ak`030>o_02?_0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@jR@0308V901699>l403?_000Ak`03
0>o_027_0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ocV900<0RHT05HTNk`<0=nl0017_00<0knl0
7nl2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0>8T00`29R@0GRAW_0`0jk`004Nl201o_
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0hR@0308V901Z94nl303g_000Ak`03
0>o_01c_00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ocZ900<0RHT07HT>k`<0@>l0017_
00<0knl06^l01KCooond00;o0[@3o`03]?oo00:d0ol00kCoo`02]0?o00Bdoond>hT00`29R@0PR@S_
0`13k`004Nl00`3_k`0Ik`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0>HT00`29
R@0RR@;_1016k`004Nl00`3_k`0Gk`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lkR@03
08V902:90`000hW_k`17k`004Nl00`3_k`0Ek`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]3^900<0RHT07XT400J9Anl0017_0P0Ek`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?oRHT0>XT00`29R@0JR@@038U5k`004Nl00`3_k`0Bk`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_llR@0308V901R90`0CRD;_000Ak`030>o_013_00?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d?8T00`29R@0DR@@068U0k`004Nl00`3_k`0?k`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0>hT00`29R@0AR@<07hTmk`00
4Nl00`3_k`0=k`04okCoo`:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
?8T00`29R@0?R@<098Tkk`004Nl00`3_k`0;k`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]3f900<0RHT038T302Z9>>l0017_00<0knl02^l00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV903b900<0RHT02HT302n9=^l0017_0P09k`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0kR@0308V900N90`0dRCC_
000Ak`030>o_00O_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@nR@03
08V900B90`0jRC7_000Ak`030>o_00G_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2ocj900@0RHV90`0oRBo_000Ak`030>o_00?_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V903f91015RBc_000Ak`030>o_00;_00?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@mR@@0BXTZk`002nl200C_00@0knoo
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
>XT300:900<0RHT0C8TWk`002nl00`3_0003k`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0fR@<01HT00`29R@1>RBG_000;k`030>l000?_00@0]?oo
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV903>90`07R@03
08V905698nl000__0P04k`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_lbR@@02XT00`29R@1DRB3_000;k`030>o_00?_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0]R@@03XT00`29R@1FRAk_000<k`800nl0103o
];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV902V9100AR@03
08V905Z96nl0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_lYR@<05HT00`29R@1LRAW_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V902F90`0HR@0308V905n95^l0017_00@0]?oo0[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]003ohV902:90`0JR@0308V906:95>l0017_
00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o8XT301f900<0RHT0
I8TBk`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@OR@<0
88T00`29R@1WR@o_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@00on9R@0KR@<08XT00`29R@1[R@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lKR@<09HT00`29R@1[R@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@GR@@0:8T00`29R@1[R@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT04hT302^900<0RHT0K8T<k`004Nl0103o];@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V901290`0^R@0308V906b93>l0017_
00@0]?oo0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kB9R@0>R@<0
<HT00`29R@1/R@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ohV900b90`0cR@0308V906f93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT02HT303J900<0RHT0KHT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@9R@<0>HT00`29R@1]R@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`J90`0lR@0308V906f93>l0017_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V900:90`0nR@0308V906j93>l0017_00@0]?oo0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003R@000080@HT00`29R@1^R@c_000Ak`040?nd]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]0000080AHT00`29R@1^R@c_000Ak`040;Coo`:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d00?o00000P000ondR@15R@0308V906n93>l0017_00@0okBd
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]000008000>dool00[@00on9R@14R@0308V906n93>l0017_
00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l30003okBd00;o0[@2odN900<0RHT0KhT<k`004Nl0103o
];@2o`:d0_l2]0;o0[@2o`:d00Co00000_l2]0;o0[@2o`03]8V904F900<0RHT0L8T<k`003>l00`3_
k`02k`040;Coo`:d0_l2]0;o0[@2o`:d0`000kCoo`02]0;o0[@2o`:d00?oRHT0AHT00`29R@1`R@c_
000;k`030>l000?_00@0okBd0_l2]0;o0[@2o`04]00000:d0_l2]0;o0[@2o`:d0_m8R@0308V90729
3>l000__00<0k`000nl0102dool2]0;o0[@00ol000020003okBd00;o0[@2o`:d0_l2]0;o0[A7R@03
08V907693>l000c_00<0knl00^l0103o];@2o`:d0`000kCoo`02]0;o0[@2o`:d0_l2]0;o0[@00on9
R@16R@0308V907693>l000__00<0k`000nl01@2doond00<000Co]?oo0[@3o`03]?oo00:d0ol00kCo
o`02]0;oBHT00`29R@1aR@c_000<k`030>o_00;_00<0o`000P000ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[A8R@0308V907:93>l0017_0P02o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
AhT00`29R@1bR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0AhT00`29
R@1bR@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dBXT00`29R@1bR@c_000Ak`04
0?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV904R900<0RHT0LhT<k`004Nl0102dool2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@18R@0308V907>93>l0017_00@0okBd0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:dBhT00`29R@1cR@c_000Ak`040;Coo`:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo04Z900<0RHT0M8T<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0BHT00`29
R@1dR@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[A<R@0308V907B93>l0017_00@0okBd
0_l2]0;o0[@2o`:d0_l2]0;o0[@2od^900<0RHT0MHT<k`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]8V904Z900<0RHT0MHT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV904Z9
00<0RHT0MHT<k`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2odf900<0RHT0MHT<k`004Nl0103o
];@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@1;R@0308V907J93>l0017_00@0]?oo0[@3o`03]?oo00:d
0ol00kCoo`02]003ohV904^900<0RHT0MXT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_m>R@03
08V907J93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:dCXT00`29R@1fR@c_000Ak`040?nd]0;o
0[@2o`:d0_l2]0;o0[@00on9R@1<R@0308V907N93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2odn9
00<0RHT0MhT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:dChT00`29R@1gR@c_000Ak`040;Coo`:d
0_l2]0;o0[@2o`:d00?oRHT0CXT00`29R@1gR@c_0005k`D00^l00`3_k`02k`040?nd]0;o0[@2o`:d
0_l2]0;o00>dRHT0CHT00`29R@1hR@c_0007k`070>o_k`3_0003k`040;Coo`:d0ol00kCoo`02]0?o
00>dRHT0CXT00`29R@1hR@c_0007k`070>o_k`3_0003k`<0Gnl00`3_k`24k`001nl01`3_knl0k`00
k>l000O_00L0kno_0>l00>c_0006k`801>l00`3_k`3[k`00n^l00001\
\>"],
  ImageRangeCache->{{{0, 249}, {153.5, 0}} -> {-1.60977, -0.858167, 
  0.0900766, 0.0728735}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Related games: A numeric illustration", "Section"],

Cell[CellGroupData[{

Cell["Bertrand-Nash (price game)", "Subsection"],

Cell[BoxData[{
    \(QXBB[px_, py_]\ \ \ \ \ \ \ \ \  := \ 
      x /. \(Solve[{px\  == \ PX[x, y], py\  == \ PY[x, y]}, {x, y}]\)[
          \([1]\)]\  (*\ quantity\ of\ x\ as\ a\ function\ of\ prices\ *) 
      \), 
    \(QYBB[px_, py_]\ \ \ \ \ \ \ \ \ \  := \ 
      y /. \(Solve[{px\  == \ PX[x, y], py\  == \ PY[x, y]}, {x, y}]\)[
          \([1]\)]\  (*\ quantity\ of\ y\ *) \), 
    \(qxbb[px_, py_]\ \ \ \ \ \ \ \ \ \  := \ 
      Simplify[QXBB[px, py] /. Parameters]; \n
    qybb[px_, py_]\ \ \ \ \ \ \ \ \ \  := \ 
      Simplify[QYBB[px, py] /. Parameters]; \n
    HprofBB[px_, py_]\ \  := \ px\ QXBB[px, py]\), 
    \(FprofBB[px_, py_]\  := \ \((py\  - \ t)\)\ QYBB[px, py]\), 
    \(IMB[px_, py_]\ \ \ \ \ \ \ \ \ \ \  = \ px - py; \n
    DMB[py_]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = \ 
      \((PW[w] /. Parameters)\)\  - \ py; \n
    eqid\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  = \ 
      px /. \(Solve[IMB[px, py] == DMB[py], px]\)[\([1]\)]; \n
    NPNashBB\  = \ 
      \(Solve[{D[HprofBB[px, py], px] == 0, 
            D[FprofBB[px, py] /. t -> 0, py] == 0}, {px, py}]\)[\([1]\)]; \n
    NPRxBB\  := \ Solve[D[HprofBB[px, py], px] == 0, py]\), 
    \(NPRyBB\  := \ Solve[D[FprofBB[px, py] /. t -> 0, py] == 0, py]\), 
    \(nprxbb\  = \ \(Simplify[NPRxBB /. Parameters]\)[\([1]\)]; \n
    nprybb\  = \ \(Simplify[NPRyBB /. Parameters]\)[\([1]\)]; \)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(plot\  = \ 
      Plot[{px, PW[w] /. Parameters}, {px, 0, 10}, 
        PlotRange -> {{0, 10}, {0, 10}}, AxesLabel -> {"\<PX\>", "\<PY\>"}, 
        Epilog -> {Line[{{eqid, 0}, {eqid, byh}}]}, 
        DisplayFunction -> Identity]; \n
    CornersDM\  = \ {{0, 0}, {eqid, eqid}, {eqid, 0}}; \n
    CornersIM\  = \ {{eqid, 0}, {eqid, eqid}, {bxh, eqid}, {bxh, byl}}; \n
    r3\  = \ Graphics[{\ GrayLevel[0.6], Polygon[CornersDM]}, 
        Line[CornersDM]]; \n
    r4\  = \ Graphics[{\ GrayLevel[0.9], Polygon[CornersIM]}, 
        Line[CornersIM]]; \n
    Show[plot, r3, r4, plot, DisplayFunction -> $DisplayFunction]; \n
    plot\  = Plot[{\((py /. nprxbb)\), \((py /. nprybb)\)}, {px, 0, 10}, 
        PlotLabel -> "\<Price Game\>", PlotRange -> {{0, 10}, {0, 10}}, 
        AxesLabel -> {"\<PX\>", "\<PY\>"}, DisplayFunction -> Identity]; \n
    Show[{plot, r3, r4, plot}, \ DisplayFunction -> $DisplayFunction]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0 0.0618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[1.025 0 0 -6.25 ]
[1.025 0 16 6.25 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PX) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PY) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.04057 .02507 L
.08481 .05241 L
.12636 .07809 L
.16632 .10279 L
.20885 .12908 L
.2498 .15438 L
.29331 .18128 L
.33524 .20719 L
.37557 .23212 L
.41848 .25864 L
.4598 .28417 L
.49953 .30873 L
.54183 .33487 L
.58254 .36003 L
.62583 .38678 L
.66752 .41255 L
.70762 .43734 L
.7503 .46371 L
.79139 .4891 L
.83505 .51609 L
.87712 .54209 L
.9176 .56711 L
.96065 .59371 L
1 .61803 L
s
0 .39554 m
.04057 .39554 L
.08481 .39554 L
.12636 .39554 L
.16632 .39554 L
.20885 .39554 L
.2498 .39554 L
.29331 .39554 L
.33524 .39554 L
.37557 .39554 L
.41848 .39554 L
.4598 .39554 L
.49953 .39554 L
.54183 .39554 L
.58254 .39554 L
.62583 .39554 L
.66752 .39554 L
.70762 .39554 L
.7503 .39554 L
.79139 .39554 L
.83505 .39554 L
.87712 .39554 L
.9176 .39554 L
.96065 .39554 L
1 .39554 L
s
.6 g
0 0 m
.64 .39554 L
.64 0 L
F
.9 g
.64 0 m
.64 .39554 L
2 .39554 L
2 0 L
F
0 g
0 0 m
.04057 .02507 L
.08481 .05241 L
.12636 .07809 L
.16632 .10279 L
.20885 .12908 L
.2498 .15438 L
.29331 .18128 L
.33524 .20719 L
.37557 .23212 L
.41848 .25864 L
.4598 .28417 L
.49953 .30873 L
.54183 .33487 L
.58254 .36003 L
.62583 .38678 L
.66752 .41255 L
.70762 .43734 L
.7503 .46371 L
.79139 .4891 L
.83505 .51609 L
.87712 .54209 L
.9176 .56711 L
.96065 .59371 L
1 .61803 L
s
0 .39554 m
.04057 .39554 L
.08481 .39554 L
.12636 .39554 L
.16632 .39554 L
.20885 .39554 L
.2498 .39554 L
.29331 .39554 L
.33524 .39554 L
.37557 .39554 L
.41848 .39554 L
.4598 .39554 L
.49953 .39554 L
.54183 .39554 L
.58254 .39554 L
.62583 .39554 L
.66752 .39554 L
.70762 .39554 L
.7503 .39554 L
.79139 .39554 L
.83505 .39554 L
.87712 .39554 L
.9176 .39554 L
.96065 .39554 L
1 .39554 L
s
.64 0 m
.64 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 154.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0 0.0618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[1.025 0 0 -6.25 ]
[1.025 0 16 6.25 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -8 0 ]
[0 .64303 8 12.5 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PX) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PY) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Price) show
99.000000 12.750000 moveto
(Game) show
123.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.25 0 m
.29331 .10708 L
.33524 .21072 L
.37557 .31044 L
.41848 .41652 L
.4598 .51866 L
.49953 .61687 L
s
.49953 .61687 m
.5 .61803 L
s
0 .07725 m
.04057 .08666 L
.08481 .09691 L
.12636 .10654 L
.16632 .1158 L
.20885 .12566 L
.2498 .13515 L
.29331 .14523 L
.33524 .15495 L
.37557 .1643 L
.41848 .17424 L
.4598 .18382 L
.49953 .19303 L
.54183 .20283 L
.58254 .21227 L
.62583 .2223 L
.66752 .23196 L
.70762 .24126 L
.7503 .25115 L
.79139 .26067 L
.83505 .27079 L
.87712 .28054 L
.9176 .28992 L
.96065 .2999 L
1 .30902 L
s
.6 g
0 0 m
.64 .39554 L
.64 0 L
F
.9 g
.64 0 m
.64 .39554 L
2 .39554 L
2 0 L
F
0 g
.25 0 m
.29331 .10708 L
.33524 .21072 L
.37557 .31044 L
.41848 .41652 L
.4598 .51866 L
.49953 .61687 L
s
.49953 .61687 m
.5 .61803 L
s
0 .07725 m
.04057 .08666 L
.08481 .09691 L
.12636 .10654 L
.16632 .1158 L
.20885 .12566 L
.2498 .13515 L
.29331 .14523 L
.33524 .15495 L
.37557 .1643 L
.41848 .17424 L
.4598 .18382 L
.49953 .19303 L
.54183 .20283 L
.58254 .21227 L
.62583 .2223 L
.66752 .23196 L
.70762 .24126 L
.7503 .25115 L
.79139 .26067 L
.83505 .27079 L
.87712 .28054 L
.9176 .28992 L
.96065 .2999 L
1 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 154.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Translate back to quantity space, compare with Cournot", "Subsection"],

Cell[BoxData[
    \(c1\  = \ \(Solve[y == \((qybb[px, py] /. nprxbb)\), px]\)[\([1]\)]; \n
    c2\  = \ Simplify[\(qxbb[px, py] /. nprxbb\) /. c1]; \n
    nprxbq\  = \ Simplify[y /. \(Solve[x == c2, y]\)[\([1]\)]]; \n
    c1\  = \ \(Solve[x == \((qxbb[px, py] /. nprybb)\), px]\)[\([1]\)]; \n
    c2\  = \ Simplify[\(qybb[px, py] /. nprybb\) /. c1]; \n
    nprybq\  = \ Simplify[c2]; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NPN\  = \ 
      Plot[\ {\((nprxbq)\), \((nprybq)\), \((y /. nprxc)\), 
          \((y /. npryc)\)}, {x, bxl, bxh}, 
        PlotRange -> {{bxl, bxh}, {byl, byh}}, DisplayFunction -> Identity]; 
    \nShow[{NPN, r1, r2, NPN}, DisplayFunction -> $DisplayFunction]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.05 0 0.0618034 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.125 0 m
.125 .00625 L
s
[(2.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(7.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(12.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(17.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.53846 .61803 m
.54183 .60901 L
.58254 .49998 L
.62583 .38406 L
.66752 .27239 L
.70762 .16499 L
.7503 .0507 L
s
.7503 .0507 m
.76923 0 L
s
.04167 .61803 m
.08481 .60163 L
.12636 .58582 L
.16632 .57063 L
.20885 .55445 L
.2498 .53888 L
.29331 .52233 L
.33524 .50638 L
.37557 .49104 L
.41848 .47472 L
.4598 .45901 L
.49953 .4439 L
.54183 .42781 L
.58254 .41232 L
.62583 .39586 L
.66752 .38 L
.70762 .36475 L
.7503 .34852 L
.79139 .33289 L
.83505 .31629 L
.87712 .30029 L
.9176 .28489 L
.96065 .26852 L
1 .25355 L
s
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
.9 g
.36 .14833 m
.005 .36773 L
.005 .61185 L
.07875 .61185 L
F
.6 g
.36 .14833 m
.07875 .61185 L
.995 .61185 L
.995 .40996 L
F
0 g
.53846 .61803 m
.54183 .60901 L
.58254 .49998 L
.62583 .38406 L
.66752 .27239 L
.70762 .16499 L
.7503 .0507 L
s
.7503 .0507 m
.76923 0 L
s
.04167 .61803 m
.08481 .60163 L
.12636 .58582 L
.16632 .57063 L
.20885 .55445 L
.2498 .53888 L
.29331 .52233 L
.33524 .50638 L
.37557 .49104 L
.41848 .47472 L
.4598 .45901 L
.49953 .4439 L
.54183 .42781 L
.58254 .41232 L
.62583 .39586 L
.66752 .38 L
.70762 .36475 L
.7503 .34852 L
.79139 .33289 L
.83505 .31629 L
.87712 .30029 L
.9176 .28489 L
.96065 .26852 L
1 .25355 L
s
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 154.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixed Game: Home Quant, Foreign Price", "Subsection"],

Cell[BoxData[{
    \(DSCB\  = \ 
      \(Solve[\ {px\  == \ PX[x, y], py == PY[x, y]}, {px, y}]\)[\([1]\)]; \n
    HprofCB[x_, py_]\  := \ HprofC[x, y] /. DSCB\), 
    \(FprofCB[x_, py_]\  := \ FprofC[x, y] /. DSCB\), 
    \(PXCB[x_, py_]\  := \ px /. DSCB\), 
    \(QYCB[x_, py_]\  := \ y /. DSCB\), 
    \(qxcb[x, py]\  = \ Simplify[PXCB[x, py] /. Parameters]; \n
    qycb[x, py]\  = \ Simplify[\ QYCB[x, py] /. Parameters]; \n
    npnashcb\  = \ 
      \((Solve[{D[HprofCB[x, py], x] == 0, 
                D[FprofCB[x, py] /. t -> 0, py] == 0}, {x, py}] /. Parameters)
          \)[\([1]\)]; \n
    CBQ\  = \ {"\<CB quant\>", x /. npnashcb, 
        \(QYCB[x, py] /. npnashcb\) /. Parameters}; \n
    CBP\  = \ \({"\<CB prices\>", PXCB[x, py], py} /. npnashcb\) /. 
        Parameters; \n
    CBprof\  = \ 
      \({"\<CB profits\>", HprofCB[x, py], FprofCB[x, py] /. t -> 0} /. 
          npnashcb\) /. Parameters; \)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mixed Game: Home Price, Foreign Quant", "Subsection"],

Cell[BoxData[{
    \(DSBC = \ 
      \(Solve[\ {px\  == \ PX[x, y], py == PY[x, y]}, {x, py}]\)[\([1]\)]; \n
    HprofBC[px_, y_]\  := \ HprofC[x, y] /. DSBC\), 
    \(FprofBC[px_, y_]\  := \ FprofC[x, y] /. DSBC\), 
    \(QXBC[px_, y_]\  := \ x /. DSBC\), 
    \(PYBC[px_, y_]\  := \ py /. DSBC\), 
    \(qxbc[px, y]\  = \ Simplify[QXBC[x, py] /. Parameters]; \n
    pybc[px, y]\  = \ Simplify[\ PYBC[x, py] /. Parameters]; \n
    npnashbc\  = 
      \((Solve[\ {D[HprofBC[px, y], px] == 0, \n
                \t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ D[FprofBC[px, y] /. t -> 0, y] == 0}, {px, y}] /. Parameters)\)[
        \([1]\)]; \n
    BCQ\  = \ \({"\<BC quant\>", QXBC[px, y], y} //. npnashbc\) /. 
        Parameters; \n
    BCP\  = \ \({"\<BC prices\>", px, PYBC[x, py]} /. npnashbc\) /. 
        Parameters; \n
    BCprof\  = \ 
      \({"\<BC profits\>", HprofBC[px, y], FprofBC[xp, y] /. t -> 0} /. 
          npnashbc\) /. Parameters; \)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Comparison: Quantities, Prices and Profits", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Labels\  = \ {"\<Criterion\>", "\<Home\>", "\<Foreign\>"}; \n
    Cq\ \  = \ \({"\<Cournot Quant\>", x, y} /. NPNashC\) /. Parameters; \n
    Cp\  = \ \({"\<Cournot Prices\>", PX[x, y], PY[x, y]} /. NPNashC\) /. 
        Parameters; \n
    CProf\  = \ 
      \({"\<Cournot Profits\>", HprofC[x, y], FprofC[x, y] /. t -> 0} /. 
          NPNashC\) /. Parameters; \n
    Cournot\  = \ {Labels, Cq, Cp, CProf} // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"\<\"Criterion\"\>", "\<\"Home\"\>", "\<\"Foreign\"\>"},
            {"\<\"Cournot Quant\"\>", "10.3448275862068972`", 
              "5.74712643678160883`"},
            {"\<\"Cournot Prices\"\>", "4.137931034482758`", 
              "3.44827586206896619`"},
            {"\<\"Cournot Profits\"\>", "42.8061831153388805`", 
              "19.8176773682124469`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Bq\  = \ 
      \({x -> QXBB[px, py], y -> QYBB[px, py]} /. NPNashBB\) /. Parameters; \n
    npnashbb\  = NPNashBB /. Parameters; \n
    Bprof\  = \ 
      \({"\<Bertrand Profits\>", HprofC[x, y], FprofC[x, y] /. t -> 0} /. Bq
          \) /. Parameters; \n
    NPFprofB\  = \ \(\(FprofC[x, y] /. Bq\) /. Parameters\) /. t -> 0; \n
    Bertrand\  = 
      \ {Labels, {"\<Bertrand quant\>", x, y} /. 
            Bq, {"\<Bertrand Prices\>", px, py} /. npnashbb, Bprof} // 
        MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"\<\"Criterion\"\>", "\<\"Home\"\>", "\<\"Foreign\"\>"},
            {"\<\"Bertrand quant\"\>", "12.4137931034482784`", 
              "6.43678160919539976`"},
            {"\<\"Bertrand Prices\"\>", "3.10344827586206939`", 
              "2.41379310344827668`"},
            {"\<\"Bertrand Profits\"\>", "38.5255648038050058`", 
              "15.5370590566785571`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CournotBertrand\  = \ {Labels, CBQ, CBP, CBprof} // MatrixForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"\<\"Criterion\"\>", "\<\"Home\"\>", "\<\"Foreign\"\>"},
            {"\<\"CB quant\"\>", "13.0434782608695676`", 
              "5.07246376811593879`"},
            {"\<\"CB prices\"\>", "3.26086956521739157`", 
              "3.04347826086956718`"},
            {"\<\"CB profits\"\>", "42.5330812854442452`", 
              "15.4379332073093911`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BertrandCournot\  = \ {Labels, BCQ, BCP, BCprof} // MatrixForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"\<\"Criterion\"\>", "\<\"Home\"\>", "\<\"Foreign\"\>"},
            {"\<\"BC quant\"\>", "9.78260869565217028`", 
              "7.24637681159420399`"},
            {"\<\"BC prices\"\>", "3.91304347826087095`", 
              "2.71739130434782705`"},
            {"\<\"BC profits\"\>", "38.2797731568998109`", 
              "19.6912413358538209`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["Home Firm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ {"\<Strategey\>", "\<Cournot\>", "\<Bertrand\>"}, {"\<Cournot\>", 
          CProf[\([2]\)], CBprof[\([2]\)]}, 
        \n{"\<Bertrand\>", BCprof[\([2]\)], Bprof[\([2]\)]}\ \ } // MatrixForm
      \)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"\<\"Strategey\"\>", "\<\"Cournot\"\>", "\<\"Bertrand\"\>"},
            {"\<\"Cournot\"\>", "42.8061831153388805`", 
              "42.5330812854442452`"},
            {"\<\"Bertrand\"\>", "38.2797731568998109`", 
              "38.5255648038050058`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["Foreign Firm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ {"\<Strategey\>", "\<Cournot\>", "\<Bertrand\>"}, {"\<Cournot\>", 
          CProf[\([3]\)], CBprof[\([3]\)]}, 
        \n{"\<Bertrand\>", BCprof[\([3]\)], Bprof[\([3]\)]}\ \ } // MatrixForm
      \)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"\<\"Strategey\"\>", "\<\"Cournot\"\>", "\<\"Bertrand\"\>"},
            {"\<\"Cournot\"\>", "19.8176773682124469`", 
              "15.4379332073093911`"},
            {"\<\"Bertrand\"\>", "19.6912413358538209`", 
              "15.5370590566785571`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Conclusion
Cournot behavior is dominant for both players
(Singh & Vives, Rand Journal of Economics, 1984)\
\>", "DisplayText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second period protection : Nash-Cournot", "Section"],

Cell[BoxData[{
    \(N2PRxC\  := \ Solve[D[HprofC[x, y], x] == 0, y]\), 
    \(N2PRyC\  := \ Solve[D[FprofC[x, y], y] == 0, y]\), 
    \(P2NashC\  = \ 
      \(Solve[{D[HprofC[x, y], x] == 0, D[FprofC[x, y], y] == 0}, {x, y}]\)[
        \([1]\)]; \nFullSimplify[P2NashC /. Parameters]; \n
    n2prxc\  = \ N2PRxC /. Parameters; \nn2pryc\  = \ N2PRyC /. Parameters; 
    \)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NPN\  = \ 
      Plot[\ {\((y /. nprxc)\), \((y /. npryc)\), 
          \((\(y /. n2prxc\) /. t -> 1)\), \((\(y /. n2pryc\) /. t -> 1)\)}, {
          x, bxl, bxh}, PlotRange -> {{bxl, bxh}, {byl, byh}}, 
        PlotStyle -> {RGBColor[0, 0, 0], RGBColor[0, 0, 0], 
            RGBColor[0, 0, 1], RGBColor[0, 0, 1]}, 
        DisplayFunction -> Identity]; \n
    Show[{NPN, r1, r2, NPN}, DisplayFunction -> $DisplayFunction]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.05 0 0.0618034 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.125 0 m
.125 .00625 L
s
[(2.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(7.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(12.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(17.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 0 r
.5 Mabswid
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
0 0 1 r
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .46353 m
.04057 .45099 L
.08481 .43732 L
.12636 .42448 L
.16632 .41213 L
.20885 .39899 L
.2498 .38633 L
.29331 .37289 L
.33524 .35993 L
.37557 .34747 L
.41848 .33421 L
.4598 .32144 L
.49953 .30916 L
.54183 .29609 L
.58254 .28351 L
.62583 .27013 L
.66752 .25725 L
.70762 .24486 L
.7503 .23167 L
.79139 .21897 L
.83505 .20548 L
.87712 .19248 L
.9176 .17997 L
.96065 .16667 L
1 .15451 L
s
.9 g
.36 .14833 m
.005 .36773 L
.005 .61185 L
.07875 .61185 L
F
.6 g
.36 .14833 m
.07875 .61185 L
.995 .61185 L
.995 .40996 L
F
0 0 0 r
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
0 0 1 r
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .46353 m
.04057 .45099 L
.08481 .43732 L
.12636 .42448 L
.16632 .41213 L
.20885 .39899 L
.2498 .38633 L
.29331 .37289 L
.33524 .35993 L
.37557 .34747 L
.41848 .33421 L
.4598 .32144 L
.49953 .30916 L
.54183 .29609 L
.58254 .28351 L
.62583 .27013 L
.66752 .25725 L
.70762 .24486 L
.7503 .23167 L
.79139 .21897 L
.83505 .20548 L
.87712 .19248 L
.9176 .17997 L
.96065 .16667 L
1 .15451 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 154.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003j0000VPP10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3ooooooo[_000Wk`<00nl00`3_k`02k`030>o_01?_
00<0knl05>l00`3_k`02k`030>o_00;_00<0knl03nl500;_00<0knl03Nl50004k`0000?_00<0knl0
0^l00`3_k`0=k`D00^l00`3_k`0=k`D00^l00`3_k`02k`030>o_00;_00<0knl03Nl300?_00<0knl0
1^l002O_00<0knl01nl00`3_000Ck`030>l001G_00<0knl01^l00`3_000Bk`070>o_k`3_000@k`05
0>o_k`002Nl00`3_000@k`070>o_k`3_000@k`030>o_00;_00<0knl01^l00`3_000>k`030>o_00;_
00<0k`001nl002S_00<0knl02>l00`3_k`0Ck`030>o_01?_00<0knl02>l00`3_k`0@k`070>o_k`3_
000@k`030>o_00;_00<0knl02>l00`3_k`0>k`030>o_00?_00<0knl03^l00`3_k`02k`030>o_00S_
00<0knl03Nl01`3_knl0k`001nl002S_00<0knl01^l201C_0P0Gk`030>o_00G_0P0Ck`070>o_k`3_
000@k`030>o_00;_00<0knl01^l2017_00@0kno_0P0Ak`030>o_00?_00<0knl01Nl2013_00L0kno_
0>l000O_000Wk`030>l000O_00<0knl04nl00`3_k`0Dk`030>l000O_00<0knl04^l01`3_knl0k`00
4>l01`3_knl0k`001nl00`3_k`0@k`050>o_k`004^l01`3_knl0k`001nl00`3_k`0>k`030>l000;_
00<0k`001nl002S_00<0knl01^l301?_0`0Dk`<01nl3017_0P04k`030>o_00k_0P04k`030>o_00K_
0`0?k`800nl300o_0P03k`<01nl300o_00<0knl00^l00`3_k`06k`00n^l00?[_003jk`00n^l00?[_
000Akh/000?l0000D@0:k`004Nl00`3_k`03k`030>o_00;_00<0knl00nl00`3_k`03k`030>o_00;_
00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00;_00<0knl00nl00`3_
k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00;_
00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00nl00`3_k`02k`03o>o_00?_00<0knl00^l00`3_
k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00nl00`3_k`02k`030>o_00?_
00<0knl00^l00`3_k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00S_000Ak`030>o_08O_
00?lknl0G>l0017_00<0knl0Qnl00oc_k`1Lk`004Nl00`3_k`27k`03o>o_05c_000Ak`030>o_08O_
00?lknl0G>l0017_00<0knl0Q^l00oc_k`1Mk`004Nl208O_00?lknl0GNl0017_00<0knl0Q^l00oc_
k`1Mk`004Nl00`3_k`25k`03o>o_05k_000Ak`030>o_08G_00?lknl0G^l0017_00<0knl0QNl00oc_
k`1Nk`004Nl00`3_k`25k`03o>o_05k_000Ak`80QNl00oc_k`1Ok`004Nl00`3_k`24k`03o>o_05o_
000Ak`030>o_08C_00?lknl0Gnl0017_00<0knl0Pnl00oc_k`1Pk`004Nl00`3_k`23k`03o>o_063_
000Ak`030>o_08?_00?lknl0H>l0017_00<0knl0P^l00oc_k`1Qk`004Nl208?_00?lknl0HNl0017_
00<0knl0P^l00oc_k`1Qk`004Nl00`3_k`22k`03o>o_067_000Ak`030>o_087_00?lknl0H^l0017_
00<0knl0PNl00oc_k`1Rk`002nl300?_00<0knl0PNl00oc_k`1Rk`002nl00`3_k`03k`030>o_083_
00?lknl0Hnl000c_00<0knl00^l3083_00?lknl0Hnl000c_00<0knl00^l00`3_k`20k`03o>o_06?_
000;k`030>l000?_00<0knl0P>l00oc_k`1Sk`003>l00`3_k`02k`030>o_07o_00?lknl0I>l0017_
00<0knl0Onl00oc_k`1Tk`004Nl00`3_k`1ok`03o>o_06C_000Ak`030>o_07k_00?lknl0INl0017_
0P1=k`>9;nl00oc_k`1Ik`;l2^l0017_00<0knl0B^l00ondR@04RBg_00?lknl0Enl2o0c_000Ak`03
0>o_04S_00?o];@02HTYk`03o>o_05G_0o`>k`004Nl00`3_k`17k`:d0_l;RBO_00?lknl0D^l3o17_
000Ak`030>o_04G_0[@2o`03]8V900b99Nl00oc_k`1?k`?l5>l0017_00<0knl0@nl2]0;o0[@BRB;_
00?lknl0Bnl4o1O_000Ak`030>o_04;_00Fdoooo]002oaB97nl00oc_k`19k`?l6nl0017_0P11k`03
]?oo00:d0_l00kB9R@0FRAc_00?lknl0A^l3o1k_000Ak`030>o_03o_0_l2]0;o0[@00on9R@0HRA[_
00?lknl0@nl3o27_000Ak`030>o_03g_0_l2]0;o0[@2oaj95^l00oc_k`10k`Cl9>l0017_00<0knl0
>nl2o`:d0_l2]0;o00>dRHT07hTDk`03o>o_03c_1?`Xk`004Nl00`3_k`0jk`03okBd00;o0[@2o`:d
00?oRHT08HTBk`03o>o_03S_1?`/k`004Nl00`3_k`0hk`03okBd00;o0[@2o`:d0_lWR@k_00?lknl0
=^l3o2C_0P0:k`004Nl00`3_k`0fk`03okBd00;o0[@2o`:d0_l2]2V93>l00oc_k`0bk`Cl8nl400c_
000Ak`80=^l01?ndool2]0?o00>dool00[@00on9R@0[R@W_00?lknl0;nl3o2?_100@k`004Nl00`3_
k`0ck`:d0_l2]0;o0[@2o`:d0_l`R@O_00?lknl0;>l3o2?_0`0Dk`004Nl00`3_k`0ak`:d0_l2]0;o
0[@2o`:d0_l2]3>90nl00oc_k`0Zk`?l8^l401O_000Ak`030>o_033_00>dool00[@2o`:d0_l2]0;o
0[@00on9R@0dR@03koc_02S_0o`Rk`<06nl0017_00<0knl0;^l00kCoo`02]0;o0[@2o`:d0_l2]0;o
00>dRHT0=HT00oc_k`0Tk`?l8^l301k_000<k`<00^l00`3_k`0/k`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]3N900?lRHT00XTOk`Cl8^l3027_000=k`050>o_k`00;Nl2o`:d0_l2]0;o0[@2o`:d0_l2]003
ohV903J900?lRHT018TJk`?l8nl302C_000;k`@00^l302W_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03
]8V903J900?lRHT01hTEk`;l8nl302O_000;k`030>l000?_00<0knl09nl2o`:d0ol00kCoo`02]0?o
00>dool00[@3o`03]8V903J900?lRHT02XT@k`?l8^l302[_000<k`800nl00`3_k`0Vk`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_lhR@03o8V900f92^l3o2;_0`0]k`003Nl01@3_knl002K_00?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V903N900?lRHT03hT5k`?l8^l3033_000Ak`030>o_02?_
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@jR@03o8V901291?`Qk`@0<nl0017_00<0knl08Nl2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o>HT00ob9R@0>R@?l18TNk`<0=nl0017_00<0knl07nl2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0>8T00ob9R@0;R@?l2HTIk`<0>^l0017_0P0Ok`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0>8T00ob9R@08R@?l3hTCk`<0?Nl0017_
00<0knl07>l00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o>XT00ob9R@06R@?l58T>k`<0
@>l0017_00<0knl06^l01KCooond00;o0[@3o`03]?oo00:d0ol00kCoo`02]0?o00Bdoond>hT00ob9
R@03R@?l6XT8k`<0@nl0017_00<0knl06Nl2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ohV903V900?lRHT00o`OR@;_1016k`004Nl00`3_k`0Gk`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_lkR@Cl8HT30003RNo_04O_000Ak`030>o_01G_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d=XT6o2291006RDO_000Ak`805Nl00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]003ohV903691?`5R@03o8V901Z9100<RDG_000Ak`030>o_01;_00?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oc690o`8R@03o8V901R90`0CRD;_000Ak`030>o_013_
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d;XT3o0^900?lRHT058T401R9
@>l0017_00<0knl03nl2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV902Z9
0o`>R@03o8V901690`0ORCg_000Ak`030>o_00g_00Co]?oo0[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0olYR@?l48T00ob9R@0?R@<098Tkk`004Nl00`3_k`0;k`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]2N90o`CR@03o8V900b90`0ZRCS_000Ak`03
0>o_00[_00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0SR@?l
5XT00ob9R@09R@<0;hTfk`004Nl200W_00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V902290o`HR@03o8V900N90`0dRCC_000Ak`030>o_00O_0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@PR@?l6hT00ob9R@04R@<0>XTak`004Nl00`3_
k`05k`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lMR@?l7XT01?b9
RHT303n9;nl0017_00<0knl00nl2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT06HT3o26900Cl0000AHT/k`004Nl00`3_k`02k`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d6HT3o2690P000o`0R@19RB[_000;k`801>l0103_
kol2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`0FR@?l8HT300:900?lRHT0C8TWk`002nl00`3_0003k`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0BR@?l8HT300F900?lRHT0CXTUk`002nl00`3_
0003k`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9
R@0>R@Cl8HT300N900?lRHT0DHTSk`002nl200C_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`j90o`QR@@02XT00ob9R@1DRB3_000;k`030>o_00?_00@0]?oo
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0:R@?l88T400j9
00?lRHT0EXTNk`003>l200?_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@07R@?l7hT4016900?lRHT0FXTKk`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`J91?`OR@<05HT00ob9R@1LRAW_000Ak`040?nd]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`04]8V9R@Cl88T301R900?lRHT0
GhTFk`004Nl0102dool2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d1?`QR@<06XT00ob9R@1RRAC_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00Bdo?cl8XT301f900?lRHT0I8TBk`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00?oo?`00_`00ond]00OR@<088T00ob9R@1WR@o_000Ak`040?nd]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0o`00kCoo`02]003ohV901^90`0RR@03o8V906^9
3>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`04]?clo0:d0_l2]0;o6hT302F9
00?lRHT0JhT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`?l00?o];@00_l2]0;o
0[@GR@@0:8T00ob9R@1[R@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01?olo?`2o`:d
0_l2]0;o0[@00on9R@0CR@<0:hT00ob9R@1/R@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0o`00kCoo`02]0;o0[@2o`:d0_l00kB9R@0@R@<0;XT00ob9R@1/R@c_000Ak`040;Coo`:d0ol00kCo
o`02]0?o00Bdoond0o`01?ndool2]0?o00>dool00[@3o`03]8V900j90`0aR@03o8V906b93>l0017_
00@0okBd0_l2]0;o0[@2o`:d0_l3o003okBd00;o0[@2o`:d0_l2]0;o0[@00on9R@0<R@<0<hT00ob9
R@1]R@c_000Ak`040;Coo`:d0_l2]0;o0[@01?olo?`2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0
2HT303J900?lRHT0KHT<k`004Nl0103o];@2o`:d0_l00kClo002o003]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@9R@<0>HT00ob9R@1]R@c_000Ak`040;Coo`:d0_l3o003okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o1XT303b900?lRHT0KHT<k`004Nl01@3o];Co00?l0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>dRHT00XT303j900?lRHT0KXT<k`004Nl00`2do002o003]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003R@000080@HT00ob9R@1^R@c_000Ak`;l0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0000204F900?lRHT0KXT<k`004Nl0102dool2]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]003o`00008000?o]8T0AHT00ob9R@1_R@c_000Ak`040?nd]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@000020003]?oo00:d00?oRHT0A8T00ob9R@1_R@c_000Ak`04
0;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0`000ond]002o`:d0_m7R@03o8V906n93>l0017_00@0okBd
0_l2]0;o0[@2o`:d0_l2]004o`0000;o0[@2o`:d0_l00kB9R@15R@03o8V907293>l000c_00<0knl0
0^l0102dool2]0;o0[@2o`:d0_l2]0<000>dool00[@2o`:d0_l2]003ohV904F900?lRHT0L8T<k`00
2nl00`3_0003k`040?nd]0;o0[@2o`:d0_l01;@00002]0;o0[@2o`:d0_l2]0;oB8T00ob9R@1`R@c_
000;k`030>l000?_00@0]?oo0[@2o`:d00?o00000P000ond]002o`:d0_l2]0;o0[@2o`:dAhT00ob9
R@1aR@c_000<k`030>o_00;_00@0okBd0_l2]0<000>dool00[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
AXT00ob9R@1aR@c_000;k`030>l000?_00D0]?oo]0030004okCoo`:d0ol00kCoo`02]0?o00>dool0
0[@2odV900?lRHT0LHT<k`003>l00`3_k`02k`030?l0008000?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:dB8T00ob9R@1bR@c_000Ak`800_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV904N9
00?lRHT0LXT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V904N900?lRHT0
LXT<k`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]4Z900?lRHT0LXT<k`004Nl0103o
];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@18R@03o8V907>93>l0017_00@0]?oo0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0B8T00ob9R@1cR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]4^900?lRHT0LhT<k`004Nl0102dool2]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`1:R@03o8V907B93>l0017_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V904V900?lRHT0
M8T<k`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:dC8T00ob9R@1dR@c_000Ak`040?nd]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_m;R@03o8V907F93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@1:R@03o8V907F93>l0017_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1:R@03
o8V907F93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_m=R@03o8V907F93>l0017_00@0okBd
0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0BhT00ob9R@1fR@c_000Ak`040;Coo`:d0ol00kCoo`02]0?o
00>dool00[@00on9R@1;R@03o8V907J93>l0017_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;oCXT00ob9
R@1fR@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]4j900?lRHT0MXT<k`004Nl0103o];@2o`:d
0_l2]0;o0[@2o`:d00?oRHT0C8T00ob9R@1gR@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_m?R@03
o8V907N93>l0017_00@0okBd0_l2]0;o0[@2o`:d0_l2]4n900?lRHT0MhT<k`004Nl0102dool2]0;o
0[@2o`:d0_l2]003ohV904j900?lRHT0MhT<k`001Nl500;_00<0knl00^l0103o];@2o`:d0_l2]0;o
0[@2o`03]8V904f900?lRHT0N8T<k`001nl01`3_knl0k`000nl0102dool2]0?o00>dool00[@3o`03
]8V904j900?lRHT0N8T<k`001nl01`3_knl0k`000nl305o_00?lknl0Q>l000O_00L0kno_0>l00>c_
0007k`070>o_k`3_003/k`001^l200C_00<0knl0jnl00?[_0000\
\>"],
  ImageRangeCache->{{{0, 249}, {153.5, 0}} -> {-1.60977, -0.858167, 
  0.0900766, 0.0728735}}]
}, Open  ]]
}, Open  ]],

Cell["First period - Dumping Regime", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DM[x, y, w]\), 
    \(HprofDM\  = \ 
      FullSimplify[
        HprofC[x, y] + \((\(HprofC[x, y] /. P2NashC\) /. t -> DM[x, y, w])\)]
        \), 
    \(FprofDM\  = \ 
      FullSimplify[
        \((FprofC[x, y] /. t -> 0)\) + 
          \((\(FprofC[x, y] /. P2NashC\) /. t -> DM[x, y, w])\)]\)}], "Input"],

Cell[BoxData[
    \(\(-a\) + A - g\ w + k\ x + b\ y\)], "Output"],

Cell[BoxData[
    \(x\ \((h - l\ x - k\ y)\) + 
      \(l\ \((k\ \((\(-2\)\ a + A - g\ w + k\ x)\) + b\ \((2\ h + k\ y)\))
              \)\^2\)\/\((k\^2 - 4\ b\ l)\)\^2\)], "Output"],

Cell[BoxData[
    \(\(1\/\((k\^2 - 4\ b\ l)\)\^2\((
      k\^4\ \((a - k\ x)\)\ y - 12\ b\^3\ l\^2\ y\^2 + 
        b\ \((\((h\ k + 2\ l\ \((\(-2\)\ a + A - g\ w + k\ x)\))\)\^2 + 
              8\ k\^2\ l\ \((\(-a\) + k\ x)\)\ y - k\^4\ y\^2)\) + 
        4\ b\^2\ l\ y\ 
          \((2\ l\ \((A - g\ w)\) + k\ \((h - 2\ l\ x + 2\ k\ y)\))\))
      \)\)\)], "Output"]
}, Open  ]],

Cell["Reaction functions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(rxdm\  = \ 
      \(FullSimplify[y /. Solve[D[HprofDM, x] == 0, y]]\)[\([1]\)] /. 
        Parameters\), 
    \(rydm\  = \ 
      \(FullSimplify[y /. Solve[D[FprofDM, y] == 0, y]]\)[\([1]\)] /. 
        Parameters\)}], "Input"],

Cell[BoxData[
    RowBox[{"3.53509878100041996`", " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            StyleBox["10.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2], "\[InvisibleSpace]"}], "+", 
          \(0.0951248513674197226`\ 
            \((\(12.0000000000000017`\[InvisibleSpace]\) + 
                0.3`\ \((\(-13.6000000000000009`\) + 0.3`\ x)\))\)\), "-", 
          \(0.8`\ x\)}], ")"}]}]], "Output"],

Cell[BoxData[
    RowBox[{"1.5827793605571383`", " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"0.00809999999999999786`", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["10.`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->2], "\[InvisibleSpace]"}], "-", 
                \(0.3`\ x\)}], ")"}]}], "+", 
          \(0.575999999999999978`\ 
            \((\(8.12000000000000099`\[InvisibleSpace]\) - 
                0.239999999999999991`\ x)\)\), "+", 
          \(0.17280000000000002`\ \((\(-10.`\) + 0.3`\ x)\)\)}], ")"}]}]], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NPN\  = \ 
      Plot[\ {rxdm, rydm, \((y /. nprxc)\), \((y /. npryc)\)}, {x, bxl, bxh}, 
        PlotRange -> {{bxl, bxh}, {byl, byh}}, DisplayFunction -> Identity]; 
    \nShow[{NPN, r1, r2, NPN}, DisplayFunction -> $DisplayFunction]; \)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.05 0 0.0618034 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -6 -9 ]
[.75 -0.0125 6 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -12 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.125 0 m
.125 .00625 L
s
[(2.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(7.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(10)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(12.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(15)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(17.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(20)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(10)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.50065 .61803 m
.54183 .4756 L
.58254 .33482 L
.62583 .18512 L
.66752 .04093 L
s
.66752 .04093 m
.67936 0 L
s
0 .29641 m
.04057 .28936 L
.08481 .28167 L
.12636 .27445 L
.16632 .26751 L
.20885 .26011 L
.2498 .253 L
.29331 .24544 L
.33524 .23815 L
.37557 .23114 L
.41848 .22368 L
.4598 .2165 L
.49953 .2096 L
.54183 .20225 L
.58254 .19517 L
.62583 .18765 L
.66752 .1804 L
.70762 .17343 L
.7503 .16602 L
.79139 .15888 L
.83505 .15129 L
.87712 .14398 L
.9176 .13694 L
.96065 .12946 L
1 .12262 L
s
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
.9 g
.36 .14833 m
.005 .36773 L
.005 .61185 L
.07875 .61185 L
F
.6 g
.36 .14833 m
.07875 .61185 L
.995 .61185 L
.995 .40996 L
F
0 g
.50065 .61803 m
.54183 .4756 L
.58254 .33482 L
.62583 .18512 L
.66752 .04093 L
s
.66752 .04093 m
.67936 0 L
s
0 .29641 m
.04057 .28936 L
.08481 .28167 L
.12636 .27445 L
.16632 .26751 L
.20885 .26011 L
.2498 .253 L
.29331 .24544 L
.33524 .23815 L
.37557 .23114 L
.41848 .22368 L
.4598 .2165 L
.49953 .2096 L
.54183 .20225 L
.58254 .19517 L
.62583 .18765 L
.66752 .1804 L
.70762 .17343 L
.7503 .16602 L
.79139 .15888 L
.83505 .15129 L
.87712 .14398 L
.9176 .13694 L
.96065 .12946 L
1 .12262 L
s
.4375 .61803 m
.4598 .54452 L
.49953 .41357 L
.54183 .27414 L
.58254 .13995 L
s
.58254 .13995 m
.625 0 L
s
0 .51503 m
.04057 .50249 L
.08481 .48882 L
.12636 .47598 L
.16632 .46363 L
.20885 .45049 L
.2498 .43784 L
.29331 .42439 L
.33524 .41143 L
.37557 .39897 L
.41848 .38571 L
.4598 .37294 L
.49953 .36067 L
.54183 .34759 L
.58254 .33501 L
.62583 .32164 L
.66752 .30875 L
.70762 .29636 L
.7503 .28317 L
.79139 .27048 L
.83505 .25698 L
.87712 .24398 L
.9176 .23148 L
.96065 .21817 L
1 .20601 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{250, 154.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003j0000VPP10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3ooooooo[_000Wk`<00nl00`3_k`02k`030>o_01?_
00<0knl05>l00`3_k`02k`030>o_00;_00<0knl03nl500;_00<0knl03Nl50004k`0000?_00<0knl0
0^l00`3_k`0=k`D00^l00`3_k`0=k`D00^l00`3_k`02k`030>o_00;_00<0knl03Nl300?_00<0knl0
1^l002O_00<0knl01nl00`3_000Ck`030>l001G_00<0knl01^l00`3_000Bk`070>o_k`3_000@k`05
0>o_k`002Nl00`3_000@k`070>o_k`3_000@k`030>o_00;_00<0knl01^l00`3_000>k`030>o_00;_
00<0k`001nl002S_00<0knl02>l00`3_k`0Ck`030>o_01?_00<0knl02>l00`3_k`0@k`070>o_k`3_
000@k`030>o_00;_00<0knl02>l00`3_k`0>k`030>o_00?_00<0knl03^l00`3_k`02k`030>o_00S_
00<0knl03Nl01`3_knl0k`001nl002S_00<0knl01^l201C_0P0Gk`030>o_00G_0P0Ck`070>o_k`3_
000@k`030>o_00;_00<0knl01^l2017_00@0kno_0P0Ak`030>o_00?_00<0knl01Nl2013_00L0kno_
0>l000O_000Wk`030>l000O_00<0knl04nl00`3_k`0Dk`030>l000O_00<0knl04^l01`3_knl0k`00
4>l01`3_knl0k`001nl00`3_k`0@k`050>o_k`004^l01`3_knl0k`001nl00`3_k`0>k`030>l000;_
00<0k`001nl002S_00<0knl01^l301?_0`0Dk`<01nl3017_0P04k`030>o_00k_0P04k`030>o_00K_
0`0?k`800nl300o_0P03k`<01nl300o_00<0knl00^l00`3_k`06k`00n^l00?[_003jk`00n^l00?[_
000Akml02^l0017_00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00nl00`3_k`02k`030>o_00?_
00<0knl00^l00`3_k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00nl00`3_
k`02k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00?_
00<0knl00^l00`3_k`03k`030>o_00?_00<0knl00^l00`3_k`03k`030>o_00;_0P04k`030>o_00;_
00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00nl00`3_k`02k`030>o_00?_00<0knl00^l00`3_
k`03k`030>o_00;_00<0knl00nl00`3_k`02k`030>o_00S_000Ak`030>o_08O_00<0knl02^l00`3_
k`1?k`004Nl00`3_k`27k`030>o_00W_00<0knl0D>l0017_00<0knl0Qnl00`3_k`09k`030>o_053_
000Ak`030>o_08O_00<0knl02Nl00`3_k`1@k`004Nl00`3_k`26k`030>o_00[_00<0knl0D>l0017_
0P27k`030>o_00W_00<0knl0DNl0017_00<0knl0Q^l00`3_k`09k`030>o_057_000Ak`030>o_08G_
00<0knl02^l00`3_k`1Ak`004Nl00`3_k`25k`030>o_00[_00<0knl0DNl0017_00<0knl0QNl00`3_
k`09k`030>o_05;_000Ak`030>o_08G_00<0knl02Nl00`3_k`1Bk`004Nl208G_00<0knl02^l00`3_
k`1Bk`004Nl00`3_k`24k`030>o_00W_00<0knl0Dnl0017_00<0knl0Q>l00`3_k`09k`030>o_05?_
000Ak`030>o_08?_00<0knl02^l00`3_k`1Ck`004Nl00`3_k`23k`030>o_00W_00<0knl0E>l0017_
00<0knl0Pnl00`3_k`09k`030>o_05C_000Ak`030>o_08;_00<0knl02^l00`3_k`1Dk`004Nl208?_
00<0knl02^l00`3_k`1Dk`004Nl00`3_k`22k`030>o_00W_00<0knl0ENl0017_00<0knl0P^l00`3_
k`09k`030>o_05G_000Ak`030>o_087_00<0knl02^l00`3_k`1Ek`004Nl00`3_k`21k`030>o_00W_
00<0knl0E^l000__0`03k`030>o_087_00<0knl02Nl00`3_k`1Fk`002nl00`3_k`03k`030>o_083_
00<0knl02^l00`3_k`1Fk`003>l00`3_k`02k`<0P>l00`3_k`09k`030>o_04__0P0:k`003>l00`3_
k`02k`030>o_083_00<0knl02Nl00`3_k`17k`@03>l000__00<0k`000nl00`3_k`20k`030>o_00W_
00<0knl0@>l7013_000<k`030>o_00;_00<0knl0Onl00`3_k`09k`030>o_03W_200Gk`004Nl00`3_
k`1ok`030>o_00W_00<0knl0=Nl401o_000Ak`030>o_07o_00<0knl02Nl00`3_k`0^k`L08nl0017_
00<0knl0O^l00`3_k`09k`030>o_02S_1`0Zk`004Nl204g_0hT_k`030>o_00W_00<0knl08nl5037_
000Ak`030>o_04[_00?o]8T018T]k`030>o_00W_00<0knl07^l503K_000Ak`030>o_04S_00?o];@0
2HTYk`030>o_00[_00<0knl06^l403__000Ak`030>o_04O_0[@2o`^99nl00`3_k`09k`030>o_01C_
1`0ok`004Nl00`3_k`15k`:d0_l00kB9R@0<RBG_00<0knl02Nl00`3_k`0=k`L0A^l0017_00<0knl0
@nl2]0;o0[@BRB;_00<0knl02Nl00`3_k`09k`@0CNl0017_00<0knl0@^l01KCooond00;o58TOk`03
0>o_00W_00<0knl00nl7057_000Ak`80@Nl00kCoo`02]0;o00>dRHT05XTLk`030>o_00O_201Hk`00
4Nl00`3_k`0ok`;o0[@2o`:d00?oRHT068TJk`030>o_00?_1002k`030>o_05__000Ak`030>o_03g_
0_l2]0;o0[@2oaj95^l00`3_000400G_00<0knl0G>l0017_00<0knl0>nl2o`:d0_l2]0;o00>dRHT0
7hTBk`@02^l00`3_k`1Lk`004Nl00`3_k`0jk`03okBd00;o0[@2o`:d00?oRHT08HT9k`L00^l00`3_
k`09k`030>o_05c_000Ak`030>o_03S_00?o];@00_l2]0;o0[@2obF92008k`030>o_00[_00<0knl0
D>l200[_000Ak`030>o_03K_00?o];@00_l2]0;o0[@2o`:d8HT400B93>l00`3_k`09k`030>o_04g_
100<k`004Nl203K_00Co]?oo0[@3o`03]?oo00:d00?oRHT06HT700^92Nl00`3_k`09k`030>o_04W_
100@k`004Nl00`3_k`0ck`:d0_l2]0;o0[@2o`:d0_lER@L058T7k`030>o_00W_00<0knl0A^l301C_
000Ak`030>o_037_0[@2o`:d0_l2]0;o0[@2o`:d4HT401j90nl00`3_k`0:k`030>o_04;_100Gk`00
4Nl00`3_k`0`k`03]?oo00:d0_l2]0;o0[@2o`:d00?oRHT02hT502B900?_0>l02^l00`3_k`10k`<0
6nl0017_00<0knl0;^l00kCoo`02]0;o0[@2o`:d0_l2]0;o00>dRHT01hT402Z900<0knl02Nl00`3_
k`0mk`<07^l000c_0`02k`030>o_02c_00>dool00[@2o`:d0_l2]0;o0[@2o`:d0hT702f900<0RHT0
0XT8k`030>o_03[_0`0Qk`003Nl01@3_knl002g_0_l2]0;o0[@2o`:d0_l2]003o`0000H0=8T00`29
R@04R@G_00<0knl0>>l302C_000;k`@00^l302W_0_l2]0;o0[@2o`:d0_l00k@000020004]?oo]3R9
00<0RHT01hT2k`030>o_03G_0`0Wk`002nl00`3_0003k`030>o_02O_0_l2]0?o00>dool00[@50003
okBd00?o00>dRHT0=XT00`29R@0:R@030>o_03;_0`0Zk`003>l200?_00<0knl09^l00ond]002o`:d
0_l400:d0_l2]0;o0[@2ocR900<0RHT02XT00`29R@0_k`<0;Nl000g_00D0kno_000Vk`04okBdo`L0
0_l2]0;o0[@2o`:d0_l00kB9R@0gR@0308V900V900<0RHT00hTZk`<0<>l0017_00<0knl08>l80003
]?oo00:d0_l2]0;o0[@2o`:d0_l2]3Z900<0RHT02HT00`29R@05RBC_100ck`004Nl00`3_k`0Lk`@0
00?_];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_liR@0308V900Z900<0RHT028TNk`<0=nl0017_
00<0knl05Nl700?_0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V903R900<0RHT02XT00`29
R@0:RAW_0`0jk`004Nl200o_1`09k`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
>8T00`29R@09R@0308V900j94nl303g_000Ak`030>o_00W_1@0>k`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_ljR@0308V900Z900<0RHT048T>k`<0@>l0017_00<0knl01>l5017_00Fdoooo
]002o`:d0ol00kCoo`02]0?o00>dool00[@3o`04]?oo]3^900<0RHT02XT00`29R@0CR@S_0`13k`00
4Nl00`3_k`0401G_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0iR@0308V900V9
00<0RHT05XT2k`@0A^l0017_0`0Gk`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lkR@03
08V900Z900<0RHT05HT30003RNo_04O_000Ak`030>o_01G_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d>hT00`29R@0:R@0308V901691006RDO_000Ak`805Nl00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV903Z900<0RHT02XT00`29R@0=R@@038U5k`004Nl00`3_
k`0Bk`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_llR@0308V900Z900<0RHT0
2hT301>9@^l0017_00<0knl04>l00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@lR@0308V900Z900<0RHT01hT401R9@>l0017_00<0knl03nl2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]003ohV903^900<0RHT02XT00`29R@04R@<07hTmk`004Nl00`3_k`0=k`04
okCoo`:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o?8T00`29R@0;R@04
08V9R@<098Tkk`004Nl00`3_k`0;k`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]3f900<0RHT02XT00`29000202Z9>>l0017_00<0knl02^l00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV903b900<0RHT02HT302n9=^l0017_0P09k`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0kR@0308V900N90`000hT0
R@0aRCC_000Ak`030>o_00O_0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@nR@0308V900B90`03R@0308V903B9<Nl0017_00<0knl01Nl2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o?XT01029RHT300J900<0RHT0=XT_k`004Nl00`3_k`03k`;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0mR@@02HT00`29
R@0iRBc_000Ak`030>o_00;_00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@mR@@038T00`29R@0kRB[_000;k`801>l0103_kol2]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`0jR@<00XT00`29R@0:R@0308V903n9
9nl000__00<0k`000nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT0=XT300F900<0RHT02XT00`29R@11RBG_000;k`030>l000?_00@0]?oo0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV903>90`07R@0308V900^9
00<0RHT0@hTSk`002nl200C_00@0okBd0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2oc:9100:R@0308V900Z900<0RHT0AhTPk`002nl00`3_k`03k`040;Coo`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0;HT400j900<0RHT02XT00`29
R@19RAk_000<k`800nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]003ohV902V9100AR@0308V900^900<0RHT0C8TKk`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2obV90`0ER@0308V900^900<0RHT0CXTIk`004Nl0103o
];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0UR@<068T00`29
R@0:R@0308V905:95^l0017_00@0]?oo0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]003ohV902:90`0JR@0308V900^900<0RHT0E8TDk`004Nl0103o];@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lRR@<07HT00`29R@0;R@0308V905J9
4^l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d7hT30229
00<0RHT02XT00`29R@1JR@o_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@0KR@<08XT00`29R@0;R@0308V905f93>l0017_00@0]?oo0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oa^90`0UR@0308V900^900<0RHT0GHT<k`004Nl0103o
];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d5hT402R900<0RHT02XT00`29
R@1NR@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
4hT302^900<0RHT02hT00`29R@1NR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>dRHT048T302j900<0RHT02hT00`29R@1NR@c_000Ak`040;Coo`:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dRHT03XT3036900<0RHT02hT00`29
R@1NR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900b9
0`0cR@0308V900^900<0RHT0GhT<k`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@09R@<0=XT00`29R@0;R@0308V905n93>l0017_00@0okBd0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d2HT303V900<0RHT02hT00`29R@1OR@c_000Ak`040;Coo`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`J90`0lR@0308V900Z900<0RHT0H8T<k`00
4Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT00XT303j900<0RHT0
2hT00`29R@1PR@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00hT0
0002046900<0RHT02hT00`29R@1PR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]0000080AHT00`29R@0;R@0308V906293>l0017_00@0]?oo0[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@00ol000020003okB904F900<0RHT02hT00`29R@1QR@c_000Ak`040?nd]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@000020003]?oo00:d00?oRHT0A8T00`29R@0;R@0308V90669
3>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l30003okBd00;o0[@2odN900<0RHT02hT00`29
R@1QR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@01?l00002o`:d0_l2]0;o00>dRHT0AHT00`29
R@0;R@0308V906:93>l000c_00<0knl00^l0102dool2]0;o0[@2o`:d0_l2]0<000>dool00[@2o`:d
0_l2]003ohV904F900<0RHT02hT00`29R@1RR@c_000;k`030>l000?_00@0okBd0_l2]0;o0[@2o`04
]00000:d0_l2]0;o0[@2o`:d0_m8R@0308V900^900<0RHT0HXT<k`002nl00`3_0003k`040;Coo`:d
0_l2]003o`00008000?o];@00_l2]0;o0[@2o`:d0_l2]4N900<0RHT038T00`29R@1RR@c_000<k`03
0>o_00;_00@0okBd0_l2]0<000>dool00[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0AXT00`29R@0;R@03
08V906>93>l000__00<0k`000nl01@2doond00<000Co]?oo0[@3o`03]?oo00:d0ol00kCoo`02]0;o
BHT00`29R@0;R@0308V906>93>l000c_00<0knl00^l00`3o00020003okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]4R900<0RHT038T00`29R@1SR@c_000Ak`800_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]003ohV904N900<0RHT02hT00`29R@1TR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT0AhT00`29R@0;R@0308V906B93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[A:R@0308V900^900<0RHT0I8T<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@00on9R@18R@0308V900b900<0RHT0I8T<k`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@18R@0308V900^900<0RHT0IHT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[A;R@0308V900^900<0RHT0IHT<k`004Nl0102dool2]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`1:R@0308V900b900<0RHT0IHT<k`004Nl0103o];@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0
BHT00`29R@0;R@0308V906J93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_l2]4b900<0RHT0
2hT00`29R@1VR@c_000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_m;R@0308V900b900<0RHT0
IXT<k`004Nl0102dool2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V904Z900<0RHT038T00`29R@1VR@c_
000Ak`040?nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0BXT00`29R@0;R@0308V906N93>l0017_
00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:d0_m=R@0308V900^900<0RHT0IhT<k`004Nl0103o];@2o`:d
0_l2]0;o0[@2o`:d0_l00kB9R@1;R@0308V900b900<0RHT0IhT<k`004Nl0102dool2]0?o00>dool0
0[@3o`03]?oo00:d00?oRHT0BhT00`29R@0<R@0308V906N93>l0017_00@0okBd0_l2]0;o0[@2o`:d
0_l2]0;oCXT00`29R@0;R@0308V906R93>l0017_00@0]?oo0[@2o`:d0_l2]0;o0[@2o`:dCXT00`29
R@0;R@0308V906R93>l0017_00@0okBd0_l2]0;o0[@2o`:d0_l2]003ohV904b900<0RHT038T00`29
R@1XR@c_000Ak`040;Coo`:d0_l2]0;o0[@2o`:d0_m?R@0308V900^900<0RHT0JHT<k`004Nl0103o
];@2o`:d0_l2]0;o0[@2o`:dChT00`29R@0;R@0308V906V93>l0017_00@0]?oo0[@2o`:d0_l2]0;o
0[@00on9R@1>R@0308V900^900<0RHT0JHT<k`001Nl500;_00<0knl00^l0103o];@2o`:d0_l2]0;o
0[@2o`03]8V904f900<0RHT038T00`29R@1YR@c_0007k`070>o_k`3_0003k`040;Coo`:d0ol00kCo
o`02]0?o00>dRHT0CXT00`29R@0;R@0308V906Z93>l000O_00L0kno_0>l000?_0`1Ok`030>o_00__
00<0knl0M^l000O_00L0kno_0>l00>c_0007k`070>o_k`3_003/k`001^l200C_00<0knl0jnl00?[_
0000\
\>"],
  ImageRangeCache->{{{0, 249}, {153.5, 0}} -> {-1.60977, -0.858167, 
  0.0900766, 0.0728735}}]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Condensed",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{749, 365},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], 
      "Cell[ TextData[ {\"Dumping and Tariffs}]]", Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ "M. Weverbergh"], "Header"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
StyleDefinitions -> "Demo.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 72, 3, 79, "Title"],
Cell[1806, 56, 76, 0, 21, "Subtitle"],
Cell[1885, 58, 57, 1, 34, "Input"],

Cell[CellGroupData[{
Cell[1967, 63, 47, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[2039, 67, 136, 4, 94, "Input"],
Cell[2178, 73, 222, 5, 44, "Print"],
Cell[2403, 80, 214, 4, 25, "Print"],
Cell[2620, 86, 97, 2, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2766, 94, 27, 0, 72, "Section"],
Cell[2796, 96, 202, 7, 145, "DisplayText"],

Cell[CellGroupData[{
Cell[3023, 107, 38, 0, 72, "Section"],
Cell[3064, 109, 34, 0, 39, "Subsection"],
Cell[3101, 111, 353, 7, 126, "DisplayText"],
Cell[3457, 120, 35, 0, 39, "Subsection"],
Cell[3495, 122, 199, 4, 69, "DisplayText"],
Cell[3697, 128, 40, 0, 39, "Subsection"],
Cell[3740, 130, 104, 2, 50, "DisplayText"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3893, 138, 30, 0, 72, "Section"],
Cell[3926, 140, 194, 5, 88, "DisplayText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4157, 150, 35, 0, 72, "Section"],
Cell[4195, 152, 346, 6, 174, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4578, 163, 43, 0, 72, "Section"],
Cell[4624, 165, 1171, 24, 154, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5832, 194, 51, 0, 72, "Section"],
Cell[5886, 196, 674, 14, 174, "Input"],
Cell[6563, 212, 694, 14, 154, "Input"],
Cell[7260, 228, 1069, 23, 254, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8366, 256, 68, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[8459, 260, 467, 8, 114, "Input"],
Cell[8929, 270, 24141, 919, 171, 12111, 766, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33119, 1195, 62, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[33206, 1199, 38, 0, 39, "Subsection"],
Cell[33247, 1201, 214, 3, 74, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33498, 1209, 40, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[33563, 1213, 278, 4, 94, "Input"],
Cell[33844, 1219, 129, 3, 48, "Output"],
Cell[33976, 1224, 101, 2, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34126, 1232, 44, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[34195, 1236, 300, 5, 94, "Input"],
Cell[34498, 1243, 101, 2, 48, "Output"],
Cell[34602, 1247, 54, 1, 48, "Output"],
Cell[34659, 1250, 54, 1, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34762, 1257, 40, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[34827, 1261, 261, 5, 74, "Input"],
Cell[35091, 1268, 16187, 502, 171, 4309, 351, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51339, 1777, 56, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[51420, 1781, 48, 0, 39, "Subsection"],
Cell[51471, 1783, 1412, 25, 354, "Input"],

Cell[CellGroupData[{
Cell[52908, 1812, 952, 17, 234, "Input"],
Cell[53863, 1831, 6653, 420, 171, 6533, 416, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[60519, 2253, 7396, 438, 171, 7276, 434, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[67964, 2697, 76, 0, 39, "Subsection"],
Cell[68043, 2699, 397, 6, 134, "Input"],

Cell[CellGroupData[{
Cell[68465, 2709, 300, 6, 74, "Input"],
Cell[68768, 2717, 5453, 427, 171, 5333, 423, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[74270, 3150, 59, 0, 39, "Subsection"],
Cell[74332, 3152, 934, 19, 254, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[75303, 3176, 59, 0, 39, "Subsection"],
Cell[75365, 3178, 999, 20, 254, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76401, 3203, 64, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[76490, 3207, 453, 8, 114, "Input"],
Cell[76946, 3217, 490, 11, 105, "Output"],

Cell[CellGroupData[{
Cell[77461, 3232, 523, 11, 154, "Input"],
Cell[77987, 3245, 495, 11, 105, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[78531, 3262, 98, 2, 34, "Input"],
Cell[78632, 3266, 477, 11, 105, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[79146, 3282, 98, 2, 34, "Input"],
Cell[79247, 3286, 477, 11, 105, "Output"]
}, Open  ]],
Cell[79739, 3300, 31, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[79795, 3304, 233, 4, 54, "Input"],
Cell[80031, 3310, 380, 9, 89, "Output"]
}, Open  ]],
Cell[80426, 3322, 34, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[80485, 3326, 233, 4, 54, "Input"],
Cell[80721, 3332, 380, 9, 89, "Output"]
}, Open  ]],
Cell[81116, 3344, 136, 4, 88, "DisplayText"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81313, 3355, 58, 0, 72, "Section"],
Cell[81374, 3357, 384, 7, 134, "Input"],

Cell[CellGroupData[{
Cell[81783, 3368, 462, 9, 114, "Input"],
Cell[82248, 3379, 17525, 579, 171, 5327, 424, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[99800, 3962, 48, 0, 72, "Section"],

Cell[CellGroupData[{
Cell[99873, 3966, 328, 9, 74, "Input"],
Cell[100204, 3977, 65, 1, 48, "Output"],
Cell[100272, 3980, 183, 3, 66, "Output"],
Cell[100458, 3985, 368, 7, 84, "Output"]
}, Open  ]],
Cell[100841, 3995, 40, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[100906, 3999, 248, 6, 54, "Input"],
Cell[101157, 4007, 461, 11, 48, "Output"],
Cell[101621, 4020, 649, 16, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102307, 4041, 273, 5, 74, "Input"],
Cell[102583, 4048, 18741, 592, 171, 5295, 421, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

