(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    364090,      12401]*)
(*NotebookOutlinePosition[    395369,      13523]*)
(*  CellTagsIndexPosition[    395325,      13519]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Dumping and Tariffs:
Cournot Competition\
\>", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False],

Cell["\<\
W. Pauwels, H. Vandenbussche, M. Weverbergh
University of Antwerp, Belgium\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell["Definitions & Initialization", "Section",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[0.752941]],

Cell[BoxData[
    \(<< Utilities`CleanSlate`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(CleanSlate[]\), 
    \(Off[General::"\<spell1\>"]; \nOff[General::"\<spell\>"]; \n
    Off[Solve::"\<svars\>"]; \nOff[ParametricPlot::"\<ppcom\>"]; \n
    \(Off[ReplaceAll::"\<reps\>"]; \)\), 
    \(\(Off[ParametricPlot::"\<pptr\>"]; \)\)}], "Input",
  PageWidth->Infinity,
  CellFrame->True,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    InterpretationBox[
      \("contexts purged: "\[InvisibleSpace]{"Global`"}
          \[InvisibleSpace]"\n"\),
      SequenceForm[ "contexts purged: ", {"Global`"}, "\n"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("approximate kernel memory recovered: "\[InvisibleSpace]"2 Kb"\),
      SequenceForm[ "approximate kernel memory recovered: ", "2 Kb"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({"CleanSlate`", "Graphics`Animation`", "Global`", "System`"}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Game Setup", "Section",
  Evaluatable->False,
  Background->None],

Cell[CellGroupData[{

Cell["Inverse demand functions", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->None],

Cell[BoxData[{
    \(f[x_, y_]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  := 
      h\ x - \(l\ x\^2\)\/2 + a\ y - \(b\ y\^2\)\/2 - k\ x\ y\), 
    \(PX[x_, y_]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  := h - l\ x - k\ y\), 
    \(PY[x_, y_]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  := a - b\ y - k\ x\), 
    \(PW[w_]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  := A - g\ w\), 
    \(CSH[x_, y_]\ \ \ \ \ \ \ \ \ \ \ \ \ \  := 
      Simplify[f[x, y] - PX[x, y]\ x - PY[x, y]\ y]\), 
    \(Hprof[x_, y_]\ \ \ \ \ \ \ \ \ \  := \((PX[x, y] - hc)\)\ x\), 
    \(Fprof[x_, y_]\ \ \ \ \ \ \ \ \ \  := \((PY[x, y] - fc)\)\ y\), 
    \(IM[x_, y_]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  := PX[x, y] - PY[x, y]\), 
    \(DM[x_, y_]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  := PW[w] - PY[x, y]\), 
    \(FprofT[x_, y_, t_]\  := \((PY[x, y] - fc - t)\)\ y\), 
    \(Tariff[x_, y_]\ \ \ \ \ \ \ \  := Max[0, Min[IM[x, y], DM[x, y]]]; \n
    EQID\  = \ \ \(Solve[DM[x, y] == IM[x, y], y]\)[\([1]\)]; \)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters", "Subsection"],

Cell[BoxData[{
    \(bxl = 0; \nbxh = 5; \nbyl = 0. ; \nbyh = 5. ; \nCornbl = {bxl, byl}; \n
    \(Corntl = {bxl, byh}; \)\), 
    \(\(Corntr = {bxh, byh}; \)\), 
    \(\(Cornbr = {bxh, byl}; \)\), 
    \(kader = {{bxl, bxh}, {byl, byh}}; \n
    Parameters = {hc \[Rule] 0. , fc \[Rule] 3.5, a \[Rule] 8, h \[Rule] 9.5, 
        A \[Rule] 12. , g \[Rule] 3.0\/5, k \[Rule] 7. \/20, 
        b \[Rule] 15. \/20, l \[Rule] 20.0\/20, w -> 8.5}; \n
    Par2 = {hc \[Rule] 4. , fc \[Rule] 3.5, a \[Rule] 8, h \[Rule] 9.5, 
        A \[Rule] 12. , g \[Rule] 3.0\/5, k \[Rule] 7. \/20, 
        b \[Rule] 15. \/20, l \[Rule] 20.0\/20, w -> 8.5}; \n
    Par3 = {hc \[Rule] 6. , fc \[Rule] 3.5, a \[Rule] 8, h \[Rule] 9.5, 
        A \[Rule] 12. , g \[Rule] 3.0\/5, k \[Rule] 7. \/20, 
        b \[Rule] 15. \/20, l \[Rule] 20.0\/20, w -> 8.5}; \n
    pw = PW[w] /. Parameters; \)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Borderlines", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NulIM\ \ \  = \ y /. Solve[\((IM[x, y] /. Parameters)\) == 0, y]; \n
    NulDM\ \ \  = \ y /. Solve[\ \((DM[x, y] /. Parameters)\) == 0, y]; \n
    EqID\ \ \ \ \  = \(y /. \ EQID\) /. Parameters; \n
    XIntS\ \ \  = Solve[NulIM == NulDM, x]; \n
    YIntS\ \ \  = \((NulIM /. XIntS)\)[\([1]\)]; \n
    IntID\ \ \  = {\((x /. XIntS)\)[\([1]\)], YIntS[\([1]\)]}; \n
    IntYD\ \ \  = \ {bxl, \((NulDM /. x -> bxl)\)[\([1]\)]}; \n
    IntXEq\  = \ {\((x /. Solve[byh == EqID, x])\)[\([1]\)], byh}; \n
    IntYI\ \ \  = \ {bxh, \((NulIM /. x -> bxh)\)[\([1]\)]}; \n
    NoDM\ \ \ \ \  = Line[{IntID, IntYD}]; \n
    NoIM\ \ \ \ \  = Line[{IntID, IntYI}]; \n
    EqID\ \ \ \ \  = \ Line[{IntID, IntXEq}]; \n
    DMRegion\  = \ 
      Graphics[{\ GrayLevel[0.9], \ 
          Polygon[{IntID, IntYD, {bxl, byh}, IntXEq}]}]; \n
    IMRegion\  = \ 
      Graphics[{\ GrayLevel[0.6], 
          Polygon[{IntID, IntXEq, {bxh, byh}, IntYI}]}]; \)], "Input"],

Cell["Plot the outcome", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Qplot\  = \ 
      Plot[{0}, {x, bxl, bxh}, PlotRange -> kader, 
        PlotLabel -> "\<Protection Regions\>", Epilog -> {NoIM, NoDM, EqID}, 
        Frame -> True, DisplayFunction -> Identity, 
        FrameLabel -> {"\<X\>", "\<Y\>"}]; \n
    Show[Qplot, DMRegion, IMRegion, DisplayFunction -> $DisplayFunction]; 
    \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0 0.123607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5 -5 ]
[-0.01875 .30902 -6 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -56 0 ]
[.5 .63053 56 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 0 m
.2 .00625 L
s
[(1)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(3)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(4)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(5)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -78.25 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.25 translate
90 rotate
-66 -10.25 translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.04 .61428 m
.04 .61803 L
s
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36 .61428 m
.36 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.52 .61428 m
.52 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.68 .61428 m
.68 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.84 .61428 m
.84 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Protection) show
129.000000 12.750000 moveto
(Regions) show
171.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 0 m
.04057 0 L
.08481 0 L
.12636 0 L
.16632 0 L
.20885 0 L
.2498 0 L
.29331 0 L
.33524 0 L
.37557 0 L
.41848 0 L
.4598 0 L
.49953 0 L
.54183 0 L
.58254 0 L
.62583 0 L
.66752 0 L
.70762 0 L
.7503 0 L
.79139 0 L
.83505 0 L
.87712 0 L
.9176 0 L
.96065 0 L
1 0 L
s
.9 g
.4988 .03743 m
0 .18129 L
0 .61803 L
.17 .61803 L
F
.6 g
.4988 .03743 m
.17 .61803 L
1 .61803 L
1 .54078 L
F
0 g
.4988 .03743 m
1 .54078 L
s
.4988 .03743 m
0 .18129 L
s
.4988 .03743 m
.17 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L00?l78@L00?l78@L00?l78@L009H7
0P000`L000251`00U`L00`0700261`00V0L00`071`251`00V0L00`071`251`00U`L00`0700261`00
UPL200031`0008D7003o1b47003o1b47003o1b47001D1`D0:0L302X70P0[1`<0:@L00`071`0F1`00
EPL00`071`0X1`0300L702`700<01`L0:@L00`071`0W1`0300L001L7001F1`0300L702T700<01`L0
:PL00`071`0X1`@0:PL00`071`0E1`00EPL00`071`0Y1`0300L702/700<01`L09`L00`07000Y1`80
60L005H700<01`L0:0L00`07000Z1`0300L002X70P0Y1`0300L701L7001E1`80:`L00`071`0Z1`03
00L702X700<01`L09`L301L7003o1b47003o1b47003o1b47003o1b47003o1b47000Z1ml05`L002X7
00<01`L01PL00`071`051`0300L700H700<01`L01PL00`071`061`0300L700H700<01`L01PL00`07
1`061`0300L700H700<01`L01PL00`071`051`0300L700H700<01`L01PL00`071`061`0300L700H7
00<01`L01PL00`071`061`0300L700H700<01`L01PL00`071`061`0300L700D700<01`L01PL00`07
1`061`0300L700H700<01`L01PL00`071`0E1`00:PL00`071`3K1`0300L701D7000Z1`0300L70=/7
00<01`L05@L002X700<01`L0f`L00`071`0E1`00:PL20=/70P0G1`00:PL00`071`3K1`0300L701D7
000Z1`0300L70=/700<01`L05@L002X700<01`L0J`L206h700<01`L05@L002X700<01`L0I`L50003
R@0706`700<01`L05@L002X700<01`L0I0L30005]?oo]0000XT00`071`1Z1`0300L701D7000Z1`80
H@L40004okCoo`:d00<0RHT00XT00`071`1X1`805`L002X700<01`L0G@L300;o0[@2o`:d0_l00`29
R@03R@0300L706P700<01`L05@L002X700<01`L0F@L40003]?oo00:d0_l2]0;o00>d08T01XT00`07
1`1W1`0300L701D7000Z1`0300L705H70`000ond]002o`:d0_l2]0;o0[@00ol0R@07R@0300L706H7
00<01`L05@L002X700<01`L0DPL400;o0[@2o`:d0_l2]0;o0[@2o`0308V900R900<01`L0I@L00`07
1`0E1`00:PL205070`02]0;o0[@2o`:d0_l2]0;o0[@2o`03]02900^900<01`L0H`L201L7000Z1`03
00L704`70`000ond]002o`:d0_l2]0;o0[@2o`:d0_l2]003o`2900b900<01`L0H`L00`071`0E1`00
:PL00`071`181`@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@0=R@0300L7068700<01`L0
5@L002X700<01`L0A@L300:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00k@0R@0?R@03
00L7064700<01`L05@L002X700<01`L0@@L40003okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@00ol0R@0AR@0300L7060700<01`L05@L002X700<01`L0?PL30003]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>d08T04XT00`071`1O1`0300L701D7000Z1`80>`L400:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT04hT00`071`1M1`805`L002X700<01`L0
=`L300;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@0FR@0300L705d7
00<01`L05@L002X700<01`L0<`L40003]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00k@0R@0GR@0300L705`700<01`L05@L002871@031`0300L703070`000ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V901R900<01`L0F`L00`07
1`0E1`0090L00`071`031`0300L702`71002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`0308V901V900<01`L0FPL00`071`0E1`0090L00`071`031`80:PL30004
okCoo`:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`05
]?oo]0007HT00`071`1H1`805`L002@700<01`L00`L00`071`0U1`@000?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003o`2901f900<01`L0F0L00`07
1`0E1`0090L00`071`031`0300L702870`000kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V901j900<01`L0E`L00`071`0E1`008`L200D7
00<01`L07PL400:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]029026900<01`L0EPL00`071`0E1`00:PL00`071`0K1`<00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003o`2902:9
00<01`L0E@L00`071`0E1`00:PL00`071`0H1`<000>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V902>900<01`L0E0L00`07
1`0E1`00:PL201D71002]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT098T00`071`1B1`805`L002X700<01`L04@L300;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]003o`2902N900<01`L0DPL00`071`0E1`00:PL00`071`0=1`@000Fdoooo]002o`:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`0308V902N900<01`L0D@L00`071`0E1`00:PL00`071`0:1`<0
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V902V900<01`L0D0L00`071`0E1`00:PL00`071`061`@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@0/R@0300L704l700<01`L05@L002X70P041`<00[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0;HT00`071`1=1`805`L002X700<01`000`000ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@0^R@0300L704d700<01`L05@L002X70P000kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0;hT00`071`1<1`0300L701D7000Z1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0R@0bR@0300L704/700<01`L05@L002X700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V903>900<01`L0BPL00`071`0E1`00:PL00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`04]?oo03J900<01`L0
B@L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02903N900<01`L0
A`L201L7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?o08T0>8T00`071`171`03
00L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0>HT00`071`161`03
00L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT0>XT00`071`151`03
00L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003o`2903f900<01`L0A0L00`07
1`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@0nR@0300L704870P0G1`00
:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@0oR@0300L7048700<01`L05@L002X7
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d00?o08T0@XT00`07
1`111`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0R@13R@0300L70407
00<01`L05@L002<70`041`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@14R@0300L703l7
00<01`L05@L002<700<01`L010L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0AHT00`07
1`0n1`0300L701D7000T1`0300L700<700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0R@18R@03
00L703`70P0G1`0090L00`071`031`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT0BHT00`07
1`0l1`0300L701D7000S1`0300L000@700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@1:R@03
00L703/700<01`L05@L002@700<01`L00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0R@1=R@03
00L703X700<01`L05@L002X700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?l004n900<01`L0>@L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@1?R@03
00L703L70P0G1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@1@R@0300L703L700<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003o`2905>900<01`L0=PL00`071`0E1`00:PL00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0E8T00`071`0e1`0300L701D7000Z1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00`29R@1ER@0300L703@700<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0
R@1GR@0300L703@700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0R@1HR@0300L70387
0P0G1`005PL00`071`0A1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d00<0RHT0
FHT00`071`0b1`0300L701D7000F1`804PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V905Z900<01`L0
<@L00`071`0E1`005PL00`0700021`0300L700`700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0GHT00`07
1`0`1`0300L701D7000I1`<03PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@1NR@0300L702l700<01`L0
5@L001H700<01`000PL00`071`0<1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V905n900<01`L0;@L201L7
000F1`804PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0HXT00`071`0]1`0300L701D7000Z1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00ol0R@1SR@0300L702`700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V906B9
00<01`L0:`L00`071`0E1`00:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00k@0R@1VR@03
00L702X700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@1XR@0300L702T700<01`L05@L002X7
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l00`29R@1YR@0300L702L70P0G1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V906Z9
00<01`L09`L00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@1]R@0300L702H700<01`L05@L002<7
0P051`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]02906j900<01`L09@L00`071`0E1`009@L00`071`021`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]00308V906n900<01`L090L00`071`0E1`0090L00`071`031`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V90729
00<01`L08PL201L7000U1`0300L7008700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol01KCook@007B900<01`L0
8PL00`071`0E1`008`L00`0700041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@1dR@0300L7024700<01`L05@L002@7
00<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0MHT00`071`0P1`0300L701D7000Z1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0
N8T00`071`0O1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?o08T0NHT00`071`0N1`0300L701D7000Z1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00<0RHT0NXT00`071`0L1`805`L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@1kR@0300L701`700<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00?o08T0OXT00`071`0K1`0300L701D7000Z1`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0;o
00<0RHT0OhT00`071`0J1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V9082900<01`L06@L00`071`0E1`00
:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?o08T0PhT00`071`0G1`805`L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02908B900<01`L05`L00`071`0E1`00
:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00<0RHT0QHT00`071`0F1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@26R@0300L701D700<01`L0
5@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00k@0R@29R@0300L701@700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00`29R@2:R@0300L701<700<01`L0
5@L002X700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`04]?oo08f900<01`L04@L201L7000Z1`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02908j900<01`L04@L00`07
1`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00ol0R@2?R@0300L7010700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0T8T00`071`0?1`0300L701D7
000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]00308V9096900<01`L03PL00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?o08T0U8T00`071`0<1`805`L002X700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V909F9
00<01`L030L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT0UXT00`071`0;1`0300L701D7000Z1`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d00?o08T0
VHT00`071`0:1`0300L701D7000T1`<00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02909Z900<01`L02@L00`071`0E1`009@L00`071`021`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT0
VhT00`071`081`0300L701D7000S1`@00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@2NR@0300L700H70P0G1`008`L00`0700041`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]02909n900<01`L0
1PL00`071`0E1`0090L200@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00<0RHT0X8T00`071`051`0300L701D7000U1`0300L7008700>dool00[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00<0RHT0XHT00`071`041`03
00L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00k@0R@2TR@0300L700<700<01`L05@L002X700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>do`00YXT010071`L201L7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@2VR@0500L71`00
5`L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0
R@2YR@0400L701L7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?o08T0ZXT00`07000G1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`0308V90:^90P0G1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]00308V90:b900<01`L05@L002X700>dool00[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?o08T0[XT00`071`0E1`00:PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00k@0R@2^R@0300L701D7000Z1`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@00`29
R@2^R@0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@00ol0R@2`R@0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00k@0R@2`R@0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@00`29R@2`R@0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@2`R@0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>d08T0/XT00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003o`290;:900<01`L05@L002X700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00`29R@2bR@0300L701D7000Z1`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00<0RHT0/hT00`071`0E1`00
:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0R@2dR@0300L701D7
000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`0308V90;B900<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00<0RHT0]8T00`07
1`0E1`0090L00`071`031`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ol0
R@2fR@0300L701D7000S1`0300L000@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]0290;J900<01`L05@L002D700<01`L00PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00<0RHT0]XT00`071`0E1`008`L20?/7000S1`0300L70?X7000S1`<0nPL00?l7
8@L00?l78@L00;470P1]1`00/`L00`071`1Z1`00H`L300<70`031`800`L200<70P021`<00`L20087
0`031`8000<700000PL00`071`0>1`<000@700L70P031`<000@700000`L200031`00008700@01`00
FPL006@700<01`L00`L01@071`L0008700<01`000PL00`0700041`0300L7008700@01`L00PL01@07
1`L0008700<01`000PL00`071`0?1`0600L700L010L010071`021`0500L71`000PL00`0700021`05
00L71`00F@L006@70`031`0500L71`000PL00`0700041`<00PL00`071`021`0300L700<700D01`L7
00021`0300L0008700<01`L03`L300870`021`0400L7008700D01`L700021`0300L0008700@01`L0
FPL006@700D01`L01`0400870P000`L0000200870`021`<000<700000P021`8010L200031`000080
4PL01@071`0700<00`L300031`0000@70P000`L0000200<70P1I1`00I0L010071`0;1`0300L700`7
00<01`L08@L010071`1f1`00H`L4024700<01`L06PL400d700<01`L0I`L00?l78@L00?l78@L00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.949035, -0.883654, 
  0.0224936, 0.0363954}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Period 2 subgame", "Section"],

Cell[CellGroupData[{

Cell["Period 2 subgame: no protection", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->None],

Cell[BoxData[{
    \(\(OptH = \[PartialD]\_x Hprof[x, y] == 0; \)\), 
    \(\(Rx = \(Solve[OptH, x]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; 
    \)\), 
    \(\(OptF = \[PartialD]\_y Fprof[x, y] == 0; \)\), 
    \(\(Ry = \(Solve[OptF, y]\)\[LeftDoubleBracket]1\[RightDoubleBracket]; 
    \)\), 
    \(\(NENP = Solve[{OptH, OptF}, {x, y}]; \)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[CellGroupData[{

Cell["Period 2 subgame: Exogenous tariff", "Subsection",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->None],

Cell[BoxData[{
    \(OptFT\  = Simplify[\[PartialD]\_y FprofT[x, y, t]] == 0; \n
    NET\ \ \ \ \  = Solve[{OptH, OptFT}, {x, y}]; \n
    \(HprofTEQ = Hprof[x, y] /. NET; \)\), 
    \(\(FprofTEQ = FprofT[x, y, t] /. NET; \)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Combine two periods", "Section"],

Cell[CellGroupData[{

Cell["Symbolic part", "Subsubsection"],

Cell[BoxData[{
    \(HprofitNP = 2\ Hprof[x, y]; \n\(FprofitNP = 2\ Fprof[x, y]; \)\), 
    \(RXNP = \(Solve[\[PartialD]\_x HprofitNP == 0, y]\)[\([1]\)]; \n
    RYNP = \(Solve[\[PartialD]\_y FprofitNP == 0, y]\)[\([1]\)]; \n
    NENP = \(Solve[{\[PartialD]\_x HprofitNP == 0, 
            \[PartialD]\_y FprofitNP == 0}, {x, y}]\)[\([1]\)]; \n
    HprofitIM = Hprof[x, y] + \((HprofTEQ /. t \[Rule] IM[x, y])\); \n
    HOMEPROF\ \  = Hprof[x, y] + \((HprofTEQ /. t \[Rule] TARIFF[x, y])\); \n
    \(FprofitIM = Fprof[x, y] + \((FprofTEQ /. t \[Rule] IM[x, y])\); \)\), 
    \(RXIM = \(Solve[\[PartialD]\_x HprofitIM == 0, y]\)[\([1]\)]; \n
    RYIM = \(Solve[\[PartialD]\_y FprofitIM == 0, y]\)[\([1]\)]; \n
    NEIM = \(Solve[{\[PartialD]\_x HprofitIM == 0, 
            \[PartialD]\_y FprofitIM == 0}, {x, y}]\)[\([1]\)]; \n
    HprofitDM = Hprof[x, y] + \((HprofTEQ /. t \[Rule] DM[x, y])\); \n
    \(FprofitDM = Fprof[x, y] + \((FprofTEQ /. t \[Rule] DM[x, y])\); \)\), 
    \(RXDM = \(Solve[\[PartialD]\_x HprofitDM == 0, y]\)[\([1]\)]; \n
    RYDM = \(Solve[\[PartialD]\_y FprofitDM == 0, y]\)[\([1]\)]; \n
    NEDM = \(Solve[{\[PartialD]\_x HprofitDM == 0, 
            \[PartialD]\_y FprofitDM == 0}, {x, y}]\)[\([1]\)]; \)}], "Input",\

  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numeric Examples", "Subsection",
  Evaluatable->False,
  Background->None],

Cell[CellGroupData[{

Cell["No Protection", "Subsection",
  Evaluatable->False,
  Background->None],

Cell[BoxData[{
    \(\(rxnp = Simplify[RXNP /. Parameters]; \)\), 
    \(\(rynp = Simplify[RYNP /. Parameters]; \)\), 
    \(\(nenp = NENP /. Parameters; \)\), 
    \(\(imnp = \(IM[x, y] /. NENP\) /. Parameters; \)\), 
    \(\(dmnp = \(DM[x, y] /. NENP\) /. Parameters; \)\), 
    \(\(hprofnp = \(HprofitNP /. NENP\) /. Parameters; \)\), 
    \(\(fprofnp = \(FprofitNP /. NENP\) /. Parameters; \)\), 
    \(TariffNP := \((\(Tariff[x, y] /. NENP\) /. Par)\)\)}], "Input",
  PageWidth->Infinity,
  FontSize->12]
}, Open  ]],

Cell[CellGroupData[{

Cell["Injury Regime", "Subsection",
  Evaluatable->False,
  Background->None],

Cell[BoxData[{
    \(\(rxim = RXIM /. Parameters; \)\), 
    \(\(ryim = RYIM /. Parameters; \)\), 
    \(\(neim = NEIM /. Parameters; \)\), 
    \(\(imim = \(IM[x, y] /. NEIM\) /. Parameters; \)\), 
    \(\(dmim = \(DM[x, y] /. NEIM\) /. Parameters; \)\), 
    \(\(hprofim = \(HprofitIM /. NEIM\) /. Parameters; \)\), 
    \(\(fprofim = \(FprofitIM /. NEIM\) /. Parameters; \)\), 
    \(TariffIM := \((\(Tariff[x, y] /. NEIM\) /. Par)\)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dumping regime", "Subsection",
  Evaluatable->False,
  Background->None],

Cell[BoxData[{
    \(\(rxdm = Simplify[RXDM /. Parameters]; \)\), 
    \(\(rydm = Simplify[RYDM /. Parameters]; \)\), 
    \(\(nedm = NEDM /. Parameters; \)\), 
    \(\(imdm = \(IM[x, y] /. NEDM\) /. Parameters; \)\), 
    \(\(dmdm = \(DM[x, y] /. NEDM\) /. Parameters; \)\), 
    \(\(hprofdm = \(HprofitDM /. NEDM\) /. Parameters; \)\), 
    \(\(fprofdm = \(FprofitDM /. NEDM\) /. Parameters; \)\), 
    \(TariffDM := \((\(Tariff[x, y] /. NEDM\) /. Par)\)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical examples", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(case1\  = \ 
      FullSimplify[
        \(({y /. RXNP, y /. RYNP, y /. RXIM, y /. RYIM, y /. RXDM, y /. RYDM})
            \) //. Parameters]\), 
    \(case2\  = \ 
      FullSimplify[
        \(({y /. RXNP, y /. RYNP, y /. RXIM, y /. RYIM, y /. RXDM, y /. RYDM})
            \) //. Par2]\), 
    \(case3\  = \ 
      FullSimplify[
        \(({y /. RXNP, y /. RYNP, y /. RXIM, y /. RYIM, y /. RXDM, y /. RYDM})
            \) //. Par3]\)}], "Input"],

Cell[BoxData[
    \({\(27.1428571428571441`\[InvisibleSpace]\) - 5.71428571428571441`\ x, 
      \(3.`\[InvisibleSpace]\) - 0.233333333333333303`\ x, 
      \(24.5311833450506266`\[InvisibleSpace]\) - 5.55643307738887859`\ x, 
      \(2.97120421203843942`\[InvisibleSpace]\) - 0.389005108252801932`\ x, 
      \(28.8214724905371255`\[InvisibleSpace]\) - 5.83338397034696498`\ x, 
      \(2.16044863137579712`\[InvisibleSpace]\) - 0.146268746957490041`\ x}
      \)], "Output"],

Cell[BoxData[
    \({\(15.7142857142857161`\[InvisibleSpace]\) - 5.71428571428571441`\ x, 
      \(3.`\[InvisibleSpace]\) - 0.233333333333333303`\ x, 
      \(14.2701837319691682`\[InvisibleSpace]\) - 5.55643307738887859`\ x, 
      \(2.82460747332503814`\[InvisibleSpace]\) - 0.389005108252801932`\ x, 
      \(16.6147636357941923`\[InvisibleSpace]\) - 5.83338397034696498`\ x, 
      \(1.81219028587242387`\[InvisibleSpace]\) - 0.146268746957490041`\ x}
      \)], "Output"],

Cell[BoxData[
    \({\(10.`\[InvisibleSpace]\) - 5.71428571428571441`\ x, 
      \(3.`\[InvisibleSpace]\) - 0.233333333333333303`\ x, 
      \(9.13968392542844121`\[InvisibleSpace]\) - 5.55643307738887859`\ x, 
      \(2.75130910396833749`\[InvisibleSpace]\) - 0.389005108252801932`\ x, 
      \(10.5114092084227217`\[InvisibleSpace]\) - 5.83338397034696498`\ x, 
      \(1.63806111312073703`\[InvisibleSpace]\) - 0.146268746957490041`\ x}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the outcome", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(QSolution1\  = \ 
      Plot[\ {case1[\([1]\)], case1[\([2]\)], case1[\([3]\)], case1[\([4]\)], 
          case1[\([5]\)], case1[\([6]\)]}, \n
        \t\ \ \ \ \ \ \ \ \ {x, bxl, bxh}, 
        PlotStyle 
          \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], RGBColor[0, 0, 1]}
            \ , \n\t\tPlotRange \[Rule] kader, 
        FrameLabel -> {"\<X\>", "\<Y\>"}, 
        PlotLabel -> "\<No Protection Eq\>", \n\t\tFrame -> True, 
        DisplayFunction -> Identity]; \n
    QSolution2\  = \ 
      Plot[\ {case2[\([1]\)], case2[\([2]\)], case2[\([3]\)], case2[\([4]\)], 
          case2[\([5]\)], case2[\([6]\)]}, \n
        \t\ \ \ \ \ \ \ \ \ {x, bxl, bxh}, 
        PlotStyle 
          \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], RGBColor[0, 0, 1]}
            \ , \n\t\tPlotRange \[Rule] kader, 
        FrameLabel -> {"\<X\>", "\<Y\>"}, 
        PlotLabel -> "\<Injury Margin Eq\>", \n\t\tFrame -> True, 
        DisplayFunction -> Identity]; \n
    QSolution3\  = \ 
      Plot[\ {case3[\([1]\)], case3[\([2]\)], case3[\([3]\)], case3[\([4]\)], 
          case3[\([5]\)], case3[\([6]\)]}, \n
        \t\ \ \ \ \ \ \ \ \ {x, bxl, bxh}, 
        PlotStyle 
          \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], RGBColor[0, 0, 1]}
            \ , \n\t\tPlotRange \[Rule] kader, 
        FrameLabel -> {"\<X\>", "\<Y\>"}, PlotLabel -> "\<Dumping Eq\>", \n
        \t\tFrame -> True, DisplayFunction -> Identity]; \n
    Show[QSolution1, DMRegion, IMRegion, QSolution1, 
      DisplayFunction -> $DisplayFunction]; \n
    Show[QSolution2, DMRegion, IMRegion, QSolution2, 
      DisplayFunction -> $DisplayFunction]; \n
    Show[QSolution3, DMRegion, IMRegion, QSolution3, 
      DisplayFunction -> $DisplayFunction]; \)], "Input",
  PageWidth->Infinity,
  FontSize->11],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0 0.123607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5 -5 ]
[-0.01875 .30902 -6 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -50 0 ]
[.5 .63053 50 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 0 m
.2 .00625 L
s
[(1)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(3)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(4)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(5)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -78.25 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.25 translate
90 rotate
-66 -10.25 translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.04 .61428 m
.04 .61803 L
s
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36 .61428 m
.36 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.52 .61428 m
.52 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.68 .61428 m
.68 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.84 .61428 m
.84 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(No) show
81.000000 12.750000 moveto
(Protection) show
147.000000 12.750000 moveto
(Eq) show
159.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.775 .61803 m
.79139 .56016 L
.83505 .40596 L
.87712 .25739 L
.9176 .11444 L
s
.9176 .11444 m
.95 0 L
s
0 1 0 r
0 .37082 m
.04057 .36497 L
.08481 .35859 L
.12636 .3526 L
.16632 .34684 L
.20885 .3407 L
.2498 .3348 L
.29331 .32852 L
.33524 .32248 L
.37557 .31666 L
.41848 .31047 L
.4598 .30451 L
.49953 .29878 L
.54183 .29268 L
.58254 .28681 L
.62583 .28057 L
.66752 .27456 L
.70762 .26878 L
.7503 .26262 L
.79139 .2567 L
.83505 .2504 L
.87712 .24433 L
.9176 .2385 L
.96065 .23229 L
1 .22661 L
s
0 0 1 r
.70301 .61803 m
.70762 .6022 L
.7503 .45564 L
.79139 .31454 L
.83505 .16461 L
.87712 .02014 L
s
.87712 .02014 m
.88298 0 L
s
1 0 0 r
0 .36726 m
.04057 .35751 L
.08481 .34687 L
.12636 .33688 L
.16632 .32728 L
.20885 .31705 L
.2498 .30721 L
.29331 .29674 L
.33524 .28666 L
.37557 .27697 L
.41848 .26665 L
.4598 .25672 L
.49953 .24717 L
.54183 .23699 L
.58254 .22721 L
.62583 .2168 L
.66752 .20678 L
.70762 .19714 L
.7503 .18687 L
.79139 .177 L
.83505 .1665 L
.87712 .15639 L
.9176 .14665 L
.96065 .1363 L
1 .12684 L
s
0 1 0 r
.81673 .61803 m
.83505 .55199 L
.87712 .40032 L
.9176 .25438 L
.96065 .09916 L
s
.96065 .09916 m
.98816 0 L
s
0 0 1 r
0 .26705 m
.04057 .26338 L
.08481 .25938 L
.12636 .25562 L
.16632 .25201 L
.20885 .24817 L
.2498 .24446 L
.29331 .24053 L
.33524 .23674 L
.37557 .23309 L
.41848 .22922 L
.4598 .22548 L
.49953 .22189 L
.54183 .21807 L
.58254 .21438 L
.62583 .21047 L
.66752 .2067 L
.70762 .20308 L
.7503 .19922 L
.79139 .19551 L
.83505 .19156 L
.87712 .18776 L
.9176 .1841 L
.96065 .1802 L
1 .17665 L
s
.9 g
.4988 .03743 m
0 .18129 L
0 .61803 L
.17 .61803 L
F
.6 g
.4988 .03743 m
.17 .61803 L
1 .61803 L
1 .54078 L
F
1 0 0 r
.775 .61803 m
.79139 .56016 L
.83505 .40596 L
.87712 .25739 L
.9176 .11444 L
s
.9176 .11444 m
.95 0 L
s
0 1 0 r
0 .37082 m
.04057 .36497 L
.08481 .35859 L
.12636 .3526 L
.16632 .34684 L
.20885 .3407 L
.2498 .3348 L
.29331 .32852 L
.33524 .32248 L
.37557 .31666 L
.41848 .31047 L
.4598 .30451 L
.49953 .29878 L
.54183 .29268 L
.58254 .28681 L
.62583 .28057 L
.66752 .27456 L
.70762 .26878 L
.7503 .26262 L
.79139 .2567 L
.83505 .2504 L
.87712 .24433 L
.9176 .2385 L
.96065 .23229 L
1 .22661 L
s
0 0 1 r
.70301 .61803 m
.70762 .6022 L
.7503 .45564 L
.79139 .31454 L
.83505 .16461 L
.87712 .02014 L
s
.87712 .02014 m
.88298 0 L
s
1 0 0 r
0 .36726 m
.04057 .35751 L
.08481 .34687 L
.12636 .33688 L
.16632 .32728 L
.20885 .31705 L
.2498 .30721 L
.29331 .29674 L
.33524 .28666 L
.37557 .27697 L
.41848 .26665 L
.4598 .25672 L
.49953 .24717 L
.54183 .23699 L
.58254 .22721 L
.62583 .2168 L
.66752 .20678 L
.70762 .19714 L
.7503 .18687 L
.79139 .177 L
.83505 .1665 L
.87712 .15639 L
.9176 .14665 L
.96065 .1363 L
1 .12684 L
s
0 1 0 r
.81673 .61803 m
.83505 .55199 L
.87712 .40032 L
.9176 .25438 L
.96065 .09916 L
s
.96065 .09916 m
.98816 0 L
s
0 0 1 r
0 .26705 m
.04057 .26338 L
.08481 .25938 L
.12636 .25562 L
.16632 .25201 L
.20885 .24817 L
.2498 .24446 L
.29331 .24053 L
.33524 .23674 L
.37557 .23309 L
.41848 .22922 L
.4598 .22548 L
.49953 .22189 L
.54183 .21807 L
.58254 .21438 L
.62583 .21047 L
.66752 .2067 L
.70762 .20308 L
.7503 .19922 L
.79139 .19551 L
.83505 .19156 L
.87712 .18776 L
.9176 .1841 L
.96065 .1802 L
1 .17665 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L00?l78@L00?l78@L00?l78@L009H7
0P000`L000251`00U`L00`0700261`00V0L00`071`251`00V0L00`071`251`00U`L00`0700261`00
UPL200031`0008D7003o1b47003o1b47003o1b47001D1`D0:0L302X70P0[1`<0:@L00`071`0F1`00
EPL00`071`0X1`0300L702`700<01`L0:@L00`071`0W1`0300L001L7001F1`0300L702T700<01`L0
:PL00`071`0X1`@0:PL00`071`0E1`00EPL00`071`0Y1`0300L702/700<01`L09`L00`07000Y1`80
60L005H700<01`L0:0L00`07000Z1`0300L002X70P0Y1`0300L701L7001E1`80:`L00`071`0Z1`03
00L702X700<01`L09`L301L7003o1b47003o1b47003o1b47003o1b47003o1b47000Z1l@000?l0000
30000oT000050004nP0001L7000Z1`0300L700H700<01`L01@L00`071`061`0300L700H700<01`L0
1PL00`071`061`0300L700H700<01`L01PL00`071`061`0300L700H700<01`L01@L00`071`061`03
00L700H700<01`L01PL00`071`061`0300L700H700<01`L01PL00`071`061`0300L700H700<01`L0
1PL00`071`051`0300L700H700<0o0L01PL00`071`041`03n@L000D700Cj1`L05`L002X700<01`L0
`0L00o`71`0<1`03n@L700D700Gj1`L7000G1`00:PL00`071`301`03o0L700`700?i1`L01@L01OX7
1`L001L7000Z1`0300L70<0700?l1`L030L00oT71`051`05nPL71`005`L002X70P311`03o0L700`7
00?i1`L01@L00oX71`0201L7000Z1`0300L70;l700?l1`L030L00oT71`051`03nPL7008700<01`L0
5@L002X700<01`L0_`L00o`71`0<1`03n@L700D700?j1`L00PL00`071`0E1`00:PL00`071`2o1`03
o0L700`700?i1`L01@L00oX71`021`0300L701D7000Z1`0300L706X700?oRHT0D@L00o`71`0<1`03
n@L700H700?j1`L00PL00`071`0E1`00:PL00`071`1V1`:d0_l01;B9RHU@1`03o0L700`700?i1`L0
1@L00oX71`031`0300L701D7000Z1`80I0L2o`03]?oo00:d1HU?1`03o0L700`700?i1`L01@L00oX7
1`021`805`L002X700<01`L0G`L00kCoo`02]0;o0[@2o`J9C@L00o`71`0=1`03n@L700D700?j1`L0
0`L00`071`0E1`00:PL00`071`1L1`:d0_l2]0;o0[@2o`03]8V900J9C0L00o`71`0<1`03n@L700D7
00?j1`L010L00`071`0E1`00:PL00`071`1H1`;o0[@2o`:d0_l2]0;o0[@00on9R@07RD/700?l1`L0
30L00oT71`051`03nPL700@700<01`L05@L002X700<01`L0E@L00kCoo`02]0;o0[@2o`:d0_l2]0;o
2hU:1`03o0L700`700?i1`L01@L00oX71`041`0300L701D7000Z1`80DPL00ond]002o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@0;RDP700?l1`L03@L00oT71`051`03nPL700<70P0G1`00:PL00`071`1>1`;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900b9A`L00o`71`0<1`03n@L700D700?j1`L01@L00`07
1`0E1`00:PL00`071`1;1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oa29APL00o`71`0<1`03
n@L700D700?j1`L01@L00`071`0E1`00:PL00`071`171`03okBd00?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dRHT03hU41`03o0L700d700?i1`L01@L00oX71`051`0300L701D7000Z1`03
00L704@70_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0ARD<700?l1`L030L00oT7
1`061`03nPL700D700<01`L05@L002X700<01`L0@0L2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@0BRD8700?l1`L030L00oT71`051`03nPL700H700<01`L05@L002X70P0n1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]1J9@0L00o`71`0=1`03n@L700D7
00?j1`L01@L201L7000Z1`0300L703T700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@0FRCl700?l1`L03@L00oT71`051`03nPL700H700<01`L05@L002X700<01`L0
=PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V901N9?PL00o`7
1`0<1`03n@L700D700?j1`L01`L00`071`0E1`008PL500<700<01`L0<PL2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@KRC`700?l1`L03@L00oT71`051`03nPL700L7
00<01`L05@L002@700<01`L00`L00`071`0_1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2oab9>`L00o`71`0=1`03n@L700D700?j1`L01`L00`071`0E1`00
90L00`071`031`80;0L2o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`04]?oo]1j9>PL00o`71`0<1`03n@L700H700?j1`L01PL201L7000T1`03
00L700<700<01`L0:0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]003ohV901f9>0L00o`71`0=1`03n@L700D700?j1`L01PL3nAL7000T1`0300L700<7
00<01`L090L2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_lQRCL700?l1`L03@L00oT71`051`03nPL700871?T21`0300L701D7000S1`801@L00`07
1`0Q1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@0QRCH700?l1`L03@L00oT71`051`03n_Wi00;i1PL00`071`0E1`00:PL00`07
1`0M1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00?oRHT08XTe1`03o0L700`700?i1`L00PL4n@03nPL700P700<01`L05@L002X7
00<01`L06PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2obJ9<`L00o`71`0=1`Gi0`L00oX71`091`0300L701D7000Z1`8060L00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]2N9<PL00o`71`0;1`?i1`L00oX71`081`805`L002X700<01`L04`L00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?oRHT09hTa1`03o0L700P70oT00`Oi1`071`03nPL700T700<01`L05@L002X700<01`L0
40L2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o:XT_1`03o0L700D71?T41`03n@L700H7
00?j1`L02@L00`071`0E1`00:PL00`071`0<1`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d;8T^1`03o0L700Gi
20L00oT71`051`03nPL700X700<01`L05@L002X700<01`L02@L00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@00on9R@0/RB/71OT=1`03n@L700D700?j1`L02PL00`071`0E1`00:PL200H700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V902f99PL4n@031o`700h700?i1`L01PL00oX71`091`805`L002X7
00<01`L00PL2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d<HTP1`Gi1@L00o`71`0=1`03n@L700D7
00?j1`L01`L5o1L7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oc:96PL5n@X7
00?l1`L03@L00oT71`051`03n_cl00Ol10L00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>dRHT0<XTE1`Ci3`L00o`71`0<1`03nOcl00Ol3@L00`071`0E1`00:PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d=XTA1`?i40LCo0P700?j1`L02`L00`071`0E1`00
:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo03N9
3@L3n@X72O`21`03o0L700d700?i1`L01@L00oX71`0<1`0300L701D7000Z1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0=hT81`Ci0`L:o0/700?l1`L03@L00oT71`051`03nPL700/7
0P0G1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV903R90`L2n@Wl5@L00o`7
1`0<1`03n@L700H700?j1`L030L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2ocN92O`M1`03o0L700d700?i1`L01PL00oX71`0<1`0300L701D7000Z1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d98TCo0;i18TP1`03o0L700d700?i1`L01@L00oX71`0=1`0300L701D7
000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV901Z92O`<R@Gi2HTO1`03o0L700d7
00?i1`L01@L00oX71`0=1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oaB9
2O`@R@Gi3hTN1`03o0L700`700?i1`L01PL00oX71`0<1`805`L002X700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d2hT9o1F91?TERA`700?l1`L03@L00oT71`061`03nPL700T71OXG1`00:PL00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@01?n9RHT9o1^90oTJRA/7
00?l1`L03@L00oT71`051`03nPL700<71oX41`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]?cl017l
8HT3nAj96PL00o`71`0<1`03n@L700H700?j1oX00oX;1`0300L701D7000S1`<010L00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d2O`00ond
]002o`:d0_l2]0;o0[@QR@Ci8XTH1`03o0L700d700Ci1`L71oX?1`0300L701D7000S1`0300L700@7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d2_`2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_lMR@Ci9hTG1`03o0L700X71oX51`03nPL700h700<01`L05@L002@7
00<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003oocl00Ol
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0GR@Gi;8TF1`03o0L700D71OX31`03
n@L700D700?j1`L03PL201L7000T1`0300L700<700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o2O`00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]1J91?TbRAD7
00?ln_X01OX71`03n@L700H700?j1`L03`L00`071`0E1`008`L00`0700041`03]?oo00:d0_l2]0;o
0[@2oa;l0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lAR@Gi
=hT<1`Oj00?lnPL03@L00oT71`061`03nPL700l700<01`L05@L002@700<01`L00`L00ond]002o`[l
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT038T4nCf90`L8nPL700?l1`L03@L00oT71`051`03nPL7010700<01`L05@L002X7
1O`3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?n900R91OU0R@Cj3`L00o`71`0<1`03
n@L700H700?j1`L040L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l5R@Gi?XT7nP>9
40L00o`71`0<1`03n@L700H700?j1`L03`L201L7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ROWi00;i>XT9nP^93PL00o`71`0=1`03n@L700H700?j1`L040L00`071`0E1`00:PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0oTgR@Oj5HT=1`03o0L700`700?i1`L01PL00oX71`0A1`0300L701D7000Z1`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`04]?WinCF91OXMR@`700?l1`L030L00oT71`061`03nPL7014700<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00ooin@02n@03okBd02j91oXSR@/700?l1`L030L00oT71`061`03
nPL7014700<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]?Wi00;i00>dool00[@00on9R@0TR@Wj:XT:1`03
o0L700d700?i1`L01PL00oX71`0A1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0Gi00?o];@00_l2]0;o00>dRHT0
7HT7nSB92@L00o`71`0<1`03n@L700H700?j1`L04@L201L7000F1`0300L7014700>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oi00Ci00Co]?oo0[@3o`03]?oo00:d78T4nSb920L00o`71`0<1`03n@L700H700?j1`L04PL00`07
1`0E1`005PL2018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l5n@03]?oo00:d0_l2]0;o0[@2o`:d0_lER@Oj@HT71`03o0L700`700?i1`L01PL00oX7
1`0B1`0300L701D7000F1`0300L0008700<01`L030L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d1?T2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT02hT9nTV9
1@L00o`71`0<1`03n@L700H700?j1`L04`L00`071`0E1`006@L300h700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o1?T2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0J9
2?YCR@@700?l1`L030L00oT71`061`03nPL701<700<01`L05@L001H700<01`000PL00`071`0<1`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00ConOWi0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0XT4nUb90`L00o`71`0<1`03n@L700H700?j1`L04PL201L7000F1`80
4PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@3n@03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]?[j00GjHHT00`Ol1`0=1`03n@L700L700?j1`L04`L00`071`0E1`00
:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`Ci0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0Wj00Co];CoIHT00o`71`0<1`03n@L700H700?j1`L050L00`071`0E1`00:PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d1?T2o`:d0_l2]0;o0[@2o`:d0_l8nP:d0_l2]0;o0[@2ofJ9
00?l1`L030L00oT71`061`03nPL701@700<01`L05@L002X700>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dooT01?T01?ndool2]0?o00>dool00[@3o`03]?[j00;j0ol00kCoo`02]0?o00>dool0
0[@3o`03]8V906>900?lRHT03@L00oT71`061`03nPL701@700<01`L05@L002X700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o00>dnOT00_T00kCoo`02]0;o0[@2o`:d0_l00kCjnP05nP:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@1TR@04o8V9R@/700?i1`L01`L00oX71`0D1`0300L701D7000Z1`03]?oo00:d
0_l2]0;o0[@2o`:d1OT00ond]002o`:d0_l2]0Wj00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_mWR@03o8V900:92PL00oT71`061`03nPL701@70P0G1`00:PL00ond]002o`:d0_l2]003ooWi00?i
0[@2o`:d0_l00kCjnP05nP:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dIXT00ob9
R@04R@T700?i1`L01PL00oX71`0E1`0300L701D7000Z1`03]?oo00:d0_l5n@03]?oo00:d0_l2]003
oo[j00;j00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV906F9
00?lRHT01HT71`03n@L700L700?j1`L05@L00`071`0E1`008`L200D700?o];@01?T2o`:d0_l2]0Oj
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@1UR@03
o8V900J91PL00oT71`061`03nPL701H700<01`L05@L002D700<01`L00PL3n@:d2_X2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[AWR@03o8V900R91@L00oT7
1`061`03nPL701H700<01`L05@L002@700<01`L00`L5nP:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_mWR@03o8V900V90`L00oT71`071`03
nPL701D70P0G1`009@L00`071`021`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00BdoondJ8T00ob9R@0:R@87
00?i1`L01`L00oX71`0F1`0300L701D7000S1`0300L000@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]6R900?lRHT038T00`Oi
1`071`03nPL701L700<01`L05@L002@700<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oJ8T00ob9R@0=R@03n@L700H7
00?j1`L05`L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V906N900?lRHT038T00oV91`071`03nPL701L7
00<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1WR@03o8V900b900?iRHT01`L00oX71`0G1`0300L701D7
000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;oJHT00ob9R@0=R@04nHV9R@D700?j1`L05`L201L7000Z1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dJHT00ob9
R@0<R@03nHV900>910L00oX71`0H1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV906R900?lRHT038T00oV9
R@04R@<700?j1`L060L00`071`0E1`00:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@2ofZ900?lRHT03HT00oV9
R@05R@031oX701X700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dJXT00ob9R@0<R@03nHV900N900?j1`L06@L00`07
1`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00?oRHT0JHT00ob9R@0<R@03nHV900N900?j1`L060L201L7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9
R@1XR@03o8V900f900?iRHT01hT00oZ91`0I1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[A[R@03o8V900f900?iRHT0
1XT01?Z9RHTI1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_m[R@03o8V900b900?iRHT01hT00oZ9R@02RAP700<01`L0
5@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@1YR@03o8V900f900?iRHT01hT00oZ9R@03RAL700<01`L05@L002X700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[A/R@03
o8V900f900?iRHT01XT00oZ9R@05RAH700<01`L05@L002X700>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo06b900?lRHT0
3HT00oV9R@06R@03nXV900J950L201L7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V906Z900?lRHT03HT00oV9R@07R@03nXV900N9
50L00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@00on9R@1ZR@03o8V900f900?iRHT01XT00oZ9R@09RA<700<01`L05@L002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
KHT00ob9R@0=R@03nHV900J900?jRHT02XTB1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]6b900?lRHT03XT00oV9R@06R@03
nXV900^94@L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0JhT00ob9R@0=R@03nHV900N900?jRHT038T?1`805`L002X7
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ofj9
00?lRHT03HT00oV9R@06R@03nXV900j93`L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dKXT00ob9R@0=R@03nHV900J900?jRHT0
3hT>1`0300L701D7000Z1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d00?oRHT0K8T00ob9R@0=R@03nHV900N900?jRHT048T=1`03
00L701D7000T1`<00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V906b900?lRHT03HT00oV9R@06R@03nXV901:930L00`071`0E1`009@L00`07
1`021`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
KhT00ob9R@0=R@03nHV900J900?jRHT04hT;1`0300L701D7000S1`@00`L00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1^R@03o8V900f900?iRHT0
1XT00oZ9R@0DR@T70P0G1`008`L00`0700041`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V906f900?lRHT03HT00oV9R@07R@03nXV901F92@L00`07
1`0E1`0090L200@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:dL8T00ob9R@0=R@03nHV900J900?jRHT05hT81`0300L701D7000U1`0300L7008700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oL8T00ob9R@0=R@03
nHV900J900?jRHT068T71`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@1^R@03o8V900j900?iRHT01XT00oZ9R@0IR@H700<01`L0
5@L002X700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dohT0KhT00ob9R@0=R@03nHV900J900?jRHT06hT41`805`L002X700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2og6900?lRHT03HT00oV9R@06R@03
nXV901b910L00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V9072900?lRHT03HT00oV9R@06R@03nXV901f90`L00`071`0E1`00:PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV906n900?lRHT0
3XT00oV9R@05R@03nXV901n90PL00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2og:900?lRHT03HT00oV9R@06R@03nXV9022900<700L05PL002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[AbR@03o8V900f9
00?iRHT01XT00oZ9R@0QR@0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]003ohV9076900?lRHT03HT00oV9R@06R@03nXV9026900<01`L05@L002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0L8T00ob9
R@0>R@03nHV900F900?jRHT08XT00`071`0E1`00:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:dLhT00ob9R@0=R@03nHV900J900?jRHT08XT00`07
1`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
LXT00ob9R@0=R@03nHV900J900?jRHT08XT00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0LHT00ob9R@0>R@03nHV900F900?jRHT08hT00`07
1`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dM8T00ob9
R@0=R@03nHV900J900?jRHT08hT00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;oM8T00ob9R@0=R@03nHV900J900?jRHT08hT00`071`0E1`00:PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V907>900?lRHT03HT00oV9
R@06R@03nXV902>900<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@1bR@03o8V900f900?iRHT01XT00oZ9R@0TR@0300L701D7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oMHT00ob9R@0=R@03nHV900J900?jRHT0
98T00`071`0E1`00:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3ogJ900?lRHT03HT00oV9R@06R@03nXV902B900<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0M8T00ob9R@0=R@03nHV900F900?jRHT09HT00`07
1`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_mfR@03o8V900f9
00?iRHT01XT00oZ9R@0UR@0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]7J900?lRHT03HT00oV9R@06R@03nXV902F900<01`L05@L002@700<01`L00`L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0MHT00ob9R@0=R@03nHV900J9
00?jRHT09HT00`071`0E1`008`L00`0700041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@1dR@03o8V900f900?iRHT01XT00oZ9R@0VR@0300L701D7000U1`0300L70087
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]7N900?lRHT03HT00oV9R@06R@03
nXV902J900<01`L05@L002<70P3k1`008`L00`071`3j1`008`L30?X7003o1b47003o1b4700351`80
F@L00<H700<01`L0E`L006T70`0010L01`L200T70`031`<00`L200<70P031`800PL300<70P021`<0
0`L200031`00008700<01`L03PL500870`1I1`00JPL01P070007008700<01`L01`L00`071`031`05
00L71`000PL00`0700021`0300L000@700<01`L00PL010071`021`0500L71`000PL00`0700021`03
00L700l700H01`L01`021`0300L705L7001Z1`0600L000L00PL00`071`071`<00`L01@071`L00087
00<01`0010L3008700<01`L00PL00`071`031`0500L71`000PL00`0700021`0300L700l700<01`L0
0PL010071`1I1`00JPL200041`071`802PL01@071`0700@00PL200031`0000800PL300870`000`L0
000200870P041`8000<700000P0B1`8010L305T7001Z1`8000<700L03@L010071`0;1`0300L700`7
00<01`L08@L010071`1N1`00J@L200031`0000d7100Q1`0300L701X71@1N1`00o`LQ1`00o`LQ1`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.949035, -0.883654, 
  0.0224936, 0.0363954}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0 0.123607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5 -5 ]
[-0.01875 .30902 -6 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -50.0938 0 ]
[.5 .63053 50.0938 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 0 m
.2 .00625 L
s
[(1)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(3)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(4)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(5)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -78.25 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.25 translate
90 rotate
-66 -10.25 translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.04 .61428 m
.04 .61803 L
s
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36 .61428 m
.36 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.52 .61428 m
.52 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.68 .61428 m
.68 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.84 .61428 m
.84 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -111.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Injury) show
105.187500 12.750000 moveto
(Margin) show
147.187500 12.750000 moveto
(Eq) show
159.187500 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.375 .61803 m
.37557 .61601 L
.41848 .46447 L
.4598 .31854 L
.49953 .17824 L
.54183 .02885 L
s
.54183 .02885 m
.55 0 L
s
0 1 0 r
0 .37082 m
.04057 .36497 L
.08481 .35859 L
.12636 .3526 L
.16632 .34684 L
.20885 .3407 L
.2498 .3348 L
.29331 .32852 L
.33524 .32248 L
.37557 .31666 L
.41848 .31047 L
.4598 .30451 L
.49953 .29878 L
.54183 .29268 L
.58254 .28681 L
.62583 .28057 L
.66752 .27456 L
.70762 .26878 L
.7503 .26262 L
.79139 .2567 L
.83505 .2504 L
.87712 .24433 L
.9176 .2385 L
.96065 .23229 L
1 .22661 L
s
0 0 1 r
.33367 .61803 m
.33524 .61266 L
.37557 .47415 L
.41848 .32679 L
.4598 .1849 L
.49953 .04848 L
s
.49953 .04848 m
.51365 0 L
s
1 0 0 r
0 .34914 m
.04057 .33939 L
.08481 .32875 L
.12636 .31876 L
.16632 .30915 L
.20885 .29893 L
.2498 .28909 L
.29331 .27862 L
.33524 .26854 L
.37557 .25885 L
.41848 .24853 L
.4598 .2386 L
.49953 .22904 L
.54183 .21887 L
.58254 .20909 L
.62583 .19868 L
.66752 .18866 L
.70762 .17901 L
.7503 .16875 L
.79139 .15888 L
.83505 .14838 L
.87712 .13827 L
.9176 .12853 L
.96065 .11818 L
1 .10872 L
s
0 1 0 r
.39822 .61803 m
.41848 .54497 L
.4598 .396 L
.49953 .25278 L
.54183 .10027 L
s
.54183 .10027 m
.56964 0 L
s
0 0 1 r
0 .224 m
.04057 .22033 L
.08481 .21633 L
.12636 .21258 L
.16632 .20896 L
.20885 .20512 L
.2498 .20142 L
.29331 .19748 L
.33524 .19369 L
.37557 .19005 L
.41848 .18617 L
.4598 .18243 L
.49953 .17884 L
.54183 .17502 L
.58254 .17134 L
.62583 .16742 L
.66752 .16366 L
.70762 .16003 L
.7503 .15617 L
.79139 .15246 L
.83505 .14851 L
.87712 .14471 L
.9176 .14105 L
.96065 .13716 L
1 .1336 L
s
.9 g
.4988 .03743 m
0 .18129 L
0 .61803 L
.17 .61803 L
F
.6 g
.4988 .03743 m
.17 .61803 L
1 .61803 L
1 .54078 L
F
1 0 0 r
.375 .61803 m
.37557 .61601 L
.41848 .46447 L
.4598 .31854 L
.49953 .17824 L
.54183 .02885 L
s
.54183 .02885 m
.55 0 L
s
0 1 0 r
0 .37082 m
.04057 .36497 L
.08481 .35859 L
.12636 .3526 L
.16632 .34684 L
.20885 .3407 L
.2498 .3348 L
.29331 .32852 L
.33524 .32248 L
.37557 .31666 L
.41848 .31047 L
.4598 .30451 L
.49953 .29878 L
.54183 .29268 L
.58254 .28681 L
.62583 .28057 L
.66752 .27456 L
.70762 .26878 L
.7503 .26262 L
.79139 .2567 L
.83505 .2504 L
.87712 .24433 L
.9176 .2385 L
.96065 .23229 L
1 .22661 L
s
0 0 1 r
.33367 .61803 m
.33524 .61266 L
.37557 .47415 L
.41848 .32679 L
.4598 .1849 L
.49953 .04848 L
s
.49953 .04848 m
.51365 0 L
s
1 0 0 r
0 .34914 m
.04057 .33939 L
.08481 .32875 L
.12636 .31876 L
.16632 .30915 L
.20885 .29893 L
.2498 .28909 L
.29331 .27862 L
.33524 .26854 L
.37557 .25885 L
.41848 .24853 L
.4598 .2386 L
.49953 .22904 L
.54183 .21887 L
.58254 .20909 L
.62583 .19868 L
.66752 .18866 L
.70762 .17901 L
.7503 .16875 L
.79139 .15888 L
.83505 .14838 L
.87712 .13827 L
.9176 .12853 L
.96065 .11818 L
1 .10872 L
s
0 1 0 r
.39822 .61803 m
.41848 .54497 L
.4598 .396 L
.49953 .25278 L
.54183 .10027 L
s
.54183 .10027 m
.56964 0 L
s
0 0 1 r
0 .224 m
.04057 .22033 L
.08481 .21633 L
.12636 .21258 L
.16632 .20896 L
.20885 .20512 L
.2498 .20142 L
.29331 .19748 L
.33524 .19369 L
.37557 .19005 L
.41848 .18617 L
.4598 .18243 L
.49953 .17884 L
.54183 .17502 L
.58254 .17134 L
.62583 .16742 L
.66752 .16366 L
.70762 .16003 L
.7503 .15617 L
.79139 .15246 L
.83505 .14851 L
.87712 .14471 L
.9176 .14105 L
.96065 .13716 L
1 .1336 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L00?l78@L00?l78@L00?l78@L009H7
0P000`L000251`00U`L00`0700261`00V0L00`071`251`00V0L00`071`251`00U`L00`0700261`00
UPL200031`0008D7003o1b47003o1b47003o1b47001D1`D0:0L302X70P0[1`<0:@L00`071`0F1`00
EPL00`071`0X1`0300L702`700<01`L0:@L00`071`0W1`0300L001L7001F1`0300L702T700<01`L0
:PL00`071`0X1`@0:PL00`071`0E1`00EPL00`071`0Y1`0300L702/700<01`L09`L00`07000Y1`80
60L005H700<01`L0:0L00`07000Z1`0300L002X70P0Y1`0300L701L7001E1`80:`L00`071`0Z1`03
00L702X700<01`L09`L301L7003o1b47003o1b47003o1b47003o1b47003o1b47000Z1g8000?l0000
1@001OT0003j06005`L002X700<01`L01PL00`071`051`0300L700H700<01`L01PL00`071`061`03
00L700H700<01`L01PL00`071`061`0300L700H700<01`L01PL00`071`051`0300L700H700<01`L0
1@L00o`01`051`05n@L01oX01PL00`071`061`0300L700H700<01`L01PL00`071`061`0300L700H7
00<01`L01@L00`071`061`0300L700H700<01`L01PL00`071`061`0300L701D7000Z1`0300L706h7
00?l1`L01@L01OT71`Oj060700<01`L05@L002X700<01`L0KPL00o`71`051`05n@L71oX0H0L00`07
1`0E1`00:PL00`071`1^1`03o0L700D700Gi1`L7nP1P1`0300L701D7000Z1`80K`L00o`71`041`03
n@L7008700?j1`L0G@L201L7000Z1`0300L706d700?l1`L01@L01OT71`Oj064700<01`L05@L002X7
00<01`L0K@L00o`71`051`05n@L71oX0H@L00`071`0E1`00:PL00`071`1]1`03o0L700@700?i1`L0
0PL00oX71`1O1`0300L701D7000Z1`0300L706X700CoRHWl1PL00oT71`021`03nPL705l700<01`L0
5@L002X700<01`L0IPL2]0;o00BdROb91PL01OT71`Oj068700<01`L05@L002X70P1T1`;o00>dool0
0[@2R@03o8V900D700Gi1`L7nP1Q1`805`L002X700<01`L0G`L00kCoo`02]0;o0[@2o`:900ClRHV9
0`L00oT71`021`03nPL7060700<01`L05@L002X700<01`L0G0L2]0;o0[@2o`:d0_l01;B9RO`5R@87
00Gi1`L7nP1S1`0300L701D7000Z1`0300L705P70_l2]0;o0[@2o`:d0_l2]004ohV9o0J900<7n@L0
0PL00oX71`1Q1`0300L701D7000Z1`0300L705D700>dool00[@2o`:d0_l2]0;o0[@2o`>900?lRHT0
1HT01OT71`Oj06<700<01`L05@L002X70P1B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`05]8V9RO`0
1hT00oV91`021`03nPL706070P0G1`00:PL00`071`1>1`;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]005
ohV9RO`01hT01OV9R@Oj06@700<01`L05@L002X700<01`L0B`L00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l4R@03o8V900F900GiRHV9nP1T1`0300L701D7000Z1`0300L704L700?o];@00ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kB9R@02R@03o8V900B900?iRHT00XT00oX71`1R1`03
00L701D7000Z1`0300L704@70_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@02R@03
o8V900F900?iRHT00XT00oZ91`1R1`0300L701D7000Z1`0300L704070[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT00XT00ob9R@05R@05nHV9ROX00hUR1`0300L701D7000Z1`80
?PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@5R@03o8V900F900GiRHV9
nP04RF070P0G1`00:PL00`071`0i1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?oRHT00hT00ob9R@05R@03nHV900:900?jRHT00hUP1`0300L701D7000Z1`0300L703H7
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@03R@03o8V900F9
00GiRHV9nP07REd70oTG1`008PL500<700<01`L0<PL2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@6R@03o8V900F900GiRHV9nP08REP71?T21`0300L701D7000T1`03
00L700<700<01`L0;`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l5R@03o8V900J900GiRHV9nP09RE871OT61`0300L701D7000T1`0300L700<70P0/1`;o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00Bdoond1XT00ob9R@05R@03nHV900:900?jRHT028U=1`Ci2PL201L7000T1`0300L700<700<01`L0
:0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ohV900B900?lRHT01HT01OV9RHWj00b9B0L4n@l700<01`L05@L002@700<01`L00`L00`071`0T1`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`N9
00?lRHT01HT01OV9RHWj00f9A0L3nA<700<01`L05@L002<70P051`0300L7024700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V900F9
00?lRHT01HT00oV9R@02R@03nXV900b9@0L3n@T73_`G1`00:PL00`071`0M1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
1HT00ob9R@05R@03nHV900:900?jRHT03HTk1`Ci0`L9o0d700<01`L05@L002X700<01`L06PL2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`R900?lRHT01HT01OV9RHWj0169=@L3n@Wl5PL00`071`0E1`00:PL201P700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@7R@03o8V900J900GiRHV9nP0BRBd72_`N1`805`L002X700<01`L04`L00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?oRHT01XT00ob9R@05R@03nHV900:900?jRHT04HTS1`Wl0_TW1`0300L701D7000Z1`0300L70107
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`R900?lRHT01HT00oV9R@02R@03nXV901:9
3`LCo0871OT[1`0300L701D7000Z1`0300L700`70_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@8R@03o8V900J9
00GiRHV9nP0FR@D72O`@1`Gi<0L00`071`0E1`00:PL00`071`091`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]003ohV900N900?lRHT01XT01OV9RHWj01:92O`E1`Ci=@L00`071`0E1`00:PL200H700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V900N900?lRHT01HT00oV9R@02R@03nXV900J92_`6RAD7
0oTh1`805`L002X700<01`L00PL2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d2XT00ob9R@05R@05
nHV9ROX02O`ARA470oTl1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`F94_`KR@`71?To1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
2O`4R@03o8V900F900?iRHT00XT00oZ9R@0JR@L71?U31`0300L701D7000Z1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@:o0:d2hT00ob9R@05R@03nHV900:900?jRHT06hT00`Oin@03nDL700<01`L05@L002X7
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]003oocl00Ol00Co]?oo0[@3o`03]?oo00Z900?lRHT0
1XT01OV9RHWj01^91?U<1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l9o003]?oo00:d0_l2]0;o0[@2o`:d0_l00kB9
R@09R@03o8V900J900GiRHV9nP0FR@Gi1HU:1`805`L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00oolo00Ao0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9
R@09R@03o8V900F900?iRHT00XT00oZ9R@0?R@Gi2hU:1`0300L701D7000Z1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`Wl00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l<R@03o8V900F900?iRHT00XT00oZ9R@0:R@Gi4HU91`0300L701D7000Z1`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o00>do?`01o`2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0^900?lRHT01XT01OV9RHWj00V91?TGRDP700<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d2O`00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0:R@03o8V900F900?iRHT00XT00oZ9
R@03R@Ci78U71`0300L701D7000Z1`03]?oo00:d2_`2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l=R@03o8V900F900?iRHT0
0XT00oZ9R@03nB69A@L201L7000Z1`Gl0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0b900?lRHT01XT00oV9
R@02R@03n_Wi02F9@@L5nQL7000Z1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]003ohV900^900?lRHT01XT4n@03nXV902N9>@L7nP@700<01`L05@L002X700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V900^900?lRHT00hT4n@>900?jRHT0:8Td1`Cj2`L00`07
1`0E1`008`L300@700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0j900?lnOT00oT2R@03nHV900:9
00?jRHT0:HT/1`Oj3`L00`071`0E1`008`L00`071`041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l;R@Ci1hT00oV9R@02R@03nXV902Z990L7nQH700<01`L05@L002@700<01`L00`L00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V900F91OT2R@03o8V900F900?iRHT00XT00oZ9R@0/RAh71OXL1`80
5`L002@700<01`L00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0>91OT7R@03o8V900F900?iRHT0
0XT00oZ9R@0]RAH71oXR1`0300L701D7000S1`0300L000@700>dool00[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?onOT00_T;R@03o8V900J900?iRHT00XT00oZ9R@0^R@`72OXY1`0300L701D7000T1`0300L700<7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0?i3hT00ob9R@06R@05nHV9ROX0<XT31`Sj<PL00`071`0E1`00
:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol01;Cook@3n@03okCo00n900?lRHT01HT00oV9
R@02R@03nXV902n91?Xj1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?onOT00_T00ond]002o`n9
00?lRHT01XT00oV9R@02R@03nXV902R91oX3RCX70P0G1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dnOT00_T00kCo
o`02]0;o0[@?R@03o8V900J900?iRHT00XT00oZ9R@0OR@Wj2hTj1`0300L701D7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0Gi
00?o];@00_l2]0;o0[@00on9R@0>R@03o8V900J900GiRHV9nP0KR@Oj5HTi1`0300L701D7000Z1`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ooWi00?i0[@2o`:d0_l2]0;o0[@2oa6900?lRHT01HT00oV9R@02R@03nXV901B91OXMRCP700<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l5n@03]?oo00:d0_l2]0;o0[@2o`:d0_l2]12900?lRHT01XT00oV9R@02R@03nXV900f91oXSRCL7
00<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0Ci0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT03hT00ob9R@06R@05nHV9ROX01hT9nRZ9
=`L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l4n@:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0?R@03o8V900F900?iRHT00XT8nSB9
=@L201L7000F1`0300L7014700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCon@02n@?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@AR@03
o8V900J900?iROX00oXlRCD700<01`L05@L001H70P0B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0?i00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lAR@04
o8V9R@Oj0hT00oZ9R@0kRC@700<01`L05@L001H700<01`000PL00`071`0<1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o1?T2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@0;R@Gj00Cln_[j1HT01OV9RHWj03n9<`L00`071`0E1`006@L300h700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0Ci0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0J92?X5R@03o8V900F900?iRHT00XT00oZ9R@0nRC8700<01`L05@L001H700<01`000PL00`07
1`0<1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00ooin@03n@:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0XT4nPb900?lRHT01XT00oV9R@02R@03nXV903n9<0L201L7
000F1`804PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l00kCin@02n@03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kCjnP05nQ2900?lRHT01XT01OV9RHWj04>9<0L00`07
1`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0Gi00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d2OX01?nd]?lCR@03o8V900F900?iRHT00XT00oZ9R@12RBl700<01`L05@L002X7
00?o];@00_l2]0;o0[@00ooin@03n@:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`Sj
0[@2o`:d0_l2]0;o4hT00ob9R@06R@03nHV900:900?jRHT0@hT^1`0300L701D7000Z1`03]?oo00:d
0_l5n@05]?oook@00_l2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dn_X00_X3o`03
]?oo00:d0ol00kCoo`02]0?o00>dRHT04HT00ob9R@06R@03nHV900:900?jRHT0A8T]1`0300L701D7
000Z1`03okBd00Ci0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]?[j00Gj0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]003ohV901:900?lRHT01XT01OV9RHWj04R9;0L00`071`0E1`00:PL3n@:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0Wj00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_lDR@03o8V900J900?iRHT00XT00oZ9R@17RBX70P0G1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dn_X01OX2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]1B900?lRHT0
1XT00oV9R@02R@03nXV904R9:PL00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@00ooj
nP02nP03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0CR@03
o8V900J900?iRHT00XT00oZ9R@19RBT700<01`L05@L002<70P051`03okBd00;o0[@2o`:d0_l2]0Oj
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0CR@03
o8V900F900?iRHT00XT00oZ9R@1;RBP700<01`L05@L002D700<01`L00PL00kCoo`02]0[j0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d5HT00ob9R@06R@03
nHV900:900?jRHT0C8TW1`0300L701D7000T1`0300L700<71OX2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o5HT00ob9R@06R@03nHV900:9
00?jRHT0CHTU1`805`L002D700<01`L00PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`04]?oo]1J900?lRHT0
1XT01OV9RHWj05699@L00`071`0E1`008`L00`0700041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@FR@03o8V900J900?iRHT0
0XT00oZ9R@1@RB@700<01`L05@L002@700<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o5XT00ob9R@06R@03nHV900:9
00?jRHT0DHTS1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT05HT00ob9R@06R@03nHV900:900?jRHT0
DXTR1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT058T00ob9R@06R@03nHV900:900?jRHT0E8TQ1`03
00L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o5hT00ob9R@06R@03nHV900:900?jRHT0EHTO1`805`L002X700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@GR@03o8V900J900?iRHT00XT00oZ9R@1FRAl700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT05XT00ob9
R@06R@05nHV9ROX0FXTN1`0300L701D7000Z1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0;o68T00ob9R@06R@03
nHV900:900?jRHT0FHTM1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]1R900?lRHT01XT00oV9R@02R@03nXV905Z9
70L00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT05hT00ob9R@06R@03nHV900:900?jRHT0FhTJ1`805`L002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]8V901J900?lRHT01hT01OV9RHWj05n96PL00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d6HT00ob9R@06R@03
nHV900:900?jRHT0GXTI1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lIR@03o8V900J900?iRHT00XT00oZ9R@1ORAP7
00<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l00kB9R@0GR@03o8V900N900?iRHT00XT00oZ9R@1PRAL700<01`L05@L002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@JR@03o8V900J900?iRHT00XT00oZ9R@1RRAH700<01`L05@L002X700>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo01Z9
00?lRHT01XT00oV9R@02R@03nXV906>950L201L7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V901V900?lRHT01XT00oV9R@02R@03
nXV906B950L00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0HR@03o8V900N900GiRHV9nP1XRA<700<01`L05@L002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
6hT00ob9R@06R@03nHV900:900?jRHT0IhTB1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]1^900?lRHT01XT00oV9R@02R@03
nXV906R94@L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT06HT00ob9R@07R@03nHV900:900?jRHT0JHT?1`805`L002X7
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oab9
00?lRHT01XT00oV9R@02R@03nXV906^93`L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d78T00ob9R@06R@03nHV900:900?jRHT0
K8T>1`0300L701D7000Z1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d00?oRHT06XT00ob9R@07R@03nHV900:900?jRHT0KHT=1`03
00L701D7000T1`<00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V901Z900?lRHT01hT00oV9R@02R@03nXV906j930L00`071`0E1`009@L00`07
1`021`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
7HT00ob9R@06R@03nHV900:900?jRHT0L8T;1`0300L701D7000S1`@00`L00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0LR@03o8V900J900?iRHT0
0XT00oZ9R@1aR@T70P0G1`008`L00`0700041`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V901^900?lRHT01hT00oV9R@02R@03nXV907:92@L00`07
1`0E1`0090L200@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d7XT00ob9R@06R@03nHV900:900?jRHT0M8T81`0300L701D7000U1`0300L7008700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o7XT00ob9R@06R@03
nHV900:900?jRHT0MHT71`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0LR@03o8V900N900?iRHT00XT00oZ9R@1fR@H700<01`L0
5@L002X700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dohT07HT00ob9R@06R@03nHV900>900?jRHT0MhT41`805`L002X700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oan900?lRHT01XT00oV9R@02R@03
nXV907V910L00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V901j900?lRHT01XT00oV9R@02R@03nXV907Z90`L00`071`0E1`00:PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV901f900?lRHT0
1hT00oV9R@02R@03nXV907^90PL00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2ob2900?lRHT01XT00oV9R@03R@03nXV907b900<700L05PL002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@PR@03o8V900J9
00?iRHT00XT00oZ9R@1nR@0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]003ohV901j900?lRHT01hT00oV9R@02R@03nXV907j900<01`L05@L002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT07XT00ob9
R@06R@03nHV900>900?jRHT0OXT00`071`0E1`00:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d8HT00ob9R@06R@03nHV900:900?jRHT0OhT00`07
1`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
7hT00ob9R@07R@03nHV900:900?jRHT0OhT00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT07hT00ob9R@07R@03nHV900:900?jRHT0OhT00`07
1`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d8XT00ob9
R@06R@03nHV900:900?jRHT0P8T00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o8XT00ob9R@06R@03nHV900:900?jRHT0P8T00`071`0E1`00:PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V9022900?lRHT01hT00oV9
R@02R@03nXV9082900<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@0PR@03o8V900J900?iRHT00XT00oZ9R@21R@0300L701D7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o8hT00ob9R@06R@03nHV900:900?jRHT0
PHT00`071`0E1`00:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3ob>900?lRHT01hT00oV9R@02R@03nXV9086900<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT08HT00ob9R@06R@03nHV900>900?jRHT0PHT00`07
1`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lTR@03o8V900J9
00?iRHT00XT00oZ9R@22R@0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]2B900?lRHT01XT00oV9R@02R@03nXV908:900<01`L05@L002@700<01`L00`L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT08XT00ob9R@07R@03nHV900:9
00?jRHT0PXT00`071`0E1`008`L00`0700041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@0RR@03o8V900J900?iRHT00XT00oZ9R@23R@0300L701D7000U1`0300L70087
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]2F900?lRHT01XT00oV9R@02R@03
nXV908>900<01`L05@L002<70P3k1`008`L00`071`3j1`008`L30?X7003o1b47003o1b47001d1`<0
30L201l70P0O1`80F@L007H700<01`L02`L00`071`0O1`0300L701d700<01`L0E`L006X70`000`L0
00021`0500L71`000`L300041`0000<700<01`L030L200041`001`@000@700000`L300051`0000L0
0P021`0300L700X71@021`<0F@L006/700D01`L700021`0500L71`000PL010071`021`0700L71`07
000=1`0600L71`070`031`0500L71`000PL010071`031`0400L700d700H01`L01`021`0300L705L7
001[1`0500L71`000PL01@071`L0008700@01`L00PL01`071`L01`003@L01@0700L000<700D01`L7
00031`0400L7008700D01`L700021`0300L700/700<01`L00PL010071`1I1`00J`L00`071`040087
0`0010L000L200031`0000@000<7000030L200031`0000870P021`@00PL300031`000087100>1`80
10L305T7001[1`0300L702D70P000`L0000V1`0400L705h7001Z1`<020L00`071`0K1`8000<70000
4@L00`071`0A1`D0GPL00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.949035, -0.883654, 
  0.0224936, 0.0363954}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0 0.123607 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21.5 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -18.5 -5 ]
[-0.01875 .30902 -6 5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -32 0 ]
[.5 .63053 32 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 0 m
.2 .00625 L
s
[(1)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(2)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(3)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(4)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(5)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04 0 m
.04 .00375 L
s
.08 0 m
.08 .00375 L
s
.12 0 m
.12 .00375 L
s
.16 0 m
.16 .00375 L
s
.24 0 m
.24 .00375 L
s
.28 0 m
.28 .00375 L
s
.32 0 m
.32 .00375 L
s
.36 0 m
.36 .00375 L
s
.44 0 m
.44 .00375 L
s
.48 0 m
.48 .00375 L
s
.52 0 m
.52 .00375 L
s
.56 0 m
.56 .00375 L
s
.64 0 m
.64 .00375 L
s
.68 0 m
.68 .00375 L
s
.72 0 m
.72 .00375 L
s
.76 0 m
.76 .00375 L
s
.84 0 m
.84 .00375 L
s
.88 0 m
.88 .00375 L
s
.92 0 m
.92 .00375 L
s
.96 0 m
.96 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -78.25 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10.25 translate
90 rotate
-66 -10.25 translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.04 .61428 m
.04 .61803 L
s
.08 .61428 m
.08 .61803 L
s
.12 .61428 m
.12 .61803 L
s
.16 .61428 m
.16 .61803 L
s
.24 .61428 m
.24 .61803 L
s
.28 .61428 m
.28 .61803 L
s
.32 .61428 m
.32 .61803 L
s
.36 .61428 m
.36 .61803 L
s
.44 .61428 m
.44 .61803 L
s
.48 .61428 m
.48 .61803 L
s
.52 .61428 m
.52 .61803 L
s
.56 .61428 m
.56 .61803 L
s
.64 .61428 m
.64 .61803 L
s
.68 .61428 m
.68 .61803 L
s
.72 .61428 m
.72 .61803 L
s
.76 .61428 m
.76 .61803 L
s
.84 .61428 m
.84 .61803 L
s
.88 .61428 m
.88 .61803 L
s
.92 .61428 m
.92 .61803 L
s
.96 .61428 m
.96 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -93 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Dumping) show
111.000000 12.750000 moveto
(Eq) show
123.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.175 .61803 m
.20885 .49848 L
.2498 .35389 L
.29331 .2002 L
.33524 .05213 L
s
.33524 .05213 m
.35 0 L
s
0 1 0 r
0 .37082 m
.04057 .36497 L
.08481 .35859 L
.12636 .3526 L
.16632 .34684 L
.20885 .3407 L
.2498 .3348 L
.29331 .32852 L
.33524 .32248 L
.37557 .31666 L
.41848 .31047 L
.4598 .30451 L
.49953 .29878 L
.54183 .29268 L
.58254 .28681 L
.62583 .28057 L
.66752 .27456 L
.70762 .26878 L
.7503 .26262 L
.79139 .2567 L
.83505 .2504 L
.87712 .24433 L
.9176 .2385 L
.96065 .23229 L
1 .22661 L
s
0 0 1 r
.14901 .61803 m
.16632 .55858 L
.20885 .41251 L
.2498 .27191 L
.29331 .12247 L
s
.29331 .12247 m
.32898 0 L
s
1 0 0 r
0 .34008 m
.04057 .33033 L
.08481 .31969 L
.12636 .3097 L
.16632 .30009 L
.20885 .28987 L
.2498 .28003 L
.29331 .26956 L
.33524 .25948 L
.37557 .24979 L
.41848 .23947 L
.4598 .22954 L
.49953 .21998 L
.54183 .20981 L
.58254 .20003 L
.62583 .18962 L
.66752 .1796 L
.70762 .16995 L
.7503 .15969 L
.79139 .14982 L
.83505 .13932 L
.87712 .12921 L
.9176 .11947 L
.96065 .10912 L
1 .09966 L
s
0 1 0 r
.18896 .61803 m
.20885 .54632 L
.2498 .39871 L
.29331 .24182 L
.33524 .09067 L
s
.33524 .09067 m
.36039 0 L
s
0 0 1 r
0 .20248 m
.04057 .19881 L
.08481 .19481 L
.12636 .19105 L
.16632 .18744 L
.20885 .1836 L
.2498 .17989 L
.29331 .17596 L
.33524 .17217 L
.37557 .16852 L
.41848 .16464 L
.4598 .16091 L
.49953 .15732 L
.54183 .15349 L
.58254 .14981 L
.62583 .1459 L
.66752 .14213 L
.70762 .13851 L
.7503 .13465 L
.79139 .13093 L
.83505 .12699 L
.87712 .12318 L
.9176 .11953 L
.96065 .11563 L
1 .11208 L
s
.9 g
.4988 .03743 m
0 .18129 L
0 .61803 L
.17 .61803 L
F
.6 g
.4988 .03743 m
.17 .61803 L
1 .61803 L
1 .54078 L
F
1 0 0 r
.175 .61803 m
.20885 .49848 L
.2498 .35389 L
.29331 .2002 L
.33524 .05213 L
s
.33524 .05213 m
.35 0 L
s
0 1 0 r
0 .37082 m
.04057 .36497 L
.08481 .35859 L
.12636 .3526 L
.16632 .34684 L
.20885 .3407 L
.2498 .3348 L
.29331 .32852 L
.33524 .32248 L
.37557 .31666 L
.41848 .31047 L
.4598 .30451 L
.49953 .29878 L
.54183 .29268 L
.58254 .28681 L
.62583 .28057 L
.66752 .27456 L
.70762 .26878 L
.7503 .26262 L
.79139 .2567 L
.83505 .2504 L
.87712 .24433 L
.9176 .2385 L
.96065 .23229 L
1 .22661 L
s
0 0 1 r
.14901 .61803 m
.16632 .55858 L
.20885 .41251 L
.2498 .27191 L
.29331 .12247 L
s
.29331 .12247 m
.32898 0 L
s
1 0 0 r
0 .34008 m
.04057 .33033 L
.08481 .31969 L
.12636 .3097 L
.16632 .30009 L
.20885 .28987 L
.2498 .28003 L
.29331 .26956 L
.33524 .25948 L
.37557 .24979 L
.41848 .23947 L
.4598 .22954 L
.49953 .21998 L
.54183 .20981 L
.58254 .20003 L
.62583 .18962 L
.66752 .1796 L
.70762 .16995 L
.7503 .15969 L
.79139 .14982 L
.83505 .13932 L
.87712 .12921 L
.9176 .11947 L
.96065 .10912 L
1 .09966 L
s
0 1 0 r
.18896 .61803 m
.20885 .54632 L
.2498 .39871 L
.29331 .24182 L
.33524 .09067 L
s
.33524 .09067 m
.36039 0 L
s
0 0 1 r
0 .20248 m
.04057 .19881 L
.08481 .19481 L
.12636 .19105 L
.16632 .18744 L
.20885 .1836 L
.2498 .17989 L
.29331 .17596 L
.33524 .17217 L
.37557 .16852 L
.41848 .16464 L
.4598 .16091 L
.49953 .15732 L
.54183 .15349 L
.58254 .14981 L
.62583 .1459 L
.66752 .14213 L
.70762 .13851 L
.7503 .13465 L
.79139 .13093 L
.83505 .12699 L
.87712 .12318 L
.9176 .11953 L
.96065 .11563 L
1 .11208 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{64, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L00?l78@L00?l78@L00?l78@L009H7
0P000`L000251`00U`L00`0700261`00V0L00`071`251`00V0L00`071`251`00U`L00`0700261`00
UPL200031`0008D7003o1b47003o1b47003o1b47001D1`D0:0L302X70P0[1`<0:@L00`071`0F1`00
EPL00`071`0X1`0300L702`700<01`L0:@L00`071`0W1`0300L001L7001F1`0300L702T700<01`L0
:PL00`071`0X1`@0:PL00`071`0E1`00EPL00`071`0Y1`0300L702/700<01`L09`L00`07000Y1`80
60L005H700<01`L0:0L00`07000Z1`0300L002X70P0Y1`0300L701L7001E1`80:`L00`071`0Z1`03
00L702X700<01`L09`L301L7003o1b47003o1b47003o1b47003o1b47003o1b47000Z1dT000Gl0000
n@020003nP0008`05`L002X700<01`L01PL00`071`051`0300L700H700<01`L01PL00`071`061`03
00L700H700<01`L01PL00`071`061`0300Ol00<700Ci1`Oj20L00`071`051`0300L700H700<01`L0
1PL00`071`061`0300L700H700<01`L01PL00`071`061`0300L700H700<01`L01PL00`071`061`03
00L700D700<01`L01PL00`071`061`0300L700H700<01`L01PL00`071`0E1`00:PL00`071`151`05
o0L71oT00PL00oX71`2<1`0300L701D7000Z1`0300L704D700Gl1`L7n@021`03nPL708`700<01`L0
5@L002X700<01`L0A@L01O`71`Oi008700?j1`L0S0L00`071`0E1`00:PL204H700Ol1`L7n@Oj08h7
0P0G1`00:PL00`071`141`05o0L71oT00PL00oX71`2=1`0300L701D7000Z1`0300L704@700Gl1`L7
n@021`03nPL708d700<01`L05@L002X700<01`L0A0L01O`71`Oi008700?j1`L0S@L00`071`0E1`00
:PL00`071`131`03o0L7008700?i1oX07`L00on9R@1^1`0300L701D7000Z1`0300L704<700Gl1`L7
n@021`03nPL701T70[@2o`04]8V9RFd700<01`L05@L002X70P141`05o0L71oT00PL00oX71`0F1`;o
00>dool00[@5RF/70P0G1`00:PL00`071`121`03o0L7008700?i1oX05@L00kCoo`02]0;o0[@2o`J9
J`L00`071`0E1`00:PL00`071`121`05o0L71oT00PL00oX71`0@1`:d0_l2]0;o0[@2o`03]8V900J9
JPL00`071`0E1`00:PL00`071`121`05o0L71oT00PL00oX71`0<1`;o0[@2o`:d0_l2]0;o0[@00on9
R@07RFT700<01`L05@L002X700<01`L0@PL01o`71`Oi1oX030L00kCoo`02]0;o0[@2o`:d0_l2]0;o
2hUX1`0300L701D7000Z1`80@PL00o`71`021`03n@Oj00P700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
00>dRHT02hUV1`805`L002X700<01`L0@@L01O`71`Oi008700?j1`L00`L2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@0<RFH700<01`L05@L002X700<01`L0@@L01O`71`Oi008700Cj1`Nd0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l@RFD700<01`L05@L002X700<01`L0@0L00o`71`021`03n@Oj00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kB9R@0?RF@700<01`L05@L002X700<01`L0
@0L02?`71`OonKCj0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV90169H`L00`071`0E1`00
:PL00`071`101`08o;CoooVdooX2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT04XUR1`03
00L701D7000Z1`80?PL00ondo002o`:d00CiooZd0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]1J9
G`L3nAL7000Z1`0300L703T700>dool00[@01?ol];@2o`04nKCjo`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?oRHT05XUJ1`Ci0PL00`071`0E1`00:PL00`071`0f1`:d0_l2]0;o00Jdo?oo]?T2o`04
n[Coo`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V901N9E0L5n@H700<01`L05@L002871@031`03
00L703870_l2]0;o0[@2o`:d00Koo;BdooT2]004n_nd]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]1^9
C`L4n@L71O`G1`0090L00`071`031`0300L702l700>dool00[@2o`:d0_l2]0;o00Sl]?oo]?WonP:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lLRDL74_`41`0300L701D7000T1`0300L700<70P0/1`;o
00>dool00[@3o`03]?oo00:d0ol00kClo`02]004ooWonP;o0[@3o`03]?oo00:d0ol00kCoo`02]0?o
00Bdoond7XTm1`Wl0oTB1`805`L002@700<01`L00`L00`071`0X1`;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l02?bdoooi]?oj0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0MRC872_`61`?i5PL00`07
1`0E1`0090L00`071`031`0300L702@70[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@01?Wo
]?X2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ob69:0L9o0`71?TI1`0300L701D7000S1`801@L00`07
1`0Q1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]004oobd]0;o00Ci]?[o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>dRHT08HTM1`[l40L5nAd700<01`L05@L002X700<01`L07@L00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@01?Won[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@00on9R@0RR@X74_`E1`Gi8PL00`071`0E1`00:PL00`071`0J1`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@01_co];Con@:d00CjokBd0_l2]0;o0[@2o`:d0_l2]0;o0[@2obJ92O`S1`Ci
9`L00`071`0E1`00:PL201P700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`06
o;CookCi0_l01?Zdool2]0;o0[@2o`:d0_l2]0;o0[@2o`:d78T:o003R@L702@71OTZ1`805`L002X7
00<01`L04`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]008o?nd]?oi
]?X2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0BR@Wl38TP1`Gi<0L00`071`0E1`00:PL00`07
1`0@1`:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@2o`0:
o;CoooVdoo[o]0;o0[@3o`03]?oo00:d0ol00kCoo`02]0?o2hT9o1J96`L4nCD700<01`L05@L002X7
00<01`L030L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo
0[@01?Wo]?X2o`:d0_l2]0;o0[@2o`:d0_lBo2295`L3nCT700<01`L05@L002X700<01`L02@L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00Coo;Bd0_l01?Vd
n_l2]0;o0[@2o`[l0_l2]003ohV902b94`L3nC`700<01`L05@L002X70P061`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@00oWonP09o0;o
0[@2o`:d0_l2]0;o00>dRHT0;HT>1`Ci?PL201L7000Z1`0300L700870_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@9o003okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d<HT91`Ci@`L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@;o005]?oo]?T00_l01?Zdool2]0;o0[@2o`:d0_l2]0;o0[@2oc:9
0`L5nDL700<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@00oolo007o0:d0_l2]0;o0[@02?co];ConKCj0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90329
1?U<1`0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d00?oo?`04?`00kCoo`02]0;o
0[@2o`:d0_l2]004oobd]0;o00BdnOoj0[@2o`:d0_l2]0;o0[@2o`:d0_l2]2j91OT3RDd700<01`L0
5@L002X700>dool00[@3o`03]?oo00:d0_l9o003]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol01KCookCl00?o00FdnOndnP03o`03]?oo00:d0ol00kCoo`02]0?o00>dool0:HT5n@V9
C0L00`071`0E1`00:PL00ond]002o`[l0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@01?ol];@2o`04nKConP:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT08hT5n@n9BPL201L7
000Z1`Gl0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
00Bdo?oo0[@01?Won[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV901n91?TERDX700<01`L05@L002X7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@01_co];Con@:d00CjokBd0_l2]0;o0[@2o`:d0_l2]0;o7XT4nAZ9B@L00`071`0E1`00:PL00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`06
o;CookCi0_l01?Zdool2]0;o0[@2o`:d0_l2]0;o0[@KR@?i7hU81`0300L701D7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00KlokBd
ooT2]004n_nd]0;o0[@2o`:d0_l2]0;o0[@00on9R@0GR@?i8hU71`0300L701D7000Z1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]004oobd]0;o
00BdnOoj0[@2o`:d0_l2]0;o0[@2o`:d0_lFR@Ci9hU51`805`L002X700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@01?Wo]?X2o`:d
0_l2]0;o0[@2o`:d0_l2]1:91?T/RD471OXG1`00:PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>doo`00[@2o`04nKConP:d
0ol00kCoo`02]0?o00>dool00[@00on9R@0<R@Gi<HTi1`Oj10L00`071`0E1`00:PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l01?bdool2]004
nOndnP;o0[@2o`:d0_l2]0;o0[@2o`03]8V900R91?TgRC@71?X;1`0300L701D7000S1`<010L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01_co
];Con@:d00CjokBd0_l2]0;o0[@2o`:d0_l2]0J91OTlRB`71oX?1`0300L701D7000S1`0300L700@7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
00Kl]?oo]?T2o`04n[Coo`:d0_l2]0;o0[@2o`:d0_l00hWin@03nD:990L7nQH700<01`L05@L002@7
00<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@01_co];Con@:d00CjokBd0_l2]0;o0[@2o`:d00?onOT00_U8RAh71OXL1`805`L002@7
00<01`L00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00Coo;Bd0_l01;CiooX2]0;o0[@2o`:d0_l2]0?i00>dRHT0BXTF1`Oj8PL00`071`0E1`00
8`L00`0700041`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l01;Clool2]004nOndnP;o0[@2o`:d0_l01;CinOT2]0;oCHT<1`Wj:@L00`071`0E1`00
90L00`071`031`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@01?ol];@2o`04nKConP:d0_l2]003ooWi00;i00?o];@00_l00kB9R@1=R@<72?Xb1`03
00L701D7000Z1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0_l01?bdool2]004nOoonP;o00>dnOT00_T00kCoo`02]0?o00>dohT0
CHT4nSX700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]006o?nd]?oi0[@00o[in@02n@03okBd00;o0[@2o`:d0_m8R@Oj0hTj1`80
5`L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03o;Co00Gi00Cj]?oo0[@2o`:d0_l2]0;o0[@oR@Wj2hTj1`0300L701D7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o1OT00kCon@02]004
n_nd]0;o0[@2o`:d0_l2]003ohV903N91oXERCT700<01`L05@L002X700>dool00[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0Ci00Coo;Bd0_l01;CiooX2]0;o0[@2o`:d
0_l2]0;o=HT5nQf9>0L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l4n@:d0_l01;Clool2]004nOndnP;o0[@2o`:d0_l2]0;o0[@^R@Oj8hTg1`03
00L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00ConOWi
0_l2]0;o0[@01?ol];@2o`04nKConP:d0_l2]0;o0[@2o`:d00?oRHT098T9nRZ9=`L00`071`0E1`00
:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@3n@03]?oo00:d0_l2]0;o
00Cl]?oo0[@01?Won[@2o`:d0_l2]0;o0[@2o`03]8V901f91oXdRCD70P0G1`005PL00`071`0A1`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`04n@04okCoo`:d0ol00kCo
o`02]006o?oo]?oi0[@01?[ook@2o`:d0ol00kCoo`02]1b91?XlRCD700<01`L05@L001H70P0B1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@4n@;o0[@2o`:d0_l2]0;o0[@2o`06o;CookCi
0_l01?Zdool2]0;o0[@2o`:d0_lER@Oj@HTd1`0300L701D7000F1`0300L0008700<01`L030L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?onOT00oT2]0;o0[@2o`:d0_l2]0;o0[@2o`04]?coo`:d
00KonKBdn_l2]0;o0[@2o`:d0_l00kB9R@0;R@WjBHTc1`0300L701D7000I1`<03PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l00kCin@02n@03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01?ol];@2o`04
]?WonP:d0_l2]0;o0[@2o`:d1XT8nU>9<PL00`071`0E1`005PL00`0700021`0300L700`700>dool0
0[@2o`:d0_l2]0;o0[@5n@03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@01?Wo
]?X2o`:d0_l2]0;o0[@2o`:91?YLRC070P0G1`005PL2018700?o];@00_l2]0;o0[@00ooin@03n@:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01?ol];@2o`04nKConP:d0_l2]0;o00>dn_X0
1OYQRC0700<01`L05@L002X700>dool00[@2o`Gi00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00Cl]?oo0[@01?Won[@9nP04okBdofF9;`L00`071`0E1`00:PL00ond]004n@;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?looX01oX2]0;o0[@2o`:d
0_mWRBh700<01`L05@L002X70oT2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol01KCjn_cj00?o00Gioooj]003o`03]?oo00:d0ol00kB9R@1VRBd700<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kCjnP05nP04
]?coo`:d00KonKBdn_l2]0;o0[@2o`:d00?oRHT0J8T/1`0300L701D7000Z1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0Wj00?o];@00_l2]004oobd]0;o00BdnOoj0[@2o`:d0_l2]0;o
K8TZ1`805`L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]?[j00Gj0[@2o`:d0_l2]0;o
0[@2o`04]?coo`:d00CiokCj0_l2]0;o0[@2o`:dKHTZ1`0300L701D7000Z1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]003oo[j00;j00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@01?ol];@2o`04nKConP:d
0_l2]0;o0[@00on9R@1]RBT700<01`L05@L002<70P051`03okBd00;o0[@2o`:d0_l2]0Oj00>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Cl]?oo0[@01?Won[@2o`:d0_l2]0;o00>dRHT0KXTX1`03
00L701D7000U1`0300L7008700>dool00[@:nP:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@01_co];Con@:d00CjokBd0_l2]0;o0[AbRBL700<01`L05@L002@700<01`L00`L5nP:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Kl]?oo]?T2o`04n[Coo`:d0_l2]0;o
LhTU1`805`L002D700<01`L00PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kClo`02]004ooWonP;o0[@3o`04]?oo]7F99@L00`071`0E1`00
8`L00`0700041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00Coo;Bd0_l01;CiooX2]0;o0[@2o`:dMhTT1`0300L701D7000T1`0300L700<700>dool00[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l01;Clool2]004nOndnP;o0[@2o`:d
0_mhRB<700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@01?ol];@2o`04nKConP:d0_l2]0;o00>dRHT0N8TR1`0300L701D7000Z1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Cl]?oo0[@01?Won[@2o`:d
0_l2]003ohV907V98@L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]006o?nd]?oi0[@01?[o];@2o`:d0_mmRAl70P0G1`00:PL00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`06o;CookCi0_l01?Zdool2]0;o
0[AnRAl700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@02?co];ConKCj0_l2]0;o0[@00on9R@1nRAh700<01`L05@L002X700>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]004ooco]0;o00JdnOoj
ok@2o`:d0_n2RAd700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00Bdo?oo0[@01?Wo]?X2o`:d0_l2]8>970L00`071`0E1`00:PL00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01?ol];@2o`04nKConP:d0_l2]003
ohV908>96PL201L7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`04o;Coo`:d00CiooZd0_l2]0;o00>dRHT0Q8TJ1`0300L701D7000Z1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]006o?nd]?oi0[@01?[o];@2o`:dR8TI1`03
00L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`06
o;CookCi0_l01?Zdool2]0;oRHTH1`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]006o?nd]?oi0[@01?[o];@2o`03]8V908V95`L00`071`0E1`00
:PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00Coo;Bd0_l01;Ci
ooX2]0;o0[B=RAH700<01`L05@L002X700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol01KCookCl00?o00FdnOndnP03o`03]?oo08j950L201L7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01?ol];@2o`04nKConP:d0_l00kB9
R@2>RA@700<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`04o;Coo`:d00CiooZd0_l2]003ohV908n94`L00`071`0E1`00:PL00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00ClokBd0_l01?Vdn_l2]0;oThTB1`0300L701D7
000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l01_bdoondn@;o
00Cj]?oo0[BDRA4700<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]006o?nd]?oi0[@01O[o];Co09J93`L201L7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00Coo;Bd0_l01;CiooX2]0;oV8T?1`0300L701D7000Z1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@01?Wo]?X2o`:d
VHT>1`0300L701D7000Z1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>doo`00[@2o`04nKConP:d00?oRHT0VHT=1`0300L701D7000T1`<00`L00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`04o;Coo`:d00CiokCj0_l00kB9R@2JR@`7
00<01`L05@L002D700<01`L00PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]004o?nd]0;o00Ci]?[o0[BNR@/700<01`L05@L002<710031`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Kl]?oo]?T2o`03n[Co0:292@L201L7000S1`0300L000@7
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01_co];Con@:d00?jok@0
XHT91`0300L701D7000T1`8010L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@01?ol];@2o`04]?WonP:dXhT81`0300L701D7000U1`0300L7008700>dool00[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@01?Wo]?X2ojB91`L00`071`0E1`00:PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01?ol];@2o`05nKCon[@0YXT61`03
00L701D7000Z1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00?lool00[@01OWooo[o0:N910L201L7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]004o?nd]0;o00Ci]?[oZHT41`0300L701D7000Z1`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`06o;CookCi0_l00oZ9R@2YR@<700<01`L05@L002X700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00KlokBdooT2]003nXV90:Z90PL00`07
1`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00Coo;Bd0_l01KCi
oooj0:f900<700L05PL002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`04
]?coo`:d00ConKCj[hT00`071`0E1`00:PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00Coo;Bd0_l01?VdooZ_R@0300L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l01;Clool2]004nOndnZn900<01`L05@L002X700>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d00Cloond0_l00oVdnP2`R@0300L701D7000Z1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l02ObdoondnOn9nP2`R@0300L701D7
000Z1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@02Oco];ConKB9nP2`R@03
00L701D7000Z1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00Coo;Bd0_l01KCi
RHWj0;2900<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l01;Cl
ool2]004ooV9n[6900<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@01?ol];@2o`04nHV9n[6900<01`L05@L002X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l01?bdool2]004nHV9n[6900<01`L05@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@01?co];@2o`04nHV9n[6900<01`L05@L002X700>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`05]?ooo;@00ol018WiROZbR@0300L701D7000Z1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00KlokBdooT2R@03nXV90;2900<01`L05@L002X7
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00Coo;Bd0_l01HWiRHWj0;:900<01`L0
5@L002X700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdo?oo0[@01HWiRHWj0;:9
00<01`L05@L002@700<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01Ool
];Co00:900?iROX0/hT00`071`0E1`008`L00`0700041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`07o;CookB9n@02R@03nXV90;6900<01`L05@L002D700<01`L00PL00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@01?co];@2R@04nHV9n[>900<01`L05@L002<70P3k1`00
8`L00`071`3j1`008`L30?X7003o1b47003o1b47002:1`<03PL201H70P1[1`00R`L00`071`0?1`03
00L701@700<01`L0J@L007/710031`@000D700L01`0300870`000`L000021`0300L700<03@L50087
0`1[1`00O0L01P071`0700870P001PL01`07008700@01`L00`L01P071`07008700<01`L030L01P07
1`07008700<01`L0J@L007`700H01`L01`021`8000H700L01`021`0400L700<700H01`L01`021`03
00L700`700<01`L00PL010071`1[1`00O0L00`071`0300031`00008000<700L010021`800PL400<7
0`0>1`8010L306/7001l1`0400L702`700@01`L0L0L007/7100B1`0300L701L71@1`1`00o`LQ1`00
o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.949035, -0.883654, 
  0.0224936, 0.0363954}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equilibrium as a function of Home Company Costs", "Section"],

Cell[CellGroupData[{

Cell["Check the region for plotting", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Par = Drop[Parameters, 1]; \nim = IM[x, y] /. Par; \n
    dm = DM[x, y] /. Par; \nnenp\  = \ NENP /. Par; \nneim = NEIM /. Par; \n
    nedm = NEDM /. Par; \)], "Input",
  PageWidth->Infinity,
  FontSize->12],

Cell[BoxData[
    \(Rightedge\  = \ N[\((\(x /. nenp\) /. hc -> 0)\) + 1, 1]; \n
    Leftedge = \ 
      N[\((hc /. \(Solve[nenp[\([1, 2]\)] == 0, hc]\)[\([1]\)])\) + 1, 1]; 
    \)], "Input"]
}, Open  ]],

Cell[BoxData[{
    \(bxl = 0; \nbxh = Rightedge; \nbyl = 0. ; \nbyh = 5. ; \n
    Cornbl = {bxl, byl}; \n\(Corntl = {bxl, byh}; \)\), 
    \(\(Corntr = {bxh, byh}; \)\), 
    \(\(Cornbr = {bxh, byl}; \)\), 
    \(\(kader = {{bxl, bxh}, {byl, byh}}; \)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the path for the equilibria in the three regimes", "Subsection"],

Cell[BoxData[
    \(t1 = \ Table[{x, y} /. nenp, {hc, 0, Leftedge, 0.2}]; \n
    p1 = ListPlot[t1, PlotRange \[Rule] kader, 
        PlotStyle \[Rule] {RGBColor[1, 0, 0]}, \n\t\t\ \ \ \ \ \ 
        PlotJoined \[Rule] True, DisplayFunction \[Rule] Identity]; \)], 
  "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(\(\ t2\  = \ Table[\ {\ x, y} /. neim\ , {\ hc, 0, Leftedge, 0.2\ }]; \n
    p2 = ListPlot[\ t2, PlotRange \[Rule] kader, 
        PlotStyle \[Rule] {RGBColor[0, 1, 0]}, \n\t\t\t\ \ 
        PlotJoined \[Rule] True, DisplayFunction \[Rule] Identity]; \)\)], 
  "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(t3\  = \ Table[{x, y} /. nedm, {hc, 0, Leftedge, 0.2}]; \n
    p3 = ListPlot[t3, PlotStyle \[Rule] {RGBColor[0, 0, 1]}, 
        PlotRange \[Rule] kader, Frame -> True, PlotJoined \[Rule] True, 
        DisplayFunction \[Rule] Identity]; \)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[p3, DMRegion, IMRegion, \ p3, p2, p1, 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  PageWidth->Infinity,
  FontSize->12],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.185018 0 0.123607 [
[.18502 -0.0125 -3 -9 ]
[.18502 -0.0125 3 0 ]
[.37004 -0.0125 -3 -9 ]
[.37004 -0.0125 3 0 ]
[.55506 -0.0125 -3 -9 ]
[.55506 -0.0125 3 0 ]
[.74007 -0.0125 -3 -9 ]
[.74007 -0.0125 3 0 ]
[.92509 -0.0125 -3 -9 ]
[.92509 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18502 0 m
.18502 .00625 L
s
[(1)] .18502 -0.0125 0 1 Mshowa
.37004 0 m
.37004 .00625 L
s
[(2)] .37004 -0.0125 0 1 Mshowa
.55506 0 m
.55506 .00625 L
s
[(3)] .55506 -0.0125 0 1 Mshowa
.74007 0 m
.74007 .00625 L
s
[(4)] .74007 -0.0125 0 1 Mshowa
.92509 0 m
.92509 .00625 L
s
[(5)] .92509 -0.0125 0 1 Mshowa
.125 Mabswid
.037 0 m
.037 .00375 L
s
.07401 0 m
.07401 .00375 L
s
.11101 0 m
.11101 .00375 L
s
.14801 0 m
.14801 .00375 L
s
.22202 0 m
.22202 .00375 L
s
.25903 0 m
.25903 .00375 L
s
.29603 0 m
.29603 .00375 L
s
.33303 0 m
.33303 .00375 L
s
.40704 0 m
.40704 .00375 L
s
.44404 0 m
.44404 .00375 L
s
.48105 0 m
.48105 .00375 L
s
.51805 0 m
.51805 .00375 L
s
.59206 0 m
.59206 .00375 L
s
.62906 0 m
.62906 .00375 L
s
.66607 0 m
.66607 .00375 L
s
.70307 0 m
.70307 .00375 L
s
.77708 0 m
.77708 .00375 L
s
.81408 0 m
.81408 .00375 L
s
.85109 0 m
.85109 .00375 L
s
.88809 0 m
.88809 .00375 L
s
.9621 0 m
.9621 .00375 L
s
.9991 0 m
.9991 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.18502 .61178 m
.18502 .61803 L
s
.37004 .61178 m
.37004 .61803 L
s
.55506 .61178 m
.55506 .61803 L
s
.74007 .61178 m
.74007 .61803 L
s
.92509 .61178 m
.92509 .61803 L
s
.125 Mabswid
.037 .61428 m
.037 .61803 L
s
.07401 .61428 m
.07401 .61803 L
s
.11101 .61428 m
.11101 .61803 L
s
.14801 .61428 m
.14801 .61803 L
s
.22202 .61428 m
.22202 .61803 L
s
.25903 .61428 m
.25903 .61803 L
s
.29603 .61428 m
.29603 .61803 L
s
.33303 .61428 m
.33303 .61803 L
s
.40704 .61428 m
.40704 .61803 L
s
.44404 .61428 m
.44404 .61803 L
s
.48105 .61428 m
.48105 .61803 L
s
.51805 .61428 m
.51805 .61803 L
s
.59206 .61428 m
.59206 .61803 L
s
.62906 .61428 m
.62906 .61803 L
s
.66607 .61428 m
.66607 .61803 L
s
.70307 .61428 m
.70307 .61803 L
s
.77708 .61428 m
.77708 .61803 L
s
.81408 .61428 m
.81408 .61803 L
s
.85109 .61428 m
.85109 .61803 L
s
.88809 .61428 m
.88809 .61803 L
s
.9621 .61428 m
.9621 .61803 L
s
.9991 .61428 m
.9991 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.86736 .18229 m
.84807 .18202 L
.82878 .18175 L
.80949 .18149 L
.7902 .18122 L
.77091 .18095 L
.75162 .18068 L
.73233 .18042 L
.71305 .18015 L
.69376 .17988 L
.67447 .17961 L
.65518 .17935 L
.63589 .17908 L
.6166 .17881 L
.59731 .17854 L
.57802 .17828 L
.55873 .17801 L
.53944 .17774 L
.52015 .17748 L
.50086 .17721 L
.48157 .17694 L
.46228 .17667 L
.44299 .17641 L
.4237 .17614 L
.40441 .17587 L
.38512 .1756 L
.36583 .17534 L
.34654 .17507 L
.32725 .1748 L
.30797 .17453 L
.28868 .17427 L
.26939 .174 L
.2501 .17373 L
.23081 .17346 L
.21152 .1732 L
.19223 .17293 L
.17294 .17266 L
.15365 .17239 L
.13436 .17213 L
.11507 .17186 L
.09578 .17159 L
.07649 .17132 L
.0572 .17106 L
.03791 .17079 L
.01862 .17052 L
s
.01862 .17052 m
0 .17026 L
s
.9 g
.46144 .03743 m
0 .18129 L
0 .61803 L
.15727 .61803 L
F
.6 g
.46144 .03743 m
.15727 .61803 L
.92509 .61803 L
.92509 .54078 L
F
0 0 1 r
.86736 .18229 m
.84807 .18202 L
.82878 .18175 L
.80949 .18149 L
.7902 .18122 L
.77091 .18095 L
.75162 .18068 L
.73233 .18042 L
.71305 .18015 L
.69376 .17988 L
.67447 .17961 L
.65518 .17935 L
.63589 .17908 L
.6166 .17881 L
.59731 .17854 L
.57802 .17828 L
.55873 .17801 L
.53944 .17774 L
.52015 .17748 L
.50086 .17721 L
.48157 .17694 L
.46228 .17667 L
.44299 .17641 L
.4237 .17614 L
.40441 .17587 L
.38512 .1756 L
.36583 .17534 L
.34654 .17507 L
.32725 .1748 L
.30797 .17453 L
.28868 .17427 L
.26939 .174 L
.2501 .17373 L
.23081 .17346 L
.21152 .1732 L
.19223 .17293 L
.17294 .17266 L
.15365 .17239 L
.13436 .17213 L
.11507 .17186 L
.09578 .17159 L
.07649 .17132 L
.0572 .17106 L
.03791 .17079 L
.01862 .17052 L
s
.01862 .17052 m
0 .17026 L
s
0 1 0 r
.77195 .16664 m
.75384 .17044 L
.73574 .17424 L
.71763 .17804 L
.69952 .18184 L
.68141 .18564 L
.66331 .18944 L
.6452 .19324 L
.62709 .19704 L
.60899 .20084 L
.59088 .20464 L
.57277 .20844 L
.55466 .21224 L
.53656 .21604 L
.51845 .21984 L
.50034 .22364 L
.48223 .22744 L
.46413 .23124 L
.44602 .23504 L
.42791 .23884 L
.40981 .24264 L
.3917 .24644 L
.37359 .25024 L
.35548 .25404 L
.33738 .25784 L
.31927 .26164 L
.30116 .26544 L
.28306 .26924 L
.26495 .27304 L
.24684 .27684 L
.22873 .28064 L
.21063 .28444 L
.19252 .28824 L
.17441 .29204 L
.15631 .29583 L
.1382 .29963 L
.12009 .30343 L
.10198 .30723 L
.08388 .31103 L
.06577 .31483 L
.04766 .31863 L
.02956 .32243 L
.01145 .32623 L
s
.01145 .32623 m
0 .32864 L
s
1 0 0 r
.81498 .24378 m
.79569 .24678 L
.7764 .24979 L
.75711 .2528 L
.73782 .2558 L
.71853 .25881 L
.69924 .26182 L
.67995 .26483 L
.66067 .26783 L
.64138 .27084 L
.62209 .27385 L
.6028 .27685 L
.58351 .27986 L
.56422 .28287 L
.54493 .28587 L
.52564 .28888 L
.50635 .29189 L
.48706 .2949 L
.46777 .2979 L
.44848 .30091 L
.42919 .30392 L
.4099 .30692 L
.39061 .30993 L
.37132 .31294 L
.35203 .31594 L
.33274 .31895 L
.31345 .32196 L
.29416 .32496 L
.27488 .32797 L
.25559 .33098 L
.2363 .33399 L
.21701 .33699 L
.19772 .34 L
.17843 .34301 L
.15914 .34601 L
.13985 .34902 L
.12056 .35203 L
.10127 .35503 L
.08198 .35804 L
.06269 .36105 L
.0434 .36405 L
.02411 .36706 L
.00482 .37007 L
s
.00482 .37007 m
0 .37082 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L003l71@0/1`<0;@L202l70`0]1`03
00L701`700111`0300L702`700<01`L0;`L00`071`0]1`0300L702/700<01`007@L0044700<01`L0
;@L00`071`0]1`0300L702`7100^1`0300L701/700111`0300L702d700<01`L0;PL00`071`0[1`03
00L002d70P0N1`00@@L00`071`0/1`0300L002d700<01`00;PL202d700<01`L07@L004070P0_1`03
00L702d700<01`L0;PL00`071`0[1`<07@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00187
o`0500X7000B1`0300L700L700<01`L01PL00`071`071`0300L700H700<01`L01`L00`071`071`03
00L700H700<01`L01`L00`071`061`0300L700L700<01`L01PL00`071`071`0300L700L700<01`L0
1PL00`071`071`0300L700H700<01`L01`L00`071`071`0300L700H700<01`L01`L00`071`061`03
00L700L700<01`L01`L00`071`061`0300L700L700<01`L01PL00`071`071`0300L700P7000B1`03
00L70?l70@L00`071`081`004PL00`071`3o1`4700<01`L020L0018700<01`L0o`L11`0300L700P7
000B1`0300L70?l70@L00`071`081`004PL20?l70@L200X7000B1`0300L70?l70@L00`071`081`00
4PL00`071`3o1`4700<01`L020L0018700<01`L0o`L11`0300L700P7000B1`0300L70?l70@L00`07
1`081`004PL00`071`1c1`03ohV908X700<01`L020L0018700<01`L0L0L2o`:d0hV91`0300L700P7
000B1`80K@L2]0;o0[@00on9R@03RHL70P0:1`004PL00`071`1Y1`03okBd00;o0[@2o`03]8V900B9
Q`L00`071`081`004PL00`071`1V1`;o0[@3o`03]?oo00:d28V61`0300L700P7000B1`0300L706<7
00>dool00[@2o`:d0_l2]0;o2HV51`0300L700P7000B1`0300L705l700?o];@00_l2]0;o0[@2o`:d
0_l00kB9R@08RHD700<01`L020L0018700<01`L0G0L2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900V9
Q0L00`071`081`004PL205X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l=RH870P0:1`004PL00`07
1`1F1`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d3XV21`0300L700P7000B1`0300L705870_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900j9P@L00`071`081`004PL00`071`1?1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0?RH0700<01`L020L0018700<01`L0C0L01?nd
ool2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dRHT04HUo1`0300L700P7000B1`03
00L704T700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oaB9OPL00`071`081`00
4PL204H700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT058Ul1`80
2PL0018700<01`L0@PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9
R@0ERG`700<01`L020L0018700<01`L0?`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lIRG/700<01`L020L0018700<01`L0?0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@JRGX700<01`L020L0018700<01`L0>0L2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV901Z9N@L00`071`081`00
2PL500<700<01`L0=@L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2oaf9N@L00`071`081`0030L00`071`031`0300L703870ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]1j9N0L00`07
1`081`0030L00`071`031`<0;`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0NRGH70P0:1`0030L00`071`031`0300L702`70[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0
7hUf1`0300L700P7000<1`0300L700<700<01`L0:0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d8hUe1`0300L700P7000;1`801@L00`07
1`0U1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lTRG@700<01`L020L0018700<01`L08PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V902B9L`L00`07
1`081`004PL00`071`0O1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT09HUb1`0300L700P7000B1`8070L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lYRG070P0:1`004PL00`071`0H1`:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kB9R@0XRG0700<01`L020L0018700<01`L05@L00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?oRHT0:XU_1`0300L700P7000B1`0300L701870_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V902^9
KPL00`071`081`004PL00`071`0>1`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d;hU]1`0300L700P7
000B1`0300L700/700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l_RC070oXj1`0300L700P7
000B1b_l0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]8V902n9:`L4nSd700<01`L020L001870P061`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;oA_`WRBD71OY01`802PL0018700D01`L7o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l<RDOl1OY61`0300L700P7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d=HTJ1`Cj10LVo24700<01`L0
20L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0=HTD1`Gj
C`L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_liR@h7
1OYD1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]3Z9
2@L4nUT700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ohV903Z90`L5nU`70P0:1`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
00>dRHT0>8T5nV8700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]3J91OX4RF<700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2oc:91?X:RF8700<01`L020L0018700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o;XT5nPn9H@L00`071`081`004PL00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV902N91OXDRF4700<01`L020L0018700>dool00[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_lVR@Cj6XUO1`802PL0018700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@QR@Gj7hUO1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]003ohV901^91OXUREh700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT05hT4nR^9G@L00`071`081`004PL00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@ER@Gj<8UL1`0300L700P7000;1`<010L00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l@R@Gj=XUK1`0300L700P7000;1`0300L700@700>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol01;Cook@<R@Gj?8TX1`?i;`L00`07
1`081`0030L00`071`031`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@06R@Cj
@XTR1`Gi<@L200X7000<1`0300L700<700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`B9
1OY7RAL72_Tg1`0300L700P7000;1`0300L000@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kCjnP03nTf94@L5nD4700<01`L020L000`700<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?on_X00_YCR@/71OU61`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`Gj
00>dool0EHT:nD/700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dn_X00oX2o`:d0_l2]529
1OUE1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?on_X00_X00ond]002o`:d0_l2]003ohV904Z9
1OT6RE<70P0:1`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00Gj00>dool00[@3o`03]?oo00:d
0om7R@Gi38UC1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kCjnP03nP;o0[@2o`:d0_l2]0;o0[@2o`:d?XT:nA:9
DPL00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@00oojnP02nP03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_liR@Gi7HUA1`03
00L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o1OX00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0cR@Gi8hU@1`0300L700P7
000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l:nP;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0:HT:nBV9C`L00`071`081`004PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@4nP;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2obN91OTdRDh700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00?on_X00oX2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d8XT5nCZ9C0L200X7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o1OX00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT078T5nD29
C0L00`071`081`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCjnP02nP?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00Bdoond
58T:nDJ9B`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d00?on_X00oX2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d48T5nE69BPL00`07
1`081`004PL00kCoo`02]0;o0[@2o`:d0_l5nP03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`^91OUGRDT700<01`L020L0018700?o];@0
0_l2]0;o0[@4nP;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V900[iG8U91`0300L700P7000B1`03]?oo00:d00?on_X00oX2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`GiIhU71`802PL0018700?o]?X00oX00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dnOT00oT2of^9A`L00`071`081`00
4PL2nP03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@5n@03okBd00;o0[A/RDH700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@:n@:d0_l2]0;o0[@00on9
R@1/RDD700<01`L020L0018700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@00ooin@03n@:d0ol00kCoo`02]0?o00>dool00[@2og29
A0L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o1OT00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:dLHU31`0300L700P7000B1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`[i0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]003ohV90769@PL00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kCin@03n@;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0LXU01`80
2PL0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@5n@03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[AfRD0700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@00ooin@03n@:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2ogN9?`L00`071`081`004PL00kCoo`02]0;o0[@2o`:d00?onOT02?T00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@1gRCh700<01`L020L000/7
0P051`03okBd00;o0[@2o`Gi00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV907R9?@L00`071`081`003@L00`071`021`04]?oo]0Gi
0_l2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo07^9?@L00`071`081`0030L00`071`031`Ci00?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[AlRC/70P0:1`003@L00`071`021`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1lRC/700<01`L020L000/7
00<01`0010L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0OHTj1`0300L700P7000<1`0300L700<700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]869>@L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oPXTh1`0300L700P7000B1`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>dRHT0PXTg1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0PhTe1`80
2PL0018700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0;oQhTe1`0300L700P7000B1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]8V908N9=0L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@28RC<700<01`L020L00187
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;oS8Tb1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]8f9<@L00`071`081`004PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?oRHT0S8Ta1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@2=RBl70P0:1`004PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:dTHT_1`0300L700P7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0TXT^1`0300L700P7
000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>dRHT0TXT]1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0ThT/1`0300L700P7
000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;oUhT[1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dV8TY1`802PL0018700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
V8TY1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V909V9:0L00`071`081`004PL00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[BMRBL700<01`L0
20L0018700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0_nNRBH700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V909j99@L00`07
1`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d00?oRHT0WXTU1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_nRRB<70P0:1`004PL00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90::9
8`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]003ohV90:>98PL00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ojN98@L00`071`081`0030L300<7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[BXRB0700<01`L020L000d700<01`L00PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dohT0ZHTO1`0300L700P7000;1`@0
0`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@2YRAd70P0:1`002`L00`0700041`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]:f97@L00`071`081`0030L200@700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o[XTL1`0300L700P7
000=1`0300L7008700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V90:j96`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0[hTJ1`0300L700P7000B1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_ncRAT700<01`L0
20L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2];>960L200X7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d00?oRHT0/hTH1`0300L700P7000B1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0]8TG1`0300L700P7
000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
^8TF1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o^HTE1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90;V950L00`071`081`004PL00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@2jRA<700<01`L020L00187
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o_HTB1`80
2PL0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03
]8V90;b94`L00`071`081`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoR@2mRA<700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2okn94`L00`071`081`004PL00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d_hTC1`0300L700P7000B1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0_XTC1`03
00L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
00>dRHT0_XTB1`802PL0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[C1RA<700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_o1RA<700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0`8TC1`0300L700P7000B1`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@00on9R@30RA<700<01`L020L00187
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o`hTC1`0300L700P7
000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]<>94`L00`07
1`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
`XTB1`802PL0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03
]8V90<:94`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:daHTC1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_o5RA<700<01`L020L000`700<01`L00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V90<B900<01`L040L00`071`081`002`L00`0700041`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dohT0aHT00`071`061`03
00L700L700<01`L020L000d700<01`L00PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2olN9500:1`002`L20?l750L000/700<01`L0o`LC1`002`L30?l74`L00?l78@L00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.384832, -0.382056, 
  0.0208518, 0.0312115}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Restrict each to the proper region", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Restr\  = \ 
      ParametricPlot[{\ {x, y} /. If[TariffNP > 0, Null, nenp], \n
          \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \t{x, y} /. If[TariffIM > 0 && \((im < dm /. neim)\), neim, Null], 
          \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \t\t{x, y} /. 
            If[TariffDM > 0 && \((dm < im /. nedm)\), nedm, Null]}, \n
        \ \ \ \ \ \ \ \ \ \ \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ {hc, 0, 12}, PlotRange \[Rule] kader, Frame -> True, 
        DisplayFunction -> Identity, \n
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ 
        PlotStyle 
          \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], RGBColor[0, 0, 1]}]; 
    \nShow[Restr, IMRegion, DMRegion, Restr, 
      DisplayFunction -> $DisplayFunction]; \n\)\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.185018 0 0.123607 [
[.18502 -0.0125 -3 -9 ]
[.18502 -0.0125 3 0 ]
[.37004 -0.0125 -3 -9 ]
[.37004 -0.0125 3 0 ]
[.55506 -0.0125 -3 -9 ]
[.55506 -0.0125 3 0 ]
[.74007 -0.0125 -3 -9 ]
[.74007 -0.0125 3 0 ]
[.92509 -0.0125 -3 -9 ]
[.92509 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18502 0 m
.18502 .00625 L
s
[(1)] .18502 -0.0125 0 1 Mshowa
.37004 0 m
.37004 .00625 L
s
[(2)] .37004 -0.0125 0 1 Mshowa
.55506 0 m
.55506 .00625 L
s
[(3)] .55506 -0.0125 0 1 Mshowa
.74007 0 m
.74007 .00625 L
s
[(4)] .74007 -0.0125 0 1 Mshowa
.92509 0 m
.92509 .00625 L
s
[(5)] .92509 -0.0125 0 1 Mshowa
.125 Mabswid
.037 0 m
.037 .00375 L
s
.07401 0 m
.07401 .00375 L
s
.11101 0 m
.11101 .00375 L
s
.14801 0 m
.14801 .00375 L
s
.22202 0 m
.22202 .00375 L
s
.25903 0 m
.25903 .00375 L
s
.29603 0 m
.29603 .00375 L
s
.33303 0 m
.33303 .00375 L
s
.40704 0 m
.40704 .00375 L
s
.44404 0 m
.44404 .00375 L
s
.48105 0 m
.48105 .00375 L
s
.51805 0 m
.51805 .00375 L
s
.59206 0 m
.59206 .00375 L
s
.62906 0 m
.62906 .00375 L
s
.66607 0 m
.66607 .00375 L
s
.70307 0 m
.70307 .00375 L
s
.77708 0 m
.77708 .00375 L
s
.81408 0 m
.81408 .00375 L
s
.85109 0 m
.85109 .00375 L
s
.88809 0 m
.88809 .00375 L
s
.9621 0 m
.9621 .00375 L
s
.9991 0 m
.9991 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.18502 .61178 m
.18502 .61803 L
s
.37004 .61178 m
.37004 .61803 L
s
.55506 .61178 m
.55506 .61803 L
s
.74007 .61178 m
.74007 .61803 L
s
.92509 .61178 m
.92509 .61803 L
s
.125 Mabswid
.037 .61428 m
.037 .61803 L
s
.07401 .61428 m
.07401 .61803 L
s
.11101 .61428 m
.11101 .61803 L
s
.14801 .61428 m
.14801 .61803 L
s
.22202 .61428 m
.22202 .61803 L
s
.25903 .61428 m
.25903 .61803 L
s
.29603 .61428 m
.29603 .61803 L
s
.33303 .61428 m
.33303 .61803 L
s
.40704 .61428 m
.40704 .61803 L
s
.44404 .61428 m
.44404 .61803 L
s
.48105 .61428 m
.48105 .61803 L
s
.51805 .61428 m
.51805 .61803 L
s
.59206 .61428 m
.59206 .61803 L
s
.62906 .61428 m
.62906 .61803 L
s
.66607 .61428 m
.66607 .61803 L
s
.70307 .61428 m
.70307 .61803 L
s
.77708 .61428 m
.77708 .61803 L
s
.81408 .61428 m
.81408 .61803 L
s
.85109 .61428 m
.85109 .61803 L
s
.88809 .61428 m
.88809 .61803 L
s
.9621 .61428 m
.9621 .61803 L
s
.9991 .61428 m
.9991 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.81498 .24378 m
.76803 .2511 L
.71683 .25908 L
.69388 .26266 L
.68086 .26468 L
.675 .2656 L
.67332 .26586 L
.67255 .26598 L
.67212 .26605 L
s
0 1 0 r
.61117 .20038 m
.6108 .20046 L
.60765 .20112 L
.60195 .20232 L
.59126 .20456 L
.54505 .21426 L
.49909 .2239 L
.45486 .23318 L
.40783 .24305 L
.36253 .25256 L
.3516 .25485 L
.34845 .25551 L
.34771 .25567 L
.34738 .25574 L
.34721 .25577 L
.34711 .25579 L
.34707 .2558 L
.34705 .25581 L
.34704 .25581 L
.34703 .25581 L
s
0 0 1 r
.38871 .17565 m
.3878 .17564 L
.38614 .17562 L
.38302 .17557 L
.3352 .17491 L
.28581 .17423 L
.23825 .17357 L
.18772 .17287 L
.13903 .17219 L
.09218 .17154 L
.04235 .17085 L
.03664 .17077 L
.035 .17075 L
.03425 .17074 L
s
.6 g
.46144 .03743 m
.15727 .61803 L
.92509 .61803 L
.92509 .54078 L
F
.9 g
.46144 .03743 m
0 .18129 L
0 .61803 L
.15727 .61803 L
F
1 0 0 r
.81498 .24378 m
.76803 .2511 L
.71683 .25908 L
.69388 .26266 L
.68086 .26468 L
.675 .2656 L
.67332 .26586 L
.67255 .26598 L
.67212 .26605 L
s
0 1 0 r
.61117 .20038 m
.6108 .20046 L
.60765 .20112 L
.60195 .20232 L
.59126 .20456 L
.54505 .21426 L
.49909 .2239 L
.45486 .23318 L
.40783 .24305 L
.36253 .25256 L
.3516 .25485 L
.34845 .25551 L
.34771 .25567 L
.34738 .25574 L
.34721 .25577 L
.34711 .25579 L
.34707 .2558 L
.34705 .25581 L
.34704 .25581 L
.34703 .25581 L
s
0 0 1 r
.38871 .17565 m
.3878 .17564 L
.38614 .17562 L
.38302 .17557 L
.3352 .17491 L
.28581 .17423 L
.23825 .17357 L
.18772 .17287 L
.13903 .17219 L
.09218 .17154 L
.04235 .17085 L
.03664 .17077 L
.035 .17075 L
.03425 .17074 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L003l71@0/1`<0;@L202l70`0]1`03
00L701`700111`0300L702`700<01`L0;`L00`071`0]1`0300L702/700<01`007@L0044700<01`L0
;@L00`071`0]1`0300L702`7100^1`0300L701/700111`0300L702d700<01`L0;PL00`071`0[1`03
00L002d70P0N1`00@@L00`071`0/1`0300L002d700<01`00;PL202d700<01`L07@L004070P0_1`03
00L702d700<01`L0;PL00`071`0[1`<07@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00187
o`0500X7000B1`0300L700L700<01`L01PL00`071`071`0300L700H700<01`L01`L00`071`071`03
00L700H700<01`L01`L00`071`061`0300L700L700<01`L01PL00`071`071`0300L700L700<01`L0
1PL00`071`071`0300L700H700<01`L01`L00`071`071`0300L700H700<01`L01`L00`071`061`03
00L700L700<01`L01`L00`071`061`0300L700L700<01`L01PL00`071`071`0300L700P7000B1`03
00L70?l70@L00`071`081`004PL00`071`3o1`4700<01`L020L0018700<01`L0o`L11`0300L700P7
000B1`0300L70?l70@L00`071`081`004PL20?l70@L200X7000B1`0300L70?l70@L00`071`081`00
4PL00`071`3o1`4700<01`L020L0018700<01`L0o`L11`0300L700P7000B1`0300L70?l70@L00`07
1`081`004PL00`071`1c1`03ohV908X700<01`L020L0018700<01`L0L0L2o`:d0hV91`0300L700P7
000B1`80K@L2]0;o0[@00on9R@03RHL70P0:1`004PL00`071`1Y1`03okBd00;o0[@2o`03]8V900B9
Q`L00`071`081`004PL00`071`1V1`;o0[@3o`03]?oo00:d28V61`0300L700P7000B1`0300L706<7
00>dool00[@2o`:d0_l2]0;o2HV51`0300L700P7000B1`0300L705l700?o];@00_l2]0;o0[@2o`:d
0_l00kB9R@08RHD700<01`L020L0018700<01`L0G0L2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900V9
Q0L00`071`081`004PL205X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l=RH870P0:1`004PL00`07
1`1F1`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d3XV21`0300L700P7000B1`0300L705870_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900j9P@L00`071`081`004PL00`071`1?1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0?RH0700<01`L020L0018700<01`L0C0L01?nd
ool2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dRHT04HUo1`0300L700P7000B1`03
00L704T700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oaB9OPL00`071`081`00
4PL204H700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT058Ul1`80
2PL0018700<01`L0@PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9
R@0ERG`700<01`L020L0018700<01`L0?`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lIRG/700<01`L020L0018700<01`L0?0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@JRGX700<01`L020L0018700<01`L0>0L2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV901Z9N@L00`071`081`00
2PL500<700<01`L0=@L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2oaf9N@L00`071`081`0030L00`071`031`0300L703870ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]1j9N0L00`07
1`081`0030L00`071`031`<0;`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0NRGH70P0:1`0030L00`071`031`0300L702`70[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0
7hUf1`0300L700P7000<1`0300L700<700<01`L0:0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d8hUe1`0300L700P7000;1`801@L00`07
1`0U1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lTRG@700<01`L020L0018700<01`L08PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V902B9L`L00`07
1`081`004PL00`071`0O1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT09HUb1`0300L700P7000B1`8070L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lYRG070P0:1`004PL00`071`0H1`:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kB9R@0XRG0700<01`L020L0018700<01`L05@L00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?oRHT0:XU_1`0300L700P7000B1`0300L701870_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V902^9
KPL00`071`081`004PL00`071`0>1`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d;hU]1`0300L700P7
000B1`0300L700/700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l_RFd700<01`L020L00187
00<01`L01PLRo0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@0_RF`700<01`L020L001870P061`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o>o`bRFX70P0:1`004PL01@071`Oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2ocB9JPL00`071`081`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]3F9J@L00`071`081`004PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0eRFP700<01`L020L0018700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o>HUW1`0300L700P7000B1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]3Z9IPL00`071`081`004PL00kCoo`02]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0>XUT1`802PL0018700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V903N91?YT1`0300L700P7000B1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@fR@Cj1HUS1`0300L700P7000B1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l`R@Kj2XUR1`0300L700P7000B1`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3obb91OXARF47
00<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0VR@Cj
5XUQ1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o9HT4nQ^9
G`L200X7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d88T5nR29G`L00`07
1`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0IR@Kj9XUN1`03
00L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V901F91?X]REd7
00<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d58T4nS:9G0L00`07
1`081`002`L300@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o48T4nSN9F`L00`07
1`081`002`L00`071`041`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00Bdoond38T5nSb9:0L3nBl700<01`L020L000`700<01`L00`L00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT018T6nT:98@L6nC470P0:1`0030L00`071`031`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2R@GjBHTI1`Oi>0L00`071`081`002`L00`0700041`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00Bdn_[jChTB1`Ki?`L00`071`081`0030L00`07
1`031`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0DHT;1`KiA@L00`071`081`00
4PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oeF90PL8nD/700<01`L020L0018700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[AER@;iD`L00`071`081`004PL00ond]002o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@00on9R@1ERE<70P0:1`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3oeR9D`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[AJRE8700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oFhUA1`03
00L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@1KRE0700<01`L020L00187
00>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV905b9C`L00`071`081`004PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;oH8U>1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[AQRD`70P0:1`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV90669C0L00`071`081`00
4PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00BdoondI8U;1`0300L700P7
000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dIXU:1`0300L700P7000B1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;oIhU91`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V906J9
B@L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1WRDL70P0:1`004PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_m[RDL700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
K8U61`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1/RDD700<01`L020L00187
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@2og29A0L00`071`081`004PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:dLHU31`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0
LHU21`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0LXU01`802PL0018700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[AfRD0700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_mgRCl700<01`L0
20L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0MhTn1`0300L700P7000;1`801@L00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@00on9R@1hRCd700<01`L020L000d700<01`L00PL00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`1kRCd700<01`L020L000`700<01`L00`L00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[AlRC/7
0P0:1`003@L00`071`021`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1lRC/700<01`L020L000/700<01`00
10L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0OHTj1`0300L700P7000<1`0300L700<700>dool00[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]869>@L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oPXTh1`0300L700P7000B1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT0PXTg1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0PhTe1`802PL00187
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0;oQhTe1`0300L700P7000B1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03
]8V908N9=0L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@28RC<700<01`L020L0018700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;oS8Tb1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]8f9<@L00`071`081`004PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?oRHT0S8Ta1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@2=RBl70P0:1`004PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
THT_1`0300L700P7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0TXT^1`0300L700P7000B1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT0TXT]1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0ThT/1`0300L700P7000B1`03
okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;oUhT[1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dV8TY1`802PL0018700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0V8TY1`03
00L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V909V9:0L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[BMRBL700<01`L020L00187
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0_nNRBH700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V909j99@L00`071`081`00
4PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?oRHT0WXTU1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_nRRB<70P0:1`004PL00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90::98`L00`07
1`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]003ohV90:>98PL00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ojN98@L00`071`081`0030L300<700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[BXRB07
00<01`L020L000d700<01`L00PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dohT0ZHTO1`0300L700P7000;1`@00`L00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9
R@2YRAd70P0:1`002`L00`0700041`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]:f97@L00`071`081`0030L200@700?o];@00_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o[XTL1`0300L700P7000=1`03
00L7008700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]8V90:j96`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0[hTJ1`0300L700P7000B1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_ncRAT700<01`L020L00187
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2];>9
60L200X7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d00?oRHT0/hTH1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0]8TG1`0300L700P7000B1`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d^8TF1`03
00L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o^HTE1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V90;V950L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@2jRA<700<01`L020L0018700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o_HTB1`802PL00187
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90;b9
4`L00`071`081`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoR@2mRA<700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2okn94`L00`071`081`004PL00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d_hTC1`0300L700P7000B1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0_XTC1`0300L700P7
000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0
_XTB1`802PL0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[C1RA<700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_o1RA<700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o00>dRHT0`8TC1`0300L700P7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@00on9R@30RA<700<01`L020L0018700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o`hTC1`0300L700P7000B1`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]<>94`L00`071`081`00
4PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0`XTB1`80
2PL0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90<:9
4`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
aHTC1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_o5RA<700<01`L020L000`700<01`L00`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`03]8V90<B900<01`L040L00`071`081`002`L00`0700041`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dohT0aHT00`071`061`0300L700L7
00<01`L020L000d700<01`L00PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2olN9500:1`002`L20?l750L000/700<01`L0o`LC1`002`L30?l74`L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.384832, -0.382056, 
  0.0208518, 0.0312115}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verify the regime switching behavior", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FOREIGNPROF = Fprof[x, y] + \((FprofTEQ /. t \[Rule] Tariff[x, y])\); \n
    xswid = Simplify[\((x /. neim)\)]\), 
    \(fprofim = \(FOREIGNPROF /. NEIM\) /. Par; \n
    yswid = Simplify[
        \((y /. \((Solve[y == \((\(y /. RYDM\) /. Par)\), y] /. x -> xswid)\))
            \)[\([1]\)]]\), 
    \(\(fprid = 
      Simplify[\((\(\(FOREIGNPROF /. x -> xswid\) /. y -> yswid\) /. Par)\)[
          \([1]\)]]; \)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(\(4.17228440566278813`\[InvisibleSpace]\) - 
      0.489334487813820651`\ hc\)], "Output"],

Cell[BoxData[
    \(\(1.55017381940922511`\[InvisibleSpace]\) - 
      0.0154902440002305912`\ hc\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(xswdi = Simplify[\((x /. nedm)\)]\), 
    \(fprofdm = \(FOREIGNPROF /. NEDM\) /. Par; \n
    yswdi = Simplify[
        \((y /. \((Solve[y == \((\(y /. RYIM\) /. Par)\), y] /. x -> xswdi)\))
            \)[\([1]\)]]\), 
    \(\(fprdi = \(\(FOREIGNPROF /. x -> xswdi\) /. y -> yswdi\) /. Par; 
    \)\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(\(4.68796970202259721`\[InvisibleSpace]\) - 
      0.521285838401390044`\ hc\)], "Output"],

Cell[BoxData[
    \(\(1.14756005061728272`\[InvisibleSpace]\) + 
      0.166133669319635117`\ hc\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{\ fprofim - fprid, fprofdm - fprdi}, {hc, 4, 10}, \n\t\ \ 
      PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0]}, 
      AxesLabel \[Rule] {"\<Hc\>", "\<D(p)\>"}, 
      PlotLabel \[Rule] "\<Switching Analysis\>"]; \)\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.611111 0.15873 0.310227 0.371848 [
[.18254 .29773 -3 -9 ]
[.18254 .29773 3 0 ]
[.34127 .29773 -3 -9 ]
[.34127 .29773 3 0 ]
[.5 .29773 -3 -9 ]
[.5 .29773 3 0 ]
[.65873 .29773 -3 -9 ]
[.65873 .29773 3 0 ]
[.81746 .29773 -3 -9 ]
[.81746 .29773 3 0 ]
[.97619 .29773 -6 -9 ]
[.97619 .29773 6 0 ]
[1.025 .31023 0 -6.25 ]
[1.025 .31023 16 6.25 ]
[.01131 .03134 -30 -4.5 ]
[.01131 .03134 0 4.5 ]
[.01131 .1243 -24 -4.5 ]
[.01131 .1243 0 4.5 ]
[.01131 .21726 -30 -4.5 ]
[.01131 .21726 0 4.5 ]
[.01131 .40319 -24 -4.5 ]
[.01131 .40319 0 4.5 ]
[.01131 .49615 -18 -4.5 ]
[.01131 .49615 0 4.5 ]
[.01131 .58911 -24 -4.5 ]
[.01131 .58911 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12.5 ]
[.5 .63053 -56.0938 0 ]
[.5 .63053 56.0938 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .31023 m
.18254 .31648 L
s
[(5)] .18254 .29773 0 1 Mshowa
.34127 .31023 m
.34127 .31648 L
s
[(6)] .34127 .29773 0 1 Mshowa
.5 .31023 m
.5 .31648 L
s
[(7)] .5 .29773 0 1 Mshowa
.65873 .31023 m
.65873 .31648 L
s
[(8)] .65873 .29773 0 1 Mshowa
.81746 .31023 m
.81746 .31648 L
s
[(9)] .81746 .29773 0 1 Mshowa
.97619 .31023 m
.97619 .31648 L
s
[(10)] .97619 .29773 0 1 Mshowa
.125 Mabswid
.05556 .31023 m
.05556 .31398 L
s
.0873 .31023 m
.0873 .31398 L
s
.11905 .31023 m
.11905 .31398 L
s
.15079 .31023 m
.15079 .31398 L
s
.21429 .31023 m
.21429 .31398 L
s
.24603 .31023 m
.24603 .31398 L
s
.27778 .31023 m
.27778 .31398 L
s
.30952 .31023 m
.30952 .31398 L
s
.37302 .31023 m
.37302 .31398 L
s
.40476 .31023 m
.40476 .31398 L
s
.43651 .31023 m
.43651 .31398 L
s
.46825 .31023 m
.46825 .31398 L
s
.53175 .31023 m
.53175 .31398 L
s
.56349 .31023 m
.56349 .31398 L
s
.59524 .31023 m
.59524 .31398 L
s
.62698 .31023 m
.62698 .31398 L
s
.69048 .31023 m
.69048 .31398 L
s
.72222 .31023 m
.72222 .31398 L
s
.75397 .31023 m
.75397 .31398 L
s
.78571 .31023 m
.78571 .31398 L
s
.84921 .31023 m
.84921 .31398 L
s
.88095 .31023 m
.88095 .31398 L
s
.9127 .31023 m
.9127 .31398 L
s
.94444 .31023 m
.94444 .31398 L
s
.25 Mabswid
0 .31023 m
1 .31023 L
s
gsave
1.025 .31023 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Hc) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .03134 m
.03006 .03134 L
s
[(-0.75)] .01131 .03134 1 0 Mshowa
.02381 .1243 m
.03006 .1243 L
s
[(-0.5)] .01131 .1243 1 0 Mshowa
.02381 .21726 m
.03006 .21726 L
s
[(-0.25)] .01131 .21726 1 0 Mshowa
.02381 .40319 m
.03006 .40319 L
s
[(0.25)] .01131 .40319 1 0 Mshowa
.02381 .49615 m
.03006 .49615 L
s
[(0.5)] .01131 .49615 1 0 Mshowa
.02381 .58911 m
.03006 .58911 L
s
[(0.75)] .01131 .58911 1 0 Mshowa
.125 Mabswid
.02381 .04993 m
.02756 .04993 L
s
.02381 .06853 m
.02756 .06853 L
s
.02381 .08712 m
.02756 .08712 L
s
.02381 .10571 m
.02756 .10571 L
s
.02381 .1429 m
.02756 .1429 L
s
.02381 .16149 m
.02756 .16149 L
s
.02381 .18008 m
.02756 .18008 L
s
.02381 .19867 m
.02756 .19867 L
s
.02381 .23586 m
.02756 .23586 L
s
.02381 .25445 m
.02756 .25445 L
s
.02381 .27304 m
.02756 .27304 L
s
.02381 .29163 m
.02756 .29163 L
s
.02381 .32882 m
.02756 .32882 L
s
.02381 .34741 m
.02756 .34741 L
s
.02381 .366 m
.02756 .366 L
s
.02381 .3846 m
.02756 .3846 L
s
.02381 .42178 m
.02756 .42178 L
s
.02381 .44037 m
.02756 .44037 L
s
.02381 .45897 m
.02756 .45897 L
s
.02381 .47756 m
.02756 .47756 L
s
.02381 .51474 m
.02756 .51474 L
s
.02381 .53334 m
.02756 .53334 L
s
.02381 .55193 m
.02756 .55193 L
s
.02381 .57052 m
.02756 .57052 L
s
.02381 .01275 m
.02756 .01275 L
s
.02381 .60771 m
.02756 .60771 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(D) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.000000 12.750000 moveto
(H) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.000000 12.750000 moveto
(L) show
87.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.5 .63053 -117.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Switching) show
123.187500 12.750000 moveto
(Analysis) show
171.187500 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .36823 m
.04262 .37323 L
.0522 .37586 L
.05746 .37733 L
.06244 .37873 L
.06506 .37947 L
.06577 .37968 L
.06653 .37989 L
.06718 .38008 L
.0679 .37906 L
.06913 .37646 L
.07046 .37367 L
.07286 .36862 L
.08255 .34817 L
.10458 .30151 L
.12429 .25952 L
.12969 .24797 L
.13111 .24493 L
.13265 .24163 L
.13336 .24011 L
.13411 .23897 L
.13475 .2388 L
.13545 .23862 L
.14088 .23722 L
.1458 .23593 L
.18551 .22517 L
.22594 .21347 L
.26485 .20149 L
.30621 .18799 L
.34605 .17424 L
.38438 .16032 L
.42516 .14477 L
.46443 .12907 L
.50218 .1133 L
.54238 .09579 L
.58107 .07823 L
.62221 .0588 L
.66184 .03935 L
.6818 .02927 L
.69994 .01996 L
.70478 .01745 L
.70733 .01612 L
.70873 .0154 L
.71003 .01472 L
.71117 .01478 L
.71239 .01577 L
.71499 .01788 L
.71955 .0216 L
.7405 .03882 L
.78178 .0735 L
Mistroke
.82154 .10783 L
.85979 .14173 L
.90048 .17873 L
.93967 .21526 L
.97619 .25012 L
Mfstroke
0 1 0 r
.02381 .27295 m
.06244 .26403 L
.10458 .25322 L
.12507 .24756 L
.14415 .24204 L
.16254 .2365 L
.16783 .23486 L
.17044 .23405 L
.17284 .2333 L
.17502 .23262 L
.17612 .23227 L
.17733 .23512 L
.18221 .24665 L
.20325 .29651 L
.2225 .34234 L
.232 .36503 L
.23702 .37704 L
.23978 .38364 L
.24113 .38687 L
.24237 .38938 L
.24357 .38972 L
.24484 .39008 L
.24751 .39084 L
.25217 .39217 L
.26127 .39481 L
.29924 .40627 L
.33966 .41927 L
.37857 .43256 L
.41993 .44753 L
.45978 .46277 L
.49811 .47818 L
.53889 .49539 L
.57816 .51276 L
.61591 .53019 L
.65611 .54954 L
.6948 .56894 L
.71445 .57908 L
.73594 .59039 L
.74586 .59569 L
.75132 .59863 L
.75399 .60008 L
.75646 .60141 L
.7588 .60268 L
.75997 .60332 L
.76127 .60314 L
.76256 .60202 L
.76395 .60082 L
.76647 .59864 L
.77556 .59074 L
.81684 .55425 L
Mistroke
.8566 .51814 L
.89484 .48251 L
.93554 .44364 L
.97472 .40529 L
.97619 .40383 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L00?l78@L00?l78@L00?l78@L00?l7
8@L0020700<01`L0o@L0020700<01`L0o@L0020700<01`L0o@L002070P3n1`0080L00`071`2O1`?i
F`L0020700<01`L0WPL01?T71`L2nET7000<1`0300L7008700<01`L00PL00`071`021`0300L70087
00<01`L0W0L2n@H700?i1`L0EPL000/700<01`0020L01`071`L01`000`L00`071`2J1`;i2@L00oT7
1`1E1`001PL3008700<01`0020L00`071`031`0400L71`<0V0L2n@`700?i1`L0E0L000/700<01`00
2@L00`071`0200@700<01`L0UPL2n@l700?i1`L0D`L000/700<01`001`L00`0700021`0300L700<7
00<01`L0U0L2nA8700?i1`L0DPL000`700<01`L01PL300870`031`0300L709870_TE1`03n@L70547
000P1`80T@L2nAP70_UA1`0080L00`071`2>1`;i70L00oT71`1>1`0080L00`071`2<1`;i7`L00oT7
1`1=1`0080L00`071`2:1`;i8PL00oT71`1<1`0080L00`071`281`;i9@L2nD`7000P1`80Q`L2nBT7
00?i1`L0B@L0020700<01`L0Q0L2nB`700?i1`L0B0L0020700<01`L0P@L3nBl700?i1`L0A`L00207
00<01`L0O`L2nC<700?i1`L0APL002070P1n1`;i=PL00oT71`151`0080L00`071`1k1`;i>@L2nDD7
000P1`0300L707P70oTm1`03n@L70487000P1`0300L707H70_U11`03n@L70447000P1`80M0L3nD@7
00?i1`L0@0L0020700<01`L0L@L2nDP700?i1`L0?`L0020700<01`L0KPL3nD/700?i1`L0?PL00147
00<01`L00PL00`071`021`0300L7008700<01`L0K0L2nDl700?i1`L0?@L0010700<01`001`L00`07
00031`0300L706X70_UB1`03n@L703`7000;1`<00PL00`0700091`0400L71`<0J0L2nED70_Tl1`00
40L00`0700071`8010L00`071`1U1`?iF@L00oT71`0i1`0040L00`0700071`0300L700<700<01`L0
H`L2nEd700?i1`L0>0L0014700<01`L01PL300<700<01`L0H@L2nF0700?i1`L0=`L002070P1P1`;i
H`L00oT71`0f1`0080L00`071`1L1`?iIPL00oT71`0e1`0080L00`071`1I1`?iJPL00oT71`0d1`00
80L00`071`1E1`CiKPL00oT71`0c1`0080L00`071`1B1`?iL`L00oT71`0b1`0080L205470_Ug1`;i
<PL0020700<01`L0CPL2nG/700?i1`L0;`L0020700<01`L0C0L2nGh700?i1`L0;PL0020700<01`L0
B@L3nH4700?i1`L0;@L002070P171`?iQ@L00oT71`0/1`0080L00`071`131`?iR@L00oT71`0[1`00
80L00`071`101`?iS@L00oT71`0Z1`0080L00`071`0m1`?iT@L00oT71`0Y1`0080L00`071`0i1`Ci
U@L00oT71`0X1`0080L203L70oVJ1`03n@L702L7000P1`0300L703<70oVN1`03n@L702H7000<1`03
00L7008700@01`L70`031`0300L7008700<01`L0<0L3nJ8700?i1`L09@L000/700<01`001`L00`07
1`021`0300L000<700<01`L0;@L3nJH700?i1`L090L000H70`021`0300L000P700<01`L00`L01007
1`L302X70oVZ1`03n@L702<7000;1`0300L000P700@01`L70P041`0300L702H71?V^1`03n@L70287
000;1`0300L000L700<01`000PL00`071`031`0300L702871?Vc1`03n@L70247000<1`0300L700L7
00@01`L70`031`0300L701d71OVh1`03n@L70207000P1`806`L3n@<70oZh1`;i80L0020700<01`L0
60L2n@<70oX21`03nPL70;P700?i1`L07@L0020700<01`L05`L00oT7nP03nPH700?j1`L0^0L00oT7
1`0L1`0080L00`071`0E1`Cj2PL00oX71`2i1`03n@L701/7000P1`0300L701<70_X00`Oi1`0;1`03
nPL70;X700?i1`L06PL002070P0@1`Cj0`L00oT71`0;1`03nPL70=H7000P1`0300L700X71OX61`03
n@L700`700?j1`L0ePL0020700<01`L01@L5nP/700?i1`L02`L00`07nP0Q1`809@L00`071`0S1`03
00L702870P0P1`D00PL00`071`0H1`0080L00`071`05nPl700?i1`L02`L010070?XQ1`0300L002@7
00<01`L08PL00`07000U1`0300L701l700L01`L700L001T7000P1`?j50L00oT71`0=1`0300Oj0207
00<01`0090L00`071`0R1`0300L002@70P0Q1`0700L71`07000I1`0080L00`071`0C1`03n@L700`7
0P021`03nPL701h70P0V1`0300L7028700<01`L08PL00`07000Q1`0700L71`07000I1`0080L00`07
1`0C1`03n@L700`700D01`L7nP0P1`0300L702<700<01`008`L00`07000S1`0300L0024700L01`L7
00L001T7000P1`0300L701<700?i1`L030L3008700?j1`L07PL202<70`0T1`0300L702<70P0P1`80
10L00`071`0H1`0080L00`071`0B1`03n@L7018700?j1`L0d`L002070P0C1`03n@L701<700?j1`L0
dPL0020700<01`L04@L00oT71`0D1`03nPL70=87000P1`0300L7014700?i1`L050L00oX71`3B1`00
80L00`071`0@1`03n@L701H700?j1`L0`PL300031`0700<01PL001/760000oT0000F0003nP000;/0
20L01P071`0700P7000P1`0300L700D700<01`L01@L00`07n@041`0300L700D700<01`L010L00`07
1`041`03nP0700D700<01`L01@L00`071`041`0300L700D700<01`L010L00`071`051`0300L700D7
00<01`L010L00`071`051`0300L700@700<01`L01@L00`071`041`0300L700D700<01`L010L00`07
1`051`0300L700D700<01`L010L00`071`051`0300L700@700<01`L01@L00`071`041`0300L700D7
00<01`L010L00`071`051`0300L700`700H01`L01`081`0080L00`071`0?1`03n@L7014700<01`L0
10L00oX71`0L1`0300L702<700<01`L08PL00`071`0S1`0300L702<700<01`L030L400041`0000H7
000P1`0300L700h700?i1`L06PL00oX71`311`0400L700X7000P1`0300L700h700?i1`L06PL00oX7
1`301`<000<700L02@L002070P0>1`03n@L701`700?j1`L0cPL0020700<01`L03@L00oT71`0L1`03
nPL70<h7000P1`0300L700`700?i1`L07PL00oX71`3=1`0080L00`071`0<1`03n@L701h700?j1`L0
c@L002070P0<1`03n@L701l700?j1`L0c@L0020700<01`L02`L00oT71`0P1`03nPL70<`7000P1`03
00L700X700?i1`L08@L00oX71`3<1`0080L00`071`0:1`03n@L7028700?j1`L0b`L002070P0:1`03
n@L702<700?j1`L0b`L002070oT91`03n@L702<700?j1`L0b`L0020700<01`L00oT61`03n@L702@7
00?j1`L0bPL0020700<01`L00`L6nBL700?j1`L0bPL0020700<01`L01`L2nBP700?j1`L0b@L00207
0P0b1`03nPL70<T7000P1`0300L703470o[91`0030L00`071`021`0400L71`<00`L00`071`021`03
00L703@71?[51`002`L00`0700071`0300L7008700<01`000`L00`071`0h1`?j`PL000/700<01`00
20L00`071`031`0400L71`<0>`L3nZ8700?j1`L06PL000/700<01`0020L010071`L200@700<01`L0
?PL3nYl700?j1`L06PL000/700<01`001`L00`0700021`0300L700<700<01`L0@@L3nY/700?j1`L0
6`L000`700<01`L01`L010071`L300<700<01`L0A0L4nYH700?j1`L070L0020700<01`L0B0L3nY87
00?j1`L07@L002070P1<1`?jSPL00oX71`0N1`0080L00`071`1>1`?jR@L2nR47000P1`0300L70547
0oZ51`03nPL70247000P1`0300L705@70_Z21`03nPL70287000P1`80E`L3nWh700?j1`L08`L00207
00<01`L0F@L2nW/700?j1`L090L0020700<01`L0F`L3nWL700?j1`L09@L0020700<01`L0GPL3nW<7
00?j1`L09PL002070P1R1`?jK`L00oX71`0W1`0080L00`071`1T1`?jJ`L00oX71`0X1`0080L00`07
1`1W1`;jJ0L00oX71`0Y1`0080L00`071`1Y1`;jI@L00oX71`0Z1`0080L00`071`1[1`;jHPL00oX7
1`0[1`0080L206h70oYN1`03nPL702`7000P1`0300L707070_YK1`03nPL702d7000A1`0300L70087
00<01`L00PL00`071`021`0300L707870oYG1`03nPL702h7000@1`0300L000L700<01`000`L00`07
1`1e1`;jE0L00oX71`0_1`0040L00`0700091`0400L71`<0M`L3nU0700?j1`L0<0L0010700<01`00
1`L200@700<01`L0NPL2nTd700?j1`L0<@L0010700<01`001`L00`071`031`0300L707`70_Y91`;j
=0L0014700<01`L01PL300<700<01`L0OPL2nTH700?j1`L0=0L0020700<01`L0P0L3nT8700?j1`L0
=@L002070P241`;j?`L00oX71`0f1`0080L00`071`251`;j?0L00oX71`0g1`0080L00`071`271`;j
>@L00oX71`0h1`0080L00`071`291`;j=PL00oX71`0i1`0080L208`70_Xc1`03nPL703X7000P1`03
00L708d70_X_1`;j?@L0020700<01`L0S`L2nR`700?j1`L0?@L0020700<01`L0T@L2nRT700?j1`L0
?PL0020700<01`L0T`L2nRH700?j1`L0?`L002070P2F1`;j8`L00oX71`101`0080L00`071`2G1`;j
80L00oX71`111`0080L00`071`2I1`;j7@L00oX71`121`0080L00`071`2K1`;j6PL00oX71`131`00
80L209h70_XG1`03nPL704@7000P1`0300L709l70_XC1`;jA`L000`700<01`L00PL00`071`021`03
00L7008700<01`L00PL00`071`2Q1`;j40L00oX71`171`002`L00`0700081`0700L71`0700031`03
00L70:<70_X=1`03nPL704P7000;1`0300L000P700<01`L00`L010071`L30:D70_X:1`03nPL704T7
000;1`0300L000T700<01`L00P041`0300L70:L700?j1`L01PL00oX71`1:1`002`L00`0700071`03
00L0008700<01`L00`L00`071`2X1`;j1@L00oX71`1;1`0030L00`071`061`<00PL300<700<01`L0
ZPL5nTh7000P1`0300L70:`70_Y?1`0080L20?h7000P1`0300L70?d7000P1`0300L70?d7003o1b47
003o1b47003o1b47003o1b47003o1b4700261`809@L2074700281`0300L702<700<01`L0K`L005d7
0`021`0300L000870`031`800PL300071`0000L01`0300031`00008700<01`L00`0?1`8000<70000
0P021`0300L000<000@700000`L010071`L200<70`021`80HPL001l700<01`000P041`0300L70387
00T01`0700L01`000PL01@071`L0008700<01`0010L010071`021`0500L71`000PL00`0700021`03
00L700d700L01`L700L0008700<01`000P031`0700L71`0700041`0500L71`001@L00`071`1O1`00
7PL01@071`L000H700<01`L0<`L01`0700L01`000PL01@071`L000@700<01`L00PL010071`021`05
00L71`000PL00`0700021`0300L700h70`021`0400L700<700D01`L700031`0300L000<700<01`L0
0PL00`071`021`0300L70607000E1`@010L00`071`021`<01@L00`071`0a1`0300L7008000@70007
0P021`@00PL300870`021`800PL400<70`0@1`0400L01`@00`L200<700<01`L00P000`L000021`80
0PL200@70P1Q1`005PL010071`031`0300L7008700@01`L010L00`071`0`1`0300L000`700<01`L0
1`L00`071`0Q1`0300L700`700<01`L0M0L001H700@01`L00`L00`071`021`0400L700@700<01`L0
<0L300P700<01`L02PL200D700<01`L06PL200d70P0>1`0300L706D7000F1`0400L700<700@01`L7
10051`0300L70?<7000F1`0400L700@700<01`L020L00`071`3d1`005@L400H700<01`L01PL00`07
1`3e1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {3.12625, -0.899676, 
  0.0264992, 0.0113117}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(dif\  = \ Simplify[fprofim - fprid]; \n
    itod\  = hc /. \ FindRoot[dif, {hc, {4, 5}}]\), 
    \(dif\  = \ Simplify[fprofdm - fprdi]; \n
    dtoi\  = \ hc /. FindRoot[dif, {hc, {4, 5}}]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(4.48298798096116435`\)], "Output"],

Cell[BoxData[
    \(5.16680150068033849`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(HOMEPROF = Hprof[x, y] + \((HprofTEQ /. t \[Rule] Tariff[x, y])\); 
    \)\), 
    \(yswni = y \[Rule] \((y /. NENP)\); \n
    hprofnp = \(HOMEPROF /. NENP\) /. Par; \n
    xswni = \((Solve[y == \((y /. RXIM)\), x] /. yswni)\)[\([1]\)]; \)}], 
  "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[BoxData[
    \(hprni = \(\(HOMEPROF /. xswni\) /. yswni\) /. Par; \n
    yswin = y \[Rule] \((y /. NEIM)\); \n
    hprofim = \(HOMEPROF /. NEIM\) /. Par; \n
    xswin = \((Solve[y == \((y /. RXNP)\), x] /. yswin)
          \)\[LeftDoubleBracket]1, 1\[RightDoubleBracket]; \n
    hprin = \(\(HOMEPROF /. xswin\) /. yswin\) /. Par; \n
    yswdn\  = \ y -> \((y /. NEDM)\); \n
    hprofdm\  = \ \(HOMEPROF /. NEDM\) /. Par; \n
    xswdn\  = 
      \((Solve[y == \((y /. RXNP)\), x] /. yswdn)\)\[LeftDoubleBracket]1, 1
        \[RightDoubleBracket]; \n
    hprdn = \(\(HOMEPROF /. xswdn\) /. yswdn\) /. Par; \)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{hprofdm - hprdn}, {hc, 0, 10}, 
      PlotStyle 
        \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], RGBColor[0, 0, 1]}, 
      AxesLabel \[Rule] {"\<Hc\>", "\<D(p)\>"}, 
      PlotLabel \[Rule] "\<Switching Analysis\>"]; \n
    Plot[{hprofnp - hprni, hprofim - hprin}, {hc, 0, 5}, 
      PlotStyle 
        \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], RGBColor[0, 0, 1]}, 
      AxesLabel \[Rule] {"\<Hc\>", "\<D(p)\>"}, 
      PlotLabel \[Rule] "\<Switching Analysis\>"]; \)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.556957 7.08404 [
[.21429 .54446 -3 -9 ]
[.21429 .54446 3 0 ]
[.40476 .54446 -3 -9 ]
[.40476 .54446 3 0 ]
[.59524 .54446 -3 -9 ]
[.59524 .54446 3 0 ]
[.78571 .54446 -3 -9 ]
[.78571 .54446 3 0 ]
[.97619 .54446 -6 -9 ]
[.97619 .54446 6 0 ]
[1.025 .55696 0 -6.25 ]
[1.025 .55696 16 6.25 ]
[.01131 .13191 -30 -4.5 ]
[.01131 .13191 0 4.5 ]
[.01131 .2736 -30 -4.5 ]
[.01131 .2736 0 4.5 ]
[.01131 .41528 -30 -4.5 ]
[.01131 .41528 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12.5 ]
[.5 .63053 -56.0938 0 ]
[.5 .63053 56.0938 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .55696 m
.21429 .56321 L
s
[(2)] .21429 .54446 0 1 Mshowa
.40476 .55696 m
.40476 .56321 L
s
[(4)] .40476 .54446 0 1 Mshowa
.59524 .55696 m
.59524 .56321 L
s
[(6)] .59524 .54446 0 1 Mshowa
.78571 .55696 m
.78571 .56321 L
s
[(8)] .78571 .54446 0 1 Mshowa
.97619 .55696 m
.97619 .56321 L
s
[(10)] .97619 .54446 0 1 Mshowa
.125 Mabswid
.07143 .55696 m
.07143 .56071 L
s
.11905 .55696 m
.11905 .56071 L
s
.16667 .55696 m
.16667 .56071 L
s
.2619 .55696 m
.2619 .56071 L
s
.30952 .55696 m
.30952 .56071 L
s
.35714 .55696 m
.35714 .56071 L
s
.45238 .55696 m
.45238 .56071 L
s
.5 .55696 m
.5 .56071 L
s
.54762 .55696 m
.54762 .56071 L
s
.64286 .55696 m
.64286 .56071 L
s
.69048 .55696 m
.69048 .56071 L
s
.7381 .55696 m
.7381 .56071 L
s
.83333 .55696 m
.83333 .56071 L
s
.88095 .55696 m
.88095 .56071 L
s
.92857 .55696 m
.92857 .56071 L
s
.25 Mabswid
0 .55696 m
1 .55696 L
s
gsave
1.025 .55696 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Hc) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .13191 m
.03006 .13191 L
s
[(-0.06)] .01131 .13191 1 0 Mshowa
.02381 .2736 m
.03006 .2736 L
s
[(-0.04)] .01131 .2736 1 0 Mshowa
.02381 .41528 m
.03006 .41528 L
s
[(-0.02)] .01131 .41528 1 0 Mshowa
.125 Mabswid
.02381 .16733 m
.02756 .16733 L
s
.02381 .20276 m
.02756 .20276 L
s
.02381 .23818 m
.02756 .23818 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .34444 m
.02756 .34444 L
s
.02381 .37986 m
.02756 .37986 L
s
.02381 .4507 m
.02756 .4507 L
s
.02381 .48612 m
.02756 .48612 L
s
.02381 .52154 m
.02756 .52154 L
s
.02381 .09649 m
.02756 .09649 L
s
.02381 .06107 m
.02756 .06107 L
s
.02381 .02565 m
.02756 .02565 L
s
.02381 .59238 m
.02756 .59238 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(D) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.000000 12.750000 moveto
(H) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.000000 12.750000 moveto
(L) show
87.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.5 .63053 -117.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Switching) show
123.187500 12.750000 moveto
(Analysis) show
171.187500 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .28468 m
.06244 .31017 L
.10458 .33654 L
.14415 .35995 L
.18221 .38123 L
.22272 .40254 L
.24141 .41191 L
.25127 .41673 L
.26171 .42175 L
.26698 .42425 L
.26843 .42493 L
.26922 .42531 L
.26998 .42566 L
.27068 .42599 L
.27145 .42236 L
.27214 .41044 L
.27279 .3994 L
.28302 .22795 L
.28803 .1461 L
.29276 .07038 L
.29404 .05022 L
.29538 .02904 L
.29608 .018 L
.29686 .01472 L
.29756 .0161 L
.29821 .01739 L
.30316 .02709 L
.34206 .10036 L
.38342 .17227 L
.42327 .23574 L
.4616 .2914 L
.46651 .29815 L
.4718 .30532 L
.47423 .30859 L
.47679 .312 L
.47898 .3149 L
.48022 .31654 L
.48137 .3291 L
.48268 .35415 L
.4839 .37764 L
.4862 .42118 L
.49136 .51694 L
.49393 .56363 L
.49461 .57583 L
.49533 .58889 L
.49665 .60332 L
.49739 .60311 L
.49807 .60292 L
.49963 .60249 L
.50238 .60173 L
Mistroke
.54214 .59151 L
.58039 .58292 L
.62109 .57512 L
.66027 .56893 L
.7019 .56376 L
.72281 .56171 L
.74202 .56015 L
.7608 .55892 L
.77038 .55841 L
.78062 .55795 L
.79092 .55758 L
.8003 .55731 L
.80482 .55721 L
.80973 .55712 L
.81436 .55705 L
.81865 .557 L
.82112 .55699 L
.82341 .55697 L
.82457 .55697 L
.8258 .55696 L
.82651 .55696 L
.82718 .55696 L
.82842 .55696 L
.82909 .55696 L
.82979 .55696 L
.83106 .55696 L
.83176 .55696 L
.83242 .55696 L
.83391 .55697 L
.83518 .55697 L
.83634 .55698 L
.83894 .557 L
.84137 .55702 L
.84362 .55704 L
.84489 .55706 L
.84608 .55707 L
.84733 .55693 L
.84799 .55681 L
.84871 .5568 L
.84984 .55678 L
.85103 .55676 L
.85316 .55672 L
.85797 .55661 L
.86743 .55635 L
.87754 .55598 L
.89577 .55511 L
.91709 .55373 L
.93723 .55207 L
.97567 .54797 L
.97619 .54791 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L00?l78@L00?l78@L00?l78@L00?l7
8@L0020700<01`L0o@L0020700<01`L0o@L0020700<01`L0o@L0020700<01`L0o@L0020700<01`L0
?PL2nKd7000P1`0300L703h70_Vm1`0080L203l700?i1oT0_0L0020700<01`L0?PL00oT7n@2l1`00
80L00`071`0n1`04n@L7nK/7000P1`0300L703h700Ci1`Oi^`L0020700<01`L0?PL01OT71`Oi0;X7
000P1`0300L703h700Gi1`L7n@2j1`0080L00`071`0n1`03n@L7008700?i1`L0]`L0020700<01`L0
?PL00oT71`021`03n@L70;L7000P1`0300L703h700?i1`L00`L00oT71`2f1`0080L203h700?i1`L0
10L00oT71`2f1`0080L00`071`0m1`03n@L700D700?i1`L0]@L0020700<01`L0?@L00oT71`051`03
n@L70;D7000P1`0300L703d700?i1`L01PL00oT71`2d1`0080L00`071`0m1`03n@L700H700?i1`L0
]0L0020700<01`L0?@L00oT71`071`03n@L70;<7000P1`0300L703d700?i1`L01`L00oT71`2c1`00
80L00`071`0m1`03n@L700P700?i1`L0/PL002070P0n1`03n@L700P700?i1`L0/PL0020700<01`L0
?@L00oT71`091`03n@L70;47000P1`0300L703d700?i1`L02PL00oT71`2`1`0080L00`071`0l1`03
n@L700/700?i1`L0/0L0020700<01`L0?0L00oT71`0<1`03n@L70:l7000P1`0300L703`700?i1`L0
30L00oT71`2_1`0080L00`071`0l1`03n@L700d700?i1`L0[PL000`700<01`L00PL00`071`021`04
00L71`8010L00`071`0l1`03n@L700h700?i1`L0[@L000/700<01`001`L00`0700021`0300L000<7
00<01`L0?0L00oT71`0>1`03n@L70:d700061`<00PL00`0700071`0300L0008700<01`000`L303`7
00?i1`L03`L00oT71`2/1`002`L00`0700071`0300L000870P041`0300L703`700?i1`L03`L00oT7
1`2/1`002`L00`0700071`0300L0008700<01`L00`L00`071`0l1`03n@L7010700?i1`L0Z`L000`7
00<01`L01`L00`071`021`800`L00`071`0l1`03n@L7010700?i1`L0Z`L0020700<01`L0?0L00oT7
1`0A1`03n@L70:X7000P1`0300L703`700?i1`L04PL00oT71`2Y1`0080L00`071`0l1`03n@L70187
00?i1`L0Z@L0020700<01`L0?0L00oT71`0C1`03n@L70:P7000P1`80?@L00oT71`0C1`03n@L70:P7
000P1`0300L703`700?i1`L050L00oT71`2W1`0080L00`071`0l1`03n@L701D700?i1`L0YPL00207
00<01`L0?0L00oT71`0E1`03n@L70:H7000P1`0300L703`700?i1`L05PL00oT71`2U1`0080L00`07
1`0k1`03n@L701L700?i1`L0Y@L0020700<01`L0>`L00oT71`0H1`03n@L70:@7000P1`0300L703/7
00?i1`L06@L00oT71`2S1`0080L00`071`0k1`03n@L701T700?i1`L0X`L002070P0l1`03n@L701X7
00?i1`L0XPL0020700<01`L0>`L00oT71`0J1`03n@L70:87000P1`0300L703/700?i1`L06`L00oT7
1`2Q1`0080L00`071`0k1`03n@L701`700?i1`L0X0L0020700<01`L0>`L00oT71`0L1`03n@L70:07
000P1`0300L703/700?i1`L07@L00oT71`2O1`0080L00`071`0k1`03n@L701d700?i1`L0W`L00207
00<01`L0>`L00oT71`0N1`03n@L709h7000P1`80?0L00oT71`0O1`03n@L709d7000P1`0300L703/7
00?i1`L07`L00oT71`2M1`0080L00`071`0k1`03n@L7020700?i1`L0W0L0020700<01`L0>`L00oT7
1`0Q1`03n@L709/7000P1`0300L703/700?i1`L08PL00oT71`2J1`0080L00`071`0k1`03n@L70287
00?i1`L0VPL000`700<01`L00PL00`071`021`0300L700870`021`0300L703/700?i1`L08`L00oT7
1`2I1`002`L00`0700071`0300L000@700D01`L7000m1`03n@L702@700?i1`L0V0L000H70`021`03
00L000L700<01`000PL400870`0j1`03n@L702D700?i1`L0V0L000/700<01`001`L00`0700021`03
00L000<700<01`L0>PL00oT71`0V1`03n@L709L7000;1`0300L000L700<01`000`L200<700<01`L0
>PL00oT71`0W1`03n@L709H7000<1`0300L700L700<01`L00`L01@071`Oi03`700?i1`L0:0L00oT7
1`2E1`0080L00`3in@0j1`03n@L702P700?i1`L0U@L0020700<01`L00_Th1`03n@L702T700?i1`L0
U0L0020700<01`L00PL00oT71`0e1`03n@L702X700?i1`L0T`L0020700<01`L00`L2nCD700?i1`L0
:`L00oT71`2B1`0080L00`071`051`;i<`L00oT71`0[1`03n@L70987000P1`8020L00oT71`0`1`03
n@L702`700?i1`L0T@L0020700<01`L020L2nC0700?i1`L0;0L2nI87000P1`0300L700X70_T^1`03
n@L702d700?i1`L0T0L0020700<01`L030L00oT71`0[1`03n@L702d700?i1`L0T0L0020700<01`L0
3@L2nB/700?i1`L0;@L00oT71`2@1`0080L00`071`0?1`;i:@L00oT71`0]1`03n@L70907000P1`03
00L7014700?i1`L09PL00oT71`0]1`03n@L70907000P1`0300L701870_TV1`03n@L702d700?i1`L0
T0L002070P0E1`03n@L702<700?i1`L0;PL00oT71`2?1`0080L00`071`0E1`;i8`L00oT71`0^1`03
n@L708l7000P1`0300L701L700?i1`L080L00oT71`0^1`03n@L708l7000P1`0300L701P70_TO1`03
n@L702l700?i1`L0S`L0020700<01`L06PL00oT71`0L1`03n@L702l700?i1`L0S`L0020700<01`L0
6`L2nA`700?i1`L0;`L00oT71`2?1`0080L00`071`0M1`;i6PL00oT71`0_1`03n@L708l7000P1`03
00L701l70_TH1`03n@L702l700?i1`L0S`L0020700<01`L08@L2nAH700?i1`L0;`L00oT71`2?1`00
80L202@700?i1`L04`L00oT71`0_1`03n@L708l7000P1`0300L702@70_TC1`03n@L702l700?i1`L0
S`L0020700<01`L09PL2nA4700?i1`L0;`L00oT71`2?1`0080L00`071`0X1`;i3`L00oT71`0_1`03
n@L708l7000P1`0300L702X70_T=1`03n@L702l700?i1`L0S`L0020700<01`L0;0L2n@/700?i1`L0
;`L00oT71`2?1`0030L00`071`021`0300L7008700@01`L70`031`0300L702h70_T91`03n@L702l7
00?i1`L0S`L000/700<01`001`L00`0700021`0300L700<700<01`L0<0L3n@H700?i1`L0;`L00oT7
1`2?1`001PL3008700<01`001`L00`0700031`0300L700870`0c1`;i10L00oT71`0_1`03n@L708l7
000;1`0300L000L700<01`000`L00`071`021`0300L703D700Ci1`Oi<PL00oT71`2?1`002`L00`07
00071`0300L0008700<01`000`L00`071`0f1`?i<PL00oT71`2?1`0030L00`071`071`0300L70087
00<01`L00PL00`071`0h1`03n@L7030700?i1`L0S`L0020700<01`L0J`L00oT71`2?1`0080L00`07
1`1[1`03n@L708l7000P1`0300L706/700?i1`L0S`L0020700<01`L0K0L00oT71`2>1`0080L206d7
00?i1`L0SPL0020700<01`L0K0L00oT71`2>1`0080L00`071`1/1`03n@L708h7000P1`0300L706`7
00?i1`L0SPL0020700<01`L0K0L00oT71`2>1`0080L00`071`1/1`03n@L708h7000P1`0300L706`7
00?i1`L0SPL0020700<01`L0K0L00oT71`2>1`0080L00`071`1/1`03n@L708h7000P1`80K@L00oT7
1`2>1`0080L00`071`1/1`03n@L708h7000P1`0300L706d700?i1`L0S@L0020700<01`L0K@L00oT7
1`2=1`0080L00`071`1]1`03n@L708d7000P1`0300L706d700?i1`L0S@L0020700<01`L0:@L302`7
0`0B1`03n@L701@70P0/1`0300L702H71@021`0300L701P7000P1`0300L702T700<01`L0;@L00`07
1`0A1`03n@L701@700<01`00:PL00`07000Y1`0700L71`07000I1`0080L202/700<01`L0:PL40187
00?i1`L050L00`07000Z1`0300L002T700L01`L700L001T7000P1`0300L702X700<01`L0:PL00`07
000C1`03n@L701@70P0/1`0300L702P700L01`L700L001T7000P1`0300L702T700<01`00;0L201<7
00?i1`L050L00`071`0Z1`0300L002T700L01`L700L001T7000P1`0300L702X700<01`L0;0L00`07
1`0A1`03n@L701D70P0[1`0300L702L70P041`0300L701P7000P1`0300L706d700?i1`L0S@L00207
00<01`L0K@L00oT71`2=1`0080L00`071`1]1`03n@L708d7000P1`0300L706d700?i1`L0K0L5n@d7
0`000`L01`0300H7000P1`0300L706d700?i1`L0F`LAnA<700H01`L01`081`006`Me0003n@0003/0
8?TL00P700H01`L01`081`0080L00`071`091`0300L700P700<01`L020L00`071`091`0300L700P7
00<01`L020L00`071`091`0300L700P700<01`L020L00`071`071`03n@L000X700<01`L020L00`07
1`091`0300L700P700<0nOT03?T81`0300L700P700<01`L020L00`071`091`0300L700P700<01`L0
30L400041`0000H7000P1`0300L706d700?i1`L0:0L5nE8700@01`L02PL0020700<01`L0K@L00oT7
1`0Q1`OiEPL300031`0700T7000P1`0300L706d700?i1`L06@L8nF`7000P1`0300L706d700?i1`L0
5@L4nG@7000P1`0300L706h700?i1`L03`L5nGP7000P1`0300L706h700?i1`L02`L4nGd7000P1`80
K`L00oT71`061`GiP@L0020700<01`L0KPL01?T71`L5nHH7000P1`0300L706h71?V;1`0080L00`07
1`1^1`;iS@L0020700<01`L0o@L0020700<01`L0o@L0020700<01`L0o@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L008H70P0U1`80L@L008P700<01`L08`L00`071`1_1`00G@L3008700<01`00
0PL300<70P021`<000L700001`0700<000<700000PL00`071`0300l70P000`L00002008700<01`00
0`0010L000031`0400L71`800`L300870P1R1`007`L00`07000200@700<01`L0<PL02@0700L01`07
00021`0500L71`000PL00`0700041`0400L7008700D01`L700021`0300L0008700<01`L03@L01`07
1`L01`000PL00`07000200<700L01`L700L000@700D01`L700051`0300L705l7000N1`0500L71`00
1PL00`071`0c1`0700L01`0700021`0500L71`0010L00`071`021`0400L7008700D01`L700021`03
00L0008700<01`L03PL3008700@01`L00`L01@071`L000<700<01`000`L00`071`021`0300L70087
00<01`L0H0L001D710041`0300L700870`051`0300L7034700<01`L00P0010L000L2008710021`<0
0PL300870P021`@00`L3010700@01`0710031`800`L00`071`0200031`0000870P021`8010L20647
000F1`0400L700<700<01`L00PL010071`041`0300L7030700<01`0030L00`071`071`0300L70247
00<01`L030L00`071`1d1`005PL010071`031`0300L7008700@01`L010L00`071`0`1`<020L00`07
1`0:1`801@L00`071`0J1`803@L200h700<01`L0I@L001H700@01`L00`L010071`L400D700<01`L0
l`L001H700@01`L010L00`071`081`0300L70?@7000E1`@01PL00`071`061`0300L70?D7003o1b47
003o1b47003o1b47003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.45626, -0.0820538, 
  0.0441654, 0.000593761}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.306358 2.49655 [
[.21429 .29386 -3 -9 ]
[.21429 .29386 3 0 ]
[.40476 .29386 -3 -9 ]
[.40476 .29386 3 0 ]
[.59524 .29386 -3 -9 ]
[.59524 .29386 3 0 ]
[.78571 .29386 -3 -9 ]
[.78571 .29386 3 0 ]
[.97619 .29386 -3 -9 ]
[.97619 .29386 3 0 ]
[1.025 .30636 0 -6.25 ]
[1.025 .30636 16 6.25 ]
[.01131 .0567 -24 -4.5 ]
[.01131 .0567 0 4.5 ]
[.01131 .18153 -30 -4.5 ]
[.01131 .18153 0 4.5 ]
[.01131 .43119 -24 -4.5 ]
[.01131 .43119 0 4.5 ]
[.01131 .55601 -18 -4.5 ]
[.01131 .55601 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12.5 ]
[.5 .63053 -56.0938 0 ]
[.5 .63053 56.0938 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .30636 m
.21429 .31261 L
s
[(1)] .21429 .29386 0 1 Mshowa
.40476 .30636 m
.40476 .31261 L
s
[(2)] .40476 .29386 0 1 Mshowa
.59524 .30636 m
.59524 .31261 L
s
[(3)] .59524 .29386 0 1 Mshowa
.78571 .30636 m
.78571 .31261 L
s
[(4)] .78571 .29386 0 1 Mshowa
.97619 .30636 m
.97619 .31261 L
s
[(5)] .97619 .29386 0 1 Mshowa
.125 Mabswid
.0619 .30636 m
.0619 .31011 L
s
.1 .30636 m
.1 .31011 L
s
.1381 .30636 m
.1381 .31011 L
s
.17619 .30636 m
.17619 .31011 L
s
.25238 .30636 m
.25238 .31011 L
s
.29048 .30636 m
.29048 .31011 L
s
.32857 .30636 m
.32857 .31011 L
s
.36667 .30636 m
.36667 .31011 L
s
.44286 .30636 m
.44286 .31011 L
s
.48095 .30636 m
.48095 .31011 L
s
.51905 .30636 m
.51905 .31011 L
s
.55714 .30636 m
.55714 .31011 L
s
.63333 .30636 m
.63333 .31011 L
s
.67143 .30636 m
.67143 .31011 L
s
.70952 .30636 m
.70952 .31011 L
s
.74762 .30636 m
.74762 .31011 L
s
.82381 .30636 m
.82381 .31011 L
s
.8619 .30636 m
.8619 .31011 L
s
.9 .30636 m
.9 .31011 L
s
.9381 .30636 m
.9381 .31011 L
s
.25 Mabswid
0 .30636 m
1 .30636 L
s
gsave
1.025 .30636 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Hc) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .0567 m
.03006 .0567 L
s
[(-0.1)] .01131 .0567 1 0 Mshowa
.02381 .18153 m
.03006 .18153 L
s
[(-0.05)] .01131 .18153 1 0 Mshowa
.02381 .43119 m
.03006 .43119 L
s
[(0.05)] .01131 .43119 1 0 Mshowa
.02381 .55601 m
.03006 .55601 L
s
[(0.1)] .01131 .55601 1 0 Mshowa
.125 Mabswid
.02381 .08167 m
.02756 .08167 L
s
.02381 .10663 m
.02756 .10663 L
s
.02381 .1316 m
.02756 .1316 L
s
.02381 .15656 m
.02756 .15656 L
s
.02381 .2065 m
.02756 .2065 L
s
.02381 .23146 m
.02756 .23146 L
s
.02381 .25643 m
.02756 .25643 L
s
.02381 .28139 m
.02756 .28139 L
s
.02381 .33132 m
.02756 .33132 L
s
.02381 .35629 m
.02756 .35629 L
s
.02381 .38125 m
.02756 .38125 L
s
.02381 .40622 m
.02756 .40622 L
s
.02381 .45615 m
.02756 .45615 L
s
.02381 .48112 m
.02756 .48112 L
s
.02381 .50608 m
.02756 .50608 L
s
.02381 .53105 m
.02756 .53105 L
s
.02381 .03174 m
.02756 .03174 L
s
.02381 .00677 m
.02756 .00677 L
s
.02381 .58098 m
.02756 .58098 L
s
.02381 .60594 m
.02756 .60594 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(D) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
69.000000 12.750000 moveto
(H) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
81.000000 12.750000 moveto
(L) show
87.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.5 .63053 -117.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Switching) show
123.187500 12.750000 moveto
(Analysis) show
171.187500 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.06244 .59029 L
.10458 .57641 L
.14415 .56369 L
.18221 .55175 L
.19227 .54864 L
.20178 .54572 L
.20433 .54494 L
.20573 .54452 L
.20704 .54412 L
.20772 .54309 L
.20845 .53956 L
.21 .53208 L
.21274 .51894 L
.22272 .4715 L
.26394 .28199 L
.28453 .19132 L
.29456 .14814 L
.29929 .12796 L
.30365 .10952 L
.3048 .10468 L
.30587 .10016 L
.30699 .09943 L
.30822 .09977 L
.31317 .10117 L
.32214 .1037 L
.34184 .1092 L
.38075 .11983 L
.42211 .13081 L
.46196 .14107 L
.50029 .15065 L
.54107 .16053 L
.58034 .16973 L
.61809 .1783 L
.65829 .18712 L
.69698 .19531 L
.73812 .20369 L
.77774 .21146 L
.81585 .21864 L
.85641 .22598 L
.89546 .23274 L
.91537 .23607 L
.92585 .23779 L
.93695 .23959 L
.94667 .24115 L
.94934 .24158 L
.95081 .24181 L
.95153 .24192 L
.9522 .24203 L
.95349 .2449 L
Mistroke
.9549 .24913 L
.95737 .25652 L
.97619 .31133 L
Mfstroke
0 1 0 r
.02381 .01472 m
.06244 .02757 L
.10458 .04127 L
.14415 .05381 L
.18221 .06559 L
.22272 .07782 L
.26171 .08929 L
.30316 .10115 L
.32392 .10697 L
.34309 .11227 L
.34772 .11354 L
.35271 .11491 L
.35513 .11556 L
.35742 .11619 L
.35948 .11675 L
.36065 .11706 L
.36173 .1187 L
.36296 .12421 L
.36412 .12938 L
.36628 .13904 L
.37114 .16057 L
.3815 .20601 L
.42005 .36896 L
.43036 .4109 L
.43999 .44943 L
.44248 .45929 L
.4437 .46413 L
.44484 .46859 L
.44614 .47214 L
.44682 .47197 L
.44755 .47178 L
.45003 .47116 L
.46105 .46839 L
.4988 .45909 L
.53901 .44948 L
.57769 .44053 L
.61883 .43133 L
.65846 .42278 L
.69657 .41484 L
.73713 .4067 L
.77617 .39917 L
.81767 .39148 L
.85765 .38439 L
.89612 .37785 L
.90639 .37616 L
.91141 .37534 L
.9136 .37498 L
.91599 .37459 L
.91728 .37438 L
.91847 .37219 L
Mistroke
.91961 .36871 L
.92083 .36501 L
.92602 .3493 L
.93704 .31661 L
.97619 .20788 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L00?l78@L00?l78@L00?l78@L00?l7
8@L0020700<01`L0o@L0020700<01`L0o@L002070P3n1`0080L00`071`3m1`0080L2n_h7000P1`03
00Oj00;jn`L0020700<01`L00PL4n_L7000P1`0300L700H70o[d1`0080L200X70o[a1`0080L00`07
1`0<1`Cjk@L0020700<01`L040L3n^X7000P1`0300L701<70o[W1`004@L00`071`021`0300L700D0
0PL00`071`0F1`?ji0L0010700<01`0020L00`071`021`0300L701T70o[Q1`002`L3008700<01`00
20L00`071`021`<070L3n]h7000@1`0300L000P700<01`L00PL00`071`0O1`?jf`L0010700<01`00
20L00`071`021`0300L702870o[H1`004@L00`071`061`8010L00`071`0U1`?je@L0020700<01`L0
:0L4n]47000P1`0300L702`70o[>1`0080L203070o[;1`0080L00`071`0b1`?jb0L0020700<01`L0
=@L4n/@7000P1`0300L703T71OZo1`0080L00`071`0n1`Cj00?i1`L0^0L0020700<01`L0@0L01?T7
n_X3nKH7000P1`80@@L01?T71`L3nPCi/PL0020700<01`L0@0L00oT71`041`Cj0oV_1`0080L00`07
1`101`03n@L700P71?X2nJ`7000P1`0300L703l700?i1`L030L00oX71`04nJP7000P1`0300L703l7
00?i1`L030L00oX71`041`GiX`L0020700<01`L0?`L00oT71`0<1`03nPL700T71?VO1`0080L20407
00?i1`L03@L00oX71`0<1`?iW0L0020700<01`L0?`L00oT71`0=1`03nPL700l71?VH1`0080L00`07
1`0n1`03n@L700h700?j1`L04`L4nI@7000P1`0300L703h700?i1`L03PL00oX71`0G1`CiT0L00207
00<01`L0?PL00oT71`0?1`03nPL701X71?V<1`0080L00`071`0n1`03n@L700l700?j1`L07PL3nHT7
000P1`80?PL00oT71`0@1`03nPL702470oV61`0080L00`071`0m1`03n@L7010700?j1`L090L4nH87
000P1`0300L703d700?i1`L040L00oX71`0X1`GiO@L000`700<01`L00PL00`071`021`0300L70087
00<01`L00PL00`071`0l1`03n@L7018700?j1`L0;0L5nGP7000;1`0300L000L700<01`000PL00`07
00031`0300L703`700?i1`L04PL00oX71`0a1`CiM0L000H70`021`0300L000L700<01`0010L01007
1`L303`700?i1`L04PL00oX71`0e1`GiK`L000/700<01`001`L00`0700021`8010L00`071`0l1`03
n@L701<700?j1`L0>@L4nF/7000;1`0300L000L700<01`000PL00`071`031`0300L703/700?i1`L0
50L00oX71`0m1`GiIPL000`700<01`L01`L010071`L300<700<01`L0>`L00oT71`0D1`03nPL70487
1OUQ1`0080L00`071`0k1`03n@L701@700?j1`L0A`L5nE`7000P1`0300L703/700?i1`L05@L00oX7
1`1;1`CiF0L002070P0k1`03n@L701H700?j1`L0C`L5nE<7000P1`0300L703X700?i1`L05PL00oX7
1`1D1`Gi<@L00oX71`0J1`0080L00`071`0j1`03n@L701H700?j1`L0F@L7nBX700?j1`L06PL00207
00<01`L0>PL00oT71`0G1`03nPL705l71oTR1`03nPL701/7000P1`0300L703X700?i1`L05`L00oX7
1`1V1`Ci7PL00oX71`0K1`0080L00`071`0i1`03n@L701P700?j1`L0JPL5nAT700?j1`L06`L00207
0P0j1`03n@L701P700?j1`L0K`L5nA<700?j1`L070L0020700<01`L0>@L00oT71`0I1`03nPL707<7
2?T;1`03nPL701`7000P1`0300L703T700?i1`L06@L00oX71`1k1`Gi1PL00oX71`0L1`0080L00`07
1`0i1`03n@L701T700?j1`L0P0L3n@8700?j1`L07@L0020700<01`L0>@L00oT71`0I1`03nPL70887
00Ci1`Oj7`L0020700<01`L0>0L00oT71`0K1`03nPL7088700?i1oX07`L002070P0i1`03n@L701/7
00?j1`L0PPL00oWj1`0O1`0080L00`071`0X1`D02`L00oT71`0K1`04nP0002X70P0/1`<09PL01OWj
1`L001d7000P1`0300L702X700<01`L02`L00oT71`0K1`03nP0702d700<01`L0:PL00`071`0U1`06
n_T700L070L0020700<01`L0:PL00`071`0;1`03n@L701/700?j1`00;0L00`071`0Y1`@09PL00o[i
1`021`0300L701X7000P1`0300L702X700<01`L02PL00oT71`0M1`03nP0702`700<01`L0:0L00`07
000W1`03nPOi00807@L0020700<01`L0:PL00`071`0:1`03n@L701d700?j1`00:PL00`07000[1`80
9PL01OX71oT001h7000P1`80:PL200`700?i1`L07@L00oX01`0[1`0300L702/700<01`L090L01?X7
1oT301`7000P1`0300L703L700?i1`L07@L00oX71`201`05nPL71oT07PL0020700<01`L0=`L00oT7
1`0N1`03nPL707h700?j1`L00PL00oT71`0L1`0080L00`071`0f1`03n@L701l700?j1`L0OPL00oX7
1`021`03n@L701`7000P1`0300L703H700?i1`L07`L00oX71`1n1`03nPL700<700?i1`L06`L00207
00<01`L0=PL00oT71`0O1`03nPL707d700?j1`L010L00oT71`0<1`<000<700L00`061`006`Ln0003
n@00020000?j0000O0000oX000050003n@0000@020L01P071`0700P7000P1`0300L700L700<01`L0
1PL00`071`061`0300L700H700<01`L01PL00`071`061`030?T700H700<01`L01PL00`071`061`03
00L700H700<0nPL01PL00`071`061`0300L700H700<01`L01PL00`071`061`0300L700H700<01`L0
1PL00`071`061`0300L700L700<01`L01PL00`071`061`0300L700H700<01`L01PL00`071`061`03
0?X700H700?i1`L030L01P071`0700P7000P1`0300L702/700<01`L01`L00oT71`0P1`030?X702X7
00<01`L0:`L00`071`0Q1`03nPL700H700<01`L030L400041`0000H7000P1`0300L703D700?i1`L0
8@L00oX71`1k1`03nPL701D700@01`L02PL0020700<01`L0=@L00oT71`0Q1`03nPL707/700?j1`L0
50L300031`0700T7000P1`0300L703D700?i1`L08PL00oX71`1i1`03nPL702@7000P1`80=@L00oT7
1`0S1`03nPL707T700?j1`L090L0020700<01`L0=0L00oT71`0S1`03nPL707P700?j1`L09@L00207
00<01`L0=0L00oT71`0S1`03nPL707P700?j1`L09@L0020700<01`L0=0L00oT71`0T1`03nPL707H7
00?j1`L09PL0020700<01`L0<`L00oT71`0U1`03nPL707H700?j1`L09PL0020700<01`L0<`L00oT7
1`0U1`03nPL707H700?j1`L09PL002070P0d1`03n@L702D700?j1`L0M@L00oX71`0W1`0080L00`07
1`0c1`03n@L702H700?j1`L0M0L00oX71`0W1`0080L00`071`0c1`03n@L702H700?j1`L0M0L00oX7
1`0W1`0080L00`071`0b1`03n@L702L700?j1`L0L`L00oX71`0X1`0080L00`071`0b1`03n@L702L7
00?j1`L0LPL2nRX7000P1`0300L7038700?i1`L09`L00oX71`1/1`Kj;0L002070P0c1`03n@L702P7
00?j1`L0I`L4nS87000P1`0300L7034700?i1`L0:@L00oX71`1P1`Oj=PL0020700<01`L0<@L00oT7
1`0Y1`03nPL705P72?Xm1`0080L00`071`0a1`03n@L702T700?j1`L0D`L5nTD7000P1`0300L70347
00?i1`L0:@L00oX71`1>1`GjBPL0020700<01`L0<@L00oT71`0Z1`03nPL704T71?Y?1`0080L20347
00?i1`L0:`L00oX71`141`GjD`L0020700<01`L0<0L00oT71`0[1`03nPL703l71OYH1`0080L00`07
1`0`1`03n@L702/700?j1`L0>PL5nUd7000P1`0300L7030700?i1`L0:`L00oX71`0f1`CjHPL000`7
00<01`L00PL00`071`021`0300L7008700<01`L00PL00`071`0_1`03n@L702d700?j1`L0<0L5nVH7
000;1`0300L000L700<01`000PL00`0700031`0300L702l700?i1`L0;@L00oX71`0/1`CjJ`L000/7
00<01`001`L00`0700041`0400L71`<0;`L00oT71`0]1`03nPL702L71OY_1`002`L00`0700071`03
00L000870P041`0300L702l700?i1`L0;@L00oX71`0R1`GjM0L000/700<01`001`L00`0700021`03
00L700<700<01`L0;`L00oT71`0^1`03nPL701`71OYi1`0030L00`071`071`0400L71`<00`L00`07
1`0^1`03n@L702l700?j1`L060L4nWh7000P1`0300L702h700?i1`L0;`L00oX71`0C1`GjPPL00207
00<01`L0;PL00oT71`0_1`03nPL700h71OZ71`0080L202l700?i1`L0<0L00oX71`091`CjS0L00207
00<01`L0;@L00oT71`0a1`03nPL700H70oZ@1`0080L00`071`0]1`03n@L7034700?j1`L00`L3nY<7
000P1`0300L702d700?i1`L0<PL5nYH7000P1`0300L702d700?i1`L0<PL00oX71`2H1`0080L00`07
1`0/1`03n@L70<h7000P1`80;@L00oT71`3>1`0080L00`071`0/1`03n@L70<h7000P1`0300L702`7
00?i1`L0cPL0020700<01`L0:`L00oT71`3?1`0080L00`071`0[1`03n@L70<l7000P1`0300L702/7
00?i1`L0c`L002070P0/1`03n@L70<l7000P1`0300L702X700?i1`L0d0L0020700<01`L0:PL00oT7
1`3@1`0080L00`071`0Z1`03n@L70=07000P1`0300L702X700?i1`L0d0L0020700<01`L0:PL00oT7
1`3@1`0080L202/700?i1`L0d0L0020700<01`L0:@L00oT71`3A1`0080L00`071`0Y1`03n@L70=47
000P1`0300L702P70_WC1`004@L00`071`021`0300L700D00PL00`071`0U1`?ie@L0010700<01`00
20L00`071`021`0300L702471?WH1`0040L00`0700081`0300L700870`0M1`Cig0L0010700<01`00
20L00`071`021`0300L701T71?WP1`0040L00`0700081`0300L7008700<01`L05PL3nN@7000A1`03
00L700H70P041`0300L701<70oWW1`0080L00`071`0@1`?ijPL002070P0?1`;ik@L0020700<01`L0
2`L3nNl7000P1`0300L700T70_Wb1`0080L00`071`061`?im0L0020700<01`L00`L3nOL7000P1`03
00Oi00?inPL002070_Wn1`0080L00`071`3m1`0080L00`071`3m1`0080L00`071`3m1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00QPL202D70P1a1`00R0L00`071`0S1`0300L706l7001M1`<0
0PL00`0700021`<00`L200870`001`L0000700L00`000`L000021`0300L700<03`L200031`000080
0PL00`07000300041`0000<700@01`L70P031`<00PL20687000O1`0300L0008010L00`071`0b1`09
00L01`0700L0008700D01`L700021`0300L000@700@01`L00PL01@071`L0008700<01`000PL00`07
1`0=1`0700L71`0700021`0300L000800`L01`071`L01`0010L01@071`L000D700<01`L0G`L001h7
00D01`L700061`0300L703<700L01`0700L0008700D01`L700041`0300L7008700@01`L00PL01@07
1`L0008700<01`000PL00`071`0>1`<00PL010071`031`0500L71`000`L00`0700031`0300L70087
00<01`L00PL00`071`1P1`005@L400@700<01`L00PL300D700<01`L0<@L00`071`0200041`001`80
0PL400870`021`<00PL2008710031`<040L0100700L400<70P031`0300L7008000<700000PL20087
0P041`80H@L001H700@01`L00`L00`071`021`0400L700@700<01`L0<0L00`07000<1`0300L700L7
00<01`L08@L00`071`0<1`0300L707@7000F1`0400L700<700<01`L00PL010071`041`0300L70307
0`081`0300L700X70P051`0300L701X70P0=1`803PL00`071`1U1`005PL010071`031`0400L71`@0
1@L00`071`3c1`005PL010071`041`0300L700P700<01`L0m0L001D710061`0300L700H700<01`L0
m@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.72813, -0.132452, 
  0.0220827, 0.00168481}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(dif\  = \ 
      Simplify[hprofnp\[LeftDoubleBracket]1\[RightDoubleBracket] - 
          hprni\[LeftDoubleBracket]1\[RightDoubleBracket]]; \n
    ntoi\  = hc /. \ FindRoot[dif, {hc, {0.5, 1.2}}]\), 
    \(dif\  = \ 
      Simplify[hprofim\[LeftDoubleBracket]1\[RightDoubleBracket] - 
          hprin\[LeftDoubleBracket]1\[RightDoubleBracket]]; \n
    iton\  = \ hc /. FindRoot[dif, {hc, {1.5, 2}}]\), 
    \(dif\  = \ 
      Simplify[hprofdm\[LeftDoubleBracket]1\[RightDoubleBracket] - 
          hprdn\[LeftDoubleBracket]1\[RightDoubleBracket]]; \n
    dton\  = \ \ hc /. FindRoot[dif, {hc, {6, 10}}]\)}], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(1.23217147757306366`\)], "Output"],

Cell[BoxData[
    \(2.001074494774564`\)], "Output"],

Cell[BoxData[
    \(8.64600545892683136`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\tp1\  = \ 
      ParametricPlot[\ {x, y} /. nenp, \ \ \ \ {hc, 0, ntoi}, \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        PlotRange \[Rule] kader, \ Frame -> True, \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        PlotStyle \[Rule] {RGBColor[1, 0, 0]}, DisplayFunction -> Identity]; 
    \n\ \ \ p2\  = \ 
      ParametricPlot[\ {x, y} /. neim, \ \ \ \ {hc, iton, itod}, \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        PlotRange \[Rule] kader, \ \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        PlotStyle \[Rule] {RGBColor[0, 1, 0]}, DisplayFunction -> Identity]; 
    \n\ \ p3\  = \ 
      ParametricPlot[\ {x, y} /. nedm, \ \ \ \ {hc, dtoi, dton}, \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        PlotRange \[Rule] kader, Frame -> True, \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        PlotStyle \[Rule] {RGBColor[0, 0, 1]}, DisplayFunction -> Identity]; 
    \n\ \ Show[p1, DMRegion, IMRegion, p2, p3, 
      DisplayFunction -> $DisplayFunction]; \)\)], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->10,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.185018 0 0.123607 [
[.18502 -0.0125 -3 -9 ]
[.18502 -0.0125 3 0 ]
[.37004 -0.0125 -3 -9 ]
[.37004 -0.0125 3 0 ]
[.55506 -0.0125 -3 -9 ]
[.55506 -0.0125 3 0 ]
[.74007 -0.0125 -3 -9 ]
[.74007 -0.0125 3 0 ]
[.92509 -0.0125 -3 -9 ]
[.92509 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12361 -6 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -6 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -6 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -6 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18502 0 m
.18502 .00625 L
s
[(1)] .18502 -0.0125 0 1 Mshowa
.37004 0 m
.37004 .00625 L
s
[(2)] .37004 -0.0125 0 1 Mshowa
.55506 0 m
.55506 .00625 L
s
[(3)] .55506 -0.0125 0 1 Mshowa
.74007 0 m
.74007 .00625 L
s
[(4)] .74007 -0.0125 0 1 Mshowa
.92509 0 m
.92509 .00625 L
s
[(5)] .92509 -0.0125 0 1 Mshowa
.125 Mabswid
.037 0 m
.037 .00375 L
s
.07401 0 m
.07401 .00375 L
s
.11101 0 m
.11101 .00375 L
s
.14801 0 m
.14801 .00375 L
s
.22202 0 m
.22202 .00375 L
s
.25903 0 m
.25903 .00375 L
s
.29603 0 m
.29603 .00375 L
s
.33303 0 m
.33303 .00375 L
s
.40704 0 m
.40704 .00375 L
s
.44404 0 m
.44404 .00375 L
s
.48105 0 m
.48105 .00375 L
s
.51805 0 m
.51805 .00375 L
s
.59206 0 m
.59206 .00375 L
s
.62906 0 m
.62906 .00375 L
s
.66607 0 m
.66607 .00375 L
s
.70307 0 m
.70307 .00375 L
s
.77708 0 m
.77708 .00375 L
s
.81408 0 m
.81408 .00375 L
s
.85109 0 m
.85109 .00375 L
s
.88809 0 m
.88809 .00375 L
s
.9621 0 m
.9621 .00375 L
s
.9991 0 m
.9991 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
[(1)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(2)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(3)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(4)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(5)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .61178 m
0 .61803 L
s
.18502 .61178 m
.18502 .61803 L
s
.37004 .61178 m
.37004 .61803 L
s
.55506 .61178 m
.55506 .61803 L
s
.74007 .61178 m
.74007 .61803 L
s
.92509 .61178 m
.92509 .61803 L
s
.125 Mabswid
.037 .61428 m
.037 .61803 L
s
.07401 .61428 m
.07401 .61803 L
s
.11101 .61428 m
.11101 .61803 L
s
.14801 .61428 m
.14801 .61803 L
s
.22202 .61428 m
.22202 .61803 L
s
.25903 .61428 m
.25903 .61803 L
s
.29603 .61428 m
.29603 .61803 L
s
.33303 .61428 m
.33303 .61803 L
s
.40704 .61428 m
.40704 .61803 L
s
.44404 .61428 m
.44404 .61803 L
s
.48105 .61428 m
.48105 .61803 L
s
.51805 .61428 m
.51805 .61803 L
s
.59206 .61428 m
.59206 .61803 L
s
.62906 .61428 m
.62906 .61803 L
s
.66607 .61428 m
.66607 .61803 L
s
.70307 .61428 m
.70307 .61803 L
s
.77708 .61428 m
.77708 .61803 L
s
.81408 .61428 m
.81408 .61803 L
s
.85109 .61428 m
.85109 .61803 L
s
.88809 .61428 m
.88809 .61803 L
s
.9621 .61428 m
.9621 .61803 L
s
.9991 .61428 m
.9991 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .02472 m
1 .02472 L
s
.99625 .04944 m
1 .04944 L
s
.99625 .07416 m
1 .07416 L
s
.99625 .09889 m
1 .09889 L
s
.99625 .14833 m
1 .14833 L
s
.99625 .17305 m
1 .17305 L
s
.99625 .19777 m
1 .19777 L
s
.99625 .22249 m
1 .22249 L
s
.99625 .27193 m
1 .27193 L
s
.99625 .29666 m
1 .29666 L
s
.99625 .32138 m
1 .32138 L
s
.99625 .3461 m
1 .3461 L
s
.99625 .39554 m
1 .39554 L
s
.99625 .42026 m
1 .42026 L
s
.99625 .44498 m
1 .44498 L
s
.99625 .46971 m
1 .46971 L
s
.99625 .51915 m
1 .51915 L
s
.99625 .54387 m
1 .54387 L
s
.99625 .56859 m
1 .56859 L
s
.99625 .59331 m
1 .59331 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.81498 .24378 m
.81016 .24453 L
.8049 .24535 L
.79996 .24612 L
.79522 .24686 L
.79016 .24765 L
.7853 .2484 L
.78012 .24921 L
.77514 .24999 L
.77035 .25073 L
.76525 .25153 L
.76034 .2523 L
.75562 .25303 L
.75059 .25381 L
.74575 .25457 L
.74061 .25537 L
.73565 .25614 L
.73089 .25689 L
.72582 .25768 L
.72093 .25844 L
.71574 .25925 L
.71074 .26003 L
.70593 .26078 L
.70082 .26157 L
.69614 .2623 L
s
.9 g
.46144 .03743 m
0 .18129 L
0 .61803 L
.15727 .61803 L
F
.6 g
.46144 .03743 m
.15727 .61803 L
.92509 .61803 L
.92509 .54078 L
F
0 1 0 r
.59078 .20466 m
.58167 .20657 L
.57172 .20866 L
.56239 .21062 L
.55341 .2125 L
.54385 .21451 L
.53465 .21644 L
.52487 .21849 L
.51545 .22047 L
.50639 .22237 L
.49675 .22439 L
.48746 .22634 L
.47854 .22822 L
.46903 .23021 L
.45988 .23213 L
.45016 .23417 L
.44079 .23614 L
.43178 .23803 L
.42219 .24004 L
.41295 .24198 L
.40314 .24404 L
.39369 .24602 L
.38459 .24793 L
.37492 .24996 L
.36608 .25181 L
s
0 0 1 r
.36904 .17538 m
.35542 .17519 L
.34058 .17499 L
.32663 .17479 L
.31323 .17461 L
.29895 .17441 L
.28521 .17422 L
.27061 .17402 L
.25654 .17382 L
.24301 .17363 L
.22861 .17343 L
.21474 .17324 L
.20141 .17306 L
.18722 .17286 L
.17356 .17267 L
.15903 .17247 L
.14504 .17228 L
.13159 .17209 L
.11726 .17189 L
.10348 .1717 L
.08883 .1715 L
.07471 .1713 L
.06113 .17111 L
.04668 .17091 L
.03348 .17073 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L003l71@0/1`<0;@L202l70`0]1`03
00L701`700111`0300L702`700<01`L0;`L00`071`0]1`0300L702/700<01`007@L0044700<01`L0
;@L00`071`0]1`0300L702`7100^1`0300L701/700111`0300L702d700<01`L0;PL00`071`0[1`03
00L002d70P0N1`00@@L00`071`0/1`0300L002d700<01`00;PL202d700<01`L07@L004070P0_1`03
00L702d700<01`L0;PL00`071`0[1`<07@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00187
o`0500X7000B1`0300L700L700<01`L01PL00`071`071`0300L700H700<01`L01`L00`071`071`03
00L700H700<01`L01`L00`071`061`0300L700L700<01`L01PL00`071`071`0300L700L700<01`L0
1PL00`071`071`0300L700H700<01`L01`L00`071`071`0300L700H700<01`L01`L00`071`061`03
00L700L700<01`L01`L00`071`061`0300L700L700<01`L01PL00`071`071`0300L700P7000B1`03
00L70?l70@L00`071`081`004PL00`071`3o1`4700<01`L020L0018700<01`L0o`L11`0300L700P7
000B1`0300L70?l70@L00`071`081`004PL20?l70@L200X7000B1`0300L70?l70@L00`071`081`00
4PL00`071`3o1`4700<01`L020L0018700<01`L0o`L11`0300L700P7000B1`0300L70?l70@L00`07
1`081`004PL00`071`1c1`03ohV908X700<01`L020L0018700<01`L0L0L2o`:d0hV91`0300L700P7
000B1`80K@L2]0;o0[@00on9R@03RHL70P0:1`004PL00`071`1Y1`03okBd00;o0[@2o`03]8V900B9
Q`L00`071`081`004PL00`071`1V1`;o0[@3o`03]?oo00:d28V61`0300L700P7000B1`0300L706<7
00>dool00[@2o`:d0_l2]0;o2HV51`0300L700P7000B1`0300L705l700?o];@00_l2]0;o0[@2o`:d
0_l00kB9R@08RHD700<01`L020L0018700<01`L0G0L2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900V9
Q0L00`071`081`004PL205X700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l=RH870P0:1`004PL00`07
1`1F1`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d3XV21`0300L700P7000B1`0300L705870_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900j9P@L00`071`081`004PL00`071`1?1`03]?oo00:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@0?RH0700<01`L020L0018700<01`L0C0L01?nd
ool2]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dRHT04HUo1`0300L700P7000B1`03
00L704T700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oaB9OPL00`071`081`00
4PL204H700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT058Ul1`80
2PL0018700<01`L0@PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9
R@0ERG`700<01`L020L0018700<01`L0?`L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lIRG/700<01`L020L0018700<01`L0?0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@JRGX700<01`L020L0018700<01`L0>0L2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV901Z9N@L00`071`081`00
2PL500<700<01`L0=@L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2oaf9N@L00`071`081`0030L00`071`031`0300L703870ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]1j9N0L00`07
1`081`0030L00`071`031`<0;`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0NRGH70P0:1`0030L00`071`031`0300L702`70[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0
7hUf1`0300L700P7000<1`0300L700<700<01`L0:0L2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d8hUe1`0300L700P7000;1`801@L00`07
1`0U1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lTRG@700<01`L020L0018700<01`L08PL2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V902B9L`L00`07
1`081`004PL00`071`0O1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT09HUb1`0300L700P7000B1`8070L00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_lYRG070P0:1`004PL00`071`0H1`:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kB9R@0XRG0700<01`L020L0018700<01`L05@L00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?oRHT0:XU_1`0300L700P7000B1`0300L701870_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V902^9
KPL00`071`081`004PL00`071`0>1`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d;hU]1`0300L700P7
000B1`0300L700/700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l_RFd700<01`L020L00187
00<01`L01PLOo003okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l00kB9R@0_RF`700<01`L020L001870P061`03]?oo00:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l00kClo00go0;o0[@00on9R@0`RFX70P0:1`004PL01@071`Oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ocB9JPL00`071`081`004PL00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]3F9J@L00`07
1`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@0eRFP7
00<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o>HUW1`03
00L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]3Z9IPL00`07
1`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0>XUT1`80
2PL0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V903^9I0L00`07
1`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d=HT4nPJ9H`L00`07
1`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o<8T5nP^9HPL00`07
1`081`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol]R@Cj4HUQ1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d00?oRHT09XT5nQF9H@L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2obB91OXKREl70P0:1`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]1n91OXQREl700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
00?oRHT06HT5nRN9GPL00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@0DR@Gj;HUM1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]1:91OXcRE`700<01`L020L000/70`041`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2oa290_XiRE/700<01`L020L000/700<01`L010L00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`04]?oo]0b91OXlRBP70oT_1`0300L700P7000<1`0300L700<7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV900F91OY2RB071oTa1`802PL000`7
00<01`L00`L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o18T4nTR96@L6nCT700<01`L0
20L000/700<01`0010L00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dDHTA1`Oi?`L00`07
1`081`0030L00`071`031`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0DHT:1`Ki
APL00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oeF91PL3nD`700<01`L0
20L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[AERED700<01`L020L0018700?o];@0
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0EHUC1`802PL0018700>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0omHRE<700<01`L020L0018700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:dFXUB1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2oe^9D@L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0FhU@1`03
00L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1LRDl700<01`L020L00187
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2of29CPL00`071`081`004PL00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:dHHU<1`802PL0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@1QRD`7
00<01`L020L0018700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d
0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`04]?oo]6B9
B`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]6J9BPL00`071`081`004PL00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2ofN9B@L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@1VRDT700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0IhU71`80
2PL0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oJhU71`0300L700P7000B1`03]?oo00:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]6b9APL00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0K8U51`03
00L700P7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0_m`RD@700<01`L0
20L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]769@`L00`071`081`004PL00kCoo`02]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]003ohV90769@PL00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V907:9@0L200X7
000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dMXU01`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
MhTo1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V907N9?PL00`071`081`002`L200D7
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0N8Tm1`0300L700P7000=1`0300L7008700>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03
]?oo00:d0ol00kCoo`02]0?o00>dool0NhTm1`0300L700P7000<1`0300L700<700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:dO8Tk1`802PL000d700<01`L00PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0O8Tk1`0300L700P7
000;1`0300L000@700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V907f9>PL00`071`081`0030L00`071`031`03
]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[B1RCT700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2oh:9>0L00`071`081`00
4PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V908:9=`L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV908>9
=@L200X7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@2ohN9=@L00`071`081`004PL00ond
]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l00kB9R@27RC@700<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0R8Tc1`0300L700P7
000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2ohb9<PL00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[B=RC4700<01`L020L00187
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]003ohV908b9<@L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o00>dRHT0SHT_1`802PL00187
00?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]969;`L00`071`081`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo09:9;PL00`07
1`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`03]8V909:9;@L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV909>9;0L00`07
1`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2oiN9:`L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]9R9:@L200X7000B1`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ohV909R9:@L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@2IRBP700<01`L020L0018700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:dWHTW1`03
00L700P7000B1`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0;oWXTV1`0300L700P7000B1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@2NRBD7
00<01`L020L0018700>dool00[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]003ohV909j99@L00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;oXXTS1`802PL0018700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9
R@2RRB<700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@00on9R@2SRB8700<01`L020L0018700>dool00[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_nWRB4700<01`L020L000`7
0`031`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:dZ8TP1`0300L700P7000=1`0300L7008700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?n90:V97`L00`071`081`00
2`L400<700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o00>dRHT0ZHTM1`802PL000/700<01`0010L00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[B]RAd700<01`L020L000`70P041`03okBd00;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ojj970L00`07
1`081`003@L00`071`021`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l00kB9R@2^RA/700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV90:n96PL00`071`081`004PL00kCo
o`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o/hTI1`03
00L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[BcRAP70P0:1`004PL00kCoo`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o
00>dool00[@3o`03]?oo00:d0ol00kCoo`02]003ohV90;>960L00`071`081`004PL00ond]002o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90;B95`L00`07
1`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2];R95PL00`071`081`004PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2okV95@L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@2iRA@700<01`L020L0018700?o];@00_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d00?oRHT0^XTC1`0300L700P7
000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2okf9
4PL200X7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@2lRA<700<01`L020L0018700>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dohT0_HTC1`0300L700P7000B1`03okBd00;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_noRA<700<01`L020L0018700>dool0
0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2];n94`L00`071`081`00
4PL00ond]002o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003ohV90;j9
4`L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`03]8V90;j94PL200X7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d`HTC1`0300L700P7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o`HTC1`0300L700P7000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`03]8V90<294`L00`071`081`004PL00kCoo`02]0?o00>dool0
0[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?oo00:d00?oRHT0`8TC1`0300L700P7
000B1`03okBd00;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2ol>94`L00`07
1`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[C3RA<7
00<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]003
ohV90<:94PL200X7000B1`03]?oo00:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l00kB9R@32RA<700<01`L020L0018700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]<F94`L00`071`081`004PL00kCoo`02]0;o0[@2o`:d0_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;oaHTC1`0300L700P7000<1`0300L700<700?o];@00_l2]0;o0[@2o`:d0_l2]0;o
0[@2o`:d0_l2]0;o0[@2o`:d0_l00kB9R@34R@0300L7010700<01`L020L000/700<01`0010L00kCo
o`02]0?o00>dool00[@3o`03]?oo00:d0ol00kCoo`02]0?o00>dool00[@3o`03]?n90<F900<01`L0
1PL00`071`071`0300L700P7000=1`0300L7008700?o];@00_l2]0;o0[@2o`:d0_l2]0;o0[@2o`:d
0_l2]0;o0[@2o`:d0_o7RA@02PL000/70P3o1a@7000;1`0300L70?l74`L000/70`3o1a<7003o1b47
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.384832, -0.382056, 
  0.0208518, 0.0312115}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Welfare implications", "Section"],

Cell[BoxData[
    \(ConsSurNP = \ \(2*\ CSH[x, y] /. NENP\) /. Par; \n
    HomeProfNP\  = \ \(2*\ Hprof[x, y] /. NENP\) /. Par; \n
    WelftotalNP\  = \ ConsSurNP\  + \ HomeProfNP; \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\ tpuIM\  = \ {t -> IM[x, y] /. NEIM}; \n
    TaxRevIM\ \ \  = \ 
      \(Simplify[\(\((y /. NET)\)\ \ t /. tpuIM\) /. Par]\)[\([1]\)]; \n
    ConsSurIM\  = 
      \(Simplify[
          \((\((CSH[x, y] /. NEIM)\) + \((\(CSH[x, y] /. NET\) /. tpuIM)\))
              \) /. Par]\)[\([1]\)]; \ntpuDM\  = \ {t -> IM[x, y] /. NEDM}; \n
    TaxRevDM\ \ \  = \ 
      \(Simplify[\(\((y /. NET)\)\ \ t /. tpuDM\) /. Par]\)[\([1]\)]; \n
    ConsSurDM\  = \n\t
      \(Simplify[
          \((\((CSH[x, y] /. NEDM)\) + \((\(CSH[x, y] /. NET\) /. tpuDM)\))
              \) /. Par]\)[\([1]\)]; \n
    WelftotalIM\  = \ TaxRevIM + ConsSurIM\  + hprofim[\([1]\)]; \n
    WelftotalDM\  = \ TaxRevDM + ConsSurDM + hprofdm[\([1]\)]; \n
    part1\  = 
      Plot[{TaxRevIM, ConsSurIM, hprofim[\([1]\)], WelftotalIM}, {hc, iton, 
          itod}\ , \ \ \ \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ 
        DisplayFunction -> Identity\ \ \ , AxesLabel -> {"\<hc\>", "\<W\>"}, 
        \n\t\t\ \ \ \ \ \ \ \ \ \ PlotRange -> {{0, 10}, {0, 100}}]; \n
    part2\  = \ 
      Plot[{TaxRevDM, ConsSurDM, hprofdm[\([1]\)], WelftotalDM}, {hc, dtoi, 
          dton}\ , \ \ \ \n\t\ \ \ \ \ \ \ \ \ \ \ \ \ 
        DisplayFunction -> Identity\ \ \ ]; \n
    Show[part1, part2, DisplayFunction -> $DisplayFunction]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0 0.00618034 [
[.2 -0.0125 -3 -9 ]
[.2 -0.0125 3 0 ]
[.4 -0.0125 -3 -9 ]
[.4 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.8 -0.0125 -3 -9 ]
[.8 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[1.025 0 0 -6.25 ]
[1.025 0 16 6.25 ]
[-0.0125 .12361 -12 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -12 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -12 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -12 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 0 m
.2 .00625 L
s
[(2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(hc) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(20)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(40)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(60)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(80)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(100)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(W) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.20011 .00116 m
.21018 .00165 L
.22116 .00219 L
.23147 .00268 L
.24139 .00315 L
.25194 .00365 L
.2621 .00411 L
.27291 .0046 L
.28331 .00507 L
.29332 .00551 L
.30397 .00597 L
.31423 .0064 L
.32409 .00682 L
.33459 .00725 L
.34469 .00766 L
.35543 .00809 L
.36578 .00849 L
.37573 .00887 L
.38633 .00927 L
.39652 .00965 L
.40736 .01004 L
.4178 .01042 L
.42785 .01077 L
.43853 .01113 L
.4483 .01146 L
s
.20011 .11093 m
.21018 .10855 L
.22116 .106 L
.23147 .10363 L
.24139 .10139 L
.25194 .09903 L
.2621 .09679 L
.27291 .09445 L
.28331 .09223 L
.29332 .09012 L
.30397 .08791 L
.31423 .08581 L
.32409 .08383 L
.33459 .08175 L
.34469 .07978 L
.35543 .07772 L
.36578 .07577 L
.37573 .07392 L
.38633 .07199 L
.39652 .07017 L
.40736 .06826 L
.4178 .06646 L
.42785 .06475 L
.43853 .06297 L
.4483 .06138 L
s
.20011 .14382 m
.21018 .1396 L
.22116 .13507 L
.23147 .13089 L
.24139 .12693 L
.25194 .12277 L
.2621 .11884 L
.27291 .11474 L
.28331 .11085 L
.29332 .10717 L
.30397 .10332 L
.31423 .09969 L
.32409 .09625 L
.33459 .09266 L
.34469 .08927 L
.35543 .08574 L
.36578 .0824 L
.37573 .07925 L
.38633 .07597 L
.39652 .07288 L
.40736 .06966 L
.4178 .06663 L
.42785 .06377 L
.43853 .06081 L
.4483 .05816 L
s
.20011 .2559 m
.21018 .24981 L
.22116 .24326 L
.23147 .2372 L
.24139 .23147 L
.25194 .22545 L
.2621 .21975 L
.27291 .21379 L
.28331 .20814 L
.29332 .20279 L
.30397 .1972 L
.31423 .19191 L
.32409 .1869 L
.33459 .18166 L
.34469 .17671 L
.35543 .17155 L
.36578 .16666 L
.37573 .16205 L
.38633 .15724 L
.39652 .15269 L
.40736 .14796 L
.4178 .1435 L
.42785 .13929 L
.43853 .13491 L
.4483 .131 L
s
.51668 .00984 m
.53079 .01036 L
.54619 .01092 L
.56064 .01144 L
.57455 .01193 L
.58934 .01244 L
.60359 .01292 L
.61873 .01342 L
.63332 .01389 L
.64735 .01434 L
.66228 .0148 L
.67665 .01524 L
.69048 .01565 L
.70519 .01608 L
.71936 .01648 L
.73442 .0169 L
.74892 .01729 L
.76288 .01766 L
.77773 .01804 L
.79202 .0184 L
.80721 .01877 L
.82185 .01912 L
.83593 .01944 L
.85091 .01978 L
.8646 .02008 L
s
.51668 .0511 m
.53079 .04871 L
.54619 .04618 L
.56064 .04389 L
.57455 .04175 L
.58934 .03954 L
.60359 .03749 L
.61873 .03538 L
.63332 .03342 L
.64735 .03161 L
.66228 .02975 L
.67665 .02804 L
.69048 .02646 L
.70519 .02485 L
.71936 .02337 L
.73442 .02187 L
.74892 .0205 L
.76288 .01924 L
.77773 .01799 L
.79202 .01685 L
.80721 .01571 L
.82185 .01469 L
.83593 .01378 L
.85091 .01289 L
.8646 .01214 L
s
.51668 .04255 m
.53079 .03926 L
.54619 .03581 L
.56064 .03272 L
.57455 .02988 L
.58934 .027 L
.60359 .02437 L
.61873 .02172 L
.63332 .01931 L
.64735 .01713 L
.66228 .01496 L
.67665 .01301 L
.69048 .01126 L
.70519 .00954 L
.71936 .00803 L
.73442 .00657 L
.74892 .0053 L
.76288 .00422 L
.77773 .00321 L
.79202 .00238 L
.80721 .00164 L
.82185 .00109 L
.83593 .00068 L
.84321 .00053 L
.84693 .00046 L
.85091 .0004 L
.85461 .00036 L
.85799 .00032 L
.86138 .00029 L
.8646 .00028 L
s
.51668 .10349 m
.53079 .09833 L
.54619 .09292 L
.56064 .08805 L
.57455 .08355 L
.58934 .07897 L
.60359 .07477 L
.61873 .07051 L
.63332 .06662 L
.64735 .06308 L
.66228 .05951 L
.67665 .05628 L
.69048 .05337 L
.70519 .05047 L
.71936 .04787 L
.73442 .04533 L
.74892 .04309 L
.76288 .04112 L
.77773 .03924 L
.79202 .03762 L
.80721 .03613 L
.82185 .0349 L
.83593 .03391 L
.85091 .03307 L
.8646 .03249 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{60, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L004H70`0]1`<0;0L202h700<01`L0
:0L5008700<01`L05PL004H700<01`L0;PL00`071`0[1`0300L002`700<01`00:`L01`071`L01`00
5`L004L700<01`L0:`L402`700<01`00;0L00`07000[1`0700L71`07000G1`00A`L00`071`0[1`03
00L002d70P0^1`0300L702X700L01`L700L001L700161`0300L002d70P0]1`0300L702`700<01`00
:`L01`071`L01`005`L004L700<01`L0;@L00`071`0/1`80;@L00`071`0Y1`8010L00`071`0F1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`L>1`<000<700L00`0:1`00o`L?1`0600L700L030L001P7kP081`06
00L700L030L001P700<01`L0;0L00`071`0>1aH02@L00`071`0/1`0300L701T73@071`0300L702`7
00<01`L01PL300870`0:1`0060L00`071`1C1aD03`LD01D71`0R1`80:0L00`071`0?1`0060L00`07
1`2;1al04@L>02T70P0A1`0060L00`071`2B1`L04@LQ03X7000H1`0300L708/71`0A1`/0E`L001P7
00<01`L0R0L301471`1R1`0060L208871`0:1`X0:PL503X7000H1`0300L707d7100:1`L09PL>03l7
000H1`0300L707X70`071`L09PL704d7000H1`0300L707L70`031`L09PL705@7000H1`0300L707X7
0`0V1`L0F`L001P700<01`L0M`L302H70`1R1`0060L00`071`1W1`0300L70387101U1`0060L206D7
100]1`L0J@L001P700<01`L0H0L402h70`1`1`0060L00`071`1K1`D0;`L307<7000H1`0300L705<7
2P0^1`@0MPL001P700<01`L0CPL500<71@0]1`<0NPL001P700<01`L0B@L500D70`0^1`@0O@L001P7
00<01`L0A@L400P70P0_1`80P@L001P700<01`L0@0L500L71@0_1`80P`L001P70P0l1`D02@L30347
0`251`0060L00`071`0h1`<030L203470`281`0060L00`071`0c1`D03@L203070`2;1`0060L00`07
1`0^1`D03`L30<07000H1`0300L702`70P0B1`80``L000`70`031`0300L700<700<01`L0?@L30<D7
000<1`0300L7008700<01`0010L00`071`0k1`80b0L000d700L01`L700L000@70P0i1`<0bPL000d7
00L01`L700L000@700<01`L0=PL20<d7000<1`0300L0008700<01`0010L00`071`0c1`<0<@L00`07
1`2K1`003@L00`071`021`0300L700<700<01`L0<@L203470`2N1`0060L00`071`0^1`<0<@L20:47
000H1`0300L702`70P0b1`80X`L001P700<01`L0G@L30:D7000H1`80G0L20:P7000H1`0300L705P7
0`2Z1`0060L00`071`1F1`80[@L001P700<01`L0D`L30:l7000H1`0300L705470P2b1`0060L00`07
1`1?1`80]0L001P700<01`L0C@L20;H7000H1`80C@L00`071`2f1`0060L00`071`191`<0^@L001P7
00<01`L0A`L20;`7000H1`0300L704D70P2n1`0060L00`071`141`0300L70;h7000H1`0300L70487
0P311`0060L00`071`101`80``L001P700<01`L0?PL20<D7000H1`80?@L20<L7000H1`0300L703/7
00<01`L0a`L001P700<01`L0>0L30<X7000H1`0300L703H70P3=1`0060L00`071`0e1`0300L70<d7
000=1`<00PL00`071`031`0300L703<70P3@1`003PL01P071`0700@700<01`L0<@L20=87000<1`@0
00@700L010L2034700<01`L0dPL000`700<01`000PL00`0700041`0300L702h70P3E1`003@L20087
00<01`0010L00`071`0/1`80e`L000h700D01`L700051`0300L70?l71PL001P700<01`L0o`L61`00
60L00`071`3o1`H7000H1`0300L70?l71PL001P70P3o1`L7000H1`0300L70?l71PL001P700<01`L0
o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7
000H1`0300L70?l71PL001P70P3o1`L7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`07
1`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`80o`L71`00
60L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000<1`80
10L00`071`031`0300L70?l71PL000`700<01`000PL00`0700041`0300L70?l71PL000`700<01`00
0PL00`0700041`80o`L71`0030L200<700<01`0010L00`071`3o1`H7000<1`0300L7008700<01`00
10L00`071`3o1`H7000=1`800`L00`071`031`0300L70?l71PL001P700<01`L0o`L61`0060L00`07
1`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L20?l71`L001P700<01`L0o`L61`00
60L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`03
00L70?l71PL001P70P3o1`L7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7
000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`80o`L71`0060L00`07
1`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l7
1PL000d700<01`L00PL00`071`031`0300L70?l71PL000`700<01`000PL00`0700041`0300L70?l7
1PL000`700<01`000PL00`0700041`80o`L71`003@L01`071`L01`0010L00`071`3o1`H7000<1`03
00L0008700<01`0010L00`071`3o1`H7000=1`0300L7008700<01`L00`L00`071`3o1`H7000H1`03
00L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`80o`L71`0060L00`071`3o1`H7
000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P7
00<01`L0o`L61`0060L20?l71`L001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l7
1PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`00
60L20?l71`L001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0
o`L61`001PL5008700<01`L00PL00`071`031`0300L70?l71PL000P700L01`L700L0008700<01`00
10L00`071`3o1`H700081`0700L71`0700021`0300L000@70P3o1`L700081`0700L71`0700021`03
00L00?l73@L000P700L01`L700L0008700<01`00o`L=1`001`L200@700<01`L00PL00`071`3o1``7
003o1b47003o1b47003o1b47003o1b47003o1b47003o1b47003o1b47000F1`0300L00?l720L001D7
00D01`07003o1`L7000E1`0500L01`00o`L71`005@L01@0700L00?l71`L001D700D01`L7003o1`L7
000E1`8000<70000o`L71`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.03159, -8.16453, 
  0.0421736, 0.682384}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(part1\  = \ 
      Plot[{WelftotalNP}, {hc, 0, 10}, \ \n\t\t\ 
        PlotRange -> {{0, 12}, {0, 100}}, AxesLabel -> {"\<hc\>", "\<W\>"}, 
        PlotStyle \[Rule] {RGBColor[1, 0, 0]}, DisplayFunction -> Identity]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(part2 = 
      Plot[{WelftotalIM}, {hc, iton, itod}, \ \ 
        PlotRange -> {{0, 12}, {0, 100}}, 
        PlotStyle \[Rule] {RGBColor[0, 1, 0]}, DisplayFunction -> Identity]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(part3 = 
      Plot[{WelftotalDM}, {hc, dtoi, dton}, \ \ 
        PlotRange -> {{0, 12}, {0, 100}}, 
        PlotStyle \[Rule] {RGBColor[0, 0, 1]}, DisplayFunction -> Identity]; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[part1, part2, part3, DisplayFunction -> $DisplayFunction]; 
    \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0833333 0 0.00618034 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[1.025 0 0 -6.25 ]
[1.025 0 16 6.25 ]
[-0.0125 .12361 -12 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -12 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -12 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -12 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(4)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(6)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(8)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(10)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(12)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(hc) show
75.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(20)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(40)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(60)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(80)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(100)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.500000 moveto
 457.000000 16.500000 lineto
 457.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.500000 lineto
closepath
clip newpath
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(W) show
69.000000 12.750000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .41536 m
.03381 .38165 L
.07067 .3467 L
.1053 .3156 L
.1386 .28727 L
.17404 .2588 L
.20816 .23306 L
.24443 .20746 L
.27937 .18454 L
.31298 .16409 L
.34874 .14406 L
.38317 .12645 L
.41627 .11108 L
.45153 .09639 L
.48545 .08388 L
.52152 .07235 L
.55627 .06294 L
.58969 .05548 L
.62525 .04925 L
.65949 .04492 L
.67822 .04324 L
.68681 .04263 L
.69587 .0421 L
.70425 .04171 L
.70869 .04155 L
.71344 .0414 L
.71782 .04129 L
.7218 .04122 L
.72372 .04119 L
.72581 .04116 L
.72778 .04115 L
.72865 .04114 L
.72961 .04113 L
.73064 .04113 L
.73172 .04113 L
.73273 .04113 L
.73366 .04113 L
.73477 .04113 L
.73577 .04113 L
.73633 .04113 L
.73693 .04113 L
.73803 .04114 L
.74003 .04116 L
.74214 .04118 L
.74594 .04124 L
.75037 .04133 L
.75452 .04144 L
.76396 .04178 L
.77307 .04222 L
.78172 .04275 L
Mistroke
.79794 .04403 L
.8153 .0458 L
.8314 .04782 L
.83333 .04808 L
Mfstroke
0 1 0 r
.16676 .2559 m
.17515 .24981 L
.1843 .24326 L
.19289 .2372 L
.20116 .23147 L
.20995 .22545 L
.21842 .21975 L
.22742 .21379 L
.23609 .20814 L
.24443 .20279 L
.25331 .1972 L
.26186 .19191 L
.27007 .1869 L
.27882 .18166 L
.28724 .17671 L
.29619 .17155 L
.30482 .16666 L
.31311 .16205 L
.32194 .15724 L
.33044 .15269 L
.33947 .14796 L
.34817 .1435 L
.35654 .13929 L
.36544 .13491 L
.37358 .131 L
s
0 0 1 r
.43057 .10349 m
.44233 .09833 L
.45516 .09292 L
.4672 .08805 L
.47879 .08355 L
.49112 .07897 L
.50299 .07477 L
.51561 .07051 L
.52776 .06662 L
.53946 .06308 L
.5519 .05951 L
.56388 .05628 L
.5754 .05337 L
.58766 .05047 L
.59947 .04787 L
.61202 .04533 L
.6241 .04309 L
.63573 .04112 L
.6481 .03924 L
.66002 .03762 L
.67268 .03613 L
.68487 .0349 L
.69661 .03391 L
.70909 .03307 L
.7205 .03249 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool78@L003h70`0V1`<08`L202L700<01`L0
80L5008700<01`L07@L500041`0001L7000n1`0300L702L700<01`L08PL00`07000U1`0300L002<7
00L01`L700L0020700D01`L7000I1`00?`L00`071`0T1`@08`L00`07000U1`0300L002<700L01`L7
00L0020700<01`L00PL00`071`0F1`00?`L00`071`0T1`0300L002@70P0W1`0300L7028700L01`L7
00L0020700<01`L00PL00`071`0F1`00?PL00`07000V1`8090L00`071`0U1`0300L002<700L01`L7
00L0020700L01`L700L001L7000o1`0300L702H700<01`L08`L202H700<01`L08@L200@700<01`L0
7PL200@700<01`L05PL00?l78@L00?l78@L00?l78@L00?l73PL300031`0700<02PL00?l73`L01P07
1`0700`7000H1nh020L01P071`0700`7000H1`0300L702@700<01`L09@L00`071`0U1`0300L702@7
00<01`L09@L00`071`0T1`0300L700H70`021`<02PL001P700<01`L0l`L00`071`0?1`0060L00`07
1`3b1`804@L001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P70P2U1`Gl
G0L001P700<01`L0V@L;o647000H1`0300L709<71_`;1`oiDPL001P700<01`L0S@L6o0<73_T?1`gi
A@L001P700<01`L0Q`L6o0<71_TZ1`Ci@@L001P700<01`L0Q@L2o0D71?Ue1`0060L00`071`221`?l
00<7nOT01?Ui1`0060L207d71_`4nGl7000H1`0300L707T70o`21`;iQ@L001P700<01`L0MPL3o087
0oV71`0060L00`071`1c1`?l00<7nOT00_V:1`0060L00`071`1`1`?l1?V>1`0060L00`071`1^1`;l
0oVB1`0060L00`071`1/1`;l00?i1`L0U0L001P700<01`L0JPL2o003n@L709H7000H1`80J@L2o9/7
000H1`0300L706D70obM1`0060L00`071`1S1`;l00?i1`L0W@L001P700<01`L0HPL2nJ47000H1`03
00L706070_VS1`0030L300<700<01`L00`L00`071`1N1`;iY@L000`700<01`L00PL00`0700041`03
00L705`70_VW1`003@L01`071`L01`0010L205/70_VY1`003@L01`071`L01`0010L00`071`1H1`;i
Z`L000`700<01`000PL00`0700041`0300L705H700?jn@L0[0L000d700<01`L00PL00`071`031`03
00L705@70_Z_1`0060L00`071`1B1`;j/@L001P700<01`L0C`L3n[<7000H1`0300L704d70_Zf1`00
60L204`70_Zh1`0060L00`071`191`;j^PL001P700<01`L0A`L2n[`7000H1`0300L704D70_Zn1`00
60L00`071`131`;j`0L001P700<01`L0@@L2nP03n@L70;l7000H1`0300L7040700?jn@L0`PL001P7
0P101`03nPL70<<7000H1`0300L703d70_[61`0060L00`071`0k1`;j00?i1`L0a@L001P700<01`L0
>@L2nP03n@L70<L7000H1`0300L703P700?j1oT0bPL001P700<01`L0=`L00o[in@3;1`0060L00`07
1`0e1`;j00?i1`L0b`L001P700<01`L0<`L2nP;icPL001P70P0c1`03nPOi0=07000H1`0300L70347
00?jnOT0d@L001P700<01`L0;`L2nP03n@L70=47000H1`0300L702d70_X2nM@7000H1`0300L702`7
00?j1oT0ePL000d70`021`0300L700<700<01`L0:`L00oX7n@3G1`003PL01P071`0700@700<01`L0
:@L2nP;if0L000`7100010L01`041`80:0L2nP031oT70=T7000<1`0300L0008700<01`0010L00`07
1`0V1`04nPL7nM/7000=1`800PL00`0700041`0300L702D700Cj1oWig0L000h700D01`L700051`03
00L702H700?i1`L0g0L001P700<01`L09@L00oT71`3M1`0060L00`071`0T1`03n@L70=h7000H1`03
00L702<700?i1`L0g`L001P70P0R1`;ihPL001P700<01`L080L00oT71`3R1`0060L00`071`0O1`03
n@L70><7000H1`0300L701h700?i1`L0i0L001P700<01`L07@L00oT71`3U1`0060L00`071`0K1`;i
j0L001P700<01`L06PL00oT71`3X1`0060L00`071`0I1`03n@L70>T7000H1`8060L2nN`7000H1`03
00L701H700?i1`L0k0L001P700<01`L05@L00oT71`3]1`0060L00`071`0D1`03n@L70>h7000H1`03
00L701<700?i1`L0k`L001P700<01`L04PL00oT71`3`1`0060L00`071`0A1`03n@L70?47000H1`80
4@L00oT71`3b1`0060L00`071`0?1`03n@L70?<7000H1`0300L700h700?i1`L0m0L001P700<01`L0
3@L00oT71`3e1`0060L00`071`0<1`03n@L70?H7000<1`8010L00`071`031`0300L700/700?i1`L0
m`L000`700<01`000PL00`0700041`0300L700T70_Wj1`0030L00`0700021`0300L000@70P091`03
n@L70?X7000<1`800`L00`0700041`0300L700L700?i1`L0n`L000`700<01`L00PL00`0700041`03
00L700H700?i1`L0o0L000d70P031`0300L700<700<01`L01@L00oT71`3m1`0060L00`071`041`03
n@L70?h7000H1`0300L700<700?i1`L0o`L001P700<01`L00PL00oT71`3o1`47000H1`0500L71oT0
o`L41`0060L200031oT70?l710L001P700<01oT0o`L61`0060L00`3i1`3o1`H7000H1`03n@L70?l7
1PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P70P3o1`L7000H1`03
00L70?l71PL001P700<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0
o`L61`0060L00`071`3o1`H7000H1`80o`L71`0060L00`071`3o1`H7000H1`0300L70?l71PL001P7
00<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL000d700<01`L00PL00`071`031`03
00L70?l71PL000`700<01`000PL00`0700041`0300L70?l71PL000`700<01`000PL00`0700041`80
o`L71`003@L01`071`L01`0010L00`071`3o1`H7000<1`0300L0008700<01`0010L00`071`3o1`H7
000=1`0300L7008700<01`L00`L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`00
60L00`071`3o1`H7000H1`80o`L71`0060L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0
o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L20?l71`L001P7
00<01`L0o`L61`0060L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L00`07
1`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`0060L20?l71`L001P700<01`L0o`L61`00
60L00`071`3o1`H7000H1`0300L70?l71PL001P700<01`L0o`L61`001PL5008700<01`L00PL00`07
1`031`0300L70?l71PL000P700L01`L700L0008700<01`0010L00`071`3o1`H700081`0700L71`07
00021`0300L000@70P3o1`L700081`0700L71`0700021`0300L00?l73@L000P700L01`L700L00087
00<01`00o`L=1`001`L200@700<01`L00PL00`071`3o1``7003o1b47003o1b47003o1b47003o1b47
003o1b47003o1b47003o1b47000F1`0300L00?l720L001D700D01`07003o1`L7000E1`0500L01`00
o`L71`005@L01@0700L00?l71`L001D700D01`L7003o1`L7000E1`8000<70000o`L71`00o`LQ1`00
o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.23791, -8.16453, 
  0.0506084, 0.682384}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(part1\  = \ 
      Plot[{{WelftotalIM - WelftotalNP\ }, {WelftotalDM - WelftotalNP\ }, {
            ConsSurIM - ConsSurNP}, {hprofim - HomeProfNP\ }, {\ 
            TaxRevIM - \ 0}}, {hc, iton, itod}, \ \ 
        AxesLabel -> {"\<\>", "\<\>"}, \n\t\t\t\ \ \ 
        PlotStyle 
          \[Rule] {{AbsoluteThickness\ [3]}, {AbsoluteThickness\ [4]}, {
              AbsoluteThickness\ [2], Dashing\ \ [{0.01, 0.01}]}, {
              AbsoluteThickness\ [2], Dashing\ \ [{0.04, 0.02}]}, {
              AbsoluteThickness\ [2], Dashing\ \ [{0.06, 0.01}]}}, 
        DisplayFunction -> Identity, \n\t\t
        PlotRange -> {{0, 10}, {\(-6\), 6}}]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\tpart2\  = \ 
      Plot[{{WelftotalDM - WelftotalNP}, {ConsSurDM - ConsSurNP\ }, {
            hprofdm\  - HomeProfNP}, {TaxRevDM - \ 0\ }}, {hc, dtoi, dton}, 
        \ \ PlotStyle 
          \[Rule] {{AbsoluteThickness\ [3]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.01, 0.01}]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.04, 0.02}]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.06, 0.01}]}}, DisplayFunction -> Identity]; \n
    part3\  = \ 
      Plot[{{WelftotalDM - WelftotalNP}}, {hc, itod, dtoi}, \ \ 
        PlotStyle 
          \[Rule] {{AbsoluteThickness\ [3]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.01, 0.01}]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.04, 0.02}]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.06, 0.01}]}}, DisplayFunction -> Identity]; \n\t
    Show[part1, part2, part3, \ DisplayFunction -> $DisplayFunction]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0.309017 0.0515028 [
[.2 .29652 -3 -9 ]
[.2 .29652 3 0 ]
[.4 .29652 -3 -9 ]
[.4 .29652 3 0 ]
[.6 .29652 -3 -9 ]
[.6 .29652 3 0 ]
[.8 .29652 -3 -9 ]
[.8 .29652 3 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -6 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 .30902 m
.2 .31527 L
s
[(2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(10)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-6)] -0.0125 0 1 0 Mshowa
0 .10301 m
.00625 .10301 L
s
[(-4)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-2)] -0.0125 .20601 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(4)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(6)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
3 Mabswid
.20011 .23728 m
.21018 .24121 L
.22116 .24539 L
.23147 .24921 L
.24139 .2528 L
.25194 .25652 L
.2621 .26001 L
.27291 .26362 L
.28331 .26699 L
.29332 .27015 L
.30397 .2734 L
.31423 .27644 L
.32409 .27927 L
.33459 .28219 L
.34469 .28491 L
.35543 .28769 L
.36578 .29028 L
.37573 .29268 L
.38633 .29513 L
.39652 .29739 L
.40736 .29969 L
.4178 .30181 L
.42785 .30376 L
.43853 .30573 L
.4483 .30744 L
s
4 Mabswid
.20011 .2999 m
.21018 .29971 L
.22116 .29949 L
.23147 .29925 L
.24139 .29899 L
.25194 .29869 L
.2621 .29838 L
.27291 .29803 L
.27832 .29784 L
.28069 .29775 L
.28331 .29766 L
.28452 .29761 L
.28519 .29759 L
.28551 .29757 L
.28582 .29756 L
.2861 .29755 L
.28641 .29757 L
.28674 .2976 L
.28705 .29762 L
.28817 .29772 L
.29332 .29814 L
.30376 .29894 L
.31381 .29964 L
.32449 .30031 L
.33479 .30088 L
.34468 .30137 L
.35522 .30182 L
.36536 .30219 L
.37613 .3025 L
.38153 .30263 L
.38652 .30273 L
.39167 .30281 L
.39651 .30288 L
.40137 .30293 L
.40395 .30295 L
.40674 .30297 L
.40923 .30298 L
.41065 .30298 L
.41196 .30299 L
.41268 .30299 L
.41303 .30299 L
.41335 .30299 L
.41364 .30299 L
.41396 .30299 L
.41428 .30299 L
.41462 .30299 L
.41481 .30299 L
.41499 .30299 L
.41533 .30299 L
.41552 .30299 L
Mistroke
.41569 .30299 L
.41609 .30299 L
.41644 .30299 L
.41675 .30299 L
.41746 .30299 L
.41807 .30299 L
.41873 .30298 L
.42008 .30298 L
.42249 .30297 L
.4253 .30295 L
.42792 .30293 L
.43323 .30288 L
.43807 .30281 L
.4483 .30262 L
Mfstroke
2 Mabswid
[ .01 .01 ] 0 setdash
.20011 .19322 m
.21018 .19209 L
.22116 .19087 L
.23147 .18973 L
.24139 .18864 L
.25194 .18749 L
.2621 .18639 L
.27291 .18523 L
.28331 .18413 L
.29332 .18307 L
.30397 .18196 L
.31423 .18089 L
.32409 .17988 L
.33459 .1788 L
.34469 .17778 L
.35543 .1767 L
.36578 .17567 L
.37573 .17469 L
.38633 .17365 L
.39652 .17266 L
.40736 .17161 L
.4178 .17062 L
.42785 .16967 L
.43853 .16867 L
.4483 .16776 L
s
[ .04 .02 ] 0 setdash
.20011 .34344 m
.21018 .34435 L
.22116 .34529 L
.23147 .34613 L
.24139 .34689 L
.25194 .34765 L
.2621 .34834 L
.27291 .34903 L
.28331 .34965 L
.29332 .35019 L
.30397 .35073 L
.31423 .3512 L
.32409 .35161 L
.33459 .352 L
.34469 .35233 L
.35543 .35263 L
.36578 .35288 L
.37573 .35307 L
.38129 .35316 L
.38633 .35323 L
.39164 .35329 L
.39652 .35334 L
.40154 .35337 L
.40418 .35339 L
.40696 .3534 L
.40943 .35341 L
.41082 .35341 L
.41208 .35341 L
.41326 .35342 L
.41392 .35342 L
.41424 .35342 L
.41454 .35342 L
.41482 .35342 L
.41507 .35342 L
.41536 .35342 L
.41566 .35342 L
.41594 .35342 L
.41625 .35342 L
.41656 .35342 L
.41686 .35342 L
.41719 .35342 L
.41754 .35342 L
.41818 .35342 L
.41885 .35342 L
.4196 .35342 L
.42094 .35341 L
.42219 .35341 L
.42453 .3534 L
.42704 .35339 L
.43255 .35336 L
Mistroke
.43779 .35332 L
.44776 .3532 L
.4483 .3532 L
Mfstroke
[ .06 .01 ] 0 setdash
.20011 .31865 m
.21018 .3228 L
.22116 .32726 L
.23147 .33139 L
.24139 .33531 L
.25194 .33941 L
.2621 .34331 L
.27291 .34739 L
.28331 .35125 L
.29332 .35492 L
.30397 .35875 L
.31423 .36239 L
.32409 .36582 L
.33459 .36943 L
.34469 .37284 L
.35543 .3764 L
.36578 .37977 L
.37573 .38296 L
.38633 .38629 L
.39652 .38943 L
.40736 .39271 L
.4178 .39581 L
.42785 .39874 L
.43853 .40179 L
.4483 .40452 L
s
3 Mabswid
[ ] 0 setdash
.51668 .29712 m
.53079 .29461 L
.54619 .29187 L
.56064 .2893 L
.57455 .28683 L
.58934 .28421 L
.60359 .28169 L
.61873 .27901 L
.63332 .27644 L
.64735 .27397 L
.66228 .27134 L
.67665 .26881 L
.69048 .26639 L
.70519 .26381 L
.71936 .26133 L
.73442 .2587 L
.74892 .25616 L
.76288 .25373 L
.77773 .25115 L
.79202 .24866 L
.80721 .24603 L
.82185 .24349 L
.83593 .24105 L
.85091 .23846 L
.8646 .2361 L
s
2 Mabswid
[ .01 .01 ] 0 setdash
.51668 .16223 m
.53079 .15747 L
.54619 .15236 L
.56064 .14764 L
.57455 .14319 L
.58934 .13853 L
.60359 .13412 L
.61873 .12953 L
.63332 .12519 L
.64735 .12109 L
.66228 .11682 L
.67665 .11279 L
.69048 .10899 L
.70519 .10502 L
.71936 .10129 L
.73442 .09741 L
.74892 .09375 L
.76288 .09031 L
.77773 .08674 L
.79202 .08337 L
.80721 .07989 L
.82185 .07662 L
.83593 .07356 L
.85091 .07038 L
.8646 .06755 L
s
[ .04 .02 ] 0 setdash
.51668 .36191 m
.53079 .35981 L
.54619 .35751 L
.56064 .35535 L
.57455 .35328 L
.58934 .35107 L
.60359 .34895 L
.61873 .34669 L
.63332 .34452 L
.64735 .34243 L
.66228 .34021 L
.67665 .33807 L
.69048 .33602 L
.70519 .33384 L
.71936 .33173 L
.73442 .3295 L
.74892 .32735 L
.76288 .32528 L
.77773 .32309 L
.79202 .32097 L
.80721 .31872 L
.82185 .31656 L
.83593 .31448 L
.85091 .31227 L
.8646 .31025 L
s
[ .06 .01 ] 0 setdash
.51668 .39101 m
.53079 .39537 L
.54619 .40004 L
.56064 .40434 L
.57455 .40841 L
.58934 .41265 L
.60359 .41666 L
.61873 .42083 L
.63332 .42477 L
.64735 .42848 L
.66228 .43234 L
.67665 .43599 L
.69048 .43941 L
.70519 .44298 L
.71936 .44634 L
.73442 .44982 L
.74892 .4531 L
.76288 .45617 L
.77773 .45936 L
.79202 .46235 L
.80721 .46544 L
.82185 .46834 L
.83593 .47105 L
.85091 .47385 L
.8646 .47633 L
s
3 Mabswid
[ ] 0 setdash
.4483 .30262 m
.45107 .30256 L
.4541 .30248 L
.45694 .30241 L
.45967 .30233 L
.46258 .30224 L
.46538 .30215 L
.46836 .30205 L
.47122 .30194 L
.47398 .30184 L
.47692 .30172 L
.47974 .3016 L
.48246 .30148 L
.48535 .30135 L
.48813 .30122 L
.49109 .30108 L
.49257 .301 L
.49394 .30093 L
.49527 .30086 L
.49565 .30084 L
.49575 .30084 L
.49584 .30083 L
.49592 .30083 L
.49601 .30081 L
.49634 .30076 L
.49669 .30069 L
.49959 .30018 L
.50238 .29968 L
.50535 .29915 L
.50821 .29864 L
.51097 .29814 L
.51389 .29762 L
.51668 .29712 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{381, 235.313},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005m0000j`P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool7OPL00?l7OPL00?l7OPL00?l7OPL00?l7
OPL000P70P3o1g@700081`0300L00?l7L`L000<70`021`0300L000D70`3o1f/700081`801PL00`07
1`3o1f/700081`0300L700D700<01`L0o`M[1`002@L200D700<01`L0o`M[1`0040L00`071`3o1f/7
000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L00107
0P3o1f`7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7
J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`00
40L20?l7K0L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0
o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`L[1`D0>`L0010700<01`L0
o`LT1`D00`L403/7000@1`80o`LO1`801@L40487000@1`0300L70?l76@L200<710191`0040L00`07
1`3o1aT70P021`D0B@L0010700<01`L0o`LF1`@010L00`071`1:1`0040L00`071`3o1`l71@021`@0
D@L0010700<01`L0o`L91`801@L405L7000@1`0300L70?l72@L405h7000@1`0300L70?l710L20087
1@1N1`002@L300@700<01`L0o`L11`D00`L00`071`1O1`002PL00`071`031`0300L70?T71P000`L0
000306D700031`<00PL400@70`3i1`H0J`L000P700<01`001@L00`071`3c1`D0LPL000T70P051`03
00L70?871P1b1`002PL00`071`031`0300L70>/71P0010L0001e1`0040L00`071`3/1`D0N@L00107
00<01`L0i0L60807000@1`0300L70>@71P201`0040L00`071`3N1`D0Q`L0010700<01`L0g`L408L7
000@1`80f0L508h7000@1`0300L70=P7102>1`0040L00`071`3@1`D0U@L0010700<01`L0d@L409D7
000@1`0300L70<T71@2L1`0040L00`071`3:1`@0W0L0010700<01`L0a0L40:87000@1`0300L70<87
1P2R1`0040L00`071`2n1`<000<700000P2T1`0040L20;`71P2Y1`0040L00`071`2l1`<0Z`L00107
00<01`L0]@L50;07000@1`0300L70;H7102`1`0040L00`071`3o1f/7000@1`0300L709T71@3<1`00
40L00`071`2;1`D00PL500871@3<1`0040L00`071`231`H00`L400871@3C1`0040L00`071`1e1`H0
00<7000010000`L000040>47000@1`80K`L600871@000`L000040>P7000@1`0300L706L71P000`L0
00040?H7000@1`0300L705X710021`D00PL60?d7000@1`0300L705871@021`D00PL50?l71PL00107
00<01`L0B`L500871@021`<0o`L?1`0040L00`071`141`D00PL50?l76`L0010700<01`L0A0L50?l7
8PL0010700<01`L0o`M[1`0020L300D700<01`L0o`M[1`0020L00`071`051`0300L70?l7J`L000<7
0`031`0300L700@70`3o1f/700091`0300L700@700<01`L0o`M[1`0020L00`0700051`0300L70?l7
J`L000T700<01`L010L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`07
1`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L20?l7<`L303H7000@1`0300L704@7
0P3V1`P0=PL0010700<01`L0@`L70=d73@0f1`0040L00`071`131`P0e`L?03T7000@1`0300L704D7
2@3?1`l0?PL0010700<01`L0B0L90<H740131`0040L00`071`1:1`/0_@L@04P7000@1`0300L704d7
2@2b1aD0C@L0010700<01`L0D0L90:X7501C1`0040L205@72@2Q1aD0F0L0010700<01`L0E@L;09P7
401R1`0040L00`071`1H1``0S`L@06L7000@1`0300L705`72`271`l0K@L0010700<01`L0G`L:0807
3`1b1`0040L00`071`1S1`T0M`L@07L7000@1`0300L704<70`0P1`T070L304@70P0:1a00;0L00`07
1`111`D00PL00`071`021`0040L00`071`131`0300L702872P0J1`0300L704<700<01`0010L@0307
00<01`00A0L01`071`L01`000`L0010700<01`L0A0L00`071`0S1``050L40447500f1`0300L004@7
00L01`L700L000<7000@1`80A@L00`071`0W1``040L00`07000l1aD0?0L00`071`131`0700L71`07
00031`0040L00`071`131`0300L002`72`0>1`80=`LE040700<01`00A0L01`071`L01`000`L00107
00<01`L0A0L00`071`0^1``02`L00`071`0`1a0010L204D700<01`L0@PL200@700<01`L00PL00107
00<01`L0GPL200D70P0B1a00<@L?0:47000@1`0300L705T74`081`801`L?02L74@2V1`0040L00`07
1`131cD020L@01`74`2[1`0040L00`071`131gL0/0L0010700<01`L0@`Mb0;D7000@1`0300L704<7
6P0;1dL0^`L00107o`1X00H7000@1`0300L700l700<01`L03`L00`071`0?1`0300L700h700<01`L0
3`L00`071`0?1`0300L700l700<01`L03`L00`071`0;1`D04@L00`071`0?1`0300L700h700<01`L0
3`L00`071`0?1`0300L700l700<01`L03`L00`071`0?1`8040L00`071`0?1`0300L700l700<01`L0
10L0010700<01`L03`L00`071`0?1`0300L700l700<01`L03PL00`071`0?1`0300L700l700<01`L0
3`L00`071`0?1`0300L700l700<01`L03`L00`071`0?1`0300L700h700<01`L03`L00`071`0?1`03
00L700l700<01`L03`L00`071`041``04@L00`071`0?1`0300L700l700<01`L010L0010700<01`L0
A0L00`071`151`0300L704@700<01`L0A@L010071`L?03D700<01`L010L0010700<01`L0A@L40=H7
1@161`0040L00`071`141`H0``L=0507000@1`0300L704L71P2m1a00D0L0010700<01`L0B@L80;X7
101K1`0040L00`071`1;1`L0YPL<06H7000@1`0300L705070`2Q1a00IPL001070P1B1`L0W0L60707
000@1`0300L705871P2;1``0N`L0010700<01`L0E`L208H7401k1`0040L00`071`161`/01PL200<7
101o1`H0Q@L0010700<01`L0APL@00D7201a1`H0T0L0010700<01`L0C`L700H7401N1a00T0L00107
00<01`L0G0L@00D740051a400PL502`7302D1`0040L00`071`1S1`P01PL@00D74@021`D08@L60:D7
000@1`0300L706D72@1<1`/0Y@L001070P1Z1`P0A0L<0:T7000@1`0300L706`71@141`L0[PL00107
00<01`L0o`M[1`0040L00`071`1b1`L0l@L0010700<01`L0LPL;0>d7000@1`0300L707L71`3/1`00
40L00`071`1k1`H0j@L0010700<01`L0O@L70>H7000@1`0300L707l72@3R1`0040L208<71`3Q1`00
40L00`071`261`<000<70000103J1`0040L00`071`2:1`T08PL70:h7000@1`0300L708h72@0N1`P0
[@L0010700<01`L0T@L702871`2Y1`0040L00`071`2E1`H08@L:0:@7000@1`0300L709L71`0Q1`P0
X`L000P70`051`0300L709T71@0V1`L0W`L000P700<01`L01@L00`071`361`D0W`L000T700<01`L0
10L30<d71@2H1`002@L00`071`041`0300L70<d72@2D1`0020L00`0700051`0300L70=472P2?1`00
2@L00`071`041`0300L70=@7202>1`0040L00`071`3I1`L0RPL0010700<01`L0f`L808L7000@1`03
00L70=h71@021`H0O`L0010700<01`L0i@L707h7000@1`0300L70>T71`1j1`0040L20>`72P1e1`00
40L00`071`3^1``0L0L0010700<01`L0l`L906h7000@1`0300L70?P710021`80JPL0010700<01`L0
o@L806D7000@1`0300L70?l72`1P1`0040L00`071`3o1`@7301K1`0040L00`071`3o1`T7301F1`00
40L00`071`3o1`h71`1F1`0040L00`071`3o1aL72@1;1`0040L20?l760L>04H7000@1`0300L70?l7
7PL<0447000@1`0300L70?l78`L;03d7000@1`0300L70?l7:0L603d7000@1`0300L70?l7;`L503L7
000@1`0300L70?l7;`L503L7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7
000@1`80o`M/1`0040L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`07
1`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`002@L300@700<01`L0o`M[1`002PL00`07
1`031`0300L70?l7J`L000P710041`<0o`M[1`0020L00`0700051`0300L70?l7J`L000T70P051`03
00L70?l7J`L000X700<01`L00`L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`00
40L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L20?l7K0L0010700<01`L0
o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7
000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`80o`M/1`0040L00`07
1`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7
J`L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0o`M[1`00
40L20?l7K0L0010700<01`L0o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L0010700<01`L0
o`M[1`0040L00`071`3o1f/7000@1`0300L70?l7J`L000P70P061`0300L70?l7J`L000P700<01`00
1@L00`071`3o1f/700081`0300L000D70`3o1f/700081`80o`Md1`0020L00`071`3o1g<700091`80
o`Mc1`00o`Mn1`00o`Mn1`00o`Mn1`00\
\>"],
  ImageRangeCache->{{{0, 380}, {234.313, 0}} -> {-0.460689, -6.3625, 
  0.0279699, 0.0543075}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(part1\  = \ 
      Plot[{{\((
                \((\(\(x /. NET\) /. t -> \((IM[x, y] /. neim)\)\) /. Par)
                    \) + \((x /. neim)\))\) - 2\ *\((x /. nenp)\)}, {
            \((\((\(\(x /. NET\) /. t -> \((DM[x, y] /. nedm)\)\) /. Par)\) + 
                  \((x /. nedm)\))\) - 2\ *\((x /. nenp)\)}, {
            \((\(\(x /. NET\) /. t -> \((IM[x, y] /. neim)\)\) /. Par)\) - 
              \((x /. nenp)\)}, {\((x /. neim)\) - \((x /. nenp)\)}}, {hc, 
          iton, itod}, \ \ AxesLabel -> {"\<\>", "\<\>"}, \n\t\t\t\ \ \ 
        PlotStyle 
          \[Rule] {{AbsoluteThickness\ [3]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.06, 0.02}]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.01, 0.01}]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.04, 0.02}]}}, DisplayFunction -> Identity, \n\t\t
        PlotRange -> {{0, 10}, {\(-1\), 1}}]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\t\n
    part2\  = \ 
      Plot[{{\((
                \((\(\(x /. NET\) /. t -> \((DM[x, y] /. nedm)\)\) /. Par)
                    \) + \((x /. nedm)\))\) - 2\ *\((x /. nenp)\)}, {
            \((\(\(x /. NET\) /. t -> \((DM[x, y] /. nedm)\)\) /. Par)\) - 
              \((x /. nenp)\)}, {\((x /. nedm)\) - \((x /. nenp)\)}}, {hc, 
          dtoi, dton}, \ \ 
        PlotStyle 
          \[Rule] {{AbsoluteThickness\ [3]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.01, 0.01}]}, {AbsoluteThickness\ [2], 
              Dashing\ \ [{0.04, 0.02}]}}, DisplayFunction -> Identity]; \n\t
    Show[part1, part2, \ DisplayFunction -> $DisplayFunction]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.1 0.309017 0.309017 [
[.2 .29652 -3 -9 ]
[.2 .29652 3 0 ]
[.4 .29652 -3 -9 ]
[.4 .29652 3 0 ]
[.6 .29652 -3 -9 ]
[.6 .29652 3 0 ]
[.8 .29652 -3 -9 ]
[.8 .29652 3 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[-0.0125 0 -12 -4.5 ]
[-0.0125 0 0 4.5 ]
[-0.0125 .07725 -30 -4.5 ]
[-0.0125 .07725 0 4.5 ]
[-0.0125 .15451 -24 -4.5 ]
[-0.0125 .15451 0 4.5 ]
[-0.0125 .23176 -30 -4.5 ]
[-0.0125 .23176 0 4.5 ]
[-0.0125 .38627 -24 -4.5 ]
[-0.0125 .38627 0 4.5 ]
[-0.0125 .46353 -18 -4.5 ]
[-0.0125 .46353 0 4.5 ]
[-0.0125 .54078 -24 -4.5 ]
[-0.0125 .54078 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2 .30902 m
.2 .31527 L
s
[(2)] .2 .29652 0 1 Mshowa
.4 .30902 m
.4 .31527 L
s
[(4)] .4 .29652 0 1 Mshowa
.6 .30902 m
.6 .31527 L
s
[(6)] .6 .29652 0 1 Mshowa
.8 .30902 m
.8 .31527 L
s
[(8)] .8 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(10)] 1 .29652 0 1 Mshowa
.125 Mabswid
.05 .30902 m
.05 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.15 .30902 m
.15 .31277 L
s
.25 .30902 m
.25 .31277 L
s
.3 .30902 m
.3 .31277 L
s
.35 .30902 m
.35 .31277 L
s
.45 .30902 m
.45 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.55 .30902 m
.55 .31277 L
s
.65 .30902 m
.65 .31277 L
s
.7 .30902 m
.7 .31277 L
s
.75 .30902 m
.75 .31277 L
s
.85 .30902 m
.85 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.95 .30902 m
.95 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
0 0 m
.00625 0 L
s
[(-1)] -0.0125 0 1 0 Mshowa
0 .07725 m
.00625 .07725 L
s
[(-0.75)] -0.0125 .07725 1 0 Mshowa
0 .15451 m
.00625 .15451 L
s
[(-0.5)] -0.0125 .15451 1 0 Mshowa
0 .23176 m
.00625 .23176 L
s
[(-0.25)] -0.0125 .23176 1 0 Mshowa
0 .38627 m
.00625 .38627 L
s
[(0.25)] -0.0125 .38627 1 0 Mshowa
0 .46353 m
.00625 .46353 L
s
[(0.5)] -0.0125 .46353 1 0 Mshowa
0 .54078 m
.00625 .54078 L
s
[(0.75)] -0.0125 .54078 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .01545 m
.00375 .01545 L
s
0 .0309 m
.00375 .0309 L
s
0 .04635 m
.00375 .04635 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .10816 m
.00375 .10816 L
s
0 .12361 m
.00375 .12361 L
s
0 .13906 m
.00375 .13906 L
s
0 .16996 m
.00375 .16996 L
s
0 .18541 m
.00375 .18541 L
s
0 .20086 m
.00375 .20086 L
s
0 .21631 m
.00375 .21631 L
s
0 .24721 m
.00375 .24721 L
s
0 .26266 m
.00375 .26266 L
s
0 .27812 m
.00375 .27812 L
s
0 .29357 m
.00375 .29357 L
s
0 .32447 m
.00375 .32447 L
s
0 .33992 m
.00375 .33992 L
s
0 .35537 m
.00375 .35537 L
s
0 .37082 m
.00375 .37082 L
s
0 .40172 m
.00375 .40172 L
s
0 .41717 m
.00375 .41717 L
s
0 .43262 m
.00375 .43262 L
s
0 .44807 m
.00375 .44807 L
s
0 .47898 m
.00375 .47898 L
s
0 .49443 m
.00375 .49443 L
s
0 .50988 m
.00375 .50988 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .57168 m
.00375 .57168 L
s
0 .58713 m
.00375 .58713 L
s
0 .60258 m
.00375 .60258 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
3 Mabswid
.20011 .26017 m
.21018 .2626 L
.22116 .26525 L
.23147 .26774 L
.24139 .27013 L
.25194 .27268 L
.2621 .27513 L
.27291 .27774 L
.28331 .28025 L
.29332 .28267 L
.30397 .28524 L
.31423 .28771 L
.32409 .29009 L
.33459 .29263 L
.34469 .29507 L
.35543 .29766 L
.36578 .30016 L
.37573 .30256 L
.38633 .30512 L
.39652 .30758 L
.40736 .31019 L
.4178 .31272 L
.42785 .31514 L
.43853 .31772 L
.4483 .32008 L
s
2 Mabswid
[ .06 .02 ] 0 setdash
.20011 .44407 m
.21018 .44335 L
.22116 .44256 L
.23147 .44182 L
.24139 .44111 L
.25194 .44036 L
.2621 .43963 L
.27291 .43885 L
.28331 .43811 L
.29332 .43739 L
.30397 .43663 L
.31423 .43589 L
.32409 .43519 L
.33459 .43444 L
.34469 .43371 L
.35543 .43294 L
.36578 .4322 L
.37573 .43149 L
.38633 .43073 L
.39652 .43 L
.40736 .42922 L
.4178 .42848 L
.42785 .42776 L
.43853 .42699 L
.4483 .42629 L
s
[ .01 .01 ] 0 setdash
.20011 .31228 m
.21018 .31372 L
.22116 .31528 L
.23147 .31675 L
.24139 .31817 L
.25194 .31967 L
.2621 .32112 L
.27291 .32266 L
.28331 .32415 L
.29332 .32558 L
.30397 .3271 L
.31423 .32856 L
.32409 .32997 L
.33459 .33146 L
.34469 .33291 L
.35543 .33444 L
.36578 .33591 L
.37573 .33733 L
.38633 .33885 L
.39652 .3403 L
.40736 .34185 L
.4178 .34334 L
.42785 .34477 L
.43853 .34629 L
.4483 .34769 L
s
[ .04 .02 ] 0 setdash
.20011 .2569 m
.21018 .2579 L
.22116 .25898 L
.23147 .26 L
.24139 .26098 L
.25194 .26202 L
.2621 .26302 L
.27291 .26409 L
.28331 .26512 L
.29332 .26611 L
.30397 .26716 L
.31423 .26817 L
.32409 .26914 L
.33459 .27018 L
.34469 .27118 L
.35543 .27224 L
.36578 .27326 L
.37573 .27424 L
.38633 .27529 L
.39652 .2763 L
.40736 .27737 L
.4178 .2784 L
.42785 .27939 L
.43853 .28044 L
.4483 .28141 L
s
3 Mabswid
[ ] 0 setdash
.51668 .42139 m
.53079 .42038 L
.54619 .41928 L
.56064 .41824 L
.57455 .41725 L
.58934 .41619 L
.60359 .41517 L
.61873 .41408 L
.63332 .41304 L
.64735 .41203 L
.66228 .41096 L
.67665 .40993 L
.69048 .40894 L
.70519 .40789 L
.71936 .40688 L
.73442 .4058 L
.74892 .40476 L
.76288 .40376 L
.77773 .4027 L
.79202 .40167 L
.80721 .40058 L
.82185 .39953 L
.83593 .39853 L
.85091 .39745 L
.8646 .39647 L
s
2 Mabswid
[ .01 .01 ] 0 setdash
.51668 .33391 m
.53079 .3329 L
.54619 .3318 L
.56064 .33076 L
.57455 .32976 L
.58934 .3287 L
.60359 .32768 L
.61873 .3266 L
.63332 .32555 L
.64735 .32455 L
.66228 .32348 L
.67665 .32245 L
.69048 .32146 L
.70519 .32041 L
.71936 .31939 L
.73442 .31831 L
.74892 .31727 L
.76288 .31627 L
.77773 .31521 L
.79202 .31419 L
.80721 .3131 L
.82185 .31205 L
.83593 .31104 L
.85091 .30997 L
.8646 .30899 L
s
[ .04 .02 ] 0 setdash
.51668 .3965 m
.5175 .3965 L
.51795 .3965 L
.51838 .3965 L
.51877 .3965 L
.51921 .3965 L
.5196 .3965 L
.51996 .3965 L
.52039 .3965 L
.52079 .3965 L
.52123 .3965 L
.5217 .3965 L
.52194 .3965 L
.5222 .3965 L
.52267 .3965 L
.52355 .3965 L
.524 .3965 L
.52425 .3965 L
.52449 .3965 L
.52492 .3965 L
.52537 .3965 L
.52585 .3965 L
.52613 .3965 L
.52639 .3965 L
.52686 .3965 L
.52731 .3965 L
.52773 .3965 L
.52819 .3965 L
.5286 .3965 L
.52899 .3965 L
.52941 .3965 L
.52986 .3965 L
.53034 .3965 L
.53079 .3965 L
.53126 .3965 L
.53169 .3965 L
.53217 .3965 L
.53243 .3965 L
.53268 .3965 L
.53293 .3965 L
.53317 .3965 L
.53342 .3965 L
.5337 .3965 L
.53415 .3965 L
.53441 .3965 L
.53466 .3965 L
.53512 .3965 L
.53555 .3965 L
.53594 .3965 L
.53637 .3965 L
Mistroke
.53683 .3965 L
.53709 .3965 L
.53732 .3965 L
.53777 .3965 L
.5382 .3965 L
.53867 .3965 L
.53893 .3965 L
.53917 .3965 L
.53963 .3965 L
.54007 .3965 L
.54052 .3965 L
.54075 .3965 L
.54101 .3965 L
.54127 .3965 L
.54155 .3965 L
.5418 .3965 L
.54204 .3965 L
.5423 .3965 L
.54258 .3965 L
.54282 .3965 L
.54308 .3965 L
.54336 .3965 L
.54366 .3965 L
.54394 .3965 L
.5442 .3965 L
.54446 .3965 L
.54469 .3965 L
.54522 .3965 L
.54619 .3965 L
.54707 .3965 L
.54731 .3965 L
.54757 .3965 L
.54803 .3965 L
.54846 .3965 L
.54886 .3965 L
.54931 .3965 L
.54978 .3965 L
.55003 .3965 L
.55029 .3965 L
.55057 .3965 L
.55083 .3965 L
.5513 .3965 L
.55156 .3965 L
.5518 .3965 L
.55225 .3965 L
.55251 .3965 L
.55274 .3965 L
.55318 .3965 L
.55364 .3965 L
.55407 .3965 L
Mistroke
.55446 .3965 L
.55492 .3965 L
.55535 .3965 L
.55575 .3965 L
.55612 .3965 L
.55652 .3965 L
.55695 .3965 L
.55743 .3965 L
.55769 .3965 L
.55794 .3965 L
.55839 .3965 L
.55887 .3965 L
.55929 .3965 L
.55969 .3965 L
.56013 .3965 L
.5606 .3965 L
.56433 .3965 L
.56785 .3965 L
.56823 .3965 L
.56864 .3965 L
.56903 .3965 L
.56939 .3965 L
.56977 .3965 L
.57016 .3965 L
.57057 .3965 L
.57102 .3965 L
.57147 .3965 L
.57194 .3965 L
.5724 .3965 L
.57281 .3965 L
.57321 .3965 L
.57366 .3965 L
.57408 .3965 L
.57446 .3965 L
.57492 .3965 L
.57535 .3965 L
.57574 .3965 L
.57617 .3965 L
.57663 .3965 L
.57689 .3965 L
.57712 .3965 L
.57758 .3965 L
.57801 .3965 L
.57841 .3965 L
.57884 .3965 L
.5792 .3965 L
.5796 .3965 L
.58003 .3965 L
.58049 .3965 L
.58092 .3965 L
Mistroke
.58132 .3965 L
.58179 .3965 L
.58222 .3965 L
.58268 .3965 L
.58293 .3965 L
.58318 .3965 L
.58344 .3965 L
.58368 .3965 L
.58394 .3965 L
.58423 .3965 L
.58447 .3965 L
.58473 .3965 L
.5852 .3965 L
.58567 .3965 L
.58594 .3965 L
.58619 .3965 L
.58664 .3965 L
.58712 .3965 L
.58755 .3965 L
.58795 .3965 L
.58839 .3965 L
.58886 .3965 L
.58931 .3965 L
.58956 .3965 L
.5898 .3965 L
.59004 .3965 L
.59031 .3965 L
.59079 .3965 L
.59121 .3965 L
.59166 .3965 L
.59214 .3965 L
.59258 .3965 L
.59283 .3965 L
.5931 .3965 L
.59336 .3965 L
.5936 .3965 L
.59405 .3965 L
.59453 .3965 L
.59478 .3965 L
.59504 .3965 L
.59552 .3965 L
.59582 .3965 L
.5961 .3965 L
.59662 .3965 L
.60397 .3965 L
.60439 .3965 L
.60484 .3965 L
.60507 .3965 L
.60533 .3965 L
.60578 .3965 L
Mistroke
.6062 .3965 L
.60666 .3965 L
.60709 .3965 L
.60748 .3965 L
.60796 .3965 L
.60823 .3965 L
.60848 .3965 L
.60944 .3965 L
.60988 .3965 L
.61035 .3965 L
.6108 .3965 L
.61121 .3965 L
.61158 .3965 L
.61197 .3965 L
.61238 .3965 L
.61276 .3965 L
.6132 .3965 L
.61359 .3965 L
.61405 .3965 L
.61447 .3965 L
.61489 .3965 L
.61534 .3965 L
.61614 .3965 L
.61655 .3965 L
.61699 .3965 L
.61725 .3965 L
.61748 .3965 L
.61793 .3965 L
.61836 .3965 L
.61877 .3965 L
.61921 .3965 L
.61969 .3965 L
.62016 .3965 L
.62042 .3965 L
.62066 .3965 L
.62108 .3965 L
.62155 .3965 L
.62198 .3965 L
.62239 .3965 L
.62276 .3965 L
.62317 .3965 L
.6236 .3965 L
.62406 .3965 L
.62446 .3965 L
.62489 .3965 L
.62514 .3965 L
.6254 .3965 L
.62588 .3965 L
.62635 .3965 L
.62678 .3965 L
Mistroke
.62705 .3965 L
.6273 .3965 L
.62776 .3965 L
.62802 .3965 L
.62827 .3965 L
.62853 .3965 L
.62881 .3965 L
.62925 .3965 L
.62971 .3965 L
.63015 .3965 L
.63056 .3965 L
.63103 .3965 L
.63129 .3965 L
.63154 .3965 L
.63199 .3965 L
.63247 .3965 L
.63289 .3965 L
.63334 .3965 L
.63382 .3965 L
.63426 .3965 L
.63468 .3965 L
.63505 .3965 L
.63549 .3965 L
.6359 .3965 L
.63959 .3965 L
.63997 .3965 L
.64038 .3965 L
.64076 .3965 L
.64112 .3965 L
.64154 .3965 L
.64198 .3965 L
.6424 .3965 L
.64277 .3965 L
.64322 .3965 L
.64347 .3965 L
.6437 .3965 L
.64413 .3965 L
.64458 .3965 L
.645 .3965 L
.64538 .3965 L
.64581 .3965 L
.64627 .3965 L
.64673 .3965 L
.64699 .3965 L
.64722 .3965 L
.64766 .3965 L
.64813 .3965 L
.64854 .3965 L
.64893 .3965 L
.64936 .3965 L
Mistroke
.64982 .3965 L
.6503 .3965 L
.65057 .3965 L
.65083 .3965 L
.65129 .3965 L
.65155 .3965 L
.65178 .3965 L
.65223 .3965 L
.65271 .3965 L
.65316 .3965 L
.65358 .3965 L
.65397 .3965 L
.65439 .3965 L
.65478 .3965 L
.65514 .3965 L
.65557 .3965 L
.65602 .3965 L
.65646 .3965 L
.65686 .3965 L
.65727 .3965 L
.65766 .3965 L
.65808 .3965 L
.65854 .3965 L
.65899 .3965 L
.65947 .3965 L
.65988 .3965 L
.66032 .3965 L
.6608 .3965 L
.66125 .3965 L
.66148 .3965 L
.66174 .3965 L
.662 .3965 L
.66225 .3965 L
.66271 .3965 L
.66313 .3965 L
.66337 .3965 L
.66362 .3965 L
.66407 .3965 L
.66451 .3965 L
.66491 .3965 L
.66538 .3965 L
.66582 .3965 L
.66624 .3965 L
.66662 .3965 L
.66707 .3965 L
.66748 .3965 L
.66792 .3965 L
.6684 .3965 L
.66884 .3965 L
.66926 .3965 L
Mistroke
.66949 .3965 L
.66974 .3965 L
.67019 .3965 L
.67067 .3965 L
.67095 .3965 L
.6712 .3965 L
.67168 .3965 L
.67193 .3965 L
.67219 .3965 L
.67266 .3965 L
.67309 .3965 L
.67336 .3965 L
.67361 .3965 L
.67408 .3965 L
.67434 .3965 L
.67458 .3965 L
.67485 .3965 L
.67513 .3965 L
.67558 .3965 L
.67606 .3965 L
.67651 .3965 L
.67694 .3965 L
.67736 .3965 L
.67773 .3965 L
.67817 .3965 L
.67858 .3965 L
.67904 .3965 L
.67951 .3965 L
.67992 .3965 L
.68037 .3965 L
.68085 .3965 L
.68112 .3965 L
.68136 .3965 L
.68184 .3965 L
.68229 .3965 L
.68268 .3965 L
.6831 .3965 L
.68351 .3965 L
.68396 .3965 L
.68437 .3965 L
.68475 .3965 L
.68514 .3965 L
.6855 .3965 L
.68592 .3965 L
.68636 .3965 L
.68678 .3965 L
.68716 .3965 L
.68761 .3965 L
.68787 .3965 L
.6881 .3965 L
Mistroke
.68852 .3965 L
.68898 .3965 L
.68944 .3965 L
.68988 .3965 L
.69031 .3965 L
.6907 .3965 L
.69112 .3965 L
.69159 .3965 L
.69183 .3965 L
.69208 .3965 L
.69254 .3965 L
.69294 .3965 L
.69338 .3965 L
.69381 .3965 L
.69427 .3965 L
.6947 .3965 L
.69509 .3965 L
.69546 .3965 L
.69586 .3965 L
.69633 .3965 L
.69659 .3965 L
.69683 .3965 L
.69726 .3965 L
.69772 .3965 L
.69798 .3965 L
.69826 .3965 L
.69853 .3965 L
.69878 .3965 L
.69924 .3965 L
.6995 .3965 L
.69974 .3965 L
.70021 .3965 L
.70065 .3965 L
.70113 .3965 L
.70137 .3965 L
.70163 .3965 L
.70207 .3965 L
.70255 .3965 L
.703 .3965 L
.70341 .3965 L
.70381 .3965 L
.70424 .3965 L
.70472 .3965 L
.70517 .3965 L
.70564 .3965 L
.70588 .3965 L
.70614 .3965 L
.70661 .3965 L
.70704 .3965 L
.70747 .3965 L
Mistroke
.70789 .3965 L
.70826 .3965 L
.70866 .3965 L
.7091 .3965 L
.70956 .3965 L
.70996 .3965 L
.71039 .3965 L
.71063 .3965 L
.7109 .3965 L
.71138 .3965 L
.71185 .3965 L
.71228 .3965 L
.71275 .3965 L
.71302 .3965 L
.71327 .3965 L
.71353 .3965 L
.71377 .3965 L
.71404 .3965 L
.71431 .3965 L
.71623 .3965 L
.71667 .3965 L
.71714 .3965 L
.71754 .3965 L
.71798 .3965 L
.71842 .3965 L
.71884 .3965 L
.71929 .3965 L
.71977 .3965 L
.72022 .3965 L
.72065 .3965 L
.72104 .3965 L
.72146 .3965 L
.72171 .3965 L
.72195 .3965 L
.72239 .3965 L
.72287 .3965 L
.72314 .3965 L
.72339 .3965 L
.72381 .3965 L
.72426 .3965 L
.72474 .3965 L
.72518 .3965 L
.7256 .3965 L
.72605 .3965 L
.72648 .3965 L
.72688 .3965 L
.72842 .3965 L
.7288 .3965 L
.72922 .3965 L
.72967 .3965 L
Mistroke
.7301 .3965 L
.73056 .3965 L
.73103 .3965 L
.73144 .3965 L
.73189 .3965 L
.73237 .3965 L
.73282 .3965 L
.73305 .3965 L
.7333 .3965 L
.73357 .3965 L
.73382 .3965 L
.73428 .3965 L
.7347 .3965 L
.73493 .3965 L
.73518 .3965 L
.73564 .3965 L
.73609 .3965 L
.7365 .3965 L
.73697 .3965 L
.73742 .3965 L
.73783 .3965 L
.7382 .3965 L
.73862 .3965 L
.73906 .3965 L
.73953 .3965 L
.73997 .3965 L
.74021 .3965 L
.74047 .3965 L
.74095 .3965 L
.74139 .3965 L
.74186 .3965 L
.74227 .3965 L
.74271 .3965 L
.74298 .3965 L
.74323 .3965 L
.7437 .3965 L
.74397 .3965 L
.74422 .3965 L
.74449 .3965 L
.74478 .3965 L
.74503 .3965 L
.7453 .3965 L
.74555 .3965 L
.74579 .3965 L
.74624 .3965 L
.74671 .3965 L
.74716 .3965 L
.74741 .3965 L
.74764 .3965 L
.74807 .3965 L
Mistroke
.74852 .3965 L
.74892 .3965 L
.7493 .3965 L
.74972 .3965 L
.75017 .3965 L
.75062 .3965 L
.75088 .3965 L
.75111 .3965 L
.75159 .3965 L
.75186 .3965 L
.75211 .3965 L
.75254 .3965 L
.75302 .3965 L
.75347 .3965 L
.75388 .3965 L
.75427 .3965 L
.75468 .3965 L
.75507 .3965 L
.75543 .3965 L
.75585 .3965 L
.7563 .3965 L
.75673 .3965 L
.75713 .3965 L
.75759 .3965 L
.758 .3965 L
.75844 .3965 L
.75892 .3965 L
.75934 .3965 L
.75978 .3965 L
.76016 .3965 L
.76058 .3965 L
.76105 .3965 L
.7615 .3965 L
.76175 .3965 L
.76198 .3965 L
.76223 .3965 L
.7625 .3965 L
.76295 .3965 L
.76337 .3965 L
.76383 .3965 L
.76431 .3965 L
.76472 .3965 L
.76515 .3965 L
.76556 .3965 L
.76594 .3965 L
.76638 .3965 L
.76685 .3965 L
.7673 .3965 L
.76771 .3965 L
.76815 .3965 L
Mistroke
.76863 .3965 L
.76908 .3965 L
.76948 .3965 L
.76996 .3965 L
.77023 .3965 L
.77048 .3965 L
.77094 .3965 L
.77117 .3965 L
.77143 .3965 L
.77168 .3965 L
.77194 .3965 L
.7724 .3965 L
.77266 .3965 L
.7729 .3965 L
.77317 .3965 L
.77345 .3965 L
.7737 .3965 L
.77397 .3965 L
.77422 .3965 L
.77445 .3965 L
.77489 .3965 L
.77536 .3965 L
.7758 .3965 L
.77628 .3965 L
.77673 .3965 L
.77715 .3965 L
.77757 .3965 L
.77795 .3965 L
.77838 .3965 L
.7788 .3965 L
.77925 .3965 L
.77972 .3965 L
.78013 .3965 L
.78057 .3965 L
.78105 .3965 L
.78132 .3965 L
.78157 .3965 L
.78204 .3965 L
.78249 .3965 L
.78288 .3965 L
.7833 .3965 L
.78374 .3965 L
.78416 .3965 L
.78454 .3965 L
.7849 .3965 L
.78528 .3965 L
.7857 .3965 L
.78612 .3965 L
.78651 .3965 L
.78697 .3965 L
Mistroke
.78739 .3965 L
.78783 .3965 L
.78831 .3965 L
.78876 .3965 L
.78918 .3965 L
.78964 .3965 L
.79007 .3965 L
.79046 .3965 L
.79089 .3965 L
.79135 .3965 L
.79161 .3965 L
.79184 .3965 L
.79229 .3965 L
.79272 .3965 L
.79313 .3965 L
.79355 .3965 L
.79392 .3965 L
.79431 .3965 L
.79474 .3965 L
.79521 .3965 L
.79564 .3965 L
.79604 .3965 L
.7965 .3965 L
.79674 .3965 L
.797 .3965 L
.79746 .3965 L
.79789 .3965 L
.79814 .3965 L
.7984 .3965 L
.79886 .3965 L
.79912 .3965 L
.79936 .3965 L
.79963 .3965 L
.79991 .3965 L
.80039 .3965 L
.80065 .3965 L
.8009 .3965 L
.80135 .3965 L
.80183 .3965 L
.80226 .3965 L
.80266 .3965 L
.8031 .3965 L
.80358 .3965 L
.80402 .3965 L
.80427 .3965 L
.80451 .3965 L
.80499 .3965 L
.80526 .3965 L
.8055 .3965 L
.80592 .3965 L
Mistroke
.80637 .3965 L
.80685 .3965 L
.80729 .3965 L
.80754 .3965 L
.80781 .3965 L
.80807 .3965 L
.80831 .3965 L
.80876 .3965 L
.80924 .3965 L
.80949 .3965 L
.80975 .3965 L
.81023 .3965 L
.81053 .3965 L
.8108 .3965 L
.81105 .3965 L
.81133 .3965 L
.81157 .3965 L
.81183 .3965 L
.81229 .3965 L
.81275 .3965 L
.81317 .3965 L
.81363 .3965 L
.81389 .3965 L
.81413 .3965 L
.81438 .3965 L
.81462 .3965 L
.81488 .3965 L
.81514 .3965 L
.81557 .3965 L
.81602 .3965 L
.81641 .3965 L
.81683 .3965 L
.81729 .3965 L
.81755 .3965 L
.81778 .3965 L
.81822 .3965 L
.81868 .3965 L
.81913 .3965 L
.81936 .3965 L
.81962 .3965 L
.82008 .3965 L
.8205 .3965 L
.82091 .3965 L
.8213 .3965 L
.82172 .3965 L
.82217 .3965 L
.82264 .3965 L
.82291 .3965 L
.82317 .3965 L
.82363 .3965 L
Mistroke
.82388 .3965 L
.82411 .3965 L
.82456 .3965 L
.82503 .3965 L
.82548 .3965 L
.82589 .3965 L
.82628 .3965 L
.8267 .3965 L
.82709 .3965 L
.82745 .3965 L
.82787 .3965 L
.82833 .3965 L
.82876 .3965 L
.82916 .3965 L
.82957 .3965 L
.82996 .3965 L
.83038 .3965 L
.83083 .3965 L
.83131 .3965 L
.83176 .3965 L
.83216 .3965 L
.8326 .3965 L
.83284 .3965 L
.83309 .3965 L
.83354 .3965 L
.83402 .3965 L
.83429 .3965 L
.83454 .3965 L
.83501 .3965 L
.83543 .3965 L
.83566 .3965 L
.83591 .3965 L
.83637 .3965 L
.83678 .3965 L
.83723 .3965 L
.83767 .3965 L
.83815 .3965 L
.83859 .3965 L
.83899 .3965 L
.83938 .3965 L
.83979 .3965 L
.84027 .3965 L
.84071 .3965 L
.84095 .3965 L
.84121 .3965 L
.84168 .3965 L
.84252 .3965 L
.84297 .3965 L
.84345 .3965 L
.84372 .3965 L
Mistroke
.84397 .3965 L
.84422 .3965 L
.84446 .3965 L
.84472 .3965 L
.84497 .3965 L
.84524 .3965 L
.84553 .3965 L
.84578 .3965 L
.84605 .3965 L
.8463 .3965 L
.84654 .3965 L
.84698 .3965 L
.84745 .3965 L
.8479 .3965 L
.84815 .3965 L
.84838 .3965 L
.84881 .3965 L
.84927 .3965 L
.84965 .3965 L
.85006 .3965 L
.85051 .3965 L
.85092 .3965 L
.85136 .3965 L
.85183 .3965 L
.85228 .3965 L
.85269 .3965 L
.85294 .3965 L
.85318 .3965 L
.85363 .3965 L
.85411 .3965 L
.85439 .3965 L
.85464 .3965 L
.85502 .3965 L
.85544 .3965 L
.85583 .3965 L
.85619 .3965 L
.85661 .3965 L
.85706 .3965 L
.85749 .3965 L
.85789 .3965 L
.8583 .3965 L
.85869 .3965 L
.85911 .3965 L
.85956 .3965 L
.86001 .3965 L
.86049 .3965 L
.86089 .3965 L
.86134 .3965 L
.86176 .3965 L
.86216 .3965 L
Mistroke
.86252 .3965 L
.86291 .3965 L
.86334 .3965 L
.86379 .3965 L
.86418 .3965 L
.8646 .3965 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{381, 235.375},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005m0000j`P10`40000100000800002008200000
P800P020P<30`4Q8B71`L<3L`:C8l3<006H009T00<`0000c03<c06Hc09Tc0<`c0?lc001V03=V06IV
09UV0<aV0?mV002I03>I06JI09VI0<bI0?nI003<03?<06K<09W<0<c<0?o<03?o06Ko09Wo0<co0000
<c<0<fH0<iT0<l`0<ol0<`0c<c<c<fHc<iTc<l`c<olc<`1V<c=V<fIV<iUV<laV<omV<`2I<c>I<fJI
<iVI<lbI<onI<`3<<c?<<fK<<iW<<lc<<oo<<`3o<c?o<fKo<iWo<lco<ooo<`00IS<0IVH0IYT0I/`0
I_l0IP0cIS<cIVHcIYTcI/`cI_lcIP1VIS=VIVIVIYUVI/aVI_mVIP2IIS>IIVJIIYVII/bII_nIIP3<
IS?<IVK<IYW<I/c<I_o<IP3oIS?oIVKoIYWoI/coI_ooIP00VC<0VFH0VIT0VL`0VOl0V@0cVC<cVFHc
VITcVL`cVOlcV@1VVC=VVFIVVIUVVLaVVOmVV@2IVC>IVFJIVIVIVLbIVOnIV@3<VC?<VFK<VIW<VLc<
VOo<V@3oVC?oVFKoVIWoVLcoVOooV@00c3<0c6H0c9T0c<`0c?l0c00cc3<cc6Hcc9Tcc<`cc?lcc01V
c3=Vc6IVc9UVc<aVc?mVc02Ic3>Ic6JIc9VIc<bIc?nIc03<c3?<c6K<c9W<c<c<c?o<c03oc3?oc6Ko
c9Woc<coc?ooc3<0ofH0oiT0ol`0o`0coc<cofHcoiTcol`coolco`1Voc=VofIVoiUVolaVoomVo`2I
oc>IofJIoiVIolbIoonIo`3<oc?<ofK<oiW<olc<ooo<oc?oofKooiWoolcoo`410@820P<30`@410D5
1@H61PL71`P820T92@X:2P/;2``<30h>3Pl?3a0@414A4A8B4Q<C4a@D5?okl0000000000000000000
00000;Rh^:2PY820P?l0003o0?oo0000ool0o`3oooooool7OPL00?l7OPL00?l7OPL00?l7OPL00?l7
OPL00?l7OPL00?l7OPL00?l7OPL00?l7OPL00?l7OPL001T71@3o1f07000K1`0300L70?l7H0L001D7
0`031`0300L700@70`3o1eT7000K1`0300L700@700<01`L0o`MI1`006`L00`071`041`0300L70?l7
F@L001X70P061`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`80o`MJ1`00
8PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`80
o`MJ1`008PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7
000R1`80o`MJ1`008PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`07
1`3o1eT7000R1`80o`MJ1`008PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0o`MI1`00
30L00`071`021`0300L7008700<01`L00PL00`071`041`0300L70?l7F@L000/700<01`0020L01`07
1`L01`001@L00`071`3o1eT700061`<00PL00`0700081`0300L700<700<01`L00`L30?l7F@L000/7
00<01`002@L00`071`0200H700<01`L0o`MI1`002`L00`0700071`0300L0008700<01`L01@L00`07
1`3o1eT7000<1`0300L700H70`021`<01@L00`071`3o1eT7000R1`0300L70?l7F@L002870P3o1eX7
000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`0300L70?l7F@L00287
0P3o1eX7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`0300L70?l7
F@L002870P3o1eX7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`03
00L70?l7F@L0028700<01`L0o`MI1`008PL20?l7FPL0028700<01`L0o`MI1`008PL00`071`3o1eT7
000A1`0300L7008700<01`L00PL00`071`041`0300L70?l7F@L0010700<01`001`L00`0700051`03
00L70?l7F@L000/70`021`0300L000T700<01`L00`L30?l7F@L0010700<01`001`L200H700<01`L0
o`MI1`0040L00`0700071`0300L700D700<01`L0o`MI1`004@L00`071`061`<01@L00`071`3o1eT7
000R1`0300L70?l7F@L002870P3o1eX7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`07
1`3o1eT7000R1`0300L70?l7F@L002870P3o1eX7000R1`0300L70?l7F@L0028700<01`L0o`MI1`00
8PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL20?l7FPL0028700<01`L0
o`MI1`008PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL20?l7FPL00287
00<01`L0o`MI1`008PL00`071`3o1eT7000<1`0300L7008700@01`L70`031`0300L700@700<01`L0
o`MI1`002`L00`0700071`0300L7008700<01`001@L00`071`3o1eT700061`<00PL00`0700081`03
00L700<700<01`L00`L30?l7F@L000/700<01`0020L010071`L200H700<01`L0o`MI1`002`L00`07
00071`0300L0008700<01`L01@L00`071`3o1eT7000<1`0300L700L700@01`L70`051`0300L70?l7
F@L0028700<01`L0o`MI1`008PL20?l7FPL0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`03
00L70?l7F@L0028700<01`L0@0L<0?l73@L0028700<01`L0?`L@0?l72PL002870P101a001@L=0?L7
000R1`0300L704473`041`l0m@L0028700<01`L0B0L<00/710051`l0h@L0028700<01`L0?`L300X7
2`0A1a0030L304070P131`0300L703d71@021`0300L70087000R1`0300L703l700<01`L03@L<01X7
0`051`/0?`L00`0700111`0300L0040700L01`L700L000<7000R1`80@@L00`071`0@1`l06`L?03/7
00<01`00@@L00`0700101`0700L71`0700031`008PL00`071`101`0300L701<73`0N1`0300L000H0
1@L503470P131`0300L703l700L01`L700L000<7000R1`0300L703l700<01`0060L?01/70P0;1`D0
<@L00`071`111`0300L0040700L01`L700L000<7000R1`0300L7040700<01`L07PL<01P700<01`L0
@0L2048700<01`L0?PL200@700<01`L00PL0028700<01`L0I@L;0>P7000R1`80J@L@0>07000R1`03
00L706/7403M1`008PL00`071`1_1`l0fPL0028700<01`L0MPL;0=L7000R1`0300L707T7303C1`00
8POo05H01PL0028700<01`L03PL00`071`0>1`0300L700h700<01`L03PL400d700<01`L03PL00`07
1`0>1`0300L700T740061`0300L700h700<01`L03PL00`071`0>1`0300L700h700<01`L03PL00`07
1`0>1`0300L700h700@01`L71@021`D000<700000`0<1`0300L700h700<01`L03PL00`071`041`00
8PL00`071`0>1`0300L700h700<01`L03PL00`071`0=1`D000<7000010061`0300L700h700<01`L0
3PL00`071`0=1`l00`L00`071`0>1`0300L700h700<01`L03PL00`071`0>1`0300L700h700<01`L0
3PL00`071`041`H000<7000010021`@00PL500031`0700l700<01`L03PL00`071`0>1`0300L700@7
000R1`0300L704H71P000`L0000403D73`1O1`D00PL500031`0000@000<7000010181`008PL00`07
1`1=1`H000<700000`0f1`P0D@L600031`0000<00PL500871@1F1`008PL00`071`1D1`D00PL50387
10151`D000<7000010000`L0000400031`0000<0I0L002870P1L1`D000<7000010041`0300L705l7
1P000`L0000300871@000`L000040747000R1`0300L706471P000`L0000200H700<01`L0B`L50003
1`0000@000<7000010000`L0000307l7000R1`0300L706P71@021`@01PL00`071`0f1`D00PL50087
1@000`L0000408`7000R1`0300L706/70P021`D000<700000`061`0300L702P71P000`L000030087
1@2J1`008PL00`071`1b1`8000<7000010000`L0000302X71P2W1`008PL207X70P000`L000040003
1`0000<0d0L0028700<01`L0P0L200031`0000<00PL50<T7000R1`0300L708H70P021`D000<70000
10321`008PL00`071`2@1`H0`PL0028700<01`L0o`MI1`008PL20?l7FPL0028700<01`L0o`MI1`00
8PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL20?l7FPL0028700<01`L0
o`MI1`008PL00`071`3o1eT7000R1`0300L70?l7F@L000`700<01`L00PL010071`L300<700<01`L0
10L00`071`3o1eT7000;1`0300L000L700<01`L00PL00`0700051`0300L70?l7F@L000/700<01`00
20L00`071`031`0300L700<70`3o1eT7000;1`0300L000P700@01`L70P061`0300L70?l7F@L000/7
00<01`001`L00`0700021`0300L700D700<01`L0o`LN1`L0=0L000`700<01`L01`L010071`L300D7
00<01`L0Z`L:00<73`061a001@L?00H740041aT0=0L0028700<01`L0Z`L:00<73`061a001@L?00H7
;@0d1`008PL20?H7:00k1`008PL00`071`3V1bP0BPL0028700<01`L0f0L/05@7000R1`0300L70<T7
;01S1`008PL00`071`2j1b`0LPL002870P2/1bd0P0L0028700<01`L0Z`LN08l7000R1`0300L70:/7
3`2N1`008PL00`071`2A1`D0`PL0028700<01`L0O`L=00D71@321`008PL207L75P3<1`008PL00`07
1`1S1`h01@L;0=L7000R1`0300L705/75P3W1`008PL00`071`171`l01@L:0?<7000R1`0300L70407
5P3o1`<7000R1`0300L704072@3o1a07000R1`80o`MJ1`008PL00`071`3o1eT7000R1`0300L70?l7
F@L0014700<01`L00PL00`071`021`0300L700@700<01`L0o`MI1`0040L00`0700071`0300L000D7
00<01`L0o`MI1`0040L00`0700091`0300L700<70`3o1eT7000@1`0300L000L70P061`0300L70?l7
F@L0010700<01`001`L00`071`051`0300L70?l7F@L0014700<01`L01PL300D700<01`L0o`MI1`00
8PL00`071`3o1eT7000R1`80o`MJ1`008PL00`071`3o1eT7000R1`0300L70?l7F@L0028700<01`L0
o`MI1`008PL00`071`3o1eT7000R1`80o`MJ1`008PL00`071`3o1eT7000R1`0300L70?l7F@L00287
00<01`L0o`MI1`008PL00`071`3o1eT7000R1`0300L70?l7F@L002870P3o1eX7000R1`0300L70?l7
F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`0300L70?l7F@L002870P3o1eX7000R1`03
00L70?l7F@L0028700<01`L0o`MI1`0030L00`071`021`0300L7008700<01`L00PL00`071`041`03
00L70?l7F@L000/700<01`0020L01`071`L01`001@L00`071`3o1eT7000;1`0300L000P700<01`L0
0`L00`071`031`<0o`MI1`002`L00`0700091`0300L700801PL00`071`3o1eT7000;1`0300L000L7
00<01`000PL00`071`051`0300L70?l7F@L000`700<01`L01PL300870`051`0300L70?l7F@L00287
00<01`L0o`MI1`008PL20?l7FPL0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`0300L70?l7
F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`80o`MJ1`008PL00`071`3o1eT7000R1`03
00L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`80o`MJ1`008PL00`071`3o1eT7
000R1`0300L70?l7F@L0028700<01`L0o`MI1`008PL00`071`3o1eT7000R1`80o`MJ1`008PL00`07
1`3o1eT7000R1`0300L70?l7F@L001T71@041`0300L70?l7F@L001/700<01`L010L00`071`3o1eT7
000K1`0300L700@70`3o1eT7000K1`0300L70?l7H0L001/700<01`L0o`MP1`006PL20?l7HPL00?l7
OPL00?l7OPL00?l7OPL00?l7OPL00?l7OPL00?l7OPL00?l7OPL00?l7OPL00?l7OPL00001\
\>"],
  ImageRangeCache->{{{0, 380}, {234.375, 0}} -> {-1.00805, -1.1162, 
  0.0294334, 0.00952486}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Presentation",
PrintingStyleEnvironment->"Printout",
WindowToolbars->"EditBar",
CellGrouping->Manual,
WindowSize->{749, 446},
WindowMargins->{{11, Automatic}, {Automatic, 4}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{None, Cell[ 
            TextData[ {"Printed by ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], " from ", 
              StyleBox[ "YOUR TITLE HERE", FontSlant -> "Italic"], 
              " by AUTHOR. \n\[Copyright] YEAR HOLDER. All rights \
reserved."}], "Footer"], None}, {None, Cell[ 
            TextData[ {"Printed by ", 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], " from ", 
              StyleBox[ "YOUR TITLE HERE", FontSlant -> "Italic"], 
              " by AUTHOR. \n\[Copyright] YEAR HOLDER. All rights \
reserved."}], "Footer"], None}},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FirstPageFace"->Right},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontSize->34,
    FontTracking->"SemiCondensed",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{18, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{17, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{22, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{32, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{16, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{19, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{18, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{18, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    FontSize->10,
    FontWeight->"Bold",
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{37, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    FontSize->9,
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{37, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None,
    FontSize->9,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{64, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{64, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Info"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    StyleMenuListing->None],
  
  Cell[StyleData["Info", "Presentation"],
    CellMargins->{{64, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Info", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Info", "Printout"],
    CellMargins->{{30, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{28, Inherited}, {Inherited, 0}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Miscellaneous Elements", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{18, 10}, {8, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->20],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{18, 10}, {50, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{72, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontFamily->"Times"],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{100, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{60, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{0, 0}, {4, 4}},
    TextAlignment->Center,
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{72, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{37, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseBig"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{24, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseBig", "Presentation"],
    CellMargins->{{35, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["ExerciseBig", "Condensed"],
    CellMargins->{{16, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseBig", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {4, 32}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{52, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{72, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{40, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{37, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"]],
  
  Cell[StyleData["NumberedEquation", "Condensed"]],
  
  Cell[StyleData["NumberedEquation", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherResourcesLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherResources", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherResourcesLink", "Presentation"]],
  
  Cell[StyleData["OtherResourcesLink", "Condensed"]],
  
  Cell[StyleData["OtherResourcesLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 121, 5, 118, "Title",
  Evaluatable->False],
Cell[1855, 58, 102, 3, 98, "Subtitle"],

Cell[CellGroupData[{
Cell[1982, 65, 202, 6, 70, "Section",
  Evaluatable->False],
Cell[2187, 73, 57, 1, 51, "Input"],

Cell[CellGroupData[{
Cell[2269, 78, 407, 11, 147, "Input"],
Cell[2679, 91, 222, 5, 51, "Print"],
Cell[2904, 98, 214, 4, 28, "Print"],
Cell[3121, 104, 97, 2, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3267, 112, 71, 2, 78, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3363, 118, 186, 6, 55, "Subsection",
  Evaluatable->False],
Cell[3552, 126, 1081, 19, 244, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4670, 150, 32, 0, 66, "Subsection"],
Cell[4705, 152, 1000, 20, 286, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5754, 178, 30, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[5809, 182, 965, 18, 259, "Input"],
Cell[6777, 202, 35, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[6837, 206, 354, 7, 83, "Input"],
Cell[7194, 215, 27908, 837, 186, 8547, 593, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[35163, 1059, 35, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[35223, 1063, 193, 6, 55, "Subsection",
  Evaluatable->False],
Cell[35419, 1071, 476, 12, 116, "Input"],

Cell[CellGroupData[{
Cell[35920, 1087, 196, 6, 55, "Subsection",
  Evaluatable->False],
Cell[36119, 1095, 354, 9, 100, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36534, 1111, 38, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[36597, 1115, 38, 0, 54, "Subsubsection"],
Cell[36638, 1117, 1363, 24, 300, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38038, 1146, 80, 2, 66, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38143, 1152, 77, 2, 66, "Subsection",
  Evaluatable->False],
Cell[38223, 1156, 509, 10, 194, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38769, 1171, 77, 2, 66, "Subsection",
  Evaluatable->False],
Cell[38849, 1175, 567, 13, 163, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39453, 1193, 78, 2, 66, "Subsection",
  Evaluatable->False],
Cell[39534, 1197, 587, 13, 163, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40170, 1216, 40, 0, 66, "Subsection"],

Cell[CellGroupData[{
Cell[40235, 1220, 471, 12, 83, "Input"],
Cell[40709, 1234, 476, 7, 47, "Output"],
Cell[41188, 1243, 476, 7, 47, "Output"],
Cell[41667, 1252, 460, 7, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42176, 1265, 35, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[42236, 1269, 1808, 37, 304, "Input"],
Cell[44047, 1308, 33658, 1064, 186, 11300, 783, "GraphicsData", 
"PostScript", "Graphics"],
Cell[77708, 2374, 33427, 1062, 186, 11353, 785, "GraphicsData", 
"PostScript", "Graphics"],
Cell[111138, 3438, 30120, 1017, 187, 11237, 779, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[141319, 4462, 66, 0, 78, "Section"],

Cell[CellGroupData[{
Cell[141410, 4466, 54, 0, 54, "Subsubsection"],

Cell[CellGroupData[{
Cell[141489, 4470, 227, 5, 154, "Input"],
Cell[141719, 4477, 192, 4, 67, "Input"]
}, Open  ]],
Cell[141926, 4484, 382, 10, 179, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142345, 4499, 75, 0, 66, "Subsection"],
Cell[142423, 4501, 392, 10, 83, "Input"],
Cell[142818, 4513, 406, 10, 83, "Input"],
Cell[143227, 4525, 388, 9, 67, "Input"],

Cell[CellGroupData[{
Cell[143640, 4538, 169, 4, 54, "Input"],
Cell[143812, 4544, 28687, 878, 186, 7868, 616, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[172548, 5428, 56, 0, 66, "Subsection"],

Cell[CellGroupData[{
Cell[172629, 5432, 1075, 22, 147, "Input"],
Cell[173707, 5456, 27072, 778, 186, 6343, 518, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[200828, 6240, 58, 0, 66, "Subsection"],

Cell[CellGroupData[{
Cell[200911, 6244, 565, 14, 115, "Input"],
Cell[201479, 6260, 110, 2, 47, "Output"],
Cell[201592, 6264, 111, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[201740, 6271, 450, 12, 99, "Input"],
Cell[202193, 6285, 110, 2, 47, "Output"],
Cell[202306, 6289, 110, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[202453, 6296, 384, 9, 67, "Input"],
Cell[202840, 6307, 18876, 674, 186, 9975, 560, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[221753, 6986, 367, 10, 99, "Input"],
Cell[222123, 6998, 54, 1, 47, "Output"],
Cell[222180, 7001, 54, 1, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[222271, 7007, 394, 11, 99, "Input"],
Cell[222668, 7020, 739, 17, 179, "Input"],

Cell[CellGroupData[{
Cell[223432, 7041, 635, 15, 67, "Input"],
Cell[224070, 7058, 17338, 570, 186, 8607, 458, "GraphicsData", 
"PostScript", "Graphics"],
Cell[241411, 7630, 18246, 625, 186, 9262, 510, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[259706, 8261, 781, 18, 131, "Input"],
Cell[260490, 8281, 54, 1, 47, "Output"],
Cell[260547, 8284, 52, 1, 47, "Output"],
Cell[260602, 8287, 54, 1, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260693, 8293, 1241, 26, 195, "Input"],
Cell[261937, 8321, 26894, 762, 186, 6152, 501, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[288892, 9090, 39, 0, 78, "Section"],
Cell[288934, 9092, 194, 3, 83, "Input"],

Cell[CellGroupData[{
Cell[289153, 9099, 1312, 25, 275, "Input"],
Cell[290468, 9126, 13943, 586, 186, 8153, 510, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[304448, 9717, 259, 5, 83, "Input"],
Cell[304710, 9724, 220, 5, 67, "Input"],
Cell[304933, 9731, 220, 5, 67, "Input"],

Cell[CellGroupData[{
Cell[305178, 9740, 106, 2, 51, "Input"],
Cell[305287, 9744, 12990, 503, 186, 6908, 423, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[318326, 10253, 685, 12, 147, "Input"],

Cell[CellGroupData[{
Cell[319036, 10269, 964, 17, 195, "Input"],
Cell[320003, 10288, 15703, 662, 244, 8138, 564, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[335733, 10954, 930, 15, 163, "Input"],

Cell[CellGroupData[{
Cell[336688, 10973, 700, 13, 131, "Input"],
Cell[337391, 10988, 26659, 1408, 244, 18811, 1307, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

